@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCRROOT_H
 #define WSCRROOT_H
@@ -41,16 +41,16 @@ class WSCRroot :public WSCroot{
   WSDserialize* _db;
   long _rstatus;
  public:
-  WSCRroot();
-  virtual ~WSCRroot();
+  WSDLEX32 WSCRroot();
+  WSDLEX32 virtual ~WSCRroot();
 
-  void setInstanceName(char*);
-  void setAddr(char*);
-  void setPort(WSCushort);
-  long beginRemoteCall(WSCremoteCall*);
-  long endRemoteCall();
+  WSDLEX32 void setInstanceName(char*);
+  WSDLEX32 void setAddr(char*);
+  WSDLEX32 void setPort(WSCushort);
+  WSDLEX32 long beginRemoteCall(WSCremoteCall*);
+  WSDLEX32 long endRemoteCall();
 
-  long getRemoteCallStatus();
+  WSDLEX32 long getRemoteCallStatus();
 
   WSMFclassDef(WSCRroot,WSCroot);
 };
