@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCCOLORSET_H
 #define WSCCOLORSET_H
@@ -43,28 +43,28 @@ class WSCcolorSet{
    WSDcolor*  _default_colors[WS_MAX_DF_COLORS];
 
  public:
-   WSCcolorSet();
-   virtual ~WSCcolorSet();
+   WSDLEX32 WSCcolorSet();
+   WSDLEX32 virtual ~WSCcolorSet();
 
-   long setCreateHandler(WSDcolor* (*)());
+   WSDLEX32 long setCreateHandler(WSDcolor* (*)());
 
-   void  setColor(short no,char* cname);
-   void  addColor(WSDcolor* color);
-   void  delColor(WSDcolor* color);
-   short getColorNo(char* cname);
-   short getStaticColorNo(char* cname);
-   char* getColorName(short);
+   WSDLEX32 void  setColor(short no,char* cname);
+   WSDLEX32 void  addColor(WSDcolor* color);
+   WSDLEX32 void  delColor(WSDcolor* color);
+   WSDLEX32 short getColorNo(char* cname);
+   WSDLEX32 short getStaticColorNo(char* cname);
+   WSDLEX32 char* getColorName(short);
 
-   WSDcolor* getColor(short no);
-   WSDcolor* getColor(char* name);
-   WSDcolor* getNewColor();
+   WSDLEX32 WSDcolor* getColor(short no);
+   WSDLEX32 WSDcolor* getColor(char* name);
+   WSDLEX32 WSDcolor* getNewColor();
 
-   long  setDefaultColorNo(long kind,short no);
-   short getDefaultColorNo(long kind);
-   WSDcolor* getDefaultColor(long kind);
+   WSDLEX32 long  setDefaultColorNo(long kind,short no);
+   WSDLEX32 short getDefaultColorNo(long kind);
+   WSDLEX32 WSDcolor* getDefaultColor(long kind);
 
-   WSClistData* getColorList();
-   WSCbool      existColor(short cid);
+   WSDLEX32 WSClistData* getColorList();
+   WSDLEX32 WSCbool      existColor(short cid);
 };
 extern WSDLEX WSCcolorSet*  WSGIappColorSet();
 extern WSDLEX short WSGFindexColor(char*);
