@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCDEVICE_H
 #define WSCDEVICE_H
@@ -38,11 +38,11 @@ class WSCdevice{
    WSClistData  _device_name;
    WSClistData  _deleted_instances;
  public:
-   virtual ~WSCdevice();
-   WSDdev*  getDevObject(char*,WSCbase* base=NULL);
-   long     setCreateHandler(char*,WSDdev* (*)() );
-   void addDeleteInstance(WSDdev*);
-   void clearDeleteList();
+   WSDLEX32 virtual ~WSCdevice();
+   WSDLEX32 WSDdev*  getDevObject(char*,WSCbase* base=NULL);
+   WSDLEX32 long     setCreateHandler(char*,WSDdev* (*)() );
+   WSDLEX32 void addDeleteInstance(WSDdev*);
+   WSDLEX32 void clearDeleteList();
 };
 extern WSDLEX WSCdevice* WSGIappDevice();
 #endif
