@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCFFORM_H
 #define WSCFFORM_H
@@ -80,6 +80,7 @@ class WSCfform :public WSCbase{
     unsigned  _orientation:1;
     unsigned  _mouse_pressed_resize:1;
     unsigned  _indicator:1;
+    unsigned  _start_moving:1;
     unsigned  _font:4;
 
 static WSDprivateTimer* _move_timer;
@@ -121,45 +122,48 @@ static WSDprivateTimer* _resize_timer;
     WSMFpropertyDef(WSNfont,         WSCuchar,   _font         );
     WSMFpropertyDef(WSNmargin,   WSCuchar,  _margin    );
 
-    virtual long  _device_initialize();
-    virtual void  _exec_child_adjust_for_anchors();
-static void _delay_proc(WSCuchar,void*);
-static void _move_proc(void*);
-static void _resize_proc(void*);
-    void _set_floated();
-    void _detach_dev();
-    void _detach_dev_sub(WSCbase*);
+    WSDLEX32 virtual long  _device_initialize();
+    WSDLEX32 virtual void  _exec_child_adjust_for_anchors();
+WSDLEX32 static void _delay_proc(WSCuchar,void*);
+WSDLEX32 static void _move_proc(void*);
+WSDLEX32 static void _resize_proc(void*);
+    WSDLEX32 void _set_floated();
+    WSDLEX32 void _detach_dev();
+    WSDLEX32 void _detach_dev_sub(WSCbase*);
+    WSDLEX32 void _update_only_xy();
   public:
-    WSCfform(WSCbase*,char*);
-    virtual ~WSCfform();
+    WSDLEX32 WSCfform(WSCbase*,char*);
+    WSDLEX32 virtual ~WSCfform();
 
-    virtual long execEventProc(long ev,void*);
+    WSDLEX32 virtual long execEventProc(long ev,void*);
 
-    virtual void onResize(WSCrect*);
-    virtual void onVisibleChange(WSCbool);
-    virtual void onMousePress(WSCpoint*);
-    virtual void onMouseMove(WSCpoint*);
-    virtual void onMouseRelease(WSCpoint*);
-    virtual void onParentVisibleChange(WSCbool);
-    virtual void onStatusChange(WSCbool floated);
-    virtual void _adjust_for_anchors(WSCushort,WSCushort);
+    WSDLEX32 virtual void onResize(WSCrect*);
+    WSDLEX32 virtual void onVisibleChange(WSCbool);
+    WSDLEX32 virtual void onMousePress(WSCpoint*);
+    WSDLEX32 virtual void onMouseMove(WSCpoint*);
+    WSDLEX32 virtual void onMouseRelease(WSCpoint*);
+    WSDLEX32 virtual void onParentVisibleChange(WSCbool);
+    WSDLEX32 virtual void onStatusChange(WSCbool floated);
+    WSDLEX32 virtual void _adjust_for_anchors(WSCushort,WSCushort);
 
-    virtual long draw();
-    virtual long clear();
-    virtual long redraw();
-    virtual long cdraw();
+    WSDLEX32 virtual long draw();
+    WSDLEX32 virtual long clear();
+    WSDLEX32 virtual long redraw();
+    WSDLEX32 virtual long cdraw();
 //    virtual long execEventProc(long ev, void*);
 //    virtual long drawGriphand();
-    virtual void update();
-    virtual long getObjectType();
-    virtual WSClistData& getChildren();
-    virtual void setChildren(WSClistData&);
-    void execResizeEvent();
-    void setNoRefresh(WSCbool);
-    WSCbool getNoRefresh();
-    void setFloated(WSCbool);
-    WSCbool getFloated();
-    long getPixmapStyle();
+    WSDLEX32 virtual void update();
+    WSDLEX32 virtual long getObjectType();
+    WSDLEX32 virtual WSClistData& getChildren();
+    WSDLEX32 virtual void setChildren(WSClistData&);
+    WSDLEX32 virtual void internalUpdate();
+
+    WSDLEX32 void execResizeEvent();
+    WSDLEX32 void setNoRefresh(WSCbool);
+    WSDLEX32 WSCbool getNoRefresh();
+    WSDLEX32 void setFloated(WSCbool);
+    WSDLEX32 WSCbool getFloated();
+    WSDLEX32 long getPixmapStyle();
 
     WSMFguiClassDef(WSCfform,WSCbase);
     WSMFsetUseDevice(fformDev);
