@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCINPUTDIALOG_H
 #define WSCINPUTDIALOG_H
@@ -45,24 +45,24 @@ class WSCinputDialog :public WSCbaseDialog{
 
     WSMFpropertyDef( WSNlabelString,   char*,   _label_string ); 
     WSMFpropertyDef( WSNworkBackColor,  short,      _wbg_no );
-    static void _label_focus_work(WSCbase*);
-    virtual void setWorkWSNforeColor(short);
-    virtual void setWorkWSNtitleString(char*);
+    WSDLEX32 static void _label_focus_work(WSCbase*);
+    WSDLEX32 virtual void setWorkWSNforeColor(short);
+    WSDLEX32 virtual void setWorkWSNtitleString(char*);
 
   public:
-    WSCinputDialog(WSCbase*,char*);
-    virtual ~WSCinputDialog();
+    WSDLEX32 WSCinputDialog(WSCbase*,char*);
+    WSDLEX32 virtual ~WSCinputDialog();
 
-    virtual  long initialize();
-    virtual void adjustForm();
+    WSDLEX32 virtual  long initialize();
+    WSDLEX32 virtual void adjustForm();
 
 //    virtual void onResize(WSCrect* rect);
-    virtual void onVisibleChange(WSCbool);
-    virtual void onActivate();
-    virtual void onGuiPolicyChange(long);
-    virtual char* getDefaultProperty();
+    WSDLEX32 virtual void onVisibleChange(WSCbool);
+    WSDLEX32 virtual void onActivate();
+    WSDLEX32 virtual void onGuiPolicyChange(long);
+    WSDLEX32 virtual char* getDefaultProperty();
 
-    virtual  long popup();
+    WSDLEX32 virtual  long popup();
 
     WSMFguiClassDef(WSCinputDialog,WSCbaseDialog);
     WSMFversionDef(WSCinputDialog);
