@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCPULLDOWNMENUPOPUP_H
 #define WSCPULLDOWNMENUPOPUP_H
@@ -64,58 +64,58 @@ class WSCpulldownMenuPopup    :public WSCwindow{
     WSMFpropertyDef( WSNmenuItems,      char*,     _menu_string); 
     WSMFpropertyDef( WSNmenuItemHeight, WSCushort, _item_height); 
 
-    virtual void setWorkWSNwidth(WSCushort);
-    virtual void setWorkWSNheight(WSCushort);
-    virtual void setWorkWSNemboss(WSCbool);
+    WSDLEX32 virtual void setWorkWSNwidth(WSCushort);
+    WSDLEX32 virtual void setWorkWSNheight(WSCushort);
+    WSDLEX32 virtual void setWorkWSNemboss(WSCbool);
 
-    virtual long _device_initialize();
+    WSDLEX32 virtual long _device_initialize();
 
-    WSCpulldownMenuPopup* _check_child_status_no_mouse();
-static void      (*_ext_draw_proc)(void*);
-static WSCstring _policy_name;
+    WSDLEX32 WSCpulldownMenuPopup* _check_child_status_no_mouse();
+WSDLEX32 static void      (*_ext_draw_proc)(void*);
+WSDLEX32 static WSCstring _policy_name;
 
   public:
-    WSCpulldownMenuPopup(WSCbase*,char*);
-    virtual ~WSCpulldownMenuPopup();
+    WSDLEX32 WSCpulldownMenuPopup(WSCbase*,char*);
+    WSDLEX32 virtual ~WSCpulldownMenuPopup();
 
-    virtual void onVisibleChange(WSCbool);
-    virtual void onResize(WSCrect*);
-    virtual void onKeyPress(WSDkeyboard*,WSCbool);
-    virtual void onGuiPolicyChange(long);
+    WSDLEX32 virtual void onVisibleChange(WSCbool);
+    WSDLEX32 virtual void onResize(WSCrect*);
+    WSDLEX32 virtual void onKeyPress(WSDkeyboard*,WSCbool);
+    WSDLEX32 virtual void onGuiPolicyChange(long);
 
-    virtual long initialize();
-    virtual long draw();
+    WSDLEX32 virtual long initialize();
+    WSDLEX32 virtual long draw();
 
-    void setEmboss(WSCbool);
-    long setItemSensitive(short no,WSCbool flag);    
-    long setValueSensitive(short id,WSCbool flag);    
-    void setParentMenu(WSCpulldownMenuPopup*);
+    WSDLEX32 void setEmboss(WSCbool);
+    WSDLEX32 long setItemSensitive(short no,WSCbool flag);    
+    WSDLEX32 long setValueSensitive(short id,WSCbool flag);    
+    WSDLEX32 void setParentMenu(WSCpulldownMenuPopup*);
 
-    WSCpulldownMenuPopup* getParentMenu();
-    WSCushort getItemHeight();
-    WSCuchar  getFontNo();
-    long      getItems();
-    char*     getProcName();
-    WSCbool   getSelected();
-    WSCbool   getNextPopup();
-    WSCbool   getEmboss();
-    WSCbool*  getItemSensitive();
-    long      getValue();
-    void   setSelected(WSCbool);
+    WSDLEX32 WSCpulldownMenuPopup* getParentMenu();
+    WSDLEX32 WSCushort getItemHeight();
+    WSDLEX32 WSCuchar  getFontNo();
+    WSDLEX32 long      getItems();
+    WSDLEX32 char*     getProcName();
+    WSDLEX32 WSCbool   getSelected();
+    WSDLEX32 WSCbool   getNextPopup();
+    WSDLEX32 WSCbool   getEmboss();
+    WSDLEX32 WSCbool*  getItemSensitive();
+    WSDLEX32 long      getValue();
+    WSDLEX32 void   setSelected(WSCbool);
 
     //internal
-    void set_items(long items);
-    WSCstring& get_prc_name();
-    void set_selected(WSCbool fl);
-    void* get_pld_data();
-    void set_child_popup_waited(WSCbool fl);
-    void set_selected_item(long item);
-    void set_id_value(long v);
-    WSClistData& get_child_pld_list();
-    void popupChildPld(short childno,char* menustr, short x, short y);
-    void popdownChildPld(short childno);
-    void updateChild();
-    WSCbool checkChildStatus();
+    WSDLEX32 void set_items(long items);
+    WSDLEX32 WSCstring& get_prc_name();
+    WSDLEX32 void set_selected(WSCbool fl);
+    WSDLEX32 void* get_pld_data();
+    WSDLEX32 void set_child_popup_waited(WSCbool fl);
+    WSDLEX32 void set_selected_item(long item);
+    WSDLEX32 void set_id_value(long v);
+    WSDLEX32 WSClistData& get_child_pld_list();
+    WSDLEX32 void popupChildPld(short childno,char* menustr, short x, short y);
+    WSDLEX32 void popdownChildPld(short childno);
+    WSDLEX32 void updateChild();
+    WSDLEX32 WSCbool checkChildStatus();
 
     WSMFguiClassDef(WSCpulldownMenuPopup,WSCwindow);
 };
@@ -131,19 +131,19 @@ struct WSCpulldownData {
   WSCbool    _cascaded;
   WSCbool    _sensitive;
 
-  WSCpulldownData();
-  ~WSCpulldownData();
-  WSCbool   getSensitive(long no);
-  WSCbool   getSensitiveWithId(long id);
-  WSCpulldownData* getItem(long no);
-  WSCpulldownData* getItemWithId(long no);
-  long   setSensitive(long no,WSCbool fl );
-  long   setSensitiveWithId(long id,WSCbool fl );
-  void   setCascaded(WSCbool fl);
-  void   add(WSCpulldownData* data);
-  long   getItems();
+  WSDLEX32 WSCpulldownData();
+  WSDLEX32 ~WSCpulldownData();
+  WSDLEX32 WSCbool   getSensitive(long no);
+  WSDLEX32 WSCbool   getSensitiveWithId(long id);
+  WSDLEX32 WSCpulldownData* getItem(long no);
+  WSDLEX32 WSCpulldownData* getItemWithId(long no);
+  WSDLEX32 long   setSensitive(long no,WSCbool fl );
+  WSDLEX32 long   setSensitiveWithId(long id,WSCbool fl );
+  WSDLEX32 void   setCascaded(WSCbool fl);
+  WSDLEX32 void   add(WSCpulldownData* data);
+  WSDLEX32 long   getItems();
 
-  static  WSCpulldownData* parse(char* menu_string);
+  WSDLEX32 static  WSCpulldownData* parse(char* menu_string);
 };
 
 struct WSCpulldownMenuPopup_draw_struct{
