@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCVODBC_H
 #define WSCVODBC_H
@@ -48,23 +48,23 @@ class WSCvodbc   :public WSCngbase{
 
 
   public:
-    void _init();
-    WSCodbcDatabase* getODBCDatabase();
+    WSDLEX32 void _init();
+    WSDLEX32 WSCodbcDatabase* getODBCDatabase();
 
-    WSCvodbc(WSCbase* base, char* name);
-    virtual ~WSCvodbc();
+    WSDLEX32 WSCvodbc(WSCbase* base, char* name);
+    WSDLEX32 virtual ~WSCvodbc();
 
-    long open(char* dsn,char* uid,char* passwd);
-    long open();
-    long close();
-    WSCbool isOpen();
-    long sqlExecute(const char*);
-    long beginTran();
-    long commitTran();
-    long abortTran();
+    WSDLEX32 long open(char* dsn,char* uid,char* passwd);
+    WSDLEX32 long open();
+    WSDLEX32 long close();
+    WSDLEX32 WSCbool isOpen();
+    WSDLEX32 long sqlExecute(const char*);
+    WSDLEX32 long beginTran();
+    WSDLEX32 long commitTran();
+    WSDLEX32 long abortTran();
 
-    void getErrorMsg(char* msg,long size);
-    WSCstring getErrorMessage();
+    WSDLEX32 void getErrorMsg(char* msg,long size);
+    WSDLEX32 WSCstring getErrorMessage();
 
     WSMFguiClassDef(WSCvodbc,WSCngbase);
     WSMFversionDef(WSCvodbc);
