@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCVSCRBAR_H
 #define WSCVSCRBAR_H
@@ -81,38 +81,39 @@ class WSCvscrBar :public WSCnwbase{
     WSMFpropertyDef(WSNbackPixmap,        short,     _bp_no         );
     WSMFpropertyDef(WSNgradation,         WSCbool,   _grad_on       );
 
-    static void _timer_work(WSCuchar,void*);
+    WSDLEX32 static void _timer_work(WSCuchar,void*);
 
-    long _bar_in(short px,short py, short x,short y,WSCushort w,WSCushort h,
+    WSDLEX32 long _bar_in(short px,short py, short x,short y,WSCushort w,WSCushort h,
                   WSCushort st);
-    long _draw_sl_bar();
+    WSDLEX32 long _draw_sl_bar();
 
 
-    virtual long _device_initialize();
-static void      (*_ext_draw_proc)(void*);
-static WSCstring _policy_name;
+    WSDLEX32 virtual long _device_initialize();
+WSDLEX32 static void      (*_ext_draw_proc)(void*);
+WSDLEX32 static WSCstring _policy_name;
 
   public:
-    WSCvscrBar(WSCbase*,char*);
-    virtual ~WSCvscrBar();
+    WSDLEX32 WSCvscrBar(WSCbase*,char*);
+    WSDLEX32 virtual ~WSCvscrBar();
 
-    virtual void onActivate();
-    virtual void onBegin();
-    virtual void onEnd();
-    virtual void onIncrement();
-    virtual void onDecrement();
-    virtual void onPageIncrement();
-    virtual void onPageDecrement();
-    virtual void onMousePress(WSCpoint*);
-    virtual void onMouseMove(WSCpoint*);
-    virtual void onMouseRelease(WSCpoint*);
-    virtual void onValueChange();
-    virtual void onGuiPolicyChange(long);
+    WSDLEX32 virtual void onActivate();
+    WSDLEX32 virtual void onBegin();
+    WSDLEX32 virtual void onEnd();
+    WSDLEX32 virtual void onIncrement();
+    WSDLEX32 virtual void onDecrement();
+    WSDLEX32 virtual void onPageIncrement();
+    WSDLEX32 virtual void onPageDecrement();
+    WSDLEX32 virtual void onMousePress(WSCpoint*);
+    WSDLEX32 virtual void onMouseMove(WSCpoint*);
+    WSDLEX32 virtual void onMouseRelease(WSCpoint*);
+    WSDLEX32 virtual void onValueChange();
+    WSDLEX32 virtual void onGuiPolicyChange(long);
 
-    virtual long execEventProc(long ev,void* data);
-    virtual long draw();
+    WSDLEX32 virtual long execEventProc(long ev,void* data);
+    WSDLEX32 virtual long draw();
+    WSDLEX32 virtual char* getDefaultProperty();
 
-    WSCulong getMaxSlideValue();
+    WSDLEX32 WSCulong getMaxSlideValue();
 
     WSMFguiClassDef(WSCvscrBar,WSCnwbase);
     WSMFversionDef(WSCvscrBar);
