@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCVUDPSOCKET_H
 #define WSCVUDPSOCKET_H
@@ -48,28 +48,28 @@ class WSCvudpsocket   :public WSCngbase{
     WSMFpropertyDef(WSNtimeout,   WSCulong,      _timeout);
     WSMFpropertyDef(WSNrunning,   WSCbool,      _on);
 
-    void _init();
+    WSDLEX32 void _init();
 
-static void _udp_read_work(WSDsocket*,void*,WSCulong);
+WSDLEX32 static void _udp_read_work(WSDsocket*,void*,WSCulong);
 
   public:
 
-    WSCvudpsocket(WSCbase* base, char* name);
-    virtual ~WSCvudpsocket();
-    virtual void onActivate();
-    long read(WSCuchar* buf,long size);
-    long write(WSCuchar* buf,long size);
+    WSDLEX32 WSCvudpsocket(WSCbase* base, char* name);
+    WSDLEX32 virtual ~WSCvudpsocket();
+    WSDLEX32 virtual void onActivate();
+    WSDLEX32 long read(WSCuchar* buf,long size);
+    WSDLEX32 long write(WSCuchar* buf,long size);
 
-    WSCstring getDestAddr();
+    WSDLEX32 WSCstring getDestAddr();
 //    WSCushort getDestPort();
 
-    void setBindAddr(char* addr);
-    WSCstring getBindAddr();
+    WSDLEX32 void setBindAddr(char* addr);
+    WSDLEX32 WSCstring getBindAddr();
 
-    long start();
-    long stop();
-    void getErrorMsg(char* buffer,long size);
-    WSCstring getErrorMessage();
+    WSDLEX32 long start();
+    WSDLEX32 long stop();
+    WSDLEX32 void getErrorMsg(char* buffer,long size);
+    WSDLEX32 WSCstring getErrorMessage();
 
     WSMFguiClassDef(WSCvudpsocket,WSCngbase);
     WSMFversionDef(WSCvudpsocket);
