@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSDIMAGE_H
 #define WSDIMAGE_H
@@ -36,19 +36,19 @@ class WSDimage :public WSDres{
     WSCushort  _h;
     WSCulong       _mode;
   public:
-    WSDimage();
-    virtual ~WSDimage();
-    long destroyImage();
+    WSDLEX32 WSDimage();
+    WSDLEX32 virtual ~WSDimage();
+    WSDLEX32 long destroyImage();
 
-    long setImageName(char* iname); 
-    long setImageWidth(WSCushort );
-    long setImageHeight(WSCushort );
+    WSDLEX32 long setImageName(char* iname); 
+    WSDLEX32 long setImageWidth(WSCushort );
+    WSDLEX32 long setImageHeight(WSCushort );
 
-    WSCushort getImageWidth();
-    WSCushort getImageHeight();
-    WSCbool   getReady();
-    void   setImageMode(WSCulong);
-    WSCulong   getImageMode();
+    WSDLEX32 WSCushort getImageWidth();
+    WSDLEX32 WSCushort getImageHeight();
+    WSDLEX32 WSCbool   getReady();
+    WSDLEX32 void   setImageMode(WSCulong);
+    WSDLEX32 WSCulong   getImageMode();
 
     WSMFclassDef(WSDimage,WSDres);
 };
