@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSDMESSAGE_H
 #define WSDMESSAGE_H
@@ -43,22 +43,22 @@ class WSDmessage :public WSCroot{
 
     static int (*_ext_send_msg1)(char* disp,char *message,char *data);
     static int (*_ext_send_msg2)(char* disp,char *message,char* data);
-    static WSDmessage* (*_chandler)();
-    virtual long initialize();
+    WSDLEX32 static WSDmessage* (*_chandler)();
+    WSDLEX32 virtual long initialize();
   public:
-    static void _setup_ext_send_msg_proc(void* fn1,void* fn2);
+    WSDLEX32 static void _setup_ext_send_msg_proc(void* fn1,void* fn2);
 
-    void setupMessage(char *,void (*cbwork)(char *));
-    void setupMessage(char *,void (*cbwork)(char *,void*),void*);
+    WSDLEX32 void setupMessage(char *,void (*cbwork)(char *));
+    WSDLEX32 void setupMessage(char *,void (*cbwork)(char *,void*),void*);
 
-    virtual void sendMessage(char *data);
-    static int sendMessageEx(char* disp,char *message,char *data);
+    WSDLEX32 virtual void sendMessage(char *data);
+    WSDLEX32 static int sendMessageEx(char* disp,char *message,char *data);
 
-    static int extSendMessage(char* disp,char *message,char *data);
-    static int extSendNewMessage(char* disp,char *message,char *data);
+    WSDLEX32 static int extSendMessage(char* disp,char *message,char *data);
+    WSDLEX32 static int extSendNewMessage(char* disp,char *message,char *data);
 
-    static WSDmessage* getNewInstance();
-    static void setCreateHandler(WSDmessage*(*)());
+    WSDLEX32 static WSDmessage* getNewInstance();
+    WSDLEX32 static void setCreateHandler(WSDmessage*(*)());
 
     WSMFclassDef(WSDmessage, WSCroot) ;
 };
