@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSNDEF_H
 #define WSNDEF_H
@@ -407,379 +407,379 @@ extern char* _WSNfilter;
 #else //MSW
 
 #define       WSNtitleString              _WSNtitleString()
-extern char* _WSNtitleString();
+extern WSDLEX32 char* _WSNtitleString();
 #define       WSNuserString               _WSNuserString()
-extern char* _WSNuserString();
+extern WSDLEX32 char* _WSNuserString();
 #define       WSNuserValue                _WSNuserValue()
-extern char* _WSNuserValue();
+extern WSDLEX32 char* _WSNuserValue();
 #define       WSNx                        _WSNx()
-extern char* _WSNx();
+extern WSDLEX32 char* _WSNx();
 #define       WSNy                        _WSNy()
-extern char* _WSNy();
+extern WSDLEX32 char* _WSNy();
 #define       WSNwidth                    _WSNwidth()
-extern char* _WSNwidth();
+extern WSDLEX32 char* _WSNwidth();
 #define       WSNheight                   _WSNheight()
-extern char* _WSNheight();
+extern WSDLEX32 char* _WSNheight();
 #define       WSNshadowThickness          _WSNshadowThickness()
-extern char* _WSNshadowThickness();
+extern WSDLEX32 char* _WSNshadowThickness();
 #define       WSNbackColor                _WSNbackColor()
-extern char* _WSNbackColor();
+extern WSDLEX32 char* _WSNbackColor();
 #define       WSNforeColor                _WSNforeColor()
-extern char* _WSNforeColor();
+extern WSDLEX32 char* _WSNforeColor();
 #define       WSNtopShadowColor           _WSNtopShadowColor()
-extern char* _WSNtopShadowColor();
+extern WSDLEX32 char* _WSNtopShadowColor();
 #define       WSNbottomShadowColor        _WSNbottomShadowColor()
-extern char* _WSNbottomShadowColor();
+extern WSDLEX32 char* _WSNbottomShadowColor();
 #define       WSNshadowType               _WSNshadowType()
-extern char* _WSNshadowType();
+extern WSDLEX32 char* _WSNshadowType();
 #define       WSNvis                      _WSNvis()
-extern char* _WSNvis();
+extern WSDLEX32 char* _WSNvis();
 #define       WSNdet                      _WSNdet()
-extern char* _WSNdet();
+extern WSDLEX32 char* _WSNdet();
 #define       WSNlabelString              _WSNlabelString()
-extern char* _WSNlabelString();
+extern WSDLEX32 char* _WSNlabelString();
 #define       WSNfont                     _WSNfont()
-extern char* _WSNfont();
+extern WSDLEX32 char* _WSNfont();
 #define       WSNfontName                 _WSNfontName()
-extern char* _WSNfontName();
+extern WSDLEX32 char* _WSNfontName();
 #define       WSNtitleBar                 _WSNtitleBar()
-extern char* _WSNtitleBar();
+extern WSDLEX32 char* _WSNtitleBar();
 #define       WSNtwinBlink                _WSNtwinBlink()
-extern char* _WSNtwinBlink();
+extern WSDLEX32 char* _WSNtwinBlink();
 #define       WSNblinkColor               _WSNblinkColor()
-extern char* _WSNblinkColor();
+extern WSDLEX32 char* _WSNblinkColor();
 #define       WSNblinkRefreshing          _WSNblinkRefreshing()
-extern char* _WSNblinkRefreshing();
+extern WSDLEX32 char* _WSNblinkRefreshing();
 #define       WSNpixmapStyle              _WSNpixmapStyle()
-extern char* _WSNpixmapStyle();
+extern WSDLEX32 char* _WSNpixmapStyle();
 #define       WSNlabelPixmap              _WSNlabelPixmap()
-extern char* _WSNlabelPixmap();
+extern WSDLEX32 char* _WSNlabelPixmap();
 #define       WSNkanjiIn                  _WSNkanjiIn()
-extern char* _WSNkanjiIn();
+extern WSDLEX32 char* _WSNkanjiIn();
 #define       WSNinterCur                 _WSNinterCur()
-extern char* _WSNinterCur();
+extern WSDLEX32 char* _WSNinterCur();
 #define       WSNinterval                 _WSNinterval()
-extern char* _WSNinterval();
+extern WSDLEX32 char* _WSNinterval();
 #define       WSNcont                     _WSNcont()
-extern char* _WSNcont();
+extern WSDLEX32 char* _WSNcont();
 #define       WSNrunning                  _WSNrunning()
-extern char* _WSNrunning();
+extern WSDLEX32 char* _WSNrunning();
 #define       WSNextension                _WSNextension()
-extern char* _WSNextension();
+extern WSDLEX32 char* _WSNextension();
 #define       WSNmaxLength                _WSNmaxLength()
-extern char* _WSNmaxLength();
+extern WSDLEX32 char* _WSNmaxLength();
 #define       WSNworkWidth                _WSNworkWidth()
-extern char* _WSNworkWidth();
+extern WSDLEX32 char* _WSNworkWidth();
 #define       WSNworkHeight               _WSNworkHeight()
-extern char* _WSNworkHeight();
+extern WSDLEX32 char* _WSNworkHeight();
 #define       WSNbarValue                _WSNbarValue()
-extern char* _WSNbarValue();
+extern WSDLEX32 char* _WSNbarValue();
 #define       WSNvbarValue                _WSNvbarValue()
-extern char* _WSNvbarValue();
+extern WSDLEX32 char* _WSNvbarValue();
 #define       WSNhbarValue                _WSNhbarValue()
-extern char* _WSNhbarValue();
+extern WSDLEX32 char* _WSNhbarValue();
 #define       WSNhbarVisible              _WSNhbarVisible()
-extern char* _WSNhbarVisible();
+extern WSDLEX32 char* _WSNhbarVisible();
 #define       WSNvbarVisible              _WSNvbarVisible()
-extern char* _WSNvbarVisible();
+extern WSDLEX32 char* _WSNvbarVisible();
 #define       WSNworkBackColor            _WSNworkBackColor()
-extern char* _WSNworkBackColor();
+extern WSDLEX32 char* _WSNworkBackColor();
 #define       WSNbarThickness             _WSNbarThickness()
-extern char* _WSNbarThickness();
+extern WSDLEX32 char* _WSNbarThickness();
 #define       WSNincrement                _WSNincrement()
-extern char* _WSNincrement();
+extern WSDLEX32 char* _WSNincrement();
 #define       WSNpageIncrement            _WSNpageIncrement()
-extern char* _WSNpageIncrement();
+extern WSDLEX32 char* _WSNpageIncrement();
 #define       WSNsliderSize               _WSNsliderSize()
-extern char* _WSNsliderSize();
+extern WSDLEX32 char* _WSNsliderSize();
 #define       WSNvalue                    _WSNvalue()
-extern char* _WSNvalue();
+extern WSDLEX32 char* _WSNvalue();
 #define       WSNmaximum                  _WSNmaximum()
-extern char* _WSNmaximum();
+extern WSDLEX32 char* _WSNmaximum();
 #define       WSNorientation              _WSNorientation()
-extern char* _WSNorientation();
+extern WSDLEX32 char* _WSNorientation();
 #define       WSNbackPixmap               _WSNbackPixmap()
-extern char* _WSNbackPixmap();
+extern WSDLEX32 char* _WSNbackPixmap();
 #define       WSNcolumns                  _WSNcolumns()
-extern char* _WSNcolumns();
+extern WSDLEX32 char* _WSNcolumns();
 #define       WSNcursorPos                _WSNcursorPos()
-extern char* _WSNcursorPos();
+extern WSDLEX32 char* _WSNcursorPos();
 #define       WSNmenuItems                _WSNmenuItems()
-extern char* _WSNmenuItems();
+extern WSDLEX32 char* _WSNmenuItems();
 #define       WSNmenuItemHeight           _WSNmenuItemHeight()
-extern char* _WSNmenuItemHeight();
+extern WSDLEX32 char* _WSNmenuItemHeight();
 #define       WSNbarShadowColor           _WSNbarShadowColor()
-extern char* _WSNbarShadowColor();
+extern WSDLEX32 char* _WSNbarShadowColor();
 #define       WSNupward                   _WSNupward()
-extern char* _WSNupward();
+extern WSDLEX32 char* _WSNupward();
 #define       WSNdownward                 _WSNdownward()
-extern char* _WSNdownward();
+extern WSDLEX32 char* _WSNdownward();
 #define       WSNleftward                 _WSNleftward()
-extern char* _WSNleftward();
+extern WSDLEX32 char* _WSNleftward();
 #define       WSNrightward                _WSNrightward()
-extern char* _WSNrightward();
+extern WSDLEX32 char* _WSNrightward();
 #define       WSNreturn                   _WSNreturn()
-extern char* _WSNreturn();
+extern WSDLEX32 char* _WSNreturn();
 #define       WSNtab                      _WSNtab()
-extern char* _WSNtab();
+extern WSDLEX32 char* _WSNtab();
 #define       WSNbacktab                  _WSNbacktab()
-extern char* _WSNbacktab();
+extern WSDLEX32 char* _WSNbacktab();
 #define       WSNenableFocusMove          _WSNenableFocusMove()
-extern char* _WSNenableFocusMove();
+extern WSDLEX32 char* _WSNenableFocusMove();
 #define       WSNclient                   _WSNclient()
-extern char* _WSNclient();
+extern WSDLEX32 char* _WSNclient();
 #define       WSNselectReset              _WSNselectReset()
-extern char* _WSNselectReset();
+extern WSDLEX32 char* _WSNselectReset();
 #define       WSNselectString             _WSNselectString()
-extern char* _WSNselectString();
+extern WSDLEX32 char* _WSNselectString();
 #define       WSNselectColor              _WSNselectColor()
-extern char* _WSNselectColor();
+extern WSDLEX32 char* _WSNselectColor();
 #define       WSNselectForeColor              _WSNselectForeColor()
-extern char* _WSNselectForeColor();
+extern WSDLEX32 char* _WSNselectForeColor();
 #define       WSNselectPixmap             _WSNselectPixmap()
-extern char* _WSNselectPixmap();
+extern WSDLEX32 char* _WSNselectPixmap();
 #define       WSNindicatorPixmap          _WSNindicatorPixmap()
-extern char* _WSNindicatorPixmap();
+extern WSDLEX32 char* _WSNindicatorPixmap();
 #define       WSNindicatorColor           _WSNindicatorColor()
-extern char* _WSNindicatorColor();
+extern WSDLEX32 char* _WSNindicatorColor();
 #define       WSNindicatorOn              _WSNindicatorOn()
-extern char* _WSNindicatorOn();
+extern WSDLEX32 char* _WSNindicatorOn();
 #define       WSNindicatorType            _WSNindicatorType()
-extern char* _WSNindicatorType();
+extern WSDLEX32 char* _WSNindicatorType();
 #define       WSNindicatorSize            _WSNindicatorSize()
-extern char* _WSNindicatorSize();
+extern WSDLEX32 char* _WSNindicatorSize();
 #define       WSNgroup                    _WSNgroup()
-extern char* _WSNgroup();
+extern WSDLEX32 char* _WSNgroup();
 #define       WSNid                       _WSNid()
-extern char* _WSNid();
+extern WSDLEX32 char* _WSNid();
 #define       WSNunique                   _WSNunique()
-extern char* _WSNunique();
+extern WSDLEX32 char* _WSNunique();
 #define       WSNscrollWidth              _WSNscrollWidth()
-extern char* _WSNscrollWidth();
+extern WSDLEX32 char* _WSNscrollWidth();
 #define       WSNscrollHeight             _WSNscrollHeight()
-extern char* _WSNscrollHeight();
+extern WSDLEX32 char* _WSNscrollHeight();
 #define       WSNtitleHeight              _WSNtitleHeight()
-extern char* _WSNtitleHeight();
+extern WSDLEX32 char* _WSNtitleHeight();
 #define       WSNfillSpace                _WSNfillSpace()
-extern char* _WSNfillSpace();
+extern WSDLEX32 char* _WSNfillSpace();
 #define       WSNifieldSkipMode           _WSNifieldSkipMode()
-extern char* _WSNifieldSkipMode();
+extern WSDLEX32 char* _WSNifieldSkipMode();
 #define       WSNcursorAdjust             _WSNcursorAdjust()
-extern char* _WSNcursorAdjust();
+extern WSDLEX32 char* _WSNcursorAdjust();
 #define       WSNdateFormat               _WSNdateFormat()
-extern char* _WSNdateFormat();
+extern WSDLEX32 char* _WSNdateFormat();
 #define       WSNweekFormat               _WSNweekFormat()
-extern char* _WSNweekFormat();
+extern WSDLEX32 char* _WSNweekFormat();
 #define       WSNclockFormat              _WSNclockFormat()
-extern char* _WSNclockFormat();
+extern WSDLEX32 char* _WSNclockFormat();
 #define       WSNsecondOn                 _WSNsecondOn()
-extern char* _WSNsecondOn();
+extern WSDLEX32 char* _WSNsecondOn();
 #define       WSNdirName                  _WSNdirName()
-extern char* _WSNdirName();
+extern WSDLEX32 char* _WSNdirName();
 #define       WSNfileName                 _WSNfileName()
-extern char* _WSNfileName();
+extern WSDLEX32 char* _WSNfileName();
 #define       WSNmaskFileName             _WSNmaskFileName()
-extern char* _WSNmaskFileName();
+extern WSDLEX32 char* _WSNmaskFileName();
 #define       WSNreplyHandler             _WSNreplyHandler()
-extern char* _WSNreplyHandler();
+extern WSDLEX32 char* _WSNreplyHandler();
 #define       WSNdefaultPosition          _WSNdefaultPosition()
-extern char* _WSNdefaultPosition();
+extern WSDLEX32 char* _WSNdefaultPosition();
 #define       WSNlineWidth                _WSNlineWidth()
-extern char* _WSNlineWidth();
+extern WSDLEX32 char* _WSNlineWidth();
 #define       WSNblinkType                _WSNblinkType()
-extern char* _WSNblinkType();
+extern WSDLEX32 char* _WSNblinkType();
 #define       WSNpushPixmap               _WSNpushPixmap()
-extern char* _WSNpushPixmap();
+extern WSDLEX32 char* _WSNpushPixmap();
 #define       WSNblinkPixmap              _WSNblinkPixmap()
-extern char* _WSNblinkPixmap();
+extern WSDLEX32 char* _WSNblinkPixmap();
 #define       WSNmarginTop                _WSNmarginTop()
-extern char* _WSNmarginTop();
+extern WSDLEX32 char* _WSNmarginTop();
 #define       WSNmarginBottom             _WSNmarginBottom()
-extern char* _WSNmarginBottom();
+extern WSDLEX32 char* _WSNmarginBottom();
 #define       WSNmarginLeft               _WSNmarginLeft()
-extern char* _WSNmarginLeft();
+extern WSDLEX32 char* _WSNmarginLeft();
 #define       WSNmarginRight              _WSNmarginRight()
-extern char* _WSNmarginRight();
+extern WSDLEX32 char* _WSNmarginRight();
 #define       WSNalignmentH               _WSNalignmentH()
-extern char* _WSNalignmentH();
+extern WSDLEX32 char* _WSNalignmentH();
 #define       WSNalignmentV               _WSNalignmentV()
-extern char* _WSNalignmentV();
+extern WSDLEX32 char* _WSNalignmentV();
 #define       WSNlineX                    _WSNlineX()
-extern char* _WSNlineX();
+extern WSDLEX32 char* _WSNlineX();
 #define       WSNlineY                    _WSNlineY()
-extern char* _WSNlineY();
+extern WSDLEX32 char* _WSNlineY();
 #define       WSNlineNum                  _WSNlineNum()
-extern char* _WSNlineNum();
+extern WSDLEX32 char* _WSNlineNum();
 #define       WSNvalue1                   _WSNvalue1()
-extern char* _WSNvalue1();
+extern WSDLEX32 char* _WSNvalue1();
 #define       WSNvalue2                   _WSNvalue2()
-extern char* _WSNvalue2();
+extern WSDLEX32 char* _WSNvalue2();
 #define       WSNlineType                 _WSNlineType()
-extern char* _WSNlineType();
+extern WSDLEX32 char* _WSNlineType();
 #define       WSNarrowDirection           _WSNarrowDirection()
-extern char* _WSNarrowDirection();
+extern WSDLEX32 char* _WSNarrowDirection();
 #define       WSNblinkFlag                _WSNblinkFlag()
-extern char* _WSNblinkFlag();
+extern WSDLEX32 char* _WSNblinkFlag();
 #define       WSNblinkRate                _WSNblinkRate()
-extern char* _WSNblinkRate();
+extern WSDLEX32 char* _WSNblinkRate();
 #define       WSNstippled                 _WSNstippled()
-extern char* _WSNstippled();
+extern WSDLEX32 char* _WSNstippled();
 #define       WSNhatchPattern             _WSNhatchPattern()
-extern char* _WSNhatchPattern();
+extern WSDLEX32 char* _WSNhatchPattern();
 #define       WSNhatchColor               _WSNhatchColor()
-extern char* _WSNhatchColor();
+extern WSDLEX32 char* _WSNhatchColor();
 #define       WSNhatchBlinkColor          _WSNhatchBlinkColor()
-extern char* _WSNhatchBlinkColor();
+extern WSDLEX32 char* _WSNhatchBlinkColor();
 #define       WSNbackColorFlag            _WSNbackColorFlag()
-extern char* _WSNbackColorFlag();
+extern WSDLEX32 char* _WSNbackColorFlag();
 #define       WSNbackBlinkColor           _WSNbackBlinkColor()
-extern char* _WSNbackBlinkColor();
+extern WSDLEX32 char* _WSNbackBlinkColor();
 #define       WSNreverseFlag              _WSNreverseFlag()
-extern char* _WSNreverseFlag();
+extern WSDLEX32 char* _WSNreverseFlag();
 #define       WSNminimum                  _WSNminimum()
-extern char* _WSNminimum();
+extern WSDLEX32 char* _WSNminimum();
 #define       WSNangle1                   _WSNangle1()
-extern char* _WSNangle1();
+extern WSDLEX32 char* _WSNangle1();
 #define       WSNangle2                   _WSNangle2()
-extern char* _WSNangle2();
+extern WSDLEX32 char* _WSNangle2();
 #define       WSNarcType                  _WSNarcType()
-extern char* _WSNarcType();
+extern WSDLEX32 char* _WSNarcType();
 #define       WSNdragInterval             _WSNdragInterval()
-extern char* _WSNdragInterval();
+extern WSDLEX32 char* _WSNdragInterval();
 #define       WSNindicatorShadow          _WSNindicatorShadow()
-extern char* _WSNindicatorShadow();
+extern WSDLEX32 char* _WSNindicatorShadow();
 #define       WSNemboss                   _WSNemboss()
-extern char* _WSNemboss();
+extern WSDLEX32 char* _WSNemboss();
 #define       WSNmouse                    _WSNmouse()
-extern char* _WSNmouse();
+extern WSDLEX32 char* _WSNmouse();
 #define       WSNusePixmap                _WSNusePixmap()
-extern char* _WSNusePixmap();
+extern WSDLEX32 char* _WSNusePixmap();
 #define       WSNenableInput              _WSNenableInput()
-extern char* _WSNenableInput();
+extern WSDLEX32 char* _WSNenableInput();
 #define       WSNok                _WSNok()
-extern char* _WSNok();
+extern WSDLEX32 char* _WSNok();
 #define       WSNno              _WSNno()
-extern char* _WSNno();
+extern WSDLEX32 char* _WSNno();
 #define       WSNcancel              _WSNcancel()
-extern char* _WSNcancel();
+extern WSDLEX32 char* _WSNcancel();
 #define       WSNokString         _WSNokString()
-extern char* _WSNokString();
+extern WSDLEX32 char* _WSNokString();
 #define       WSNnoString        _WSNnoString()
-extern char* _WSNnoString();
+extern WSDLEX32 char* _WSNnoString();
 #define       WSNcancelString        _WSNcancelString()
-extern char* _WSNcancelString();
+extern WSDLEX32 char* _WSNcancelString();
 #define       WSNmodal           _WSNmodal()
-extern char* _WSNmodal();
+extern WSDLEX32 char* _WSNmodal();
 #define       WSNtype            _WSNtype()
-extern char* _WSNtype();
+extern WSDLEX32 char* _WSNtype();
 #define       WSNmaxHeight       _WSNmaxHeight()
-extern char* _WSNmaxHeight();
+extern WSDLEX32 char* _WSNmaxHeight();
 #define       WSNmultiSelect     _WSNmultiSelect()
-extern char* _WSNmultiSelect();
+extern WSDLEX32 char* _WSNmultiSelect();
 #define       WSNreverseSelect    _WSNreverseSelect()
-extern char* _WSNreverseSelect();
+extern WSDLEX32 char* _WSNreverseSelect();
 #define       WSNmargin    _WSNmargin()
-extern char* _WSNmargin();
+extern WSDLEX32 char* _WSNmargin();
 #define       WSNname    _WSNname()
-extern char* _WSNname();
+extern WSDLEX32 char* _WSNname();
 #define       WSNuseIcon    _WSNuseIcon()
-extern char* _WSNuseIcon();
+extern WSDLEX32 char* _WSNuseIcon();
 #define       WSNiconPixmap    _WSNiconPixmap()
-extern char* _WSNiconPixmap();
+extern WSDLEX32 char* _WSNiconPixmap();
 #define       WSNvirtualScroll    _WSNvirtualScroll()
-extern char* _WSNvirtualScroll();
+extern WSDLEX32 char* _WSNvirtualScroll();
 #define       WSNnoHatch    _WSNnoHatch()
-extern char* _WSNnoHatch();
+extern WSDLEX32 char* _WSNnoHatch();
 #define       WSNselectDir    _WSNselectDir()
-extern char* _WSNselectDir();
+extern WSDLEX32 char* _WSNselectDir();
 #define       WSNgradation    _WSNgradation()
-extern char* _WSNgradation();
+extern WSDLEX32 char* _WSNgradation();
 #define       WSNgradationMargin    _WSNgradationMargin()
-extern char* _WSNgradationMargin();
+extern WSDLEX32 char* _WSNgradationMargin();
 #define       WSNshortcut    _WSNshortcut()
-extern char* _WSNshortcut();
+extern WSDLEX32 char* _WSNshortcut();
 #define       WSNreturnKeyFocus    _WSNreturnKeyFocus()
-extern char* _WSNreturnKeyFocus();
+extern WSDLEX32 char* _WSNreturnKeyFocus();
 #define       WSNexit    _WSNexit()
-extern char* _WSNexit();
+extern WSDLEX32 char* _WSNexit();
 #define       WSNitemHeight    _WSNitemHeight()
-extern char* _WSNitemHeight();
+extern WSDLEX32 char* _WSNitemHeight();
 #define       WSNdata          _WSNdata()
-extern char* _WSNdata();
+extern WSDLEX32 char* _WSNdata();
 #define       WSNdataSource    _WSNdataSource()
-extern char* _WSNdataSource();
+extern WSDLEX32 char* _WSNdataSource();
 #define       WSNdataSourceName    _WSNdataSourceName()
-extern char* _WSNdataSourceName();
+extern WSDLEX32 char* _WSNdataSourceName();
 #define       WSNanchorTop    _WSNanchorTop()
-extern char* _WSNanchorTop();
+extern WSDLEX32 char* _WSNanchorTop();
 #define       WSNanchorBottom    _WSNanchorBottom()
-extern char* _WSNanchorBottom();
+extern WSDLEX32 char* _WSNanchorBottom();
 #define       WSNanchorLeft    _WSNanchorLeft()
-extern char* _WSNanchorLeft();
+extern WSDLEX32 char* _WSNanchorLeft();
 #define       WSNanchorRight    _WSNanchorRight()
-extern char* _WSNanchorRight();
+extern WSDLEX32 char* _WSNanchorRight();
 #define       WSNanchorTopFlag    _WSNanchorTopFlag()
-extern char* _WSNanchorTopFlag();
+extern WSDLEX32 char* _WSNanchorTopFlag();
 #define       WSNanchorBottomFlag    _WSNanchorBottomFlag()
-extern char* _WSNanchorBottomFlag();
+extern WSDLEX32 char* _WSNanchorBottomFlag();
 #define       WSNanchorLeftFlag    _WSNanchorLeftFlag()
-extern char* _WSNanchorLeftFlag();
+extern WSDLEX32 char* _WSNanchorLeftFlag();
 #define       WSNanchorRightFlag    _WSNanchorRightFlag()
-extern char* _WSNanchorRightFlag();
+extern WSDLEX32 char* _WSNanchorRightFlag();
 #define       WSNflip    _WSNflip()
-extern char* _WSNflip();
+extern WSDLEX32 char* _WSNflip();
 #define       WSNframe    _WSNframe()
-extern char* _WSNframe();
+extern WSDLEX32 char* _WSNframe();
 #define       WSNformat    _WSNformat()
-extern char* _WSNformat();
+extern WSDLEX32 char* _WSNformat();
 #define       WSNworkX    _WSNworkX()
-extern char* _WSNworkX();
+extern WSDLEX32 char* _WSNworkX();
 #define       WSNworkY    _WSNworkY()
-extern char* _WSNworkY();
+extern WSDLEX32 char* _WSNworkY();
 #define       WSNdisplayOnly    _WSNdisplayOnly()
-extern char* _WSNdisplayOnly();
+extern WSDLEX32 char* _WSNdisplayOnly();
 #define       WSNrefreshing    _WSNrefreshing()
-extern char* _WSNrefreshing();
+extern WSDLEX32 char* _WSNrefreshing();
 #define       WSNvcolumns    _WSNvcolumns()
-extern char* _WSNvcolumns();
+extern WSDLEX32 char* _WSNvcolumns();
 #define       WSNhcolumns    _WSNhcolumns()
-extern char* _WSNhcolumns();
+extern WSDLEX32 char* _WSNhcolumns();
 #define       WSNseparator    _WSNseparator()
-extern char* _WSNseparator();
+extern WSDLEX32 char* _WSNseparator();
 #define       WSNfit    _WSNfit()
-extern char* _WSNfit();
+extern WSDLEX32 char* _WSNfit();
 #define       WSNip    _WSNip()
-extern char* _WSNip();
+extern WSDLEX32 char* _WSNip();
 #define       WSNport    _WSNport()
-extern char* _WSNport();
+extern WSDLEX32 char* _WSNport();
 #define       WSNtimeout    _WSNtimeout()
-extern char* _WSNtimeout();
+extern WSDLEX32 char* _WSNtimeout();
 #define       WSNexport    _WSNexport()
-extern char* _WSNexport();
+extern WSDLEX32 char* _WSNexport();
 #define       WSNusername    _WSNusername()
-extern char* _WSNusername();
+extern WSDLEX32 char* _WSNusername();
 #define       WSNpassword    _WSNpassword()
-extern char* _WSNpassword();
+extern WSDLEX32 char* _WSNpassword();
 #define       WSNdbname    _WSNdbname()
-extern char* _WSNdbname();
+extern WSDLEX32 char* _WSNdbname();
 #define       WSNdsn    _WSNdsn()
-extern char* _WSNdsn();
+extern WSDLEX32 char* _WSNdsn();
 #define       WSNhostname    _WSNhostname()
-extern char* _WSNhostname();
+extern WSDLEX32 char* _WSNhostname();
 #define       WSNstatus    _WSNstatus()
-extern char* _WSNstatus();
+extern WSDLEX32 char* _WSNstatus();
 #define       WSNdbTableName    _WSNdbTableName()
-extern char* _WSNdbTableName();
+extern WSDLEX32 char* _WSNdbTableName();
 #define       WSNshowItem    _WSNshowItem()
-extern char* _WSNshowItem();
+extern WSDLEX32 char* _WSNshowItem();
 #define       WSNsortItems    _WSNsortItems()
-extern char* _WSNsortItems();
+extern WSDLEX32 char* _WSNsortItems();
 #define       WSNsort         _WSNsort()
-extern char* _WSNsort();
+extern WSDLEX32 char* _WSNsort();
 #define       WSNitem         _WSNitem()
-extern char* _WSNitem();
+extern WSDLEX32 char* _WSNitem();
 #define       WSNfilter         _WSNfilter()
-extern char* _WSNfilter();
+extern WSDLEX32 char* _WSNfilter();
 
 #endif //MSW
 
