@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,18 +14,19 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSCOM_H
 #define WSCOM_H
 
+#include <wsconfig.h>
 ///////////////////////////////////////
 // definition of directories and files
 ///////////////////////////////////////
@@ -53,6 +54,12 @@
 
 //#define WS_NO_DEBUG_TRACE 0
 //#define WS_NO_DEBUG_TRACE 1
+#ifdef _WSWIN32
+#include "win32/wswin32.h"
+#define WSDLEX32 __declspec(dllexport)
+#else
+#define WSDLEX32
+#endif
 
 #ifdef MSW
 # define WSDLEX __declspec(dllexport)
@@ -164,6 +171,7 @@ extern void operator delete[](void*);
 #define WS_EN_DEFAULT    -2
 #define WS_EN_LOCALE     -1
 #define WS_EN_NONE        0
+#define WS_EN_ISO8859(n)  (n)
 #define WS_EN_ISO8859_1   1
 #define WS_EN_ISO8859_2   2
 #define WS_EN_ISO8859_3   3
@@ -187,8 +195,8 @@ extern void operator delete[](void*);
 #define WS_EN_EUCCN       40
 #define WS_EN_BIG5        50
 
-#define WS_EN_LANG_NONE    0
-#define WS_EN_LANG_JP      1
+//#define WS_EN_LANG_NONE    0
+//#define WS_EN_LANG_JP      1
 
 #define WSN_EN_DEFAULT    "DEFAULT"
 #define WSN_EN_LOCALE     "LOCALE"
@@ -215,7 +223,7 @@ extern void operator delete[](void*);
 #define WSN_EN_EUCKR      "EUCKR"
 #define WSN_EN_EUCCN      "EUCCN"
 #define WSN_EN_BIG5       "BIG5"
-#define WSN_EN_UTF8_JP    "UTF8_JP"
+//#define WSN_EN_UTF8_JP    "UTF8_JP"
 
 typedef unsigned char  WSCbool;
 typedef void*          WSCptr;
@@ -416,11 +424,21 @@ extern int gettimeofday(struct timeval *__tv,
 
 #ifdef MSW //if not unix system
 #include <windows.h>
+#ifndef _WSWINCE
 #define WS_WINMAIN extern "C" { \
-extern int _win_main(HINSTANCE hInstance,HINSTANCE hPrevInstance,LPSTR lpCmdLine,int nCmdShow); \
+extern WSDLEX32 int _win_main(HINSTANCE hInstance,HINSTANCE hPrevInstance,LPSTR lpCmdLine,int nCmdShow); \
 int APIENTRY WinMain(HINSTANCE hInstance,HINSTANCE hPrevInstance,LPSTR lpCmdLine,int nCmdShow){ \
 return _win_main(hInstance,hPrevInstance,lpCmdLine,nCmdShow); }; };
-
+#else
+#define WS_WINMAIN extern "C" { \
+extern WSDLEX32 int _win_main(HINSTANCE hInstance,HINSTANCE hPrevInstance,LPSTR lpCmdLine,int nCmdShow); \
+int APIENTRY WinMain(HINSTANCE hInstance,HINSTANCE hPrevInstance,LPWSTR lpCmdLine,int nCmdShow){ \
+char* cmd = WSGFgetString(lpCmdLine,WS_EN_DEFAULT); \
+int ret = _win_main(hInstance,hPrevInstance,cmd,nCmdShow); \
+delete cmd; \
+return ret; \
+}; };
+#endif
 #endif
 
 #include <stdio.h>
@@ -430,13 +448,22 @@ return _win_main(hInstance,hPrevInstance,lpCmdLine,nCmdShow); }; };
 #include <stdarg.h>
 
 #if defined MSW
-extern int _dbprintf_init();
-extern int _dbprintf(const char*,...);
-#define dbprintf _dbprintf
+extern "C" {
+extern WSDLEX32 int _dbprintf_init();
+extern WSDLEX32 int _dbprintf(const char*,...);
+};
+#ifdef _WSWIN32
+#define dbprintf
 #else
-extern int _dbprintf_init();
-extern int _dbprintf(const char*,...);
+#define dbprintf(...) 
+#endif
+#define dbprintf2 _dbprintf
+#else
+extern "C" {
+extern WSDLEX32 int _dbprintf_init();
+extern WSDLEX32 int _dbprintf(const char*,...);
 extern FILE* _ws_debug_fp;
+}
 #define dbprintf if (_ws_debug_fp) _dbprintf
 #endif
 
@@ -678,6 +705,17 @@ extern WSDLEX void WSGFsetGetLanguageHandler(long(*)());
 extern WSDLEX void WSGFwsNsPluginInitialize();
 extern WSDLEX void WSGFwsIePluginInitialize();
 
+extern WSDLEX char* WSGFvalueToType(long val);
+extern WSDLEX long WSGFtypeToValue(char* typen);
+extern WSDLEX void _get_2_words(char* src,char* word1,char* word2);
+extern WSDLEX void _add_default_changed_property(WSCbase* btarget,char* pn,char tp,char* pdata,WSClistData* plist);
+
+extern WSDLEX void WSGFdrawModern1Shadow(WSDdev* dev,long shadow_type,WSCushort stick,
+   short fg_no, short ts_no, short bs_no, short bg_no,short pno,
+   short x, short y, WSCushort w,WSCushort h,WSCbool nodark);
+
+extern WSDLEX void WSGFexit(int);
+
 #ifndef WS_DIALOG_CANCEL
 #define WS_DIALOG_CANCEL  0
 #endif
@@ -771,8 +809,9 @@ extern WSDLEX void WSGFwsIePluginInitialize();
 #define WS_GR_R_L   8
 
 
-extern WSDLEX char* WSGFgetLocaleName(long);
-extern WSDLEX long WSGFgetLocaleValue(char*);
+extern WSDLEX char* WSGFgetEncodingName(long);
+extern WSDLEX long WSGFgetEncodingValue(char* encode_name);
+extern WSDLEX long WSGFgetEncoding(char* locale_name);
 
 #define WS250MS   (WSCuchar)1
 #define WS500MS   (WSCuchar)2
