@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <advance/WSCclassPropEditor.h>
@@ -43,6 +43,7 @@
 #include <WSCmessageDialog.h>
 #include <WSCfileSelect.h>
 #include <WSCvtoggle.h>
+#include <WSCvradio.h>
 #include <WSDfile.h>
 #include <WSCballoonHelp.h>
 #include <WSClist.h>
@@ -167,6 +168,54 @@ void WSCclassPropEditor::_dialog2_set_work(WSCbase* obj){
 //printf("WSCclassPropEditor::_dialog2_set_work #%s#\n",(char*)tmp);
   op_edit->_dialog2->setVisible(False);
 }
+void WSCclassPropEditor::_value_set_work(WSCbase* obj){
+  WSCclassPropEditor* op_edit = (WSCclassPropEditor*)obj->getUserData("WIN EDIT");
+
+//Normal:0
+//Invisible:4
+//Deleted:1
+//Default changed:2
+//Hidden:3
+  long value = obj->getProperty(WSNvalue);
+//printf("WSCclassPropEditor::_value_set_work val=%d\n",value);
+  if (value == 0 || value == 4){
+    op_edit->_var_if->setSensitive(True);
+    op_edit->_var_if->setProperty(WSNbackColor,WS_DF_WORKBACKCOLOR);
+    op_edit->_value_if->setSensitive(True);
+    op_edit->_value_if->setProperty(WSNbackColor,WS_DF_WORKBACKCOLOR);
+    op_edit->_bname_if->setSensitive(True);
+    op_edit->_bname_if->setProperty(WSNbackColor,WS_DF_WORKBACKCOLOR);
+  }else if (value == 1){
+    op_edit->_var_if->setSensitive(False);
+    op_edit->_var_if->setProperty(WSNbackColor,WS_DF_BACKCOLOR);
+    op_edit->_value_if->setSensitive(False);
+    op_edit->_value_if->setProperty(WSNbackColor,WS_DF_BACKCOLOR);
+    op_edit->_bname_if->setSensitive(False);
+    op_edit->_bname_if->setProperty(WSNbackColor,WS_DF_BACKCOLOR);
+  }else if (value == 2){
+    op_edit->_var_if->setSensitive(False);
+    op_edit->_var_if->setProperty(WSNbackColor,WS_DF_BACKCOLOR);
+    op_edit->_value_if->setSensitive(True);
+    op_edit->_value_if->setProperty(WSNbackColor,WS_DF_WORKBACKCOLOR);
+    op_edit->_bname_if->setSensitive(False);
+    op_edit->_bname_if->setProperty(WSNbackColor,WS_DF_BACKCOLOR);
+  }else if (value == 3){
+    op_edit->_var_if->setSensitive(False);
+    op_edit->_var_if->setProperty(WSNbackColor,WS_DF_BACKCOLOR);
+    op_edit->_value_if->setSensitive(False);
+    op_edit->_value_if->setProperty(WSNbackColor,WS_DF_BACKCOLOR);
+    op_edit->_bname_if->setSensitive(False);
+    op_edit->_bname_if->setProperty(WSNbackColor,WS_DF_BACKCOLOR);
+  }else{
+    op_edit->_var_if->setSensitive(True);
+    op_edit->_var_if->setProperty(WSNbackColor,WS_DF_WORKBACKCOLOR);
+    op_edit->_value_if->setSensitive(True);
+    op_edit->_value_if->setProperty(WSNbackColor,WS_DF_WORKBACKCOLOR);
+    op_edit->_bname_if->setSensitive(True);
+    op_edit->_bname_if->setProperty(WSNbackColor,WS_DF_WORKBACKCOLOR);
+  }
+
+}
 void WSCclassPropEditor::_dialog_set_work(WSCbase* obj){
   WSCclassPropEditor* op_edit = (WSCclassPropEditor*)obj->getUserData("WIN EDIT");
   op_edit->_dialog2->setVisible(False);
@@ -212,6 +261,7 @@ void WSCclassPropEditor::_dialog_set_work(WSCbase* obj){
 //Default changed:2
 //Hidden:3
 
+
   if ((val2 == 0 || val2 == 4) && WSGFcheckNameString(varname.getString()) != True){
     op_edit->_msg->setPropertyV(WSNlabelString,WSGFgettext("N3:WSSTR Invalid variable name..."));
     op_edit->_msg->setVisible(True);
@@ -367,6 +417,7 @@ void WSCclassPropEditor::_ibtn1_work(WSCbase* obj){
     op_edit->_vsname.setString("");
     op_edit->_opt1->setPropertyV(WSNvalue,(long)0);
     op_edit->_opt2->setPropertyV(WSNvalue,(long)0);
+    op_edit->_opt2->execProcedure(WSEV_ACTIVATE);
     op_edit->_dialog1->setPropertyV(WSNokString,WSGFgettext("T3:WSSTR Create"));
     op_edit->_use_file->setStatus(False,False);
     op_edit->_dialog1->setUserData("PROPERTY NO",(void*)-1);
@@ -463,6 +514,7 @@ void WSCclassPropEditor::_ibtn2_work(WSCbase* obj){
   op_edit->_value_if->setPropertyV(WSNlabelString,propdata->value.getString());
   op_edit->_opt1->setPropertyV(WSNvalue,(long)propdata->type);
   op_edit->_opt2->setPropertyV(WSNvalue,(long)propdata->att);
+  op_edit->_opt2->execProcedure(WSEV_ACTIVATE);
   op_edit->_dialog1->setPropertyV(WSNokString,WSGFgettext("Y3:WSSTR Update"));
   op_edit->_bname_if->setPropertyV(WSNlabelString,propdata->bname.getString());
   op_edit->_vsname.setString(propdata->values.getString());
@@ -768,6 +820,13 @@ long WSCclassPropEditor::initialize(){
   _opt2->setPropertyV(WSNmenuItems,WS_PEDLD_ATTMENU);
   _opt2->setPropertyV(WSNemboss,(WSCbool)True);
   _opt2->setVisible(True);
+  _opt2->setUserData("WIN EDIT",(void*)this); 
+
+  WSCprocedure* vchop1 = new WSCprocedure("vshop1",WSEV_ACTIVATE);
+  vchop1->setFunction(_value_set_work,"_value_set_work");
+  _opt2->addProcedure(vchop1);
+
+//XXZZ
 
   _bname_if = new WSCvifield(_darea1,"pe-tlb");
   _bname_if->initialize();
@@ -925,7 +984,8 @@ long WSCclassPropEditor::initialize(){
   tlbs8->setVisible(True);
 
       //-------END BTN SETTING ---------//
-  _use_file = new WSCvtoggle(_darea1,"ope-use_file");
+//  _use_file = new WSCvtoggle(_darea1,"ope-use_file");
+  _use_file = new WSCvradio(_darea1,"ope-use_file");
   _use_file->initialize();
   _use_file->setInternalObject(True);
   _use_file->setPropertyV(WSNx, (short)5);
@@ -935,11 +995,11 @@ long WSCclassPropEditor::initialize(){
   _use_file->setPropertyV(WSNlabelString, WSGFgettext("e3:WSSTR  Use the handler defined by user"));
   _use_file->setPropertyV(WSNmarginLeft, (WSCuchar)10);
   _use_file->setPropertyV(WSNalignmentH, (WSCuchar)WS_LEFT);
-  _use_file->setPropertyV(WSNindicatorPixmap,WS_TG1_PIX);
-  _use_file->setPropertyV(WSNselectPixmap,WS_TG2_PIX);
-  _use_file->setPropertyV(WSNindicatorType,WS_IN);
+//  _use_file->setPropertyV(WSNindicatorPixmap,WS_TG1_PIX);
+//  _use_file->setPropertyV(WSNselectPixmap,WS_TG2_PIX);
+//  _use_file->setPropertyV(WSNindicatorType,WS_IN);
   _use_file->setPropertyV(WSNindicatorSize,(WSCuchar)16);
-  _use_file->setPropertyV(WSNshadowThickness,(WSCuchar)0);
+//  _use_file->setPropertyV(WSNshadowThickness,(WSCuchar)0);
   _use_file->setProperty(WSNbackColor,WS_DF_DARKBACKCOLOR);
   WSGFsetMargin(_use_file,0);
   _use_file->setVisible(True);
@@ -1182,7 +1242,6 @@ long WSCclassPropEditor::initialize(){
 //XXZZ
 
 
-
   onGuiPolicyChange(WSGIappDev()->getGuiPolicy());
 
   _adjust(); 
