@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCbase.h>
@@ -41,6 +41,13 @@ WSMFclassInit(WSCbase,WSCroot);
 
 //#define TDBG
 
+#ifdef WS_EMBED
+void _df_def_dummy_ref(){
+extern void _libws_drdef();
+  _libws_drdef();
+}
+#endif
+
 #ifdef MEMDBG
 WSClistData* memlist = NULL;
 long memflg = 0;
@@ -180,6 +187,7 @@ WSCbase::~WSCbase(){
   }
 //  clearGriphand();
 
+#ifndef WS_EMBED
   WSCbase* client = NULL;
   WSCbase* prop_editor = WSGIappPropertyEditor();
   if (prop_editor != NULL && prop_editor != this){
@@ -191,7 +199,7 @@ WSCbase::~WSCbase(){
       prop_editor->setPropertyV(WSNclient,(void*)client);
     }
   }
-
+#endif
   WSCbase* parent = getParent();
   if (parent != NULL){
     WSClistData* list = (WSClistData*)parent->getUserData("FOCUS_LIST");
@@ -424,6 +432,7 @@ long WSCbase::delAllProcedure(){
 }
 
 long WSCbase::setPropertyEditExecute(WSCbool fl ){
+#ifndef WS_EMBED
   if (fl !=  False) {
     setPropertyEditMode(True);
     WSCbase* client = this;
@@ -448,11 +457,13 @@ long WSCbase::setPropertyEditExecute(WSCbool fl ){
   }
   setAbsoluteDraw(True);
   redraw();
+#endif
   return WS_NO_ERR;
 }
 
 long WSCbase::setPropertyEditMode(WSCbool fl ){
 //printf("WSCbase::setPropertyEditMode %s %d\n",getInstanceName(),fl);
+#ifndef WS_EMBED
   if (fl !=  False) {
     if (_property_edit_mode == False){
       _property_edit_mode = True;
@@ -469,6 +480,7 @@ long WSCbase::setPropertyEditMode(WSCbool fl ){
     _property_edit_mode = False;
     onEditModeChange(False);
   }
+#endif
   return WS_NO_ERR;
 }
 void WSCbase::_adjust_for_anchors(WSCushort,WSCushort){
@@ -560,6 +572,7 @@ void WSCbase::getGripHandGrid(WSCushort* x,WSCushort* y){
   *y = _grid_y;
 }
 void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
+#ifndef NO_GRIPHAND
   if (base->existProperty(WSNx) == False ||
       base->existProperty(WSNy) == False ||
       base->existProperty(WSNwidth) == False ||
@@ -747,15 +760,17 @@ void _griph_geom_handler(WSCbase* base,short no,short diff_x,short diff_y){
     }
     base->drawGriphand();
     base->update(); 
+#ifndef WS_EMBED
     WSGFmarkChanged(base);
-
     //update xy position...
     WSCbase* prop_editor = WSGIappPropertyEditor();
     if (prop_editor != NULL){
       WSGIappPropertyEditor()->setUserData(WS_GEOMETRY_UPDATE,(void*)1); 
       WSGIappPropertyEditor()->update();
     }
+#endif
   }
+#endif
 }
 
 WSCbool WSCbase::getVisible(){
@@ -795,6 +810,7 @@ void WSCbase::onEditModeChange(WSCbool fl){
 }
 
 void WSCbase::_draw_grip_hand(short x,short y,WSCushort w,WSCushort h){
+#ifndef NO_GRIPHAND
   WSClistData* glist = (WSClistData*)getUserData("GH-LIST");
   long i;
   WSCbase* gh = NULL;
@@ -867,6 +883,7 @@ void WSCbase::_draw_grip_hand(short x,short y,WSCushort w,WSCushort h){
     gh = (WSCbase*)(*glist)[i];
     gh->setVisible(True);
   }
+#endif
 }
 
 //WSCbool WSCbase::getGriphandOn(){
@@ -1928,6 +1945,7 @@ dbprintf("WSCbase::execProcedure %s:%d %s done2 ev=0x%x\n",__FILE__,__LINE__,get
   return;
 }
 void WSCbase::_exec_procedure(WSCprocedure* op){
+#ifndef WS_EMBED
   if (WSGIappDev()->getTraceMode() != False && op->getInternal() == False){
     char sbuf[1024];
     WSCstring str;
@@ -1940,6 +1958,7 @@ void WSCbase::_exec_procedure(WSCprocedure* op){
     str = sbuf;
     WSGFsendMessage("WS-TRACER",str.getString(WS_EN_UTF8));
   }
+#endif
   void (*proc)(WSCbase*); 
   proc = (void(*)(WSCbase*))op->getProc();
   if (proc != NULL){
@@ -1955,6 +1974,7 @@ dbprintf("WSCbase::_exec_procedure %s:%d %s start op=%s\n",__FILE__,__LINE__,get
 dbprintf("WSCbase::_exec_procedure %s:%d %s done op=%s\n",__FILE__,__LINE__,getInstanceName(),op->getFunctionName());
     }
   }
+#ifndef WS_EMBED
   if (WSGIappDev()->getTraceMode() != False && op->getInternal() == False){
     char sbuf[1024];
     WSCstring str;
@@ -1962,6 +1982,7 @@ dbprintf("WSCbase::_exec_procedure %s:%d %s done op=%s\n",__FILE__,__LINE__,getI
     str = sbuf;
     WSGFsendMessage("WS-TRACER",str.getString(WS_EN_UTF8));
   }
+#endif
 }
 void WSCbase::_exec_procedure(WSCprocedure** opl,long ev,WSCbool del){
   if (ev == WSEV_INITIALIZE){
@@ -2263,6 +2284,7 @@ void WSCbase::onSpecialFocusChange(WSCbool){
 }
 
 void WSCbase::onMousePress(WSCpoint* point){
+#ifndef WS_EMBED
   if (_internal_object != False){
     WSCbase* parent = _parent;
     while(parent != NULL){
@@ -2399,6 +2421,7 @@ void WSCbase::onMousePress(WSCpoint* point){
       setPropertyEditExecute(True); 
     }
   }
+#endif
 }
 void WSCbase::onMouseDoubleClick(WSCpoint*){ }
 
@@ -3110,6 +3133,7 @@ WSCbool WSCbase::isParent(WSCbase* inst){
 }
 
 void WSCbase::setExported(WSCbool fl){
+#ifndef NO_REMOTE_INSTANCE
   if (_export_bk == False){
     if (fl != False){
       WSGIappObjectList()->addExportInstanceUpdateList(this);
@@ -3121,23 +3145,28 @@ void WSCbase::setExported(WSCbool fl){
   }
   _export_ = fl;
   _export_bk = fl;
+#endif
 }
 WSCbool WSCbase::getExported(){
   return _export_;
 }
 
 void WSCbase::setExportName(char* name){
+#ifndef NO_REMOTE_INSTANCE
   char* ename = (char*)getUserData("export-name");
   if (ename != NULL){
     delete ename;
   }
   setUserData("export-name",WSGFstrdup(name));
+#endif
 }
 char* WSCbase::getExportName(){
+#ifndef NO_REMOTE_INSTANCE
   char* ename = (char*)getUserData("export-name");
   if (ename != NULL){
     return ename;
   }
+#endif
   return "";
 }
 WSCbase* (*WSCbase::_create_instance_handler)(char*,WSCbase*,char*) = NULL;
