@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCclassInformation.h>
@@ -353,6 +353,7 @@ WSClistData* WSCbaseList::getRemoteInstanceList(){
 }
 
 
+#ifndef NO_REMOTE_INSTANCE
 WSCremoteInstanceData::WSCremoteInstanceData(){
   _port = 0;
 }
@@ -391,6 +392,7 @@ WSCstring WSCremoteInstanceData::getClassName(){
 WSCushort WSCremoteInstanceData::getPort(){
   return _port;
 }
+#endif
 
 WSCbool WSCbaseList::getRemoteInstanceListUpdated(){
   return _remote_data_list_updated;
@@ -400,6 +402,7 @@ void WSCbaseList::setRemoteInstanceListUpdated(WSCbool fl){
 }
 
 long WSCbaseList::addRemoteInstanceData(WSCremoteInstanceData* idata){
+#ifndef NO_REMOTE_INSTANCE
   long i;
   long num = _remote_instance_list.getNum();
   for(i=0; i<num; i++){
@@ -445,10 +448,12 @@ long WSCbaseList::addRemoteInstanceData(WSCremoteInstanceData* idata){
   _remote_instance_list.add(inst);
 //printf("WSCbaseList::addRemoteInstanceData added. %s %s %s %d\n", (char*)inst->_instance_name,(char*)inst->_class_name,(char*)inst->_addr,inst->_port);
   _remote_data_list_updated = True;
+#endif
   return WS_NO_ERR;
 }
 
 long WSCbaseList::delRemoteInstanceData(WSCremoteInstanceData* idata){
+#ifndef NO_REMOTE_INSTANCE
   long i;
   long num = _remote_instance_list.getNum();
   for(i=0; i<num; i++){
@@ -487,10 +492,12 @@ long WSCbaseList::delRemoteInstanceData(WSCremoteInstanceData* idata){
       return WS_NO_ERR;
     }
   }
+#endif
   return WS_ERR;
 }
 
 WSCremoteInstanceData* WSCbaseList::getRemoteInstanceData(char* pn){
+#ifndef NO_REMOTE_INSTANCE
   long i;
   long num = _remote_instance_list.getNum();
   for(i=0; i<num; i++){
@@ -504,10 +511,12 @@ WSCremoteInstanceData* WSCbaseList::getRemoteInstanceData(char* pn){
       continue;
     }
   }
+#endif
   return NULL;
 }
 
 WSCRbase* WSCbaseList::getRemoteInstance(char* iname){
+#ifndef NO_REMOTE_INSTANCE
   WSCRbaseList* orb = new WSCRbaseList();
   orb->setAddr(WSGIconductor()->getAddr());
   orb->setPort(WS_DEFAULT_AGENT_PORT);
@@ -530,9 +539,13 @@ WSCRbase* WSCbaseList::getRemoteInstance(char* iname){
   inst->setInstanceName(rinst->getInstanceName());
   delete rinst;
   return inst;
+#else
+  return NULL;
+#endif
 }
 
 long WSCbaseList::addExportInstanceList(WSCbase* inst){
+#ifndef NO_REMOTE_INSTANCE
   long num = _export_instance_list.getNum();
   long i;
   for(i=0; i<num; i++){
@@ -542,10 +555,12 @@ long WSCbaseList::addExportInstanceList(WSCbase* inst){
     }
   }
   _export_instance_list.add((void*)inst);
+#endif
   return WS_NO_ERR;
 }
 
 long WSCbaseList::delExportInstanceList(WSCbase* inst){
+#ifndef NO_REMOTE_INSTANCE
   long num = _export_instance_list.getNum();
   long i;
   for(i=0; i<num; i++){
@@ -555,7 +570,7 @@ long WSCbaseList::delExportInstanceList(WSCbase* inst){
       return WS_NO_ERR;
     }
   }
-  
+#endif  
   return WS_NO_ERR;
 }
 
@@ -563,6 +578,7 @@ WSClistData* WSCbaseList::getExportInstanceList(){
   return &_export_instance_list;
 }
 long WSCbaseList::addExportInstanceUpdateList(WSCbase* inst){
+#ifndef NO_REMOTE_INSTANCE
   long num = _export_instance_update_list.getNum();
   long i;
   for(i=0; i<num; i++){
@@ -572,10 +588,12 @@ long WSCbaseList::addExportInstanceUpdateList(WSCbase* inst){
     }
   }
   _export_instance_update_list.add((void*)inst);
+#endif
   return WS_NO_ERR;
 }
 
 long WSCbaseList::delExportInstanceUpdateList(WSCbase* inst){
+#ifndef NO_REMOTE_INSTANCE
   long num = _export_instance_update_list.getNum();
   long i;
   for(i=0; i<num; i++){
@@ -585,6 +603,7 @@ long WSCbaseList::delExportInstanceUpdateList(WSCbase* inst){
       return WS_NO_ERR;
     }
   }
+#endif
   return WS_NO_ERR;
 }
 
@@ -592,6 +611,7 @@ WSClistData* WSCbaseList::getExportInstanceUpdateList(){
   return &_export_instance_update_list;
 }
 long WSCbaseList::addExportInstanceDeleteList(WSCbase* inst){
+#ifndef NO_REMOTE_INSTANCE
   long num = _export_instance_delete_list.getNum();
   long i;
   for(i=0; i<num; i++){
@@ -601,10 +621,12 @@ long WSCbaseList::addExportInstanceDeleteList(WSCbase* inst){
     }
   }
   _export_instance_delete_list.add((void*)inst);
+#endif
   return WS_NO_ERR;
 }
 
 long WSCbaseList::delExportInstanceDeleteList(WSCbase* inst){
+#ifndef NO_REMOTE_INSTANCE
   long num = _export_instance_delete_list.getNum();
   long i;
   for(i=0; i<num; i++){
@@ -614,6 +636,7 @@ long WSCbaseList::delExportInstanceDeleteList(WSCbase* inst){
       return WS_NO_ERR;
     }
   }
+#endif
   return WS_NO_ERR;
 }
 
@@ -622,6 +645,7 @@ WSClistData* WSCbaseList::getExportInstanceDeleteList(){
 }
 
 
+#ifndef NO_REMOTE_INSTANCE
 void _WSCremoteInstanceData_save(WSDserialize* db,void* ptr){
 //printf("WSCremoteInstanceData_save...\n");
   WSCremoteInstanceData* obj =(WSCremoteInstanceData*)ptr;
@@ -678,4 +702,4 @@ void _WSCremoteInstanceData_delete(void* ptr){
 WSMFdefineDrClient(WSCremoteInstanceData,_WSCremoteInstanceData_save,
   _WSCremoteInstanceData_load, _WSCremoteInstanceData_create,
   _WSCremoteInstanceData_delete);
-
+#endif
