@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCconductor.h>
@@ -341,6 +341,7 @@ void WSCconductor::setTimeout(WSCulong t){
   _timeout = t;
 }
 long WSCconductor::startDispatch(){
+#ifndef NO_REMOTE_INSTANCE
   if (_sock == NULL){
     _sock = WSDsocket::getNewInstance();
   }
@@ -363,9 +364,11 @@ long WSCconductor::startDispatch(){
     _timer_id = WSGIappTimer()->addTimerProc(_timer_work,WS10000MS,this);
   }
   _need_update = True;
+#endif
   return WS_NO_ERR;
 }
 long WSCconductor::stopDispatch(){
+#ifndef NO_REMOTE_INSTANCE
   if (_timer_id != 0){
     WSGIappTimer()->delTimerProc(_timer_id);
     _timer_id = 0;
@@ -398,6 +401,7 @@ long WSCconductor::stopDispatch(){
       }
     }
   }
+#endif
   if (_sock == NULL){
     return WS_ERR;
   }
@@ -411,6 +415,7 @@ long WSCconductor::stopDispatch(){
 }
 
 void WSCconductor::_accepted_work(WSDsocket* sock,void* socket,WSCulong addr){
+#ifndef NO_REMOTE_INSTANCE
   WSCconductor* _this = (WSCconductor*)sock->getUserData();
 
   WSDserialize* db = _this->getNewSerialize("SOCKET");
@@ -454,9 +459,11 @@ void WSCconductor::_accepted_work(WSDsocket* sock,void* socket,WSCulong addr){
 
   sock->close(socket);
   delete db;
+#endif
 }
 
 WSDserialize* WSCconductor::beginRemoteCall(WSCremoteCall* rc){
+#ifndef NO_REMOTE_INSTANCE
 //printf("WSCconductor::remoteCall started.\n");
   if (_csock == NULL){
     _csock = WSDsocket::getNewInstance();
@@ -487,11 +494,16 @@ WSDserialize* WSCconductor::beginRemoteCall(WSCremoteCall* rc){
   db->save("WSCremoteCall","call1",(void*)rc);
 //printf("WSCconductor::beginRemoteCall  done.\n");
   return db;
+#else
+  return NULL;
+#endif
 }
 
 long WSCconductor::endRemoteCall(WSDserialize* db){
+#ifndef NO_REMOTE_INSTANCE
   endTransaction(db);
   delete db;
+#endif
   return WS_NO_ERR;
 }
 
@@ -500,6 +512,7 @@ void WSCconductor::addNetServerHandler(char* cname,void* handler){
 }
 
 void WSCconductor::_timer_work(WSCuchar,void* ptr){
+#ifndef NO_REMOTE_INSTANCE
 //printf("WSCconductor::_timer_work.. \n");
   WSCconductor* _this = (WSCconductor*)ptr;
   if (_this->_accepted == False){
@@ -604,7 +617,7 @@ void WSCconductor::_timer_work(WSCuchar,void* ptr){
   if (orb != NULL){
     delete orb;
   }
-
+#endif
 }
 
 void WSCconductor::clearUpdateCounter(){
@@ -654,6 +667,7 @@ void WSCremoteCall::setClassName(char* cname){
   _class = WSGFstrdup(cname);
 }
 
+#ifndef NO_REMOTE_INSTANCE
 void _WSCremoteCall_save(WSDserialize* db,void* ptr){
 //printf("WSCremoteCall_save...\n");
   WSCremoteCall* obj =(WSCremoteCall*)ptr;
@@ -679,4 +693,4 @@ void _WSCremoteCall_delete(void* ptr){
 WSMFdefineDrClient(WSCremoteCall,_WSCremoteCall_save,
   _WSCremoteCall_load, _WSCremoteCall_create, _WSCremoteCall_delete);
 
-
+#endif
