@@ -20,9 +20,16 @@ void libname_init()
 	_lib_name_list->setData("PGSQL",(void*)"libwspostgres.so");
 	_lib_name_list->setData("MYSQL",(void*)"libwsmysql.so");
 #else //MSW
+#ifdef _WSWIN32
+#define _to_str_(p) #p
+	_lib_name_list->setData("ODBC",(void*)_to_str_(ODBCLIBNAME));
+	_lib_name_list->setData("PGSQL",(void*)_to_str_(PGLIBNAME));
+	_lib_name_list->setData("MYSQL",(void*)_to_str_(MYSQLLIBNAME));
+#else
 	_lib_name_list->setData("ODBC",(void*)ODBCLIBNAME);
 	_lib_name_list->setData("PGSQL",(void*)PGLIBNAME);
 	_lib_name_list->setData("MYSQL",(void*)MYSQLLIBNAME);
+#endif
 #endif //MSW
 #endif // FACTORY_METHOD
 }
