@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCform.h>
@@ -32,6 +32,7 @@
 #include <WSDappDev.h>
 #include <WSCbaseList.h>
 #include <WSDwindowDev.h>
+#include <WSCguiPolicy.h>
 
 WSMFguiClassInitialize(WSCform,WSCbase);
 WSMFversion(WSCform,WSCbase);
@@ -621,6 +622,7 @@ dbprintf("WSCform::draw %s:%d %s dev not ready..\n",__FILE__,__LINE__,getInstanc
     if (_grad_no == 0){
       dev->setForeColor(_back_color);
       dev->drawFillRect(0,0,_w,_h);
+#ifndef WS_EMBED
       if ((WSGIappDev()->getGuiPolicy() & WS_POLICY_AQUA) != 0 &&
            _bp_color == -1){
         if (_a1_color == -1){
@@ -628,6 +630,7 @@ dbprintf("WSCform::draw %s:%d %s dev not ready..\n",__FILE__,__LINE__,getInstanc
         }
         WSGFdrawStripes(dev,_w,_h,_a1_color,_a2_color,_a3_color);
       }
+#endif
       dev->setForeColor(_back_color);
 
     }else{
@@ -912,3 +915,15 @@ void WSCform::internalUpdate(){
     }
   }
 }
+#ifdef WS_EMBED
+#ifndef NO_EXT_GUI_POLICY
+class _gui_policy_register_{
+  public: _gui_policy_register_(){
+extern void WSCform_draw_mdr1(void*);
+    WSGIappGuiPolicy()->setExtGuiPolicyProc("Modern1","WSCform::draw",WSCform_draw_mdr1);
+  }
+};
+static _gui_policy_register_ _run_register;
+#endif
+#endif
+
