@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSClocaleSet.h>
@@ -95,25 +95,24 @@ void WSClocaleSet::initialize(){
   }
 
   _init = True;
-  long locale_value = WSGIappCodeConvert()->getSystemLocale();
-
-  if (locale_value == WS_EN_NONE){
-fprintf(stderr,"ERROR: LANG not supported... using locale=C.\n");
-    locale_value = WS_EN_ISO8859_1;
-  }
+//  long locale_value = WSGIappCodeConvert()->getSystemLocale();
+//  if (locale_value == WS_EN_NONE){
+//fprintf(stderr,"ERROR: LANG not supported... using locale=C.\n");
+//    locale_value = WS_EN_ISO8859_1;
+//  }
 //printf("WSClocaleSet::initialize systemlocale=%s\n",WSGFgetLocaleName(locale_value));
   long i;
   long num = _locale_list.getNum();
   for(i=0; i<num; i++){
     WSClocale* locale = (WSClocale*)_locale_list[i];
-    if (locale != NULL && !strcmp(locale->getLocaleName(),WSGFgetLocaleName(locale_value))){
+    if (locale != NULL && !strcmp(locale->getLocaleName(),WSGIappCodeConvert()->getSystemLocaleName())){
       _default_locale = locale;
       break;
     }
   }
   if (_default_locale == NULL){
     _default_locale = new WSClocale();
-    _default_locale->setLocaleName(WSGFgetLocaleName(locale_value));
+    _default_locale->setLocaleName(WSGIappCodeConvert()->getSystemLocaleName());
     _locale_list.add((void*)_default_locale);
   }
 }
@@ -206,8 +205,8 @@ WSClocale::~WSClocale(){
 }
 void WSClocale::setLocaleName(char* lname){
 //printf("this=0x%x\n",this);
-//printf("WSClocale::setLocaleName #%s#\n",lname);
-  _locale = WSGFgetLocaleValue(lname);
+  _locale = WSGFgetEncoding(lname);
+//printf("WSClocale::setLocaleName #%s# %d\n",lname,_locale);
   if (_locale == WS_EN_NONE){
 //printf("WSClocale::setString Error encoding=%s not found.\n",index);
     _locale = WS_EN_ISO8859_1; 
@@ -243,7 +242,8 @@ char* WSClocale::getString(char* index,long encode){
     if (tmp.isExist(":WSSTR") <0){
     }else{
 //      if (!strcmp(getLocaleName(),"UTF8")){
-        WSClocale* locale = WSGIappLocaleSet()->getLocale(WSN_EN_ISO8859_1);
+//        WSClocale* locale = WSGIappLocaleSet()->getLocale(WSN_EN_ISO8859_1);
+        WSClocale* locale = WSGIappLocaleSet()->getLocale("en_US");
         if (locale != NULL && this != locale){
           return locale->getString(index,encode);
         }
@@ -279,15 +279,18 @@ fprintf(stderr,"ERROR. WSGFgettext locale C does not found.\n");
     }
   }
 //  return locale->getString(index,WSGIappLocaleSet()->getSystemLocaleEncoding());
-
+//printf("WSGFgettext %d index=%s %s\n",WSGIappLocaleSet()->getDefaultEncoding(),index,locale->getString(index,WSGIappLocaleSet()->getDefaultEncoding()));
   return locale->getString(index,WSGIappLocaleSet()->getDefaultEncoding());
 }
 long WSClocaleSet::getSystemLocaleEncoding(){
-  return WSGIappCodeConvert()->getSystemLocale();
+  return WSGIappCodeConvert()->getSystemEncoding();
+}
+char* WSClocaleSet::getSystemLocaleName(){
+  return WSGIappCodeConvert()->getSystemLocaleName();
 }
 long WSClocaleSet::getDefaultEncoding(){
   if (_encoding == WS_EN_LOCALE){
-    return WSGIappCodeConvert()->getSystemLocale();
+    return WSGIappCodeConvert()->getSystemEncoding();
   }
   return _encoding;
 }
@@ -297,3 +300,250 @@ void WSClocaleSet::setDefaultEncoding(long encoding){
 void WSGFsetDefaultEncoding(long en){
   WSGIappLocaleSet()->setDefaultEncoding(en);
 }
+
+WSDcodeConvert::WSDcodeConvert(){
+  strcpy(_locale_name,"en_US");
+}
+WSDcodeConvert::~WSDcodeConvert(){
+}
+
+void WSDcodeConvert::setSystemLocaleName(char* val,long encoding){
+  char buf[32];
+  strcpy(buf,val);
+  int i;
+  for(i=0; i<32; i++){
+    if (buf[i] == '.'){
+      buf[i] = 0;
+      break;
+    }
+  }
+  char* suffix = "";
+  if (encoding == WS_EN_UTF8){
+    suffix = ".utf8";
+  }
+  if (encoding == WS_EN_EUCJP){
+    strcpy(_locale_name,"ja_JP.eucjp");
+    return;
+  }
+  if (encoding == WS_EN_SJIS){
+    strcpy(_locale_name,"ja_JP.sjis");
+    return;
+  }
+  if (encoding == WS_EN_EUCKR){
+    strcpy(_locale_name,"ko_KR.euckr");
+    return;
+  }
+  if (encoding == WS_EN_EUCCN){
+    strcpy(_locale_name,"zh_CN");
+    return;
+  }
+  if (!strcmp(buf,"ja") && encoding == WS_EN_UTF8){
+    strcpy(_locale_name,"ja_JP.utf8");
+  }
+
+  if (!strcmp(buf,"") || !strcmp(buf,"C")){
+    strcpy(_locale_name,"en_US");
+  }else{
+    strcpy(_locale_name,buf);
+  }
+
+  if (!strcmp(buf,"es")){
+    strcpy(buf,"es_ES");
+  }
+  if (!strcmp(buf,"cs")){
+    strcpy(buf,"cs_CZ");
+  }
+  if (!strcmp(buf,"he")){
+    strcpy(buf,"he_IL");
+  }
+  if (!strcmp(buf,"hr")){
+    strcpy(buf,"hr_HR");
+  }
+  if (!strcmp(buf,"hu")){
+    strcpy(buf,"hu_HU");
+  }
+  if (!strcmp(buf,"pl")){
+    strcpy(buf,"pl_PL");
+  }
+  if (!strcmp(buf,"ro")){
+    strcpy(buf,"ro_RO");
+  }
+  if (!strcmp(buf,"ru")){
+    strcpy(buf,"ru_RU");
+  }
+  if (!strcmp(buf,"zh")){
+    strcpy(buf,"zh_CN");
+  }
+  if (!strcmp(buf,"af")){
+    strcpy(buf,"af_ZA");
+  }
+  if (!strcmp(buf,"be")){
+    strcpy(buf,"be_BY");
+  }
+  if (!strcmp(buf,"bg")){
+    strcpy(buf,"bg_BG");
+  }
+  if (!strcmp(buf,"br")){
+    strcpy(buf,"br_FR");
+  }
+  if (!strcmp(buf,"bs")){
+    strcpy(buf,"bs_BA");
+  }
+  if (!strcmp(buf,"ca")){
+    strcpy(buf,"ca_ES");
+  }
+  if (!strcmp(buf,"cy")){
+    strcpy(buf,"cy_GB");
+  }
+  if (!strcmp(buf,"da")){
+    strcpy(buf,"da_DK");
+  }
+  if (!strcmp(buf,"de")){
+    strcpy(buf,"de_DE");
+  }
+  if (!strcmp(buf,"el")){
+    strcpy(buf,"el_GR");
+  }
+  if (!strcmp(buf,"et")){
+    strcpy(buf,"et_EE");
+  }
+  if (!strcmp(buf,"eu")){
+    strcpy(buf,"eu_ES");
+  }
+  if (!strcmp(buf,"fa")){
+    strcpy(buf,"fa_IR");
+  }
+  if (!strcmp(buf,"fi")){
+    strcpy(buf,"fi_FI");
+  }
+  if (!strcmp(buf,"fo")){
+    strcpy(buf,"fo_FO");
+  }
+  if (!strcmp(buf,"fr")){
+    strcpy(buf,"fr_FR");
+  }
+  if (!strcmp(buf,"ga")){
+    strcpy(buf,"ga_IE");
+  }
+  if (!strcmp(buf,"gl")){
+    strcpy(buf,"gl_ES");
+  }
+  if (!strcmp(buf,"gv")){
+    strcpy(buf,"gv_GB");
+  }
+  if (!strcmp(buf,"hi")){
+    strcpy(buf,"hi_IN");
+  }
+  if (!strcmp(buf,"id")){
+    strcpy(buf,"id_ID");
+  }
+  if (!strcmp(buf,"is")){
+    strcpy(buf,"is_IS");
+  }
+  if (!strcmp(buf,"it")){
+    strcpy(buf,"it_IT");
+  }
+  if (!strcmp(buf,"iw")){
+    strcpy(buf,"iw_IL");
+  }
+  if (!strcmp(buf,"ka")){
+    strcpy(buf,"ka_GE");
+  }
+  if (!strcmp(buf,"kl")){
+    strcpy(buf,"kl_GL");
+  }
+  if (!strcmp(buf,"kw")){
+    strcpy(buf,"kw_GB");
+  }
+  if (!strcmp(buf,"lt")){
+    strcpy(buf,"lt_LT");
+  }
+  if (!strcmp(buf,"mi")){
+    strcpy(buf,"mi_NZ");
+  }
+  if (!strcmp(buf,"mk")){
+    strcpy(buf,"mk_MK");
+  }
+  if (!strcmp(buf,"mr")){
+    strcpy(buf,"mr_IN");
+  }
+  if (!strcmp(buf,"ms")){
+    strcpy(buf,"ms_MY");
+  }
+  if (!strcmp(buf,"mt")){
+    strcpy(buf,"mt_MT");
+  }
+  if (!strcmp(buf,"nl")){
+    strcpy(buf,"nl_NL");
+  }
+  if (!strcmp(buf,"nn")){
+    strcpy(buf,"nn_NO");
+  }
+  if (!strcmp(buf,"no")){
+    strcpy(buf,"no_NO");
+  }
+  if (!strcmp(buf,"oc")){
+    strcpy(buf,"oc_FR");
+  }
+  if (!strcmp(buf,"pt")){
+    strcpy(buf,"pt_PT");
+  }
+  if (!strcmp(buf,"se")){
+    strcpy(buf,"se_NO");
+  }
+  if (!strcmp(buf,"sk")){
+    strcpy(buf,"sk_SK");
+  }
+  if (!strcmp(buf,"sl")){
+    strcpy(buf,"sl_SI");
+  }
+  if (!strcmp(buf,"sq")){
+    strcpy(buf,"sq_AL");
+  }
+  if (!strcmp(buf,"sr")){
+    strcpy(buf,"sr_YU");
+  }
+  if (!strcmp(buf,"ta")){
+    strcpy(buf,"ta_IN");
+  }
+  if (!strcmp(buf,"tg")){
+    strcpy(buf,"tg_IN");
+  }
+  if (!strcmp(buf,"th")){
+    strcpy(buf,"th_TH");
+  }
+  if (!strcmp(buf,"tl")){
+    strcpy(buf,"tl_PH");
+  }
+  if (!strcmp(buf,"tr")){
+    strcpy(buf,"tr_TR");
+  }
+  if (!strcmp(buf,"uk")){
+    strcpy(buf,"uk_UA");
+  }
+  if (!strcmp(buf,"ur")){
+    strcpy(buf,"ur_PK");
+  }
+  if (!strcmp(buf,"uz")){
+    strcpy(buf,"uz_UZ");
+  }
+  if (!strcmp(buf,"vi")){
+    strcpy(buf,"vi_VN");
+  }
+  if (!strcmp(buf,"wa")){
+    strcpy(buf,"wa_BE");
+  }
+  if (!strcmp(buf,"yi")){
+    strcpy(buf,"yi_US");
+  }
+  strcpy(_locale_name,buf);
+  if (strcmp(suffix,"")){
+    long len = strlen(_locale_name);
+    strcpy(&_locale_name[len],suffix);
+  }
+}
+
+char* WSDcodeConvert::getSystemLocaleName(){
+  return _locale_name;
+}
+
