@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCoption.h>
@@ -37,6 +37,7 @@
 #include <WSDappDev.h>
 #include <WSCblink.h>
 #include <WSCbaseList.h>
+#include <WSCguiPolicy.h>
 
 WSMFguiClassInitialize(WSCoption, WSCvlabel);
 WSMFversion(WSCoption, WSCvlabel);
@@ -106,7 +107,7 @@ void WSCoption::setWorkWSNmenuItems(char* data){
     sect.replaceString(":","\n",0);
     long value;
     WSCstring sect_value = sect.getWord(1, "\n");
-    sscanf(sect_value.getString(), "%d", &value);
+    sscanf(sect_value.getString(), "%ld", &value);
 
     if (_value == value){
       WSCstring sect_str = sect.getWord(0, "\n");
@@ -134,7 +135,7 @@ void WSCoption::setWorkWSNvalue(long data){
 
     long val = 0;
     WSCstring sect_value = sect.getWord(1, "\n");
-    sscanf(sect_value.getString(), "%d", &val);
+    sscanf(sect_value.getString(), "%ld", &val);
 
     if (val == data){
       WSCstring sect_str = sect.getWord(0, "\n");
@@ -461,7 +462,7 @@ void WSCoption::onMouseRelease(WSCpoint* point){
 
           long val1 = 0;
           WSCstring sect_value = sect.getWord(1, "\n");
-          sscanf(sect_value.getString(), "%d", &val1);
+          sscanf(sect_value.getString(), "%ld", &val1);
 
           if (val1 == val) {
             if (_status_array[i] != False) {
@@ -555,7 +556,7 @@ long WSCoption::setSelectValue(long value, WSCbool flag){
     sect.replaceString(":","\n",0);
     WSCstring sect_value = sect.getWord(1, "\n");
     long val1 = 0;
-    sscanf(sect_value.getString(), "%d", &val1);
+    sscanf(sect_value.getString(), "%ld", &val1);
     if (val1 == value) {
 //printf("WSCoption::setItemSensitive no=%d fl=%d  %s\n",i,flag,getInstanceName());
       _status_array[i] = flag;
@@ -654,7 +655,7 @@ long WSCoption::getItemValue(long pos){
     long value;
     WSCstring sect = str.getWord(pos,",");
     WSCstring sect_value = sect.getWord(1, ":");
-    sscanf(sect_value.getString(), "%d", &value);
+    sscanf(sect_value.getString(), "%ld", &value);
     return value;
   }
   return 0;
@@ -682,3 +683,15 @@ void WSCoption::onGuiPolicyChange(long policy){
 char* WSCoption::getDefaultProperty(){
   return WSNvalue;
 }
+#ifdef WS_EMBED
+#ifndef NO_EXT_GUI_POLICY
+class _gui_policy_register_{
+  public: _gui_policy_register_(){
+extern void WSCoption_draw_mdr1(void*);
+    WSGIappGuiPolicy()->setExtGuiPolicyProc("Modern1","WSCoption::draw",WSCoption_draw_mdr1);
+  }
+};
+static _gui_policy_register_ _run_register;
+#endif
+#endif
+
