@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCstring.h>
@@ -616,7 +616,7 @@ long WSCstring::getWords(const char* sep,long encode){
   long seplen = strlen(sep);
   if (seplen < 1){
     if (encode != encoding){
-      delete sep;
+      delete (char*)sep;
     }
     return 1;
   }
@@ -630,7 +630,7 @@ long WSCstring::getWords(const char* sep,long encode){
     }
   }
   if (encode != encoding){
-    delete sep;
+    delete (char*)sep;
   }
   return cnt;
 }
@@ -660,7 +660,7 @@ WSCstring WSCstring::getWord(long pos,const char* sep,long encode){
   if (seplen < 1){
     _return_tmp.setString("",encoding);
     if (encode != encoding){
-      delete sep;
+      delete (char*)sep;
     } 
     return _return_tmp;
   }
@@ -678,7 +678,7 @@ WSCstring WSCstring::getWord(long pos,const char* sep,long encode){
         _return_tmp.setString(tmp,encoding);
         delete tmp;
         if (encode != encoding){
-          delete sep;
+          delete (char*)sep;
         } 
         return _return_tmp;
       }
@@ -696,13 +696,13 @@ WSCstring WSCstring::getWord(long pos,const char* sep,long encode){
     _return_tmp.setString(tmp,encoding);
     delete tmp;
     if (encode != encoding){
-      delete sep;
+      delete (char*)sep;
     } 
     return _return_tmp;
   }
   _return_tmp.setString("",encoding);
   if (encode != encoding){
-    delete sep;
+    delete (char*)sep;
   } 
   return _return_tmp;
 }
@@ -875,7 +875,7 @@ long WSCstring::isExist(const char* str,long encode){
   long len = strlen(text) - slen +1;
   if (len < 1){
     if (encoding != encode){
-      delete str;
+      delete (char*)str;
     }
     return -1;
   }
@@ -884,7 +884,7 @@ long WSCstring::isExist(const char* str,long encode){
     if (text[i] == str[0]){
       if ( !strncmp(&text[i],str,(size_t)slen) ){
         if (encoding != encode){
-          delete str;
+          delete (char*)str;
         }
         if (i == 0){
           return 0;
@@ -900,7 +900,7 @@ long WSCstring::isExist(const char* str,long encode){
     }
   }
   if (encoding != encode){
-    delete str;
+    delete (char*)str;
   }
   return -1;
 
