@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCvbtn.h>
@@ -38,6 +38,7 @@
 #include <WSCblink.h>
 #include <WSDappDev.h>
 #include <WSDmwindowDev.h>
+#include <WSCguiPolicy.h>
 
 WSMFguiClassInitialize(WSCvbtn, WSCvlabel);
 WSMFversion(WSCvbtn, WSCvlabel);
@@ -465,6 +466,7 @@ long WSCvbtn::draw(){
   short tsno         = _ts_color;
   short bsno         = _bs_color;
 
+#ifndef WS_EMBED
   if (policy & WS_POLICY_AQUA){
 //    WSDimage* image = WSGIappImageSet()->getImage(WS_AQUA_BTN_IMAGE);
 //    WSDimage* mask = WSGIappImageSet()->getImage(WS_AQUA_BTN_MASK_IMAGE);
@@ -493,7 +495,7 @@ long WSCvbtn::draw(){
       _mask_images[4] = (WSDmwindowDev*)((WSCulong)((WSCulong)w << 16 + h));
     }
   }
-
+#endif
 
   if ( shadowtype == WS_SHADOW_NONE &&
         blinking  != False &&
@@ -540,6 +542,7 @@ long WSCvbtn::draw(){
      _push_pixmap != -1 || _blink_pixmap != -1){
       dev->drawFillRect(0, 0, w, h);
     }else{
+#ifndef WS_EMBED
       if (_press_state != False) {
         _mask_images[2]->copyToWindowWithMask(dev,0,0,w,h,1,1,_mask_images[3]);
       }else if (_mouse_in != False){
@@ -549,6 +552,7 @@ long WSCvbtn::draw(){
       }else{
         _mask_images[0]->copyToWindowWithMask(dev,0,0,w,h,0,0,_mask_images[3]);
       }
+#endif
     }
   }else{
     if (_press_state == True) {
@@ -730,7 +734,7 @@ long WSCvbtn::draw(){
     }
     if (!(policy & WS_POLICY_AQUA)){
       // draw dashed focused line...
-      if (getFocus() != False && _ef_move != False) {
+      if (getFocus() != False && _ef_move != False && _focus_border != False) {
         if (w > 4 + st*2 && h > 4 + st*2) {
           // 褹ϣ˸
           dev->setLineWidth(0);
@@ -878,3 +882,16 @@ void WSCvbtn::onGuiPolicyChange(long policy){
     redraw();
   }
 }
+#ifdef WS_EMBED
+#ifndef NO_EXT_GUI_POLICY
+class _gui_policy_register_{
+  public: _gui_policy_register_(){
+extern void WSCvbtn_draw_mdr1(void*);
+    WSGIappGuiPolicy()->setExtGuiPolicyProc("Modern1","WSCvbtn::draw",WSCvbtn_draw_mdr1);
+  }
+};
+static _gui_policy_register_ _run_register;
+
+#endif
+#endif
+
