@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCvlabel.h>
@@ -154,7 +154,7 @@ WSMFproperty(WSCvlabel, WSNgradationMargin,    WSCuchar, _grad_margin,  0  );
 void WSCvlabel::setWorkWSNshadowThickness(WSCuchar){}
 void WSCvlabel::getWorkWSNshadowThickness(WSCuchar*){}
 void WSCvlabel::setWorkWSNshadowType(char stype){
-  if (_use_pix != False && stype == WS_SHADOW_TRANS){
+  if (_use_pix != False && stype == (char)WS_SHADOW_TRANS){
     WSCbool fl = False;
     _use_pix = False;
     if (_dev != NULL){
@@ -353,10 +353,9 @@ dbprintf("WSCvlabel::draw %s:%d %s not ready..\n",__FILE__,__LINE__,getInstanceN
       xx = 0;
     }
   }
-
   WSCbase::update();
   setAbsoluteDraw(False);
-  if (shadowtype != (char)WS_SHADOW_TRANS) {
+  if (shadowtype != WS_SHADOW_TRANS) {
     if (_rv_fl == True) {
       if (bldraw && blinktype != WS_FORE ){
         dev->setForeColor(blinkcolorno);
