@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCvtoggle.h>
@@ -38,6 +38,7 @@
 #include <WSCbaseList.h>
 #include <WSCblink.h>
 #include <WSDappDev.h>
+#include <WSCguiPolicy.h>
 
 WSMFguiClassInitialize(WSCvtoggle, WSCvlabel);
 WSMFversion(WSCvtoggle, WSCvlabel);
@@ -923,7 +924,7 @@ long WSCvtoggle::setGroupValue(long value){
     if (_group_name != NULL && _group_name[0] != 0 && 
        !strcmp(tgl->_group_name, _group_name) ){
        short id = tgl->_id;
-       if (_unique == True){ //ξ
+       if (_unique == True){ //ξ...
          WSCbool ubak = tgl->_unique;
          tgl->_unique = False;
          if (id == value){
@@ -941,7 +942,7 @@ long WSCvtoggle::setGroupValue(long value){
          tgl->setAbsoluteDraw(True);
          tgl->needUpdate();
          tgl->draw();
-       }else{      //¿Ťξ
+       }else{      //¿Ťξ...
          long vl;
          if (id >-1 && id < 32){
            vl = (1 << (id-1));
@@ -984,4 +985,15 @@ void WSCvtoggle::onGuiPolicyChange(long policy){
     redraw();
   }
 }
+#ifdef WS_EMBED
+#ifndef NO_EXT_GUI_POLICY
+class _gui_policy_register_{
+  public: _gui_policy_register_(){
+extern void WSCvtoggle_draw_mdr1(void*);
+    WSGIappGuiPolicy()->setExtGuiPolicyProc("Modern1","WSCvtoggle::draw",WSCvtoggle_draw_mdr1);
+  }
+};
+static _gui_policy_register_ _run_register;
+#endif
+#endif
 
