@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCwindow.h>
@@ -634,12 +634,14 @@ dbprintf("WSCwindow::draw %s:%d %s not ready\n",__FILE__,__LINE__,getInstanceNam
     if (_grad_no == 0){
       dev->setForeColor(_bg_no);
       dev->drawFillRect(0,0,_w,_h);
+#ifndef WS_EMBED
       if ((WSGIappDev()->getGuiPolicy() & WS_POLICY_AQUA) != 0 && _bp_no == -1){
         if (_a1_color == -1){
           WSGFgetShadowColor(_bg_no,&_a1_color,&_a2_color,&_a3_color);
         }
         WSGFdrawStripes(dev,_w,_h,_a1_color,_a2_color,_a3_color);
       }
+#endif
       dev->setForeColor(_bg_no);
     }else{
       dev->drawGradation(_grad_no,_ts_no,_bg_no,_bs_no,0,0,_w,_h,_grad_margin);
@@ -739,12 +741,14 @@ void WSCwindow::onResize(WSCrect* area){
   if (getPropertyEditMode() != False){
     drawGriphand();
     if (fl != False){
+#ifndef WS_EMBED
       WSGFmarkChanged(this);
       WSCbase* prope = WSGIappPropertyEditor();
       if (prope != NULL){
         prope->setUserData(WS_GEOMETRY_UPDATE,(void*)1);
         prope->update();
       }
+#endif
     }
   }
   if (fl != False){
@@ -826,7 +830,7 @@ void WSCwindow::onVisibleChange(WSCbool fl){
         }
         if (no_exit == 0){
           if (WSGIappDev()->getMode() == WS_MODE_NORMAL){
-            exit(0);
+            WSGFexit(0);
           }
         }
       }
