@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSDkeyboard.h>
@@ -86,6 +86,7 @@ WSCbool WSDkeyboard::getFepStatus(){
 //}
 
 void WSDkeyboard::setPositionModeWindow(short x,short y){
+#ifndef WS_EMBED
    if (_status_win == NULL){
      _status_win = new WSCballoonHelp(NULL,"mode win");
      _status_win->initialize();
@@ -102,6 +103,7 @@ void WSDkeyboard::setPositionModeWindow(short x,short y){
      _status_win->setPropertyV(WSNx,x);
      _status_win->setPropertyV(WSNy,y);
    }
+#endif
 }
 
 void WSDkeyboard::_mode_win_move(WSCbase* obj){
@@ -125,6 +127,7 @@ void WSDkeyboard::_mode_win_move(WSCbase* obj){
 }
 
 void WSDkeyboard::setVisibleModeWindow(WSCbool fl){
+#ifndef WS_EMBED
    if (_status_win == NULL){
      _status_win = new WSCballoonHelp(NULL,"mode win");
      _status_win->initialize();
@@ -139,13 +142,16 @@ void WSDkeyboard::setVisibleModeWindow(WSCbool fl){
      _status_win->addProcedure(ac);
    }
    _status_win->setVisible(fl);
+#endif
 }
 
 void WSDkeyboard::setModeString(char* str){
+#ifndef WS_EMBED
   if (_status_win != NULL){
     _status_win->setString(str);
     _status_win->redraw();
   }
+#endif
 }
 
 long WSDkeyboard::initialize(){
