@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WSDfont.h>
 #include <WSCfontSet.h>
@@ -1077,230 +1077,230 @@ long WSDpsdraw::outputFooter(){
   return WS_NO_ERR;
 }
 
-char* ws_ps_header = "\
-/ws_dict 6 dict def\n\
-ws_dict begin\n\
-/copyfont {\n\
-    dup maxlength 1 add dict begin\n\
-    {\n\
-        1 index /FID ne 2 index /UniqueID ne and\n\
-        {def} {pop pop} ifelse\n\
-    } forall\n\
-    currentdict\n\
-    end\n\
-} bind def\n\
-/eucfont {\n\
-    12 dict begin\n\
-        dup type /nametype eq { findfont } if\n\
-        dup /WMode known {\n\
-            dup /WMode get /WMode exch def\n\
-            WMode 1 eq {\n\
-                [0.0 1.0 -1.0 0.0 0.0 0.30] makefont\n\
-            } if\n\
-        } if\n\
-        copyfont dup begin\n\
-            /Encoding Encoding\n\
-            FMapType dup 2 eq {\n\
-                pop 128 128\n\
-            } { 5 eq {\n\
-                256 256\n\
-            } {\n\
-                /compositefont errordict /invalidfont get exec\n\
-            } ifelse\n\
-            } ifelse\n\
-            getinterval def\n\
-        end\n\
-        /kanjifont exch definefont\n\
-        exch\n\
-        dup type /nametype eq { findfont } if\n\
-        exch\n\
-        /FDepVector [ 4 2 roll ] def\n\
-        /FontType 0 def\n\
-        /FMapType 4 def\n\
-        /FontMatrix matrix def\n\
-        /Encoding [ 0 1 ] def\n\
-        /FontBBox {0 0 0 0} def\n\
-        dup /FontName exch def\n\
-        currentdict\n\
-    end\n\
-    definefont pop\n\
-} def\n\
-\n\
-/ws_ellipsedict 6 dict def\n\
-ws_ellipsedict /mtrx matrix put\n\
-\n\
-/ws_ellipse\n\
- { ws_ellipsedict begin\n\
-      /yrad exch def\n\
-      /xrad exch def\n\
-      /y exch def\n\
-      /x exch def\n\
-      /savematrix mtrx currentmatrix def\n\
-      x y translate\n\
-      xrad yrad scale\n\
-      0 0 1 0 360 arc\n\
-      savematrix setmatrix\n\
-   end\n\
- } def\n\
-\n\
-/ws_arcdict 8 dict def\n\
-ws_arcdict /mtrx matrix put\n\
-\n\
-/ws_arcn\n\
- { ws_arcdict begin\n\
-      /endangle exch def\n\
-      /startangle exch def\n\
-      /yrad exch def\n\
-      /xrad exch def\n\
-      /y exch def\n\
-      /x exch def\n\
-      /savematrix mtrx currentmatrix def\n\
-      x y translate\n\
-      xrad yrad scale\n\
-      0 0 1 startangle endangle arc\n\
-      savematrix setmatrix\n\
-   end\n\
- } def\n\
-\n\
-/ws_arc\n\
- { ws_arcdict begin\n\
-      /endangle exch def\n\
-      /startangle exch def\n\
-      /yrad exch def\n\
-      /xrad exch def\n\
-      /y exch def\n\
-      /x exch def\n\
-      /savematrix mtrx currentmatrix def\n\
-      x y translate\n\
-      xrad yrad scale\n\
-      0 0 1 startangle endangle arcn\n\
-      savematrix setmatrix\n\
-   end\n\
- } def\n\
-\n\
-/ws_hatchdict 10 dict def\n\
-\n\
-/ws_hatchbyte\n\
- { currentdict /retstr get exch\n\
-   hatch i cellsz mod get put\n\
- } def\n\
-\n\
-/ws_hatchproc\n\
- { 0 1 widthlim {ws_hatchbyte} for retstr\n\
-   /i i 1 add def\n\
- } def\n\
-\n\
-/ws_hatchfill\n\
- { ws_hatchdict begin\n\
-      /h exch def\n\
-      /w exch def\n\
-      /lty exch def\n\
-      /ltx exch def\n\
-      /cellsz exch def\n\
-      /hatch exch def\n\
-      /widthlim w cellsz div cvi 1 sub def\n\
-      /retstr widthlim 1 add string def\n\
-      /i 0 def\n\
-      ws_origctm setmatrix\n\
-      ltx lty translate\n\
-      w h true [1 0 0 1 0 0] {ws_hatchproc} imagemask\n\
-      ltx neg lty neg translate\n\
-   end\n\
- } def\n\
-\n\
-/hatch1 <0102040810204080> def\n\
-/hatch2 <8040201008040201> def\n\
-/hatch3 <9999999999999999> def\n\
-/hatch4 <ff0000ffff0000ff> def\n\
-/hatch5 <9966669999666699> def\n\
-/hatch6 <ff6666ffff6666ff> def\n\
-/hatch7 <0066660000666600> def\n\
-\n\
-/ws_imgdict 4 dict def\n\
-/ws_bwpicstr 1 string def\n\
-/ws_colorpicstr 3 string def\n\
-/ws_setpixels { ws_imgdict begin /pixels exch def end } def\n\
-/ws_setpix { ws_imgdict begin pixels 3 1 roll putinterval end } def\n\
-/ws_colorspot\n\
- { ws_imgdict begin\n\
-      /index exch def\n\
-      pixels index 3 mul 3 getinterval aload pop\n\
-      255 mul cvi ws_colorpicstr 2 3 -1 roll put\n\
-      255 mul cvi ws_colorpicstr 1 3 -1 roll put\n\
-      255 mul cvi ws_colorpicstr 0 3 -1 roll put\n\
-      ws_colorpicstr\n\
-   end\n\
- } def\n\
-/ws_newcolorspot\n\
- { ws_imgdict begin\n\
-      /index exch def\n\
-      pixels index 3 mul 3 getinterval aload pop setrgbcolor\n\
-   end\n\
- } def\n\
-/ws_colordict 4 dict def\n\
-/colorimage where\n\
- { pop }\n\
- { /colorimage\n\
-   { ws_colordict begin\n\
-        pop pop pop pop pop\n\
-        /ih exch def\n\
-        /iw exch def\n\
-        /x 0 def\n\
-        /y 0 def\n\
-        1 1 ih\n\
-         { pop 1 1 iw\n\
-            { pop currentfile\n\
-              ws_bwpicstr readhexstring pop 0 get ws_newcolorspot\n\
-              x y moveto 1 0 rlineto 0 1 rlineto -1 0 rlineto\n\
-              closepath fill\n\
-              /x x 1 add def\n\
-            } for\n\
-           /y y 1 add def\n\
-           /x 0 def\n\
-         } for\n\
-     end\n\
-   } def\n\
- } ifelse\n\
-\n\
-/ws_transcolorspot\n\
- { ws_imgdict begin\n\
-      /index exch def\n\
-      pixels index 3 mul 3 getinterval aload pop\n\
-      dup 0 lt { pop pop pop false } { setrgbcolor true } ifelse\n\
-   end\n\
- } def\n\
-\n\
-/ws_transcolorimage\n\
- { ws_colordict begin\n\
-      pop pop pop pop pop\n\
-      /ih exch def\n\
-      /iw exch def\n\
-      /x 0 def\n\
-      /y 0 def\n\
-      1 1 ih\n\
-       { pop 1 1 iw\n\
-          { pop currentfile\n\
-            ws_bwpicstr readhexstring pop 0 get ws_transcolorspot\n\
-            { x y moveto 1 0 rlineto 0 1 rlineto -1 0 rlineto\n\
-              closepath fill\n\
-            }\n\
-            if\n\
-            /x x 1 add def\n\
-          } for\n\
-         /y y 1 add def\n\
-         /x 0 def\n\
-       } for\n\
-   end\n\
- } def\n\
-\n\
-\n\
-end\n\
-\n\
-ws_dict begin\n\
-/ws_savedpage save def\n\
-1 setmiterlimit\n\
-1 setlinewidth\n\
-0 setgray\n";
+char* ws_ps_header = ""
+"/ws_dict 6 dict def\n"
+"ws_dict begin\n"
+"/copyfont {\n"
+"    dup maxlength 1 add dict begin\n"
+"    {\n"
+"        1 index /FID ne 2 index /UniqueID ne and\n"
+"        {def} {pop pop} ifelse\n"
+"    } forall\n"
+"    currentdict\n"
+"    end\n"
+"} bind def\n"
+"/eucfont {\n"
+"    12 dict begin\n"
+"        dup type /nametype eq { findfont } if\n"
+"        dup /WMode known {\n"
+"            dup /WMode get /WMode exch def\n"
+"            WMode 1 eq {\n"
+"                [0.0 1.0 -1.0 0.0 0.0 0.30] makefont\n"
+"            } if\n"
+"        } if\n"
+"        copyfont dup begin\n"
+"            /Encoding Encoding\n"
+"            FMapType dup 2 eq {\n"
+"                pop 128 128\n"
+"            } { 5 eq {\n"
+"                256 256\n"
+"            } {\n"
+"                /compositefont errordict /invalidfont get exec\n"
+"            } ifelse\n"
+"            } ifelse\n"
+"            getinterval def\n"
+"        end\n"
+"        /kanjifont exch definefont\n"
+"        exch\n"
+"        dup type /nametype eq { findfont } if\n"
+"        exch\n"
+"        /FDepVector [ 4 2 roll ] def\n"
+"        /FontType 0 def\n"
+"        /FMapType 4 def\n"
+"        /FontMatrix matrix def\n"
+"        /Encoding [ 0 1 ] def\n"
+"        /FontBBox {0 0 0 0} def\n"
+"        dup /FontName exch def\n"
+"        currentdict\n"
+"    end\n"
+"    definefont pop\n"
+"} def\n"
+"\n"
+"/ws_ellipsedict 6 dict def\n"
+"ws_ellipsedict /mtrx matrix put\n"
+"\n"
+"/ws_ellipse\n"
+" { ws_ellipsedict begin\n"
+"      /yrad exch def\n"
+"      /xrad exch def\n"
+"      /y exch def\n"
+"      /x exch def\n"
+"      /savematrix mtrx currentmatrix def\n"
+"      x y translate\n"
+"      xrad yrad scale\n"
+"      0 0 1 0 360 arc\n"
+"      savematrix setmatrix\n"
+"   end\n"
+" } def\n"
+"\n"
+"/ws_arcdict 8 dict def\n"
+"ws_arcdict /mtrx matrix put\n"
+"\n"
+"/ws_arcn\n"
+" { ws_arcdict begin\n"
+"      /endangle exch def\n"
+"      /startangle exch def\n"
+"      /yrad exch def\n"
+"      /xrad exch def\n"
+"      /y exch def\n"
+"      /x exch def\n"
+"      /savematrix mtrx currentmatrix def\n"
+"      x y translate\n"
+"      xrad yrad scale\n"
+"      0 0 1 startangle endangle arc\n"
+"      savematrix setmatrix\n"
+"   end\n"
+" } def\n"
+"\n"
+"/ws_arc\n"
+" { ws_arcdict begin\n"
+"      /endangle exch def\n"
+"      /startangle exch def\n"
+"      /yrad exch def\n"
+"      /xrad exch def\n"
+"      /y exch def\n"
+"      /x exch def\n"
+"      /savematrix mtrx currentmatrix def\n"
+"      x y translate\n"
+"      xrad yrad scale\n"
+"      0 0 1 startangle endangle arcn\n"
+"      savematrix setmatrix\n"
+"   end\n"
+" } def\n"
+"\n"
+"/ws_hatchdict 10 dict def\n"
+"\n"
+"/ws_hatchbyte\n"
+" { currentdict /retstr get exch\n"
+"   hatch i cellsz mod get put\n"
+" } def\n"
+"\n"
+"/ws_hatchproc\n"
+" { 0 1 widthlim {ws_hatchbyte} for retstr\n"
+"   /i i 1 add def\n"
+" } def\n"
+"\n"
+"/ws_hatchfill\n"
+" { ws_hatchdict begin\n"
+"      /h exch def\n"
+"      /w exch def\n"
+"      /lty exch def\n"
+"      /ltx exch def\n"
+"      /cellsz exch def\n"
+"      /hatch exch def\n"
+"      /widthlim w cellsz div cvi 1 sub def\n"
+"      /retstr widthlim 1 add string def\n"
+"      /i 0 def\n"
+"      ws_origctm setmatrix\n"
+"      ltx lty translate\n"
+"      w h true [1 0 0 1 0 0] {ws_hatchproc} imagemask\n"
+"      ltx neg lty neg translate\n"
+"   end\n"
+" } def\n"
+"\n"
+"/hatch1 <0102040810204080> def\n"
+"/hatch2 <8040201008040201> def\n"
+"/hatch3 <9999999999999999> def\n"
+"/hatch4 <ff0000ffff0000ff> def\n"
+"/hatch5 <9966669999666699> def\n"
+"/hatch6 <ff6666ffff6666ff> def\n"
+"/hatch7 <0066660000666600> def\n"
+"\n"
+"/ws_imgdict 4 dict def\n"
+"/ws_bwpicstr 1 string def\n"
+"/ws_colorpicstr 3 string def\n"
+"/ws_setpixels { ws_imgdict begin /pixels exch def end } def\n"
+"/ws_setpix { ws_imgdict begin pixels 3 1 roll putinterval end } def\n"
+"/ws_colorspot\n"
+" { ws_imgdict begin\n"
+"      /index exch def\n"
+"      pixels index 3 mul 3 getinterval aload pop\n"
+"      255 mul cvi ws_colorpicstr 2 3 -1 roll put\n"
+"      255 mul cvi ws_colorpicstr 1 3 -1 roll put\n"
+"      255 mul cvi ws_colorpicstr 0 3 -1 roll put\n"
+"      ws_colorpicstr\n"
+"   end\n"
+" } def\n"
+"/ws_newcolorspot\n"
+" { ws_imgdict begin\n"
+"      /index exch def\n"
+"      pixels index 3 mul 3 getinterval aload pop setrgbcolor\n"
+"   end\n"
+" } def\n"
+"/ws_colordict 4 dict def\n"
+"/colorimage where\n"
+" { pop }\n"
+" { /colorimage\n"
+"   { ws_colordict begin\n"
+"        pop pop pop pop pop\n"
+"        /ih exch def\n"
+"        /iw exch def\n"
+"        /x 0 def\n"
+"        /y 0 def\n"
+"        1 1 ih\n"
+"         { pop 1 1 iw\n"
+"            { pop currentfile\n"
+"              ws_bwpicstr readhexstring pop 0 get ws_newcolorspot\n"
+"              x y moveto 1 0 rlineto 0 1 rlineto -1 0 rlineto\n"
+"              closepath fill\n"
+"              /x x 1 add def\n"
+"            } for\n"
+"           /y y 1 add def\n"
+"           /x 0 def\n"
+"         } for\n"
+"     end\n"
+"   } def\n"
+" } ifelse\n"
+"\n"
+"/ws_transcolorspot\n"
+" { ws_imgdict begin\n"
+"      /index exch def\n"
+"      pixels index 3 mul 3 getinterval aload pop\n"
+"      dup 0 lt { pop pop pop false } { setrgbcolor true } ifelse\n"
+"   end\n"
+" } def\n"
+"\n"
+"/ws_transcolorimage\n"
+" { ws_colordict begin\n"
+"      pop pop pop pop pop\n"
+"      /ih exch def\n"
+"      /iw exch def\n"
+"      /x 0 def\n"
+"      /y 0 def\n"
+"      1 1 ih\n"
+"       { pop 1 1 iw\n"
+"          { pop currentfile\n"
+"            ws_bwpicstr readhexstring pop 0 get ws_transcolorspot\n"
+"            { x y moveto 1 0 rlineto 0 1 rlineto -1 0 rlineto\n"
+"              closepath fill\n"
+"            }\n"
+"            if\n"
+"            /x x 1 add def\n"
+"          } for\n"
+"         /y y 1 add def\n"
+"         /x 0 def\n"
+"       } for\n"
+"   end\n"
+" } def\n"
+"\n"
+"\n"
+"end\n"
+"\n"
+"ws_dict begin\n"
+"/ws_savedpage save def\n"
+"1 setmiterlimit\n"
+"1 setlinewidth\n"
+"0 setgray\n";
 
 char* ws_ps_header2 = "\
 gsave\n\
