@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSDserialize.h>
@@ -68,6 +68,9 @@ WSCserializeData::~WSCserializeData(){
 };
 
 long WSCserializeData::size(){
+#ifdef NO_FILE_SERIALIZE
+  return 0;
+#else
    long ret = 1; //data_name_len
 
    if (_data_name != NULL){
@@ -91,9 +94,13 @@ long WSCserializeData::size(){
      ret += cdata->size();
    }
    return ret;
+#endif
 };
 
 long WSCserializeData::write(WSDserialize* serialize){
+#ifdef NO_FILE_SERIALIZE
+  return 0;
+#else
 //printf("WSCserializeData::write len=%d %d\n",sizeof(char),_data_name_len);
   serialize->_write(&_data_name_len,sizeof(char));
 //printf("WSCserializeData::write len=%d #%s#\n",_data_name_len,_data_name);
@@ -122,9 +129,13 @@ long WSCserializeData::write(WSDserialize* serialize){
     long ret = serialize->_write(_data,_data_len);
     return ret;
   }
+#endif
 };
 
 long WSCserializeData::read(WSDserialize* serialize){
+#ifdef NO_FILE_SERIALIZE
+  return 0;
+#else
 //printf("WSCserializeData::read read start size=%d\n",sizeof(char));
   long len = serialize->_read(&_data_name_len,sizeof(char));
 //printf("WSCserializeData::read len=%d %d\n",len,_data_name_len);
@@ -208,6 +219,7 @@ long WSCserializeData::read(WSDserialize* serialize){
     }
     return ret;
   }
+#endif
 };
 
 
@@ -241,6 +253,9 @@ void WSDserialize::setPath(char* path){
 }
 
 long WSDserialize::_write_data(WSCserializeData* dt,char* type,void* data, long items){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOTYPE;
+#else
   if (dt->_data != NULL){
       delete (char*)dt->_data;
       dt->_data = NULL;
@@ -393,9 +408,13 @@ long WSDserialize::_write_data(WSCserializeData* dt,char* type,void* data, long
     _current_data = bk;
   }
   return WS_NO_ERR;
+#endif
 }
 
 long WSDserialize::_write_sub_class(WSCserializeData* dt,char* type,void* data,long items){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOTYPE;
+#else
 
   WSCtypeServer* sv = WSGIconductor()->searchTypeServer(type);
   if (sv == NULL){
@@ -422,9 +441,13 @@ long WSDserialize::_write_sub_class(WSCserializeData* dt,char* type,void* data,l
   svh(this,data); //ϥɥǥ
   _current_data = bk;
   return WS_NO_ERR;
+#endif
 }
 
 long WSDserialize::_save(WSClistData* dt_list,char* type,char* name,void* data){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR;
+#else
 
   long num = dt_list->getNum();
   long i;
@@ -457,9 +480,13 @@ long WSDserialize::_save(WSClistData* dt_list,char* type,char* name,void* data){
    dt_list->add(dt);
   _write_data(dt,type,data,1);
   return WS_NO_ERR;
+#endif
 }
 
 long WSDserialize::save(char* type,char* name,void* data){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR;
+#else
   if (_use_socket != False){
     WSClistData tmp_list;
     _current_data = NULL;
@@ -478,6 +505,7 @@ long WSDserialize::save(char* type,char* name,void* data){
   _need_save = True;
   _current_data = NULL;
   return _save(&_data_list,type,name,data);
+#endif
 }
 
 long WSDserialize::saveData(char* type,char* name,void* data){
@@ -486,6 +514,9 @@ long WSDserialize::saveData(char* type,char* name,void* data){
 }
 
 long WSDserialize::_read_data(WSCserializeData* dt,char* type,void* data, long items){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOTYPE;
+#else
   if (type[0] == '#'){
     if (!strcmp(type,WS_DcRString)){
       //TEST  //array ̤б
@@ -589,10 +620,13 @@ long WSDserialize::_read_data(WSCserializeData* dt,char* type,void* data, long i
     _current_data = bk;
   }
   return WS_NO_ERR;
+#endif
 }
 
 long WSDserialize::_read_sub_class(WSCserializeData* dt,char* type,void* data,long items){
-
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOTYPE;
+#else
   WSCtypeServer* sv = WSGIconductor()->searchTypeServer(type);
   if (sv == NULL){
     return WS_ERR_NOTYPE;
@@ -618,10 +652,14 @@ long WSDserialize::_read_sub_class(WSCserializeData* dt,char* type,void* data,lo
   lvh(this,data); //ϥɥǥ
   _current_data = bk;
   return WS_NO_ERR;
+#endif
 }
 
 
 long WSDserialize::_load(WSCserializeData* pdt,WSClistData* dt_list,char* type,char* name,void* data){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOOBJ;
+#else
   long num = dt_list->getNum();
 //printf("here0..num=%d\n",num);
   long i;
@@ -660,11 +698,14 @@ long WSDserialize::_load(WSCserializeData* pdt,WSClistData* dt_list,char* type,c
       return WS_NO_ERR;
     }
   }
-
   return WS_ERR_NOOBJ;
+#endif
 }
 
 long WSDserialize::load(char* type,char* name,void* data){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOOBJ;
+#else
   if (_use_socket){
     _current_data = NULL;
     WSCserializeData* dt = new WSCserializeData();
@@ -680,13 +721,21 @@ long WSDserialize::load(char* type,char* name,void* data){
 
   _current_data = NULL;
   return _load(NULL,&_data_list,type,name,data);
+#endif
 }
 
 long WSDserialize::loadData(char* type,char* name,void* data){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOOBJ;
+#else
   return _load(_current_data,&_current_data->_children,type,name,data);
+#endif
 }
 
 long WSDserialize::_load_alloc(WSCserializeData* pdt,WSClistData* dt_list,char* type,char* name,void** ptr,void* construct_data){
+#ifdef NO_FILE_SERIALIZE
+   return WS_ERR_NOTYPE;
+#else
   long num = dt_list->getNum();
   long i;
   WSCulong cpoint = 0;
@@ -805,9 +854,13 @@ long WSDserialize::_load_alloc(WSCserializeData* pdt,WSClistData* dt_list,char*
   //Ƹʤ
   pdt->_cache_ptr = 0;
   return _load_alloc(pdt,dt_list, type, name, ptr, construct_data);
+#endif
 }
 
 long WSDserialize::loadAlloc(char* type,char* name,void** ptr,void* construct_data){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOOBJ;
+#else
   if (_use_socket){
     _current_data = NULL;
     WSCserializeData* dt = new WSCserializeData();
@@ -824,22 +877,38 @@ long WSDserialize::loadAlloc(char* type,char* name,void** ptr,void* construct_da
 
   _current_data = NULL;
   return _load_alloc(NULL,&_data_list,type,name,ptr,construct_data);
+#endif
 }
 
 long WSDserialize::loadAllocData(char* type,char* name,void** ptr,void* construct_data){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOOBJ;
+#else
   return _load_alloc(_current_data,&_current_data->_children,type,name,ptr,construct_data);
+#endif
 }
 
 long WSDserialize::searchInstance(char* type,char mode,char*** otype,char*** onames,long* num){
   _current_data = NULL;
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOOBJ;
+#else
   return _search_instance(&_data_list,type,mode,otype,onames,num);
+#endif
 }
 
 long WSDserialize::searchInstanceData(char* type,char mode,char*** otype,char*** onames,long* num){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOOBJ;
+#else
   return _search_instance(&_current_data->_children,type,mode,otype,onames,num);
+#endif
 }
 
 long WSDserialize::_search_instance(WSClistData* dt_list,char* type,char mode,char*** otype,char*** onames,long* num){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR_NOOBJ;
+#else
   long n = dt_list->getNum();
   long i;
   WSClistData nlist;
@@ -863,21 +932,21 @@ long WSDserialize::_search_instance(WSClistData* dt_list,char* type,char mode,ch
       }
     }
     if ( !strcmp(type,target_type)){ 
-    //ƱǤ
+    //ƱǤ ....
        nlist.add(type);
        clist.add(dt->_data_name);
     }else if ( target_type[0] == '#' ){ 
-    //C++ ɤηʤФ
+    //C++ ɤηʤФ ...
        continue;
 
     }else if ( mode == WS_SEARCH_INHERIT ){
-       //ѾطθڤԤäƤߤ
+       //ѾطθڤԤäƤߤ ...
        WSCtypeServer* sv = WSGIconductor()->searchTypeServer(target_type);
        if (sv == NULL){
           continue;
        }
        if (sv->isParentClass(type) != False){
-       //Ѿطä
+       //Ѿطä ...
          clist.add(target_type);
          nlist.add(dt->_data_name);
        }
@@ -900,6 +969,7 @@ long WSDserialize::_search_instance(WSClistData* dt_list,char* type,char mode,ch
     *onames = 0;
     return WS_ERR_NOOBJ;
   }
+#endif
 }
 
 WSCbool WSDserialize::underTransaction(){
@@ -915,6 +985,9 @@ void WSDserialize::setUnderTransaction(WSCbool fl){
 }
 
 long WSDserialize::beginTransaction(char* field){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR;
+#else
   _field.setString(field);
   long ret = _open(field,WS_RW);
   if (ret != WS_NO_ERR){
@@ -939,9 +1012,13 @@ long WSDserialize::beginTransaction(char* field){
   }
 
   return WS_NO_ERR;
+#endif
 }
 
 long WSDserialize::endTransaction(){
+#ifdef NO_FILE_SERIALIZE
+  return WS_ERR;
+#else
   if (_need_save == False){
     return WS_NO_ERR;
   }
@@ -966,5 +1043,6 @@ long WSDserialize::endTransaction(){
   _data_list.clear();
   _close();
   return WS_NO_ERR;
+#endif
 }
 
