@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #if defined (BTRON)  || defined (TE)
 #include <basic.h>
@@ -55,7 +55,9 @@
 #include <time.h>
 #include <sys/time.h>
 #else
+#ifndef _WSWINCE
 #include <sys\timeb.h>
+#endif
 #include <time.h>
 #endif
 
@@ -65,6 +67,12 @@ extern "C" {
 };
 #endif
 
+#ifdef _WSWINCE
+char* getenv(char* val){
+//  return "";
+  return NULL;
+}
+#endif
 extern "C" {
 void libws_func();
 };
@@ -143,7 +151,7 @@ void WSGFsetGeometry(WSCbase* base,short x,short y,WSCushort w,WSCushort h){
   base->setPropertyV(WSNwidth,w);
   base->setPropertyV(WSNheight,h);
 }
-
+#ifndef WS_EMBED
 void _stretch_timer_proc(void* ptr){
   WSCbase* obj = (WSCbase*)ptr;
   WSCushort val = (WSCushort)((long)obj->getUserData("size"));
@@ -314,6 +322,7 @@ void WSGFcleanupStretchAction(WSCbase* obj){
 
   obj->setUserData("stretch-timer2",NULL);
 }
+
 void WSGFgetAllPropertyList(WSCbase* client,WSClistData* out){
   WSCclassInformation* inf = client->getClassInformation();
   WSClistData* property_list1 = inf->getAllPropertyList();
@@ -354,6 +363,7 @@ void WSGFgetAllPropertyList(WSCbase* client,WSClistData* out){
     }
   }
 }
+#endif
 
 //high speed strcmp
 inline long WSGFstrcmp(char* x,char* y){
@@ -370,30 +380,10 @@ inline long WSGFstrcmp(char* x,char* y){
   } while (p1 == p2);
   return p1 -p2;
 }
+#ifndef WS_EMBED
 long WSGFsendMessage(char* message,char* data){
   return WSDmessage::extSendMessage(NULL,message,data);
 }
-#if 0
-#define WS_SEND_LEN 15
-long WSGFsendMessage(char* message,char* data){
-  if (data == NULL){
-    data = "";
-  }
-  long ptr = 0;
-  char buf[WS_SEND_LEN +1];
-  long len = strlen(data);
-  while(1){
-    strncpy(buf,&data[ptr],WS_SEND_LEN);
-    buf[WS_SEND_LEN] = 0;
-//printf("WSGFsendMessage send:#%s#\n",buf);
-    WSDmessage::extSendMessage(NULL,message,buf);
-    ptr+= WS_SEND_LEN;
-    if (ptr+1 > len){
-      break;
-    }
-  }
-  return WS_NO_ERR;
-}
 #endif
 static void (*_app_base_chandler)(WSCbase*) = NULL;
 void WSGFsetCreateHandler(void (*hd)(WSCbase*) ){
@@ -419,6 +409,7 @@ static long (*_exist_name_handler)(char*,WSCbase*) = NULL;
 // ret = WS_OBJECT_NAME         //hit another externed GUI instance name
 // ret = WS_OBJECT_ARRAY_NAME   //hit arrayed GUI instance name
 // ret = WS_OBJECT_ARRAY_NAME_INVALID  //hit arrayed GUI instance name on another window
+#ifndef WS_EMBED
 long WSGFexistName(char* cname,WSCbase* base){
   if (_exist_name_handler == NULL){
     return 0;
@@ -499,7 +490,7 @@ void WSGFresetClassBase(WSCbase* base){
     base->setUserData("WS-BK-CLASS-NAME",(void*)0);
   }
 }
-
+#endif
 WSCstring* WSGFgetMouseCursorSaveData(){
   long cnt = 0;
   WSCstring* str = new WSCstring();
@@ -622,13 +613,13 @@ WSCstring* WSGFgetFontSaveData(){
   return ret;
 }
 
+#ifndef WS_EMBED
 void WSGFsetExistNameHandler(long (*hd)(char*,WSCbase*)){
   _exist_name_handler = hd;
 }
 void*  WSGFgetExistNameHandler(){
   return (void*)_exist_name_handler;
 }
-
 WSCbool WSGFcheckArrayName(char* name,long* arrayno,char* arrayname){
   WSCstring tmp(name);
   long pos1 = tmp.isExist("[");
@@ -665,6 +656,7 @@ WSCbool WSGFcheckArrayName(char* name,long* arrayno,char* arrayname){
   }
   return True;
 }
+#endif
 void WSGFdestroyPixmap(char* iname){
   WSGIappImageSet()->destroyImage(iname);
 }
@@ -778,6 +770,7 @@ long WSGFreplaceFile(char* lstr,void* data,long len,WSCbool same_save){
   }
 }
 
+#ifndef WS_EMBED
 WSCbool WSGFcheckNameString(char* str){ 
   long len = strlen(str);
   if (len == 0){
@@ -830,7 +823,7 @@ WSCbool WSGFcheckDirNameString(char* str){
   }
   return True;
 }
-
+#endif
 WSCbool WSGFcheckExistFile(char* filename){
   WSDfile* file = WSDfile::getNewInstance();
   long ret = file->open(filename,"r");
@@ -847,6 +840,7 @@ WSCbool WSGFcheckExistFile(char* filename){
 long WSGFadjustNumber(long num,long adjust){
   return (num - (num % adjust));
 }
+#ifndef WS_EMBED
 void WSGFopCreate(WSCstring* outp,char* fname,char* cname){
     *outp  = "#include <WScom.h>\n";
     *outp << "#include <WSCfunctionList.h>\n";
@@ -931,7 +925,9 @@ WSCbool WSGFreadInitString(WSCstring* in,char* sec,WSCstring* out1,WSCstring* ou
   out2->setString("");
   return False;
 }
+#endif
 
+#ifndef WS_EMBED
 static WSCbool _exist_name_(WSClistData* list,char* str){
   long num = list->getNum();
   long i;
@@ -989,7 +985,6 @@ void WSGFgetProcedureList(WSCbase* btarget,WSClistData* list){
 char* WSGFconvertPropValueString(WSCproperty* prop,char* val){
  return "not_implemented";
 }
-
 void WSGFsetEditMode(WSCbase* obj,WSCbool edit){
   obj->setPropertyEditMode(edit);
   WSClistData children = obj->getChildren();
@@ -1002,7 +997,9 @@ void WSGFsetEditMode(WSCbase* obj,WSCbool edit){
     }
   }
 }
+#endif
 
+#if 0 //moved to advance/WSadcom.cpp
 static WSCbase*  _get_parent_base(WSCbase* btarget,char* pname){
   if (!WSGFstrcmp(pname,btarget->getInstanceName())){
     return btarget;
@@ -1027,6 +1024,7 @@ static WSCbase*  _get_parent_base(WSCbase* btarget,char* pname){
   }
   return NULL;
 }
+#endif
 
 struct prop_data{
   WSCstring name;
@@ -1045,6 +1043,7 @@ struct utrg_data {
   long type;
 };
 
+#ifndef WS_EMBED
 void _get_2_words(char* src,char* word1,char* word2){
   word1[0] = 0;
   word2[0] = 0;
@@ -1101,6 +1100,7 @@ void _get_2_words(char* src,char* word1,char* word2){
     ptr++;
   }
 }
+
 void WSGFmarkChanged(WSCbase* target){
   long fl = 1;
   target->setUserData(WS_PROPERTY_CHANGED,(void*)fl);
@@ -1174,7 +1174,6 @@ static void _append(WSClistData* list,WSCstring* str){
   }
 }
 
-
 long WSGFtypeToValue(char* typen){
   if (!strcmp(typen,"long")){
     return WSTlong;
@@ -1220,6 +1219,7 @@ long WSGFtypeToValue(char* typen){
   }
   return 0;
 }
+#endif
 
 void _add_default_changed_property(WSCbase* btarget,char* pn,char tp,char* pdata,WSClistData* plist){
   WSCstring pname("WSN");
@@ -1437,238 +1437,17 @@ char* WSGFgetString(WSCushort* str,long encode){
   return ret;
 }
 
+#if 0 //move to base1/WScom.cpp
 long WSGFcalcStringXYPosToPos(WSCushort* istr,long xpos,long ypos,long* pos){
-  if (istr[0] == 0){
-    *pos=0;
-//printf("WSGFcalcStringXYPosToPos out pos=%d\n",*pos);
-    return WS_NO_ERR;
-  }
-  if (ypos < 0){
-    long lines = 1;
-    long i = 0;
-    while(1){
-      if (istr[i] == (WSCushort)0){
-        break;
-      }
-      if (istr[i] == (WSCushort)'\n'){
-        lines++;
-      }
-      i++;
-    }
-    ypos = lines -1;
-  }
-  long lines = 0;
-  long ptr = 0;
-  while(1){
-    if (lines == ypos){
-      break;
-    }
-    if (istr[ptr] == (WSCushort)0){
-      break;
-    }
-    if (istr[ptr] == (WSCushort)'\n'){
-      lines++;
-    }
-    ptr++;
-  }
-  long x = 0;
-  while(1){
-    if (xpos == x){
-      *pos = ptr;
-//printf("WSGFcalcStringXYPosToPos out1 pos=%d\n",*pos);
-      return WS_NO_ERR;
-    }
-    if (istr[ptr] == (WSCushort)0){
-      *pos = ptr;
-//printf("WSGFcalcStringXYPosToPos out2 pos=%d\n",*pos);
-      return WS_NO_ERR;
-    }
-    if (istr[ptr] == (WSCushort)'\n'){
-      *pos = ptr;
-//printf("WSGFcalcStringXYPosToPos out3 pos=%d\n",*pos);
-      return WS_NO_ERR;
-    }
-    ptr++;
-    x++;
-  }
-//printf("WSGFcalcStringXYPosToPos out4 pos=%d\n",*pos);
-  return WS_NO_ERR;
 }
 long WSGFcalcStringXYPos(WSCushort* istr,long pos,long* xpos,long* ypos){
-  long i;
-  *ypos = 0;
-  *xpos = 0;
-  for(i=0; i<pos; i++){
-    if (istr[i] == (WSCushort)0){
-      break;
-    }
-    if (istr[i] == (WSCushort)'\n'){
-      (*ypos)++;
-      (*xpos) = 0;
-    }else{
-      (*xpos)++;
-    }
-  }
-//printf("WSGFcalcStringXYPos out x,y=%d,%d\n",*xpos,*ypos);
-  return WS_NO_ERR;
 }
 
 long WSGFcalcStringPosFromAddr(WSCushort* istr,WSCrect* area,
             char alignment,WSDfont* font,long x,long y,
             long* pos ,WSCbool intercur){
-//printf("WSGFcalcStringPosFromAddr here...\n");
-  x -= area->x;
-  y -= area->y;
-  if (font == NULL){
-    *pos = 0;
-    return WS_ERR;
-  }
-  long max = WSGFstrlenUCS2(istr);
-  if (max == 0){
-    *pos=0;
-    return WS_NO_ERR;
-  }
-
-  if (intercur == False){
-    max--;
-  }
-  if (max == -1){
-    *pos=0;
-    return WS_NO_ERR;
-  }
-//printf("WSGFcalcStringPosFromAddr x=%d y=%d\n",x,y);
-
-//  short fw,fh;
-  WSCstring str(" ");
-//  fw = font->getStringWidth(&str);
-  short fh = font->getStringHeight(&str);
-//printf("WSGFcalcStringPosFromAddr fw=%d fh=%d\n",fw,fh);
-
-  long lines = WSGFgetLinesUCS2(istr);
-//printf("WSGFcalcStringPosFromAddr lines=%d\n",lines);
-  if (alignment == WS_TOP ||
-      alignment == WS_LEFT_TOP ||
-      alignment == WS_RIGHT_TOP){
-    //do nothing
-  }else 
-  if (alignment == WS_LEFT ||
-      alignment == WS_CENTER ||
-      alignment == WS_RIGHT){
-    long padh = (long)(area->height - fh * lines)/2;
-    y -= padh;
-  }else 
-  if (alignment == WS_BOTTOM ||
-      alignment == WS_LEFT_BOTTOM ||
-      alignment == WS_RIGHT_BOTTOM ){
-    long padh = area->height - fh * lines;
-    y -= padh;
-  }
-
-  long yline = y / fh;
-  
-  WSCushort tmp[2];
-  tmp[0] = (WSCushort)'\n';
-  tmp[1] = 0;
-  long ptr = WSGFgetWordCharPosUCS2(istr,yline,tmp);
-//printf("WSGFcalcStringPosFromAddr ptr=%d yline=%d y=%d max=%d\n",ptr,yline,y,max);
-  if (ptr == -1){
-    *pos = max;
-    return WS_NO_ERR;
-  }
-//#if 0//speed up
-//#else
-//  istr->seek(ptr);
-//  WSCstring tstr = istr->gets();
-//#endif
-
-  WSCushort* line_str = WSGFgetWordUCS2(istr,yline,tmp);
-  long fwidth = font->getStringWidthUCS2(line_str);
-
-  if (alignment == WS_LEFT ||
-      alignment == WS_LEFT_TOP ||
-      alignment == WS_LEFT_BOTTOM){
-    //do nothing.
-  }else
-  if (alignment == WS_TOP ||
-      alignment == WS_CENTER ||
-      alignment == WS_BOTTOM){
-    x -= (long)(area->width - fwidth)/2;
-  }else
-  if (alignment == WS_RIGHT ||
-      alignment == WS_RIGHT_TOP ||
-      alignment == WS_RIGHT_BOTTOM ){
-    x -= area->width - fwidth;
-  }
-
-  long len = WSGFstrlenUCS2(line_str);
-  if (intercur != False){
-    len ++;
-  }
-  *pos = ptr;
-  if (x < fwidth){
-extern long _calc_rawx_to_pos(WSCushort* str,long x,WSDfont* font);
-    long ret = _calc_rawx_to_pos(line_str, x, font);
-    delete line_str;
-    *pos = ptr+ ret;
-    if (*pos < WSGFstrlenUCS2(istr)){
-    }else{
-      *pos =  WSGFstrlenUCS2(istr);
-    }
-    return WS_NO_ERR;
-  }else{
-    delete line_str;
-    *pos = ptr+ len -1;
-    if (*pos < WSGFstrlenUCS2(istr)){
-    }else{
-      *pos =  WSGFstrlenUCS2(istr);
-    }
-    return WS_NO_ERR;
-  }
-#if 0
-  long p;
-  for( p=0; p < len; p++){
-    long ox = p * fw;
-
-    long tmpdist = (x-ox)*(x-ox);
-    if (dist > tmpdist || dist == -1 ){
-      dist = tmpdist;
-      *pos = p+ ptr;
-    }
-  }
+}
 #endif
-  return WS_NO_ERR;
-}
-long _calc_rawx_to_pos(WSCushort* str,long x,WSDfont* font){
-  long len = WSGFstrlenUCS2(str);
-  if (len == 1){
-    long fwidth = font->getStringWidthUCS2(str);
-    if (x < fwidth/2 ){
-      return 0;
-    }
-    return 1;
-  }
-  if (len == 0){
-    return 0;
-  }
-  WSCushort* str2 = WSGFstrdupUCS2(str);
-  str2[len/2] = 0;
-  long fwidth2 = font->getStringWidthUCS2(str2);
-  if (x < fwidth2){
-    long ret = _calc_rawx_to_pos(str2,x,font);
-    delete str2;
-//printf("_calc_rawx_to_pos ret=%d\n",ret);
-    return ret;
-  }else{
-    delete str2;
-    str2 = WSGFstrdupUCS2(str);
-    long ret = _calc_rawx_to_pos(&str2[len/2],x-fwidth2,font);
-    delete str2;
-//printf("_calc_rawx_to_pos ret+len/2=%d\n",ret+len/2);
-    return ret+len/2; 
-  }
-}
-
-
 
 long WSGFgetLinesUCS2(WSCushort* str){
   if (str == NULL){
@@ -1687,6 +1466,7 @@ long WSGFgetLinesUCS2(WSCushort* str){
   }
   return lines;
 }
+#ifndef WS_EMBED
 long WSGFcalcStringLineAddr(WSCushort* istr,WSCrect* area,
             char alignment,WSDfont* font,WSCpoint* pts,long line){
    long n = WSGFgetLinesUCS2(istr);
@@ -1766,153 +1546,13 @@ long WSGFgetWordPosUCS2(WSCushort* str,long ypos){
   }
   return i;
 }
+#endif
 
+#if 0 // move to  base1/WScom.cpp
 long WSGFcalcStringPosAddr(WSCushort* istr,WSCrect* area,
          char alignment,WSDfont* font,long pos,long* ox,long *oy){
-  if (pos < 0){
-    return WS_ERR;
-  }
-#if 0
-  long xpos,ypos;
-  WSGFcalcStringXYPos(istr,pos,&xpos,&ypos);
-  long ptr = WSGFgetWordPosUCS2(istr,ypos);
-  WSCushort* lstr = &istr[ptr];
-  WSCushort* tmp = new WSCushort[xpos+1];
-  memcpy(tmp,lstr,xpos+sizeof(WSCushort));
-  tmp[xpos] = 0;
-  WSCpoint pt;
-  WSGFcalcStringLineAddr(istr,area,alignment,font,&pt,ypos);
-  *ox = pt.x + font->getStringWidthUCS2(lstr);
-  *oy = pt.y;
-#endif
-
-  long xpos = 0;
-  long ypos = 0;
-  if (istr == NULL){
-    *ox = 0;
-    *oy = 0;
-    return WS_NO_ERR;
-  }
-  long ptr = 0;
-  long i = 0;
-  long k = 0;
-  long col = 0;
-  long line = 0;
-  while(1){
-    if (col == pos){
-       break;
-    }
-    if (istr[i] == 0){
-      ptr = i;
-      break;
-    }
-    if (istr[i] == '\n'){
-      k= 0;
-      i++;
-      line++;
-      ptr = i;
-      col++;
-      continue;
-    }
-#if 0
-    if(str[i] & 0x80){         //not ascii
-      if (str[i] == (char)0x8e){       //ȾѲ̾2byte = 1column
-        i++;
-      }else if (str[i] == (char)0x8f){ //3byte = 2column
-        i++;
-        col++;
-        k++;
-        i++;
-      }else{         //2byte = 2column
-        col++;
-        k++;
-        i++;
-      }
-    }
-#endif
-    col++;
-    k++;
-    i++;
-  }
-  xpos = k;
-  ypos = line;
-//printf("WSGFcalcStringPosAddr %d %d\n",xpos,ypos);
-//  istr->seek(ptr);
-  WSCushort* lstr = WSGFstrdupUCS2(&istr[ptr]);
-  lstr[xpos] = 0;
-  WSCpoint pt;
-
-  long n = line;
-  i = ptr;
-  while(1){
-    if (istr[i] == 0){
-      break;
-    }
-    if (istr[i] == '\n'){
-      n++;
-    }
-    i++;
-  }
-
-  if (line > n){
-    pt.x = 0;
-    pt.y = 0;
-    return 0;
-  }
-
-//   long fheight = font->getStringHeight(istr);
-  long fheight = font->getFontHeight();
-  long py = area->y;
-  long by = area->height;
-  if (alignment == WS_TOP ||
-      alignment == WS_LEFT_TOP ||
-      alignment == WS_RIGHT_TOP){
-    pt.y = py + fheight*line;
-  }else
-  if (alignment == WS_LEFT ||
-      alignment == WS_CENTER ||
-      alignment == WS_RIGHT){
-    pt.y = py + by/2  - fheight*(line+1)/2 + fheight*line;
-  }else
-  if (alignment == WS_BOTTOM ||
-      alignment == WS_LEFT_BOTTOM ||
-      alignment == WS_RIGHT_BOTTOM ){
-    pt.y = py + by + fheight*(line -n) ;
-  }
-
-  long px = area->x;
-  long pw = area->width;
-  if (alignment == WS_LEFT ||
-      alignment == WS_LEFT_TOP ||
-      alignment == WS_LEFT_BOTTOM){
-    pt.x = px;
-  }else
-  if (alignment == WS_TOP ||
-      alignment == WS_CENTER ||
-      alignment == WS_BOTTOM){
-    WSCushort tmp[2];
-    tmp[0] = (WSCushort)'\n';
-    tmp[1] = (WSCushort)0;
-    WSCushort* line_str = WSGFgetWordUCS2(istr,line,tmp);
-    long fwidth = font->getStringWidthUCS2(line_str);
-    pt.x = px + (pw - fwidth)/2;
-  }else
-  if (alignment == WS_RIGHT ||
-      alignment == WS_RIGHT_TOP ||
-      alignment == WS_RIGHT_BOTTOM ){
-    WSCushort tmp[2];
-    tmp[0] = (WSCushort)'\n';
-    tmp[1] = (WSCushort)0;
-    WSCushort* line_str = WSGFgetWordUCS2(istr,line,tmp);
-    long fwidth = font->getStringWidthUCS2(line_str);
-    pt.x = px + pw - fwidth;
-  }
-
-  *ox = pt.x + font->getStringWidthUCS2(lstr);
-  *oy = pt.y;
-
-  return WS_NO_ERR;
 }
+#endif
 
 long WSGFcalcStringAddr(WSCstring* istr,WSCrect* area,
                         char alignment,WSDfont* font,
@@ -2046,7 +1686,7 @@ long WSGFsetAppWindowList(WSCbase* pl){
   theAppWindowList = pl;
   return WS_NO_ERR;
 }
-
+#ifndef WS_EMBED
 static WSCbase* theAppPropertyEditor = NULL;
 WSCbase* WSGIappPropertyEditor(){
   return theAppPropertyEditor;
@@ -2056,7 +1696,7 @@ long WSGFsetAppPropertyEditor(WSCbase* editor){
   theAppPropertyEditor = editor;
   return WS_NO_ERR;
 }
-
+#endif
 WSCuchar WSGFblinkRate(long rate){
   return (rate/250);
 }
@@ -2176,6 +1816,7 @@ long WSGFstrnccmp(char* src1,char* src2,long cnt){
 
 //WSDnwDev WSDwindowDev ˤȤƤ
 
+#ifndef WS_EMBED
 char* WSGFtriggerToName(long ev){
 static char fl = 0;
 static char* trgtable[WSEV_HASH_MAX_NUM];
@@ -2215,8 +1856,9 @@ static char* trgtable[WSEV_HASH_MAX_NUM];
 char* WSGFeventToName(long ev){
   return WSGFtriggerToName(ev);
 }
+#endif
 
-//WSDnwDev WSDwindowDev ˤȤƤ
+//WSDnwDev WSDwindowDev ˤȤƤ...
 WSCulong WSGFeventToMaskBit(long ev){
 static char fl = 0;
 static long trgtable[WSEV_HASH_MAX_NUM];
@@ -2252,6 +1894,7 @@ static long trgtable[WSEV_HASH_MAX_NUM];
    }
    return trgtable[ev];
 }
+#ifndef WS_EMBED
 long WSGFnameToEvent(char* ev){
   if (!WSGFstrcmp("WSEV_NONE",ev)){
      return  WSEV_NONE;
@@ -2315,177 +1958,15 @@ long WSGFnameToEvent(char* ev){
   }
   return WSEV_NONE;
 }
+#endif
 
+#if 0 //move to base1/WScom.cpp
 void WSGFdrawArrow(WSDdev* dev,WSCbool fill,
                    WSCushort st,short bg_no,
                    short ts_no,short bs_no,char direction,
                    short x,short y,WSCushort w,WSCushort h ){
-
-    WSCpoint pts[6];
-    if (direction == WS_LEFT){
-      if (fill == False){
-        pts[0].setPoint( x,      y+h/2 );
-        pts[1].setPoint( x +w,   y  );
-        pts[2].setPoint( x +w,   y+h );
-        dev->setForeColor(bg_no);
-        dev->drawFillPoly(pts,3);
-
-        pts[0].setPoint( x,      y + h/2 );
-        pts[1].setPoint( x+st,   y + h/2 );
-        pts[2].setPoint( x+w-st/2, y + st*173/200  );
-        pts[3].setPoint( x+w,    y       );
-        dev->setForeColor(ts_no);
-        dev->drawFillPoly(pts,4);
-
-        pts[0].setPoint( x,      y + h/2 );
-        pts[1].setPoint( x+st,   y + h/2 );
-        pts[2].setPoint( x+w-st/2, y + h -st*173/200 );
-        pts[3].setPoint( x+w-st/2, y + st*173/200  );
-        pts[4].setPoint( x+w,    y       );
-        pts[5].setPoint( x+w,    y + h   );
-        dev->setForeColor(bs_no);
-        dev->drawFillPoly(pts,6);
-      }else{
-        if (WSGIappDev()->getGuiPolicy() & WS_POLICY_ORIGINAL){
-          pts[0].setPoint( x,   y +w/2  );
-          pts[1].setPoint( x+w, y       );
-          pts[2].setPoint( x+w, y + h   );
-          dev->setForeColor(bg_no);
-          dev->drawFillPoly(pts,3);
-        }else
-        if (WSGIappDev()->getGuiPolicy() & WS_POLICY_WINDOWS){
-          pts[0].setPoint( x+w/4,   y +w/2  );
-          pts[1].setPoint( x+w*3/4, y       );
-          pts[2].setPoint( x+w*3/4, y + h   );
-          dev->setForeColor(bg_no);
-          dev->drawFillPoly(pts,3);
-        }
-      }
-    }else if (direction == WS_RIGHT){
-
-      if (fill == False){
-        pts[0].setPoint( x,      y );
-        pts[1].setPoint( x +w,   y+h/2  );
-        pts[2].setPoint( x,   y+h );
-        dev->setForeColor(bg_no);
-        dev->drawFillPoly(pts,3);
-
-        pts[0].setPoint( x,      y + h   );
-        pts[1].setPoint( x,      y       );
-        pts[2].setPoint( x+w,    y + h/2 );
-        pts[3].setPoint( x+w-st, y + h/2 );
-        pts[4].setPoint( x+st/2,   y + st*173/200  );
-        pts[5].setPoint( x+st/2,   y +h -st*173/200);
-        dev->setForeColor(ts_no);
-        dev->drawFillPoly(pts,6);
-
-        pts[0].setPoint( x,      y + h   );
-        pts[1].setPoint( x+w,    y + h/2 );
-        pts[2].setPoint( x+w-st, y + h/2 );
-        pts[3].setPoint( x+st/2,   y +h -st*173/200);
-        dev->setForeColor(bs_no);
-        dev->drawFillPoly(pts,4);
-      }else{
-        if (WSGIappDev()->getGuiPolicy() & WS_POLICY_ORIGINAL){
-          pts[0].setPoint( x,   y      );
-          pts[1].setPoint( x+w, y +h/2 );
-          pts[2].setPoint( x,   y + h  );
-          dev->setForeColor(bg_no);
-          dev->drawFillPoly(pts,3);
-        }else
-        if (WSGIappDev()->getGuiPolicy() & WS_POLICY_WINDOWS){
-          pts[0].setPoint( x+w/4,   y      );
-          pts[1].setPoint( x+w*3/4, y +h/2 );
-          pts[2].setPoint( x+w/4,   y + h  );
-          dev->setForeColor(bg_no);
-          dev->drawFillPoly(pts,3);
-        }
-      }
-    }else if (direction == WS_UP){
-
-      if (fill == False){
-        pts[0].setPoint( x +w/2,      y );
-        pts[1].setPoint( x ,   y+h  );
-        pts[2].setPoint( x +w,   y+h );
-        dev->setForeColor(bg_no);
-        dev->drawFillPoly(pts,3);
-
-        pts[0].setPoint( x,      y + h   );
-        pts[1].setPoint( x +w/2, y       );
-        pts[2].setPoint( x +w/2, y + st  );
-        pts[3].setPoint( x + st*173/200, y +h -st/2);
-        dev->setForeColor(ts_no);
-        dev->drawFillPoly(pts,4);
-
-        pts[0].setPoint( x,      y + h   );
-        pts[1].setPoint( x +w, y + h   );
-        pts[2].setPoint( x +w/2, y       );
-        pts[3].setPoint( x + w/2,  y + st  );
-        pts[4].setPoint( x +w-st*173/200,y+h-st/2  );
-        pts[5].setPoint( x + st*173/200, y+h-st/2  );
-        dev->setForeColor(bs_no);
-        dev->drawFillPoly(pts,6);
-      }else{
-
-        if (WSGIappDev()->getGuiPolicy() & WS_POLICY_ORIGINAL){
-          pts[0].setPoint( x +w/2, y     );
-          pts[1].setPoint( x+w,    y +h  );
-          pts[2].setPoint( x,      y + h );
-          dev->setForeColor(bg_no);
-          dev->drawFillPoly(pts,3);
-        }else
-        if (WSGIappDev()->getGuiPolicy() & WS_POLICY_WINDOWS){
-          pts[0].setPoint( x +w/2, y +h/4   );
-          pts[1].setPoint( x+w,    y +h*3/4+1  );
-          pts[2].setPoint( x,      y +h*3/4+1 );
-          dev->setForeColor(bg_no);
-          dev->drawFillPoly(pts,3);
-        }
-      }
- 
-    }else if (direction == WS_DOWN){
-
-      if (fill == False){
-        pts[0].setPoint( x ,      y );
-        pts[1].setPoint( x +w,   y  );
-        pts[2].setPoint( x +w/2,   y+h );
-        dev->setForeColor(bg_no);
-        dev->drawFillPoly(pts,3);
-
-        pts[0].setPoint( x +w/2, y + h   );
-        pts[1].setPoint( x,      y       );
-        pts[2].setPoint( x + w,  y       );
-        pts[3].setPoint( x+w-st*173/200, y+st/2  );
-        pts[4].setPoint( x+st*173/200,   y+st/2  );
-        pts[5].setPoint( x +w/2, y+h-st  );
-        dev->setForeColor(ts_no);
-        dev->drawFillPoly(pts,6);
-
-        pts[0].setPoint( x +w/2, y + h   );
-        pts[1].setPoint( x + w,  y       );
-        pts[2].setPoint( x+w-st*173/200, y+st/2  );
-        pts[3].setPoint( x +w/2, y+h-st  );
-        dev->setForeColor(bs_no);
-        dev->drawFillPoly(pts,4);
-      }else{
-
-        if (WSGIappDev()->getGuiPolicy() & WS_POLICY_ORIGINAL){
-          pts[0].setPoint( x, y  );
-          pts[1].setPoint( x + w, y );
-          pts[2].setPoint( x + w / 2, y + h );
-          dev->setForeColor(bg_no);
-          dev->drawFillPoly(pts,3);
-        }else
-        if (WSGIappDev()->getGuiPolicy() & WS_POLICY_WINDOWS){
-          pts[0].setPoint( x, y +h/4  );
-          pts[1].setPoint( x + w, y +h/4 );
-          pts[2].setPoint( x + w / 2, y + h*3/4 );
-          dev->setForeColor(bg_no);
-          dev->drawFillPoly(pts,3);
-        }
-      }
-    }
 }
+#endif
 
 void WSGFdrawShadow(WSDdev* dev,char shadow_type,WSCushort st,
                     short fg_no,short ts_no,short bs_no,short bg_no,
@@ -2819,47 +2300,159 @@ long WSGFmaskBitToEvent(WSCulong bit){
    }
    return WSEV_NONE;
 }
-
-char* WSGFcreateEucStringFromJisStr(char *buf){
+#ifndef WS_EMBED
+char* WSGFcreateJisStringFromEucStr(char *buf){
    long i;
    long fl = 0;
-static  char output[2048]; 
+   char* output = NULL;
    i = 0;
 
    long max = strlen(buf) +1;
+   output = new char[max*16];
+   long limit = max*16;
    long p =0;
-   while(p<max && p < 1000){
+
+   char jish[4];
+   char jist[5];
+   char jist3[5];
+   char jist2[4];
+
+   jish[0] = 0x1b;
+   jish[1] = ')';
+   jish[2] = 'I';
+   jish[3] = 0;
+
+   jist[0] = 0x1b;
+   jist[1] = '$';
+   jist[2] = ')';
+   jist[3] = 'B';
+   jist[4] = 0;
+
+   jist2[0] = 0x1b;
+   jist2[1] = '(';
+   jist2[2] = 'B';
+   jist2[3] = 0;
+
+   jist3[0] = 0x1b;
+   jist3[1] = '$';
+   jist3[2] = '(';
+   jist3[3] = 'B';
+   jist3[4] = 0;
+
+   while(p < max && i < limit){
      if (*buf == 0){
         output[i] = 0;
         break;
      }
-     char jish[4];
-     char jist[5];
-     char jist3[5];
-     char jist2[4];
-     jish[0] = 0x1b;
-     jish[1] = ')';
-     jish[2] = 'I';
-     jish[3] = 0;
+     if ((unsigned char)*buf == 0x8e){
+       if (fl != 1){
+         output[i] = jish[0];
+         i++;
+         output[i] = jish[1];
+         i++;
+         output[i] = jish[2];
+         i++;
+         fl = 1;//hankaku kana mode
+       }
+       buf++;
+       output[i] = (*buf & 0x7f);
+       buf++;
+       p++;
+       i++;
+     }else if(*buf | 0x80){
+       if (fl != 2){
+         output[i] = jist3[0];
+         i++;
+         output[i] = jist3[1];
+         i++;
+         output[i] = jist3[2];
+         i++;
+         output[i] = jist3[3];
+         i++;
+         fl = 2;//hankaku kana mode
+       }
+       output[i] = (*buf & 0x7f);
+       buf++;
+       p++;
+       i++;
+       output[i] = (*buf & 0x7f);
+       buf++;
+       p++;
+       i++;
+     }else if(!(*buf | 0x80)){
+       if (fl != 0){
+         output[i] = jist2[0];
+         i++;
+         output[i] = jist2[1];
+         i++;
+         output[i] = jist2[2];
+         i++;
+         fl = 0;//hankaku kana mode
+       }
+       output[i] = *buf;
+       buf++;
+       i++;
+       p++;
+     }else{
+       buf++;
+       p++;
+     }
+   }
+   if (fl != 0){
+     output[i] = jist2[0];
+     i++;
+     output[i] = jist2[1];
+     i++;
+     output[i] = jist2[2];
+     i++;
+   }
+   output[i] = 0;
+   return output;
+}
+#endif
 
-     jist[0] = 0x1b;
-     jist[1] = '$';
-     jist[2] = ')';
-     jist[3] = 'B';
-     jist[4] = 0;
+char* WSGFcreateEucStringFromJisStr(char *buf){
+   long i;
+   long fl = 0;
+   char* output = NULL;
+   i = 0;
 
-     jist3[0] = 0x1b;
-     jist3[1] = '$';
-     jist3[2] = '(';
-     jist3[3] = 'B';
-     jist3[4] = 0;
+   long max = strlen(buf) +1;
+   long limit = max*4;
+   output = new char[limit];
+   long p =0;
 
+   char jish[4];
+   char jist[5];
+   char jist3[5];
+   char jist2[4];
+   jish[0] = 0x1b;
+   jish[1] = ')';
+   jish[2] = 'I';
+   jish[3] = 0;
 
-     jist2[0] = 0x1b;
-     jist2[1] = '(';
-     jist2[2] = 'B';
-     jist2[3] = 0;
+   jist[0] = 0x1b;
+   jist[1] = '$';
+   jist[2] = ')';
+   jist[3] = 'B';
+   jist[4] = 0;
 
+   jist3[0] = 0x1b;
+   jist3[1] = '$';
+   jist3[2] = '(';
+   jist3[3] = 'B';
+   jist3[4] = 0;
+
+   jist2[0] = 0x1b;
+   jist2[1] = '(';
+   jist2[2] = 'B';
+   jist2[3] = 0;
+
+   while( p < max && i < limit){
+     if (*buf == 0){
+        output[i] = 0;
+        break;
+     }
      if (!strncmp(jish,buf,3)){
          buf = buf +3;;
          output[i] = 0x8e;
@@ -2870,7 +2463,7 @@ static  char output[2048];
          i++;
          fl = 1;//hankaku kana mode
      }else if(!strncmp(jist,buf,4) || !strncmp(jist3,buf,4)){
-printf("kanjimode!! %d\n",i);
+//printf("kanjimode!! %d\n",i);
          buf = buf +4;
          output[i] = (*buf | 0x80);
          buf++;
@@ -2898,7 +2491,7 @@ printf("kanjimode!! %d\n",i);
          i++;
          buf++;
          p++;
-printf("output=#%s#\n",output);
+//printf("output=#%s#\n",output);
        }else if (!(*buf & 0x80) && (*buf >= 0x20)){
          output[i] = *buf;
          i++;
@@ -3408,10 +3001,15 @@ long _lang = 0;
 void WSGFsetLangVal(long lang){
   _lang = lang;
 }
-char* WSGFgetLocaleName(long locale){
+
+char _lang_name[32];
+void WSGFsetLangName(char* langname){
+  strcpy(_lang_name,langname);
+}
+char* WSGFgetEncodingName(long locale){
   switch(locale){
     case WS_EN_DEFAULT:
-        return WSGFgetLocaleName(WSGIappCodeConvert()->getSystemLocale());
+        return WSGFgetEncodingName(WSGIappCodeConvert()->getSystemEncoding());
     case WS_EN_LOCALE:
         return WSN_EN_ISO8859_1;
     case WS_EN_ISO8859_1:
@@ -3445,9 +3043,9 @@ char* WSGFgetLocaleName(long locale){
     case WS_EN_ISO8859_15:
         return WSN_EN_ISO8859_15;
     case WS_EN_UTF8:
-        if (_lang == WS_EN_LANG_JP){
-          return WSN_EN_UTF8_JP;
-        }
+//        if (_lang == WS_EN_LANG_JP){
+//          return WSN_EN_UTF8_JP;
+//        }
         return WSN_EN_UTF8;
     case WS_EN_KOI8R:
         return WSN_EN_KOI8R;
@@ -3465,7 +3063,84 @@ char* WSGFgetLocaleName(long locale){
       return WSN_EN_NONE;
   }
 }
-long WSGFgetLocaleValue(char* lname){
+
+WSCbool WSGFisEncoding(const char* locale,const char* enc){
+  const char* p1 = 0;
+  const char* p2 = 0;
+  char c = 0;
+  for(p1 = locale; *p1 != '.'; p1++) {
+    if(!*p1) return False;
+  }
+  p1++;
+  for(p2 = enc; (c = *p1) && *p2; p1++) {
+    if(c == '_' || c == '-') continue;
+    if('A' <= c && c <= 'Z') c += 32;
+    if(c != *p2) return False;
+    p2++;
+  }
+  if(!*p2) return True;
+  return False;
+}
+
+long WSGFgetISO8859(const char* locale){
+  const char* p = 0;
+  int iso = 0;
+  for(p = locale + strlen(locale) - 1; *p != '-'; p--) {
+    if(p <= locale) return WS_EN_NONE;
+  }
+  iso = atoi(p + 1);
+  if(iso < 1 || iso > 15) return WS_EN_NONE;
+  return WS_EN_ISO8859(iso);
+}
+
+long WSGFgetEncoding(char* locale){
+  long ret = WS_EN_NONE;
+  if(WSGFisEncoding(locale,"utf8")) {
+    ret = WS_EN_UTF8;
+  } else if(WSGFisEncoding(locale,"sjis") || WSGFisEncoding(locale,"shiftjis")) {
+    ret = WS_EN_SJIS;
+  } else if(WSGFisEncoding(locale,"eucjp")) {
+    ret = WS_EN_EUCJP;
+  } else if(WSGFisEncoding(locale,"euckr")) {
+    ret = WS_EN_EUCKR;
+  } else if(WSGFisEncoding(locale,"euccn")) {
+    ret = WS_EN_EUCCN;
+  } else if(WSGFisEncoding(locale,"big5")) {
+    ret = WS_EN_BIG5;
+  } else if(WSGFisEncoding(locale,"koi8r")) {
+    ret = WS_EN_KOI8R;
+  } else if(WSGFisEncoding(locale,"iso8859") || WSGFisEncoding(locale,"dis8859")) {
+    ret = WSGFgetISO8859(locale);
+  }
+  if(ret != WS_EN_NONE) return ret;
+
+  char lang_name[3];
+  strncpy(lang_name,locale,2);
+  lang_name[2] = 0;
+
+#ifdef MacOS
+  if(!strcmp(lang_name, "ja")){
+    ret = WS_EN_UTF8;
+    return ret;
+  }
+#endif //MacOS
+
+  if(!strcmp(lang_name, "cs")) ret = WS_EN_ISO8859(2);
+  if(!strcmp(lang_name, "he")) ret = WS_EN_ISO8859(8);
+  if(!strcmp(lang_name, "hr")) ret = WS_EN_ISO8859(2);
+  if(!strcmp(lang_name, "hu")) ret = WS_EN_ISO8859(2);
+  if(!strcmp(lang_name, "pl")) ret = WS_EN_ISO8859(2);
+  if(!strcmp(lang_name, "ro")) ret = WS_EN_ISO8859(2);
+  if(!strcmp(lang_name, "ru")) ret = WS_EN_KOI8R;
+  if(!strcmp(lang_name, "ja")) ret = WS_EN_EUCJP;
+  if(!strcmp(lang_name, "ko")) ret = WS_EN_EUCKR;
+  if(!strcmp(lang_name, "zh")) ret = WS_EN_EUCCN;
+  if(ret != WS_EN_NONE) return ret;
+
+  return WS_EN_ISO8859(1);
+}
+
+long WSGFgetEncodingValue(char* lname){
   if (!strcmp(lname,WSN_EN_LOCALE)){
     return WS_EN_LOCALE;
   }else
@@ -3523,9 +3198,9 @@ long WSGFgetLocaleValue(char* lname){
   if (!strcmp(lname,WSN_EN_UTF8)){
     return WS_EN_UTF8;
   }else
-  if (!strcmp(lname,WSN_EN_UTF8_JP)){
-    return WS_EN_UTF8;
-  }else
+//  if (!strcmp(lname,WSN_EN_UTF8_JP)){
+//    return WS_EN_UTF8;
+//  }else
   if (!strcmp(lname,WSN_EN_KOI8R)){
     return WS_EN_KOI8R;
   }else
@@ -3607,6 +3282,7 @@ void WSGFgetShadowColor(short in,short* ts,short* bs,short* bg){
   *bs = WSGIappColorSet()->getColorNo(cname);
 }
 void WSGFdrawStripes(WSDdev* dev,WSCushort w,WSCushort h,short ts,short bs,short bg){
+#ifndef WS_EMBED
   long i;
   for(i=0; i<h; i+=6){
     dev->setForeColor(bs);
@@ -3616,9 +3292,11 @@ void WSGFdrawStripes(WSDdev* dev,WSCushort w,WSCushort h,short ts,short bs,short
     dev->setForeColor(ts);
     dev->drawLine(0,i+3,w,i+3);
   }
+#endif
 }
 
 WSDmwindowDev* WSGFgetAquaImage(short col,WSCushort w,WSCushort h,long no){
+#ifndef WS_EMBED
   WSDcolor* color = WSGIappColorSet()->getColor(col);
   WSDmwindowDev* mdev = WSDmwindowDev::getNewInstance();
   WSDmwindowDev* mdev3 = WSDmwindowDev::getNewInstance();
@@ -3695,9 +3373,13 @@ WSDmwindowDev* WSGFgetAquaImage(short col,WSCushort w,WSCushort h,long no){
   mdev3->putBufferToPixmap();
   delete mdev;
   return mdev3;
+#else
+  return NULL;
+#endif
 }
 
 WSDmwindowDev* WSGFgetAquaMaskImage(WSCushort w,WSCushort h,long no){
+#ifndef WS_EMBED
   short cno = WSGIappColorSet()->getColorNo("#ffffff");
   WSDmwindowDev* mdev = WSDmwindowDev::getNewInstance();
 
@@ -3731,12 +3413,17 @@ WSDmwindowDev* WSGFgetAquaMaskImage(WSCushort w,WSCushort h,long no){
 
   mdev->endDraw();
   return mdev;
+#else
+  return NULL;
+#endif
 }
 
 void WSGFtrace(WSCstring str){
+#ifndef WS_EMBED
   if (WSGIappDev()->getTraceMode() != False ){
     WSGFsendMessage("WS-TRACER",str.getString(WS_EN_UTF8));
   }
+#endif
 }
 long(*_get_lang_handler)() = NULL;
 long WSGFgetLanguage(){
@@ -3748,4 +3435,31 @@ long WSGFgetLanguage(){
 void WSGFsetGetLanguageHandler(long(*hd)()){
   _get_lang_handler = hd;
 }
+#ifdef WS_EMBED
+void ws_dummy_call(){
+extern void _libws_lang();
+  _libws_lang();
+}
+#endif
 
+#ifdef BTRON
+#ifndef TE
+#include <basic.h>
+extern "C" {
+WERR u_wait (int *status);
+};
+#endif
+#endif
+void WSGFexit(int val){
+#ifdef BTRON
+#ifndef TE
+  while(1){
+    int status;
+    if (u_wait(&status)<0){
+      break;
+    }
+  }
+#endif
+#endif
+  exit(val);
+}
