@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCpulldownMenu.h>
@@ -40,6 +40,7 @@
 #include <WSCblink.h>
 #include <WSCbaseList.h>
 #include <ctype.h>
+#include <WSCguiPolicy.h>
 
 WSMFguiClassInitialize(WSCpulldownMenu, WSCvlabel);
 WSMFversion(WSCpulldownMenu, WSCvlabel);
@@ -248,6 +249,9 @@ long WSCpulldownMenu::draw(){
       st.top_shadow_color = _ts_color;
       st.bottom_shadow_color = _bs_color;
       st.label_string = _label_string;
+//--
+      st.short_cut = _sc_str;
+//--
       st.label_pixmap = _label_pixmap;
       st.blink_pixmap = _blink_pixmap;
       st.press_state = _press_state;
@@ -344,18 +348,88 @@ long WSCpulldownMenu::draw(){
         blinkfore == False &&
         _bl_type != WS_BACK &&
         _tw_fl == False){
-        // 褷ʤ
+        // 褷ʤ...
       }else{
-        // ɽʸ
+        // ɽʸ...
         if (_tw_fl == False || _bl_fl == False){
-          dev->drawString(sx+1, sy+1, sw, sh, &str, _font, getAlignment(), -1, False);
+
+//--
+
+	// Accelerator key char underline show
+
+	WSCstring _accel_str;
+	WSCstring _accel_char;
+	int _accel_x;
+	int _str_long;
+	int _char_long;
+	int _char_pos;
+	WSCstring str1 = "__"; // We need two '_' to be sure line is long enough
+	
+	WSDfont* _accel_font = WSGIappFontSet()->getFont(_font);
+
+	// We determinate _sc_str position
+
+	_accel_char = _sc_str;
+	_accel_char.to_lower();
+
+	_accel_str = str;
+	_accel_str.to_lower();
+//	_char_pos = strcspn((char*)_accel_str, _accel_char);
+	_char_pos = _accel_str.isExist(_accel_char);
+	
+	// If it is in on string, we have a short cut key to show
+	
+	if(_char_pos > -1 ){
+		
+		_accel_str = str;
+		_accel_str.cutString(_char_pos);
+	
+		_accel_x = _accel_font->getStringWidth(_accel_str);
+		_str_long = _accel_font->getStringWidth(str);
+	
+		_accel_char = str;
+		_accel_char.deleteChars(0,_char_pos);
+		_accel_char.cutString(1);
+		_char_long = _accel_font->getStringWidth(_accel_char);
+
+		switch(getAlignment())
+		{
+
+		
+			case WS_LEFT:
+			
+				// Do nothing
+				break;
+	
+			case WS_CENTER:
+
+				_accel_x = _accel_x + int((sw-_str_long)/2);
+				break;
+	
+			case WS_RIGHT:
+
+				_accel_x = _accel_x + sw - _str_long;
+				break;
+			
+			default:
+			break;
+	
+		}
+	
+	dev->drawString(sx+_accel_x+1, sy+2, _char_long, sh, &str1, _font, WS_LEFT, -1, False);
+	
+	}
+
+//--
+          
+	  dev->drawString(sx+1, sy+1, sw, sh, &str, _font, getAlignment(), -1, False);
         }
       }
     }else{
-      dev->setHatchPattern(8); //
+      dev->setHatchPattern(8);
     }
   }else{
-    dev->setHatchPattern(0); //٥
+    dev->setHatchPattern(0);
   }
 
   if (_rv_fl != False) {
@@ -402,6 +476,76 @@ long WSCpulldownMenu::draw(){
      // 褷ʤ
   }else{
     // ɽʸ
+
+//--
+
+	// Accelerator key char underline show
+
+	WSCstring _accel_str;
+	WSCstring _accel_char;
+	int _accel_x;
+	int _str_long;
+	int _char_long;
+	int _char_pos;
+	WSCstring str1 = "__"; // We need two '_' to be sure line is long enough
+	
+	WSDfont* _accel_font = WSGIappFontSet()->getFont(_font);
+
+	// We determinate _sc_str position
+
+	_accel_char = _sc_str;
+	_accel_char.to_lower();
+	
+	_accel_str = str;
+	_accel_str.to_lower();
+//	_char_pos = strcspn((char*)_accel_str, _accel_char);
+	_char_pos = _accel_str.isExist(_accel_char);
+
+	// If it is in on string, we have a short cut key to show
+	
+	if(_char_pos > -1 ){
+
+		_accel_str = str;
+		_accel_str.cutString(_char_pos);
+	
+		_accel_x = _accel_font->getStringWidth(_accel_str);
+		_str_long = _accel_font->getStringWidth(str);
+	
+		_accel_char = str;
+		_accel_char.deleteChars(0,_char_pos);
+		_accel_char.cutString(1);
+		_char_long = _accel_font->getStringWidth(_accel_char);
+
+		switch(getAlignment())
+		{
+
+		
+			case WS_LEFT:
+			
+				// Do nothing
+				break;
+	
+			case WS_CENTER:
+
+				_accel_x = _accel_x + int((sw-_str_long)/2);
+				break;
+	
+			case WS_RIGHT:
+
+				_accel_x = _accel_x + sw - _str_long;
+				break;
+			
+			default:
+			break;
+	
+		}
+	
+	dev->drawString(sx+_accel_x, sy+1, _char_long, sh, &str1, _font, WS_LEFT, -1, False);
+
+	}
+
+//--
+
     dev->drawString(sx, sy, sw, sh, &str, _font, getAlignment(), -1, False);
   }
 
@@ -942,4 +1086,15 @@ void WSCpulldownMenu::onGuiPolicyChange(long policy){
     redraw();
   }
 }
+#ifdef WS_EMBED
+#ifndef NO_EXT_GUI_POLICY
+class _gui_policy_register_{
+  public: _gui_policy_register_(){
+extern void WSCpulldownMenu_draw_mdr1(void*);
+    WSGIappGuiPolicy()->setExtGuiPolicyProc("Modern1","WSCpulldownMenu::draw",WSCpulldownMenu_draw_mdr1);
+  }
+};
+static _gui_policy_register_ _run_register;
+#endif
+#endif
 
