@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCpulldownMenuPopup.h>
@@ -36,6 +36,7 @@
 #include <WSDappDev.h>
 #include <WSDkeyboard.h>
 #include <string.h>
+#include <WSCguiPolicy.h>
 
 #define WS_ERR2 -2
 #define WS_NO_SELECTED -2
@@ -513,7 +514,51 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
         if ( own_pld->getSensitive(cnt) == False) {
           if (getEmboss() != False){
             dev->setForeColor(_ts_no);
-            dev->drawString(st*2 + smargin/2+1, posy +st+1, w -st*4 - smargin , _item_height -st*2, &item_str, _font, WS_LEFT, -1, False);
+
+//--
+	
+	WSCstring _accel_str;
+	WSCstring _accel_char;
+	int _accel_x;
+	int _str_long;
+	int _char_long;
+	int _char_pos;
+	WSCstring str1 = "__";
+	
+	WSDfont* _accel_font = WSGIappFontSet()->getFont(_font);
+
+	// We determinate _sc_str position
+
+	_accel_str = item_str;
+	_accel_str.to_lower();
+	_accel_char = item.getWord(2, ":");
+	_accel_char.to_lower();
+//	_char_pos = strcspn((char*)_accel_str, (char*)_accel_char);
+    _char_pos = _accel_str.isExist(_accel_char);
+
+	// If it is in on string, we have a short cut key to show
+	
+    if(_char_pos > -1 ){
+		
+		_accel_str = item_str;
+		_accel_str.cutString(_char_pos);
+	
+		_accel_x = _accel_font->getStringWidth(_accel_str);
+		_str_long = _accel_font->getStringWidth(item_str);
+	
+		_accel_char = item_str;
+		_accel_char.deleteChars(0,_char_pos);
+		_accel_char.cutString(1);
+		_char_long = _accel_font->getStringWidth(_accel_char);
+	
+		dev->drawString((st*2 + smargin/2)+_accel_x, posy +st+2, _char_long,
+			_item_height -st*2, &str1, _font, WS_LEFT, -1, False);
+
+	}
+
+//--
+
+	    dev->drawString(st*2 + smargin/2+1, posy +st+1, w -st*4 - smargin , _item_height -st*2, &item_str, _font, WS_LEFT, -1, False);
           }else{
             dev->setHatchPattern(8);
           }
@@ -537,6 +582,48 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
           }
         }
 
+//--
+	
+	WSCstring _accel_str;
+	WSCstring _accel_char;
+	int _accel_x;
+	int _str_long;
+	int _char_long;
+	int _char_pos;
+	WSCstring str1 = "__";
+	
+	WSDfont* _accel_font = WSGIappFontSet()->getFont(_font);
+
+	// We determinate _sc_str position
+
+	_accel_str = item_str;
+	_accel_str.to_lower();
+	_accel_char = item.getWord(2, ":");
+	_accel_char.to_lower();
+//	_char_pos = strcspn((char*)_accel_str, (char*)_accel_char);
+    _char_pos = _accel_str.isExist(_accel_char);
+
+	// If it is in on string, we have a short cut key to show
+	
+    if(_char_pos > -1 ){
+		
+		_accel_str = item_str;
+		_accel_str.cutString(_char_pos);
+	
+		_accel_x = _accel_font->getStringWidth(_accel_str);
+		_str_long = _accel_font->getStringWidth(item_str);
+	
+		_accel_char = item_str;
+		_accel_char.deleteChars(0,_char_pos);
+		_accel_char.cutString(1);
+		_char_long = _accel_font->getStringWidth(_accel_char);
+	
+		dev->drawString((st*2 + smargin/2)+_accel_x, posy +st+1, _char_long,
+			_item_height -st*2, &str1, _font, WS_LEFT, -1, False);
+
+	}
+
+//--
 
         dev->drawString(st*2 + smargin/2, posy +st, w -st*4 - smargin , _item_height -st*2, &item_str, _font, WS_LEFT, -1, False);
 
@@ -1150,3 +1237,15 @@ void WSCpulldownMenuPopup::set_child_popup_waited(WSCbool fl){
 void WSCpulldownMenuPopup::set_id_value(long v){
   _id_value = v;
 }
+#ifdef WS_EMBED
+#ifndef NO_EXT_GUI_POLICY
+class _gui_policy_register_{
+  public: _gui_policy_register_(){
+extern void WSCpulldownMenuPopup_draw_mdr1(void*);
+    WSGIappGuiPolicy()->setExtGuiPolicyProc("Modern1","WSCpulldownMenuPopup::draw",WSCpulldownMenuPopup_draw_mdr1);
+  }
+};
+static _gui_policy_register_ _run_register;
+#endif
+#endif
+
