@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSkeysym.h>
@@ -510,7 +510,7 @@ dbprintf("WSCvifield::draw %s:%d  %s dev=NULL\n",__FILE__,__LINE__,getInstanceNa
         dev->setValue(WSDEV_USE_PIXMAP,&fl);
     }
   }
-  if (shadow_type == WS_SHADOW_TRANS){
+  if (shadow_type == (char)WS_SHADOW_TRANS){
     if (getFocus() != False){
       shadow_type = WS_SHADOW_IN;
     }else if (_use_pix != False){
@@ -683,7 +683,9 @@ dbprintf("WSCvifield::draw %s:%d %s draw shadow..\n",__FILE__,__LINE__,getInstan
 
   if (getSensitive() == False ||
       (getPropertyEditMode() != False && (long)getUserData(WS_DET) == 0)){
-    dev->setHatchPattern(8);
+    if (_no_hatch == False){
+      dev->setHatchPattern(8);
+    }
   }
 
 #ifdef TDBG
@@ -2323,3 +2325,9 @@ WSMFtrace("WSCvifiled::onWindowFocusChange(%d)   _cur_timer_id ERROR!!!!\n",fl);
     WSGIappKeyboard()->resetFep(getowndev());
   }
 }
+void WSCvifield::setKeyInputDisable(WSCbool fl){
+  _key_input_disable = fl;
+}
+WSCbool WSCvifield::getKeyInputDisable(){
+  return _key_input_disable;
+}
