@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCvscrBar.h>
@@ -35,6 +35,7 @@
 #include <WSCbaseList.h>
 #include <WSDappDev.h>
 #include <WSDmwindowDev.h>
+#include <WSCguiPolicy.h>
 
 
 WSMFguiClassInitialize(WSCvscrBar,WSCnwbase);
@@ -597,6 +598,7 @@ long WSCvscrBar::draw(){
                       ah,ah);
         }
         //bar
+#ifndef WS_EMBED
         if (policy & WS_POLICY_AQUA){
           WSCushort bw = (long)(x +w + st*3 -((double)h)*3/2 - (((double)bar_area_width) * (_maximum -_value_alt -_slider_size_alt) / _maximum )
                    -(x +((double)h)*3/2 -st*3 + (((double)bar_area_width) * _value_alt / _maximum )));
@@ -633,6 +635,9 @@ long WSCvscrBar::draw(){
 //            _mask_images[0]->copyToWindowWithMask(dev,0,0,bw,bh,posx,posy,_mask_images[3]);
           }
         }else{
+#else
+        {
+#endif
           dev->setForeColor( _bg_no );
           dev->drawFillRect( (short)(x +(double)h*3/2 -st*2 + (bar_area_width * _value_alt / _maximum )),
                    y +st*2 ,
@@ -768,6 +773,7 @@ long WSCvscrBar::draw(){
                       ah,ah);
         }
         //bar
+#ifndef WS_EMBED
         if (policy & WS_POLICY_AQUA){
           WSCushort bw = w -st*2;
           WSCushort bh = (long)((y +h +st*3 - ((double)w)*3/2 - (((double)bar_area_height) * (_maximum -_value_alt - _slider_size_alt) / _maximum ))
@@ -800,7 +806,9 @@ long WSCvscrBar::draw(){
             _mask_images[2]->copyToWindowWithMask(dev,0,0,bw,bh,posx,posy,_mask_images[3]);
           }
         }else{
-
+#else
+        {
+#endif
           dev->setForeColor( _bg_no );
           dev->drawFillRect(
                    x +st*2 ,
@@ -1030,3 +1038,15 @@ void WSCvscrBar::onGuiPolicyChange(long policy){
 char* WSCvscrBar::getDefaultProperty(){
   return WSNvalue;
 }
+#ifdef WS_EMBED
+#ifndef NO_EXT_GUI_POLICY
+class _gui_policy_register_{
+  public: _gui_policy_register_(){
+extern void WSCvscrBar_draw_mdr1(void*);
+    WSGIappGuiPolicy()->setExtGuiPolicyProc("Modern1","WSCvscrBar::draw",WSCvscrBar_draw_mdr1);
+  }
+};
+static _gui_policy_register_ _run_register;
+#endif
+#endif
+
