@@ -14,10 +14,6 @@
 #include <WSCpulldownMenu.h>
 #include <WSCguiPolicy.h>
 
-extern void WSGFdrawModern1Shadow(WSDdev* dev,long shadow_type,WSCushort stick,
-   short fg_no, short ts_no, short bs_no, short bg_no,short pno,
-   short x, short y, WSCushort w,WSCushort h,WSCbool nodark);
-
 
 void WSCindexForm_draw_mdr1(void* ptr){
   WSCindexForm_draw_struct* st = (WSCindexForm_draw_struct*)ptr;
@@ -357,7 +353,51 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
         if ( own_pld->getSensitive(cnt) == False) {
           if (st->_this->getEmboss() != False){
             dev->setForeColor(_ts_no);
-            dev->drawString(st1*2 + smargin/2+1, posy +st1+1, w -st1*4 - smargin , _item_height -st1*2, &item_str, _font, WS_LEFT, -1, False);
+
+//--
+	
+	WSCstring _accel_str;
+	WSCstring _accel_char;
+	int _accel_x;
+	int _str_long;
+	int _char_long;
+	int _char_pos;
+	WSCstring str1 = "__";
+	
+	WSDfont* _accel_font = WSGIappFontSet()->getFont(_font);
+
+	// We determinate _sc_str position
+
+	_accel_str = item_str;
+	_accel_str.to_lower();
+	_accel_char = item.getWord(2, ":");
+	_accel_char.to_lower();
+//	_char_pos = strcspn((char*)_accel_str, (char*)_accel_char);
+    _char_pos = _accel_str.isExist(_accel_char);
+
+	// If it is in on string, we have a short cut key to show
+	
+    if(_char_pos > -1 ){
+		
+		_accel_str = item_str;
+		_accel_str.cutString(_char_pos);
+	
+		_accel_x = _accel_font->getStringWidth(_accel_str);
+		_str_long = _accel_font->getStringWidth(item_str);
+	
+		_accel_char = item_str;
+		_accel_char.deleteChars(0,_char_pos);
+		_accel_char.cutString(1);
+		_char_long = _accel_font->getStringWidth(_accel_char);
+	
+		dev->drawString((st1*2 + smargin/2+1)+_accel_x, posy +st1+2, _char_long,
+			_item_height -st1*2, &str1, _font, WS_LEFT, -1, False);
+
+	}
+
+//--
+
+	    dev->drawString(st1*2 + smargin/2+1, posy +st1+1, w -st1*4 - smargin , _item_height -st1*2, &item_str, _font, WS_LEFT, -1, False);
           }else{
             dev->setHatchPattern(8);
           }
@@ -378,6 +418,47 @@ WSMFtrace("WSCpulldownMenuPopup::draw ERROR.target->_pld_data is NULL!    %s\n",
           }
         }
 
+//--
+	
+	WSCstring _accel_str;
+	WSCstring _accel_char;
+	int _accel_x;
+	int _str_long;
+	int _char_long;
+	int _char_pos;
+	WSCstring str1 = "__";
+	
+	WSDfont* _accel_font = WSGIappFontSet()->getFont(_font);
+
+	// We determinate _sc_str position
+
+	_accel_str = item_str;
+	_accel_str.to_lower();
+	_accel_char = item.getWord(2, ":");
+	_accel_char.to_lower();
+//	_char_pos = strcspn((char*)_accel_str, (char*)_accel_char);
+    _char_pos = _accel_str.isExist(_accel_char);
+
+	// If it is in on string, we have a short cut key to show
+	
+    if(_char_pos > -1 ){
+		
+		_accel_str = item_str;
+		_accel_str.cutString(_char_pos);
+	
+		_accel_x = _accel_font->getStringWidth(_accel_str);
+		_str_long = _accel_font->getStringWidth(item_str);
+	
+		_accel_char = item_str;
+		_accel_char.deleteChars(0,_char_pos);
+		_accel_char.cutString(1);
+		_char_long = _accel_font->getStringWidth(_accel_char);
+		dev->drawString((st1*2 + smargin/2)+_accel_x, posy +st1+1, _char_long,
+			_item_height -st1*2, &str1, _font, WS_LEFT, -1, False);
+
+	}
+
+//--
 
         dev->drawString(st1*2 + smargin/2, posy +st1, w -st1*4 - smargin , _item_height -st1*2, &item_str, _font, WS_LEFT, -1, False);
 
@@ -931,6 +1012,9 @@ void WSCpulldownMenu_draw_mdr1(void* ptr){
   short   _ts_color     = dt->top_shadow_color;
   short   _bs_color     = dt->bottom_shadow_color;
   char*   _label_string = dt->label_string;
+//--
+  char*   _short_cut    = dt->short_cut;
+//--
   short   _label_pixmap = dt->label_pixmap;
   short   _blink_pixmap = dt->blink_pixmap;
   WSCbool _press_state  = dt->press_state;
@@ -1016,11 +1100,78 @@ void WSCpulldownMenu_draw_mdr1(void* ptr){
         blinkfore == False &&
         _bl_type != WS_BACK &&
         _tw_fl == False){
-        // 褷ʤ
+        // 褷ʤ...
       }else{
-        // ɽʸ
+        // ɽʸ...
         if (_tw_fl == False || _bl_fl == False){
-          dev->drawString(sx+1, sy+1, sw, sh, &str, _font, _this->getAlignment(), -1, False);
+
+//--
+
+	// Accelerator key char underline show
+
+	WSCstring _accel_str;
+	WSCstring _accel_char;
+	int _accel_x;
+	int _str_long;
+	int _char_long;
+	int _char_pos;
+	WSCstring str1 = "__";
+	
+	WSDfont* _accel_font = WSGIappFontSet()->getFont(_font);
+
+	// We determinate _sc_str position
+
+	_accel_str = str;
+	_accel_str.to_lower();
+//	_char_pos = strcspn((char*)_accel_str, _short_cut);
+    _char_pos = _accel_str.isExist(_short_cut);
+	
+	// If it is in on string, we have a short cut key to show
+	
+    if(_char_pos > -1 ){
+		
+		_accel_str = str;
+		_accel_str.cutString(_char_pos);
+	
+		_accel_x = _accel_font->getStringWidth(_accel_str);
+		_str_long = _accel_font->getStringWidth(str);
+	
+		_accel_char = str;
+		_accel_char.deleteChars(0,_char_pos);
+		_accel_char.cutString(1);
+		_char_long = _accel_font->getStringWidth(_accel_char);
+
+		switch(_this->getAlignment())
+		{
+
+		
+			case WS_LEFT:
+			
+				// Do nothing
+				break;
+	
+			case WS_CENTER:
+
+				_accel_x = _accel_x + int((sw-_str_long)/2);
+				break;
+	
+			case WS_RIGHT:
+
+				_accel_x = _accel_x + sw - _str_long;
+				break;
+			
+			default:
+			break;
+	
+		}
+	
+	dev->drawString(sx+_accel_x+1, sy+2, _char_long, sh, &str1, _font, WS_LEFT, -1, False);
+	
+	}
+
+//--
+
+	  dev->drawString(sx+1, sy+1, sw, sh, &str, _font, _this->getAlignment(), -1, False);
         }
       }
     }else{
@@ -1072,6 +1223,73 @@ void WSCpulldownMenu_draw_mdr1(void* ptr){
      // 褷ʤ
   }else{
     // ɽʸ
+
+//--
+
+	// Accelerator key char underline show
+
+	WSCstring _accel_str;
+	WSCstring _accel_char;
+	int _accel_x;
+	int _str_long;
+	int _char_long;
+	int _char_pos;
+	WSCstring str1 = "__";
+	
+	WSDfont* _accel_font = WSGIappFontSet()->getFont(_font);
+
+	// We determinate _sc_str position
+
+	_accel_str = str;
+	_accel_str.to_lower();
+//	_char_pos = strcspn((char*)_accel_str, _short_cut);
+    _char_pos = _accel_str.isExist(_short_cut);
+	
+	// If it is in on string, we have a short cut key to show
+	
+    if(_char_pos > -1 ){
+		
+		_accel_str = str;
+		_accel_str.cutString(_char_pos);
+	
+		_accel_x = _accel_font->getStringWidth(_accel_str);
+		_str_long = _accel_font->getStringWidth(str);
+	
+		_accel_char = str;
+		_accel_char.deleteChars(0,_char_pos);
+		_accel_char.cutString(1);
+		_char_long = _accel_font->getStringWidth(_accel_char);
+
+		switch(_this->getAlignment())
+		{
+
+		
+			case WS_LEFT:
+			
+				// Do nothing
+				break;
+	
+			case WS_CENTER:
+
+				_accel_x = _accel_x + int((sw-_str_long)/2);
+				break;
+	
+			case WS_RIGHT:
+
+				_accel_x = _accel_x + sw - _str_long;
+				break;
+			
+			default:
+			break;
+	
+		}
+	
+	dev->drawString(sx+_accel_x, sy+1, _char_long, sh, &str1, _font, WS_LEFT, -1, False);
+
+	}
+
+//--
+
     dev->drawString(sx, sy, sw, sh, &str, _font, _this->getAlignment(), -1, False);
   }
 
