@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCcomboBox.h>
@@ -93,7 +93,7 @@ WSCcomboBox::WSCcomboBox(WSCbase* base,char* objname):WSCform(base,objname){
   _icursor = True;
   _fspace = False;
   _item_height = 20;
-
+  _enable_input = 1;
 
   WSMFpropertyCreateStart
     WSMFparentCheckVerSrc(WSCcomboBox);
@@ -150,6 +150,8 @@ WSCcomboBox::WSCcomboBox(WSCbase* base,char* objname):WSCform(base,objname){
     WSMFpropertyCreate(WSNifieldSkipMode,WSCbool,_skip_mode,WSSifieldSkipMode );
       WSMFpropertySetSelection(WSRbool1,WSRbool1D);
     WSMFpropertyCreate(WSNitemHeight,  WSCuchar, _item_height,WSSitemHeight  );
+    WSMFpropertyCreate(WSNenableInput,WSCbool,_enable_input,WSSenableInput );
+      WSMFpropertySetSelection(WSRbool3,WSRbool3D);
 
     WSMFpropertyValueChangeDef( WSCcomboBox,WSNshadowType ,char);
     WSMFpropertyValueChangeDef( WSCcomboBox,WSNshadowType ,char);
@@ -200,6 +202,7 @@ WSMFproperty(WSCcomboBox, WSNfillSpace,   WSCbool,    _fspace,    False );
 WSMFproperty(WSCcomboBox, WSNcursorAdjust,WSCbool,    _cursor_adjust, True );
 WSMFproperty(WSCcomboBox, WSNifieldSkipMode, WSCbool,  _skip_mode,     False );
 WSMFproperty(WSCcomboBox, WSNitemHeight,     WSCuchar,  _item_height, 20);
+WSMFproperty(WSCcomboBox, WSNenableInput, WSCbool,_enable_input,1);
 
 void WSCcomboBox::setWorkWSNdet(WSCbool fl){
   WSCform::setWorkWSNdet(fl);
@@ -363,6 +366,16 @@ void WSCcomboBox::setWorkWSNblinkPixmap(short no){
 }
 void WSCcomboBox::getWorkWSNblinkPixmap(short*){}
 
+void WSCcomboBox::setWorkWSNenableInput(WSCbool data){
+  if (data == False){
+    _if->setKeyInputDisable(True);
+  }else{
+    _if->setKeyInputDisable(False);
+  }
+}
+
+void WSCcomboBox::getWorkWSNenableInput(WSCbool* data){}
+
 WSCcomboBox::~WSCcomboBox(){
   _menu_popdown();
   if (_win != NULL){
@@ -606,7 +619,11 @@ long WSCcomboBox::_menu_popup(){
   if (height < WS_STRETCH_HEIGHT){
     _win->setVisible(True);
   }else{
+#ifdef WS_EMBED
+    _win->setVisible(True);
+#else
     WSGFstretchPopup(_win);
+#endif
   }
   WSDdev* ldev = _list->getowndev();
   if (ldev != NULL){
@@ -651,7 +668,11 @@ long WSCcomboBox::_menu_popdown(){
     if (height < WS_STRETCH_HEIGHT){
       _win->setVisible(False);
     }else{
+#ifdef WS_EMBED
+      _win->setVisible(False);
+#else
       WSGFstretchPopdown(_win);
+#endif
     }
   }
   if (_timer != NULL){
