@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCvlabel.h>
@@ -41,6 +41,11 @@
 #include <WSCcolorSet.h>
 #include <WSCvifield.h>
 
+#ifdef _WSWINCE
+#include <stdlib.h>
+#define strdup _strdup
+#endif
+
 WSMFguiClassInitialize(WSCgrid,WSCform);
 WSMFpropertyValueChange( WSCgrid, WSNbackColor , short,WS_DF_WORKBACKCOLOR);
 
@@ -461,6 +466,7 @@ long WSCgrid::draw(){
     if (_grad_no == 0){
       dev->setForeColor(_back_color);
       dev->drawFillRect(0,0,_w,_h);
+#ifndef WS_EMBED
       if ((WSGIappDev()->getGuiPolicy() & WS_POLICY_AQUA) != 0 &&
            _bp_color == -1){
         if (_a1_color == -1){
@@ -468,6 +474,7 @@ long WSCgrid::draw(){
         }
         WSGFdrawStripes(dev,_w,_h,_a1_color,_a2_color,_a3_color);
       }
+#endif
       dev->setForeColor(_back_color);
 
     }else{
