@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,18 +14,19 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <basic.h>
 #include <assert.h>
+#include <WScom.h>
 #include <WSCbaseList.h>
 #include <WSCbase.h>
 #include <WSCdevice.h>
@@ -93,8 +94,10 @@ extern WSDmouse* _btronMouse_create_handler();
     WSDmouse::setCreateInstanceHandler(_btronMouse_create_handler);
 extern WSDprivateTimer* _btronPrivatetimer_create();
     WSDprivateTimer::setCreateInstanceHandler((void*)_btronPrivatetimer_create);
+#ifndef NO_SOCKET
 extern WSDsocket* _btronSocket_create_handler();
     WSDsocket::setCreateHandler(_btronSocket_create_handler);
+#endif
 extern WSDtimer* _btronTimer_create_handler();
     WSDtimer::setCreateInstanceHandler(_btronTimer_create_handler);
 
@@ -106,9 +109,10 @@ extern WSDdev* _wsdbtronNwdev_init_();
     WSGIappDevice()->setCreateHandler("nwDev",_wsdbtronNwdev_init_);
 extern WSDdev* _wsdbtronScrdev_init_();
     WSGIappDevice()->setCreateHandler("scrFrameDev",_wsdbtronScrdev_init_);
+#ifndef NO_MWINDEV
 extern WSDdev* _wsdbtronmwindev_init_();
     WSGIappDevice()->setCreateHandler("mwindowDev",_wsdbtronmwindev_init_);
-
+#endif
 extern WSDkeyboard* _btronKeyboard_create_handler();
     WSDkeyboard::setCreateInstanceHandler(_btronKeyboard_create_handler);
 
@@ -376,57 +380,57 @@ long WSDbtronAppDev::initialize(){
 
   short cno;
 
-  cno = WSGIappColorSet()->getColorNo("gray85");
+  cno = WSGIappColorSet()->getColorNo("#d9d9d9"); //gray85
   WSGIappColorSet()->setDefaultColorNo(WS_DF_BACKCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("black");
+  cno = WSGIappColorSet()->getColorNo("#000000"); //black
   WSGIappColorSet()->setDefaultColorNo(WS_DF_FORECOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("gray95");
+  cno = WSGIappColorSet()->getColorNo("#f2f2f2"); //gray95
   WSGIappColorSet()->setDefaultColorNo(WS_DF_TOPSHADOWCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("gray55");
+  cno = WSGIappColorSet()->getColorNo("#8c8c8c"); //gray55
   WSGIappColorSet()->setDefaultColorNo(WS_DF_BOTTOMSHADOWCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("black");
+  cno = WSGIappColorSet()->getColorNo("#000000"); //black
   WSGIappColorSet()->setDefaultColorNo(WS_DF_MENUFORECOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("white");
+  cno = WSGIappColorSet()->getColorNo("#ffffff"); //white
   WSGIappColorSet()->setDefaultColorNo(WS_DF_MENUSELECTFORECOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("gray80");
+  cno = WSGIappColorSet()->getColorNo("#cccccc"); //gray80
   WSGIappColorSet()->setDefaultColorNo(WS_DF_MENUBACKCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("slategray4");
+  cno = WSGIappColorSet()->getColorNo("#6c7b8b"); //slategray4
   WSGIappColorSet()->setDefaultColorNo(WS_DF_MENUSELECTCOLOR,cno);
 
 
-  cno = WSGIappColorSet()->getColorNo("gray95");
+  cno = WSGIappColorSet()->getColorNo("#f2f2f2"); //gray95
   WSGIappColorSet()->setDefaultColorNo(WS_DF_MENUTOPSHADOWCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("gray55");
+  cno = WSGIappColorSet()->getColorNo("#8c8c8c"); //gray55
   WSGIappColorSet()->setDefaultColorNo(WS_DF_MENUBOTTOMSHADOWCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("gray80");
+  cno = WSGIappColorSet()->getColorNo("#cccccc"); //gray80
   WSGIappColorSet()->setDefaultColorNo(WS_DF_DARKBACKCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("white");
+  cno = WSGIappColorSet()->getColorNo("#ffffff"); //white
   WSGIappColorSet()->setDefaultColorNo(WS_DF_WORKBACKCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("gray80");
+  cno = WSGIappColorSet()->getColorNo("#cccccc"); //gray80
   WSGIappColorSet()->setDefaultColorNo(WS_DF_BARSHADOWCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("gray85");
+  cno = WSGIappColorSet()->getColorNo("#d9d9d9"); //gray85
   WSGIappColorSet()->setDefaultColorNo(WS_DF_NWBACKCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("black");
+  cno = WSGIappColorSet()->getColorNo("#000000"); //black
   WSGIappColorSet()->setDefaultColorNo(WS_DF_NWFORECOLOR,cno);
   WSGIappColorSet()->setDefaultColorNo(WS_DF_DARKBOTTOMSHADOWCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("gray95");
+  cno = WSGIappColorSet()->getColorNo("#f2f2f2"); //gray95
   WSGIappColorSet()->setDefaultColorNo(WS_DF_NWTOPSHADOWCOLOR,cno);
 
-  cno = WSGIappColorSet()->getColorNo("gray55");
+  cno = WSGIappColorSet()->getColorNo("#8c8c8c"); //gray55
   WSGIappColorSet()->setDefaultColorNo(WS_DF_NWBOTTOMSHADOWCOLOR,cno);
 
   cno = WSGIappColorSet()->getColorNo("#e0e0ff");
@@ -764,6 +768,7 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d APPL5x2 done\n",__FILE__,__LINE__);
 #endif
   }else if (msg->msg_type == MS_TYPE4){ 
 dbprintf("WSDxappDev::_dispatchEvent %s:%d APPL5x start\n",__FILE__,__LINE__);
+#ifndef NO_WSDTHREAD
     WSDbtronThread* th = NULL;
     memcpy(&th,msg->msg_body.ANYMSG.msg_str,sizeof(W));
     if (th->getCallbackFunction() != NULL){
@@ -774,6 +779,7 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d APPL5x start\n",__FILE__,__LINE__);
         fn(th,th->getCallbackData());
       }
     }
+#endif
   }
 }
 
