@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <basic.h>
 #include <WScom.h>
@@ -134,6 +134,7 @@ long WSDbtronColor::getRGB(long* r,long* g,long* b){
 }
 
 struct color_data color_names[] ={
+#ifndef NO_COLOR_NAME
 {255,250,250,"SNOW"},
 {248,248,255,"GHOST WHITE"},
 {248,248,255,"GHOSTWHITE"},
@@ -213,7 +214,9 @@ struct color_data color_names[] ={
 {255,240,245,"LAVENDERBLUSH"},
 {255,228,225,"MISTY ROSE"},
 {255,228,225,"MISTYROSE"},
+#endif
 {255,255,255,"WHITE"},
+#ifndef NO_COLOR_NAME
 {  0,  0,205,"MEDIUM BLUE"},
 {  0,  0,205,"MEDIUMBLUE"},
 { 65,105,225,"ROYAL BLUE"},
@@ -672,7 +675,9 @@ struct color_data color_names[] ={
 {238,210,238,"THISTLE2"},
 {205,181,205,"THISTLE3"},
 {139,123,139,"THISTLE4"},
+#endif
 {  0,  0,  0,"BLACK"},
+#ifndef NO_COLOR_NAME
 {  0,  0,  0,"GRAY0"},
 {  0,  0,  0,"GREY0"},
 {  3,  3,  3,"GRAY1"},
@@ -889,6 +894,7 @@ struct color_data color_names[] ={
 {139,  0,  0,"DARKRED"},
 {144,238,144,"LIGHT GREEN"},
 {144,238,144,"LIGHTGREEN"},
+#endif
 {  0,  0,  0,NULL}
 };
 
