@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <basic.h>
 #include <btron/WSDbtronAppDev.h>
@@ -1285,6 +1285,7 @@ extern WSCulong WSGFxcolorval(WSDcolor*,WSCuchar,WSCuchar,WSCuchar);
 
 long WSDbtronDraw::drawGradation(long type,short c1,short c2,short c3,
                   short x,short y,WSCushort w,WSCushort h,WSCuchar gradm){
+#ifndef NO_GRADATION
   if (_clip_w == 0 || _clip_h == 0){
     return WS_NO_ERR;
   }
@@ -1644,7 +1645,7 @@ static WSDcolor* color = NULL;
   r.c.bottom = cly_bk+clh_bk + dy;
 
   gset_vis(_gid,r);
-
+#endif
   return WS_NO_ERR;
 }
 
