@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,31 +14,39 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <basic.h>
 #include <unistd.h>
 #ifdef TE
+#ifndef NO_PNG
 #include <btron/img/png.h>
+#endif
+#ifndef NO_JPEG
 extern "C" {
 #include <btron/img/jpeglib.h>
 #include <btron/img/jerror.h>
 };
+#endif
 #else
+#ifndef NO_PNG
 #include <util/png.h>
+#endif
+#ifndef NO_JPEG
 extern "C" {
 #include <util/jpeglib.h>
 #include <util/jerror.h>
 };
 #endif
+#endif
 
 #include <WScom.h>
 #include <WSCimageSet.h>
@@ -57,8 +65,9 @@ long WSGFbtronBufToPixmapG(unsigned char *buf,W* pixmap,long width,long height,l
 long WSGFbtronBmpReadFpToPixmap(FILE* ifile,W* pixmap,W*,long* w,long* h,UB**,UB**);
 long WSGFbtronBmpReadFileToPixmap(char* filename,W* pixmap,W*,long* w,long* h,UB**,UB**);
 long PngReadFileToPixmap(char* filename,GID* mem_gid,GID* mem_gid2,long* w,long* h,UB**,UB**);
+#ifndef NO_JPEG
 extern long JpegReadFileToPixmap(char* filename,long size,GID* mem_gid,GID* mem_gid2,long* w,long* h,UB**,UB**,WSCbool reuse_mem);
-
+#endif
 
 WSMFclassInit(WSDbtronImage,WSDimage);
 
@@ -109,6 +118,7 @@ dbprintf("IMG>> WSDbtronImage::initialize img=%s\n",in.getString());
     in2.replaceString(".XPM",".png",1);
     in = in2;
   }
+#ifndef NO_JPEG
   if (in.isExist(".jpg") != -1 || in.isExist(".JPG") != -1){
      GID mem_gid = 0;
      GID mem_gid2 = 0;
@@ -131,7 +141,9 @@ dbprintf("IMG>> WSDbtronImage::initialize img=%s\n",in.getString());
        long reti;
        char*  ctype = NULL;
        long  ishtml = 0;
+#ifndef NO_SOCKET
        WSGFloadRemoteFile(in.getString(),&pbuf,&ctype,&size,&ishtml,1);
+#endif
        if (pbuf != NULL){
          if (_mode & WS_IMAGE_MODE_REUSE_MEM){
            reti = JpegReadFileToPixmap( pbuf,size, &mem_gid,&mem_gid2,
@@ -157,6 +169,8 @@ dbprintf("IMG>> WSDbtronImage::initialize img=%s\n",in.getString());
 //WSMFtrace("ERROR. WSDbtronImage::initialize file open error. file=%s\n",load_file_name);
      }
   }else
+#endif
+#ifndef NO_PNG
   if (in.isExist(".png") != -1 || in.isExist(".PNG") != -1){
 //WSMFtrace("WSDbtronImage::initialize %s\n",in.getString());
      W mem_gid;
@@ -181,6 +195,7 @@ dbprintf("IMG>> WSDbtronImage::initialize png done..\n");
      }
 
   }else
+#endif
 //WSMFtrace("WSDbtronImage::initialize %s\n",in.getString());
   if (in.isExist(".bmp") != -1 || in.isExist(".BMP") != -1){
      W mem_gid;
@@ -1172,6 +1187,7 @@ long WSGFbtronBmpReadFileToPixmap(char* filename,W* pixmap,W* pixmap2,long* w,lo
 
 //PNG
 
+#ifndef NO_PNG
 void png_cexcept_error(png_structp png_ptr, png_const_charp msg){
    if(png_ptr){
      fprintf(stderr, "png file read error: %s\n", msg);
@@ -1397,6 +1413,9 @@ fprintf(stderr,"png read error: out of memory..\n");
     fclose(ifile);
     return 0;
 }
+#endif
+
+#ifndef NO_JPEG
 struct jpeg_error_mgr2 {
   struct jpeg_error_mgr pub;
   jmp_buf setjmp_buffer;
@@ -1556,7 +1575,6 @@ void jpeg_buf_src (j_decompress_ptr cinfo, char* buf,long size){
   src->pos = 0;
 }
 
-
 long JpegReadFileToPixmap(char* filename,long size,GID* mem_gid,GID* mem_gid2,long* w,long* h,UB** ptr1,UB** ptr2,WSCbool reuse_mem){
     FILE* ifile = NULL;
     if (size == 0){
@@ -1673,4 +1691,4 @@ long JpegReadFileToPixmap(char* filename,long size,GID* mem_gid,GID* mem_gid2,lo
     }
     return 0;
 }
-
+#endif
