@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <basic.h>
 #include <btron/hmi.h>
@@ -83,12 +83,12 @@ WSDbtronKeyboard::~WSDbtronKeyboard(){}
 long xim_lang = WS_EN_NONE;
 long WSDbtronKeyboard::initialize(){
   if (getenv("WS_XIM_LANG")){
-extern long WSGFgetLocaleValue(char*);
-    xim_lang = WSGFgetLocaleValue(getenv("WS_XIM_LANG"));
+extern long WSGFgetEncodingValue(char*);
+    xim_lang = WSGFgetEncodingValue(getenv("WS_XIM_LANG"));
   }
   //ISO8859..
-  if (WSGIappCodeConvert()->getSystemLocale() > WS_EN_NONE &&
-      WSGIappCodeConvert()->getSystemLocale() < WS_EN_UTF8){
+  if (WSGIappCodeConvert()->getSystemEncoding() > WS_EN_NONE &&
+      WSGIappCodeConvert()->getSystemEncoding() < WS_EN_UTF8){
     return WS_NO_ERR;
   }
   return WS_NO_ERR;
