@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,21 +14,22 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 //#include <X11/Xlib.h>
 #define _ANSI_SOURCE
 #include <basic.h>
 #include <btron/event.h>
 #include <WScom.h>
+#ifndef NO_SOCKET
 //#include <x11/WSDxappDev.h>
 #include <btron/WSDbtronSocket.h>
 #include <btron/bsocket.h>
@@ -125,7 +126,7 @@ fprintf(stderr,"WSDbtronSocket::connect socket is udp.\n");
     ret = so_gethostbyname((char*)_dest_naddr,hp,tmpbuf);
   }
   server.sin_family = AF_INET;
-  if (ret < 0){
+  if (hp == NULL){
     server.sin_addr.s_addr = (unsigned long)inet_addr((char*)_dest_naddr);
     if ( server.sin_addr.s_addr == (unsigned long)-1 ) {
 fprintf(stderr,"WSDbtronSocket::connect invarid addr=%s\n",(char*)_dest_naddr);
@@ -747,4 +748,4 @@ void WSDbtronSocket::seterr(int err){
 WSCstring WSDbtronSocket::getLastError(){
   return _error_str;
 }
-
+#endif //NO_SOCKET
