@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <basic.h>
 #include <btron/hmi.h>
@@ -428,6 +428,7 @@ long WSDbtronWinDev::destroyWindow(){
 //    WSGIbtronAppDev()->delWindow(_window);
     wcls_wnd(_window,CLR);
     _window = 0;
+    _gid = 0;
   }
   if (getChildDevListFlag() != False){
     WSDbtronFormDev* pdev = getParentAreaDev();
@@ -534,6 +535,9 @@ dbprintf("WSDbtronFormDev::createPixmap() gcls_env=0x%x\n",ret);
   }
                                                                                 
   _mem_gid = WSGIbtronAppDev()->getNewMemGid(w,h,&_mem_gid_buf);
+  if (_mem_gid < 1){
+    return WS_NO_ERR;
+  }
   WSDwindowDev::createPixmap();
 //dbprintf("WSDbtronWinDev::createPixmap() wh=%d,%d %s\n",w,h,getAttachedClient()->getInstanceName());
   _setup_pixmap(0,0,w,h,_bg,_bg_pix);
@@ -576,10 +580,10 @@ long WSDbtronWinDev::createContext(){
   return WS_NO_ERR;
 }
 long WSDbtronWinDev::destroyContext(){
-  if (_gid > 0){
-    gcls_env(_gid);
+//  if (_gid > 0){
+//    gcls_env(_gid);
     _gid = 0;
-  }
+//  }
   return WS_NO_ERR;
 }
 WSCbool WSDbtronWinDev::getParentVisible(){
