@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifdef TE
 #include <tstring.h>
@@ -85,8 +85,9 @@ void WSGFsetRect(RECT* r,short x,short y,WSCushort w,WSCushort h){
 
 TF_CTX tc_to_string_ctx = NULL;
 TF_CTX string_to_tc_ctx = NULL;
-
+//#define NO_LIBTF
 char* WSGFbtronTcToString(TC* src){
+#ifndef NO_LIBTF
 //#ifndef TE
   if (tc_to_string_ctx == NULL){
     ERR ret = tf_open_ctx(&tc_to_string_ctx);
@@ -128,10 +129,12 @@ char* WSGFbtronTcToString(TC* src){
   buffer[len] = 0;
   return (char*)buffer;
 //#endif
-//  return NULL;
+#endif
+  return NULL;
 }
 
 TC* WSGFbtronStringToTc(char* src,long* tlen){
+#ifndef NO_LIBTF
 //#ifdef TE
 //  WSCstring str(src,WS_EN_UTF8);
 //  long tclen = eucstotcs(NULL,(UB*)str.getString(WS_EN_EUCJP));
@@ -207,8 +210,11 @@ TC* WSGFbtronStringToTc(char* src,long* tlen){
   *tlen = len;
   return tcs;
 //#endif
+#endif
+  return NULL;
 }
 TC* WSGFbtronStringToTc2(char* src,long* tlen){
+#ifndef NO_LIBTF
   if (string_to_tc_ctx == NULL){
     ERR ret = tf_open_ctx(&string_to_tc_ctx);
     if( ret != 0){
@@ -252,6 +258,8 @@ TC* WSGFbtronStringToTc2(char* src,long* tlen){
   }
   *tlen = len;
   return tcs;
+#endif
+return NULL;
 }
 
 TC begin_ascii[5] = { 0xffa2,0x6,0x300,0,0x102 };
