@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall 
-// not be used in advertising or otherwise to promote the sale, use or other 
-// dealings in this Software without prior written authorization from  
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team 
+// shall not be used in advertising or otherwise to promote the sale, use or 
+// other dealings in this Software without prior written authorization from  
+// WideStudio Development Team.
 
 #include <basic.h>
 #include "xunicode.h"
@@ -32,6 +32,16 @@
 #include <stdarg.h>
 #include <string.h>
 
+static char* xu_lang = NULL;
+static char xu_language[3] = {0, 0, 0};
+//int xunicode_enable = False;
+char* XUGetLang(){
+  if (xu_lang == NULL){
+    return "C";
+  }
+  return xu_lang;
+} 
+
 //static int xu_locale_encoding = XU_CONV_ISO8859(1);
 static int xu_locale_encoding = XU_CONV_EUCJP;
 int XUGetLocale(){
@@ -43,11 +53,6 @@ BOOL xunicode_enable = FALSE;
 #else
 #include <X11/Xlocale.h>
 #include <locale.h>
-int xunicode_enable = False;
-
-static const char* xu_lang = NULL;
-static char xu_language[3] = {0, 0, 0};
-
 
 
 /* link list */
@@ -90,19 +95,30 @@ static char* xu_charset[XU_FONT_COUNT] =
 /* encodings */
 #include "iso8859.h"
 #include "koi8r.h"
-#include "jis0208.h"
-#include "ksc5601.h"
-#include "gb2312.h"
-#include "big5.h"
 static XUChar table_rev_latin2 [ 1024];
 static XUChar table_rev_koi8r_1[ 1024];
 static XUChar table_rev_koi8r_2[ 1024];
 static XUChar table_rev_iso8859[65536];
-static XUChar table_rev_jis0208[65536];
-static XUChar table_rev_ksc5601[65536];
-static XUChar table_rev_gb2312 [65536];
-static XUChar table_rev_big5   [65536];
 
+#ifndef NO_JAPANESE
+#include "jis0208.h"
+static XUChar table_rev_jis0208[65536];
+#endif
+
+#ifndef NO_KSC5601
+#include "ksc5601.h"
+static XUChar table_rev_ksc5601[65536];
+#endif
+
+#ifndef NO_GB2312
+static XUChar table_rev_gb2312 [65536];
+#include "gb2312.h"
+#endif
+
+#ifndef NO_BIG5
+static XUChar table_rev_big5   [65536];
+#include "big5.h"
+#endif
 
 static void XUInitTable();
 #ifndef WIN32
@@ -176,11 +192,18 @@ static void XUInitTable()
   }
   
   for(i = 0; i < 65536; i++) table_rev_iso8859[i] = 0;
+#ifndef NO_JAPANESE
   for(i = 0; i < 65536; i++) table_rev_jis0208[i] = 0;
+#endif
+#ifndef NO_KSC5601
   for(i = 0; i < 65536; i++) table_rev_ksc5601[i] = 0;
+#endif
+#ifndef NO_GB2312
   for(i = 0; i < 65536; i++) table_rev_gb2312 [i] = 0;
+#endif
+#ifndef NO_BIG5
   for(i = 0; i < 65536; i++) table_rev_big5   [i] = 0;
-
+#endif
   for(i = 9; i >= 1; i--) {
     c = (i << 8) + 128;
     for(j = 0; j < 128; j++, c++) {
@@ -190,6 +213,7 @@ static void XUInitTable()
   
   c1 = 0x21;
   c2 = 0x21;
+#ifndef NO_JAPANESE
   for(i = 0; i < MAX_JIS_CHARS; i++) {
     c = table_jis0208[i];
     if(c) table_rev_jis0208[c] = (c1 << 8) + c2;
@@ -199,9 +223,11 @@ static void XUInitTable()
       c1++;
     }
   }
+#endif
   
   c1 = 0x21;
   c2 = 0x21;
+#ifndef NO_GB2312
   for(i = 0; i < 8178; i++) {
     c = table_gb2312[i];
     if(c) table_rev_gb2312[c] = (c1 << 8) + c2;
@@ -211,9 +237,11 @@ static void XUInitTable()
       c1++;
     }
   }
-  
+#endif
+
   c1 = 0xa1;
   c2 = 0x40;
+#ifndef NO_BIG5
   for(i = 0; i < 13973; i++) {
     c = table_big5[i];
     if(c) table_rev_big5[c] = (c1 << 8) + c2;
@@ -225,9 +253,11 @@ static void XUInitTable()
       c1++;
     }
   }
-  
+#endif
+ 
   c1 = 0x81;
   c2 = 0x41;
+#ifndef NO_KSC5601
   for(i = 0; i < 12816; i++) {
     c = table_ksc5601[i];
     if(c) table_rev_ksc5601[c] = (c1 << 8) + c2;
@@ -241,9 +271,11 @@ static void XUInitTable()
       c1++;
     }
   }
+#endif
   
   c1 = 0xca;
   c2 = 0xa1;
+#ifndef NO_KSC5601
   for(i = 0; i < 4888; i++) {
     c = table_ksc5601_hanja[i];
     if(c) table_rev_ksc5601[c] = (c1 << 8) + c2;
@@ -253,6 +285,7 @@ static void XUInitTable()
       c1++;
     }
   }
+#endif
 }
 
 
@@ -272,13 +305,14 @@ static void XUInitLocale()
 
 static void XUInitEncoding()
 {
-extern void WSGFsetLangVal(long);
-#define WS_EN_LANG_JP 1
+#if 0
+//extern void WSGFsetLangVal(long);
+//#define WS_EN_LANG_JP 1
   if(XUIsEncoding("utf8")) {
     xu_locale_encoding = XU_CONV_UTF8;
-    if(!strcmp(xu_language, "ja")){
-      WSGFsetLangVal(WS_EN_LANG_JP);
-    }
+//    if(!strcmp(xu_language, "ja")){
+//      WSGFsetLangVal(WS_EN_LANG_JP);
+//    }
   } else if(XUIsEncoding("sjis") || XUIsEncoding("shiftjis")) {
     xu_locale_encoding = XU_CONV_SJIS;
   } else if(XUIsEncoding("eucjp")) {
@@ -295,15 +329,15 @@ extern void WSGFsetLangVal(long);
     xu_locale_encoding = XUGetISO8859();
   }
   if(xu_locale_encoding != XU_CONV_NONE) return;
-
+#endif
 #ifdef MacOS
   if(!strcmp(xu_language, "ja")){
     xu_locale_encoding = XU_CONV_UTF8;
-    WSGFsetLangVal(WS_EN_LANG_JP);
+//    WSGFsetLangVal(WS_EN_LANG_JP);
     return;
   }
 #endif //MacOS
-
+#if 0
   if(!strcmp(xu_language, "cs")) xu_locale_encoding = XU_CONV_ISO8859(2);
   if(!strcmp(xu_language, "he")) xu_locale_encoding = XU_CONV_ISO8859(8);
   if(!strcmp(xu_language, "hr")) xu_locale_encoding = XU_CONV_ISO8859(2);
@@ -317,6 +351,9 @@ extern void WSGFsetLangVal(long);
   if(xu_locale_encoding != XU_CONV_NONE) return;
   
   xu_locale_encoding = XU_CONV_ISO8859(1);
+#endif
+extern long WSGFgetEncoding(char*);
+  xu_locale_encoding = WSGFgetEncoding(xu_lang);
 }
 
 
@@ -342,7 +379,7 @@ static void XUInitFontSet()
   }
 }
 
-
+#if 0
 static Bool XUIsEncoding(const char* enc)
 {
   const char* p1 = 0;
@@ -376,7 +413,7 @@ static int XUGetISO8859()
   if(iso < 1 || iso > 15) return XU_CONV_NONE;
   return XU_CONV_ISO8859(iso);
 }
-
+#endif
 
 static void XUInitSetting()
 {
@@ -684,12 +721,19 @@ int XUQueryChar(XUChar* c, Display* display, XUInfoFont* fi)
   
   check = 0x2000;
   
+#ifndef NO_KSC5601
   if(0xac00 <= *c && *c <= 0xd7a3 && table_rev_ksc5601[*c]) {
     charset = XU_FONT_KSC5601;
     *c = table_rev_ksc5601[*c];
-  } else if(0xff61 <= *c && *c <= 0xff9f) {
+  } else
+#endif
+  if(0xff61 <= *c && *c <= 0xff9f) {
+#ifndef NO_JAPANESE
     charset = XU_FONT_JIS0201;
     *c -= 0xfec0;
+#else
+    charset = XU_FONT_UNICODE;
+#endif
   } else {
     charset = XU_FONT_UNICODE;
   }
@@ -716,30 +760,38 @@ int XUQueryChar(XUChar* c, Display* display, XUInfoFont* fi)
       }
       if(fi->none[XU_FONT_UNICODE]) check = 0;
       break;
+#ifndef NO_JAPANESE
     case XU_FONT_JIS0208:
       if(*c >= check && table_rev_jis0208[*c]) {
         charset = XU_FONT_JIS0208;
         *c = table_rev_jis0208[*c];
       }
       break;
+#endif
+#ifndef NO_KSC5601
     case XU_FONT_KSC5601:
       if(*c >= check && table_rev_ksc5601[*c]) {
         charset = XU_FONT_KSC5601;
         *c = table_rev_ksc5601[*c];
       }
       break;
+#endif
+#ifndef NO_GB2312
     case XU_FONT_GB2312:
       if(*c >= check && table_rev_gb2312[*c]) {
         charset = XU_FONT_GB2312;
         *c = table_rev_gb2312[*c];
       }
       break;
+#endif
+#ifndef NO_BIG5
     case XU_FONT_BIG5:
       if(*c >= check && table_rev_big5[*c]) {
         charset = XU_FONT_BIG5;
         *c = table_rev_big5[*c];
       }
       break;
+#endif
     }
   }
   
@@ -2193,14 +2245,19 @@ int XUctEncode(XUChar* dest, int max, const char* text, int length)
       }
     }
     if(code == XU_FONT_GB2312) {
+#ifndef NO_GB2312
       if(c1 < 0xa1 || c1 > 0xf7) ch = '?';
       if(c2 < 0xa1 || c2 > 0xfe) ch = '?';
       if(!ch) ch = table_gb2312[(c1 - 0xa1) * 94 + (c2 - 0xa1)];
+#endif
     } else if(code == XU_FONT_JIS0208) {
+#ifndef NO_JAPANESE
       if(c1 < 0xa1 || c1 > 0xf4) ch = '?';
       if(c2 < 0xa1 || c2 > 0xfe) ch = '?';
       if(!ch) ch = table_jis0208[(c1 - 0xa1) * 94 + (c2 - 0xa1)];
+#endif
     } else if(code == XU_FONT_KSC5601) {
+#ifndef NO_KSC5601
       if(0x81 <= c1 && c1 <= 0xc8) {
         if(c2 < 0x41 || c2 > 0xfe) ch = '?';
         if(0x5a < c2 && c2 < 0x61) ch = '?';
@@ -2214,10 +2271,13 @@ int XUctEncode(XUChar* dest, int max, const char* text, int length)
       } else {
         ch = '?';
       }
+#endif
     } else if(code == XU_FONT_BIG5) {
+#ifndef NO_BIG5
       if(c1 < 0xa1 || c1 > 0xfe) ch = '?';
       if(c2 < 0xa1 || c2 > 0xfe) ch = '?';
       if(!ch) ch = table_big5[(c1 - 0xa1) * 94 + (c2 - 0xa1)];
+#endif
     }
     if(ch && ret < max) {
       *dest = ch;
@@ -2289,19 +2349,38 @@ int XUctDecode(char* dest, int max, const XUChar* text, int length)
       if(ret++ < max) *(dest++) = (char)(ch - 0xfec0);
       continue;
     }
+#ifndef NO_GB2312
     if(xu_locale_encoding == XU_CONV_EUCCN && table_rev_gb2312[ch]) {
       code = XU_FONT_GB2312;
-    } else if(xu_locale_encoding == XU_CONV_EUCKR && table_rev_ksc5601[ch]) {
+    } else
+#endif
+#ifndef NO_KSC5601
+    if(xu_locale_encoding == XU_CONV_EUCKR && table_rev_ksc5601[ch]) {
       code = XU_FONT_KSC5601;
-    } else if(table_rev_jis0208[ch]) {
+    } else
+#endif
+#ifndef NO_JAPANESE
+    if(table_rev_jis0208[ch]) {
       code = XU_FONT_JIS0208;
-    } else if(xu_locale_encoding != XU_CONV_EUCCN && table_rev_gb2312[ch]) {
+    } else
+#endif
+#ifndef NO_GB2312
+    if(xu_locale_encoding != XU_CONV_EUCCN && table_rev_gb2312[ch]) {
       code = XU_FONT_GB2312;
-    } else if(xu_locale_encoding != XU_CONV_EUCKR && table_rev_ksc5601[ch]) {
+    } else
+#endif
+#ifndef NO_KSC5601
+    if(xu_locale_encoding != XU_CONV_EUCKR && table_rev_ksc5601[ch]) {
       code = XU_FONT_KSC5601;
     }
+#endif
+#ifndef NO_GB2312
     if(code == XU_FONT_GB2312 ) ch = table_rev_gb2312 [ch];
+#endif
+#ifndef NO_JAPANESE
     if(code == XU_FONT_JIS0208) ch = table_rev_jis0208[ch];
+#endif
+#ifndef NO_KSC5601
     if(code == XU_FONT_KSC5601) {
       if((table_rev_ksc5601[ch] & 0x00ff) > 0x0080) {
         ch = table_rev_ksc5601[ch] - 0x8080;
@@ -2309,6 +2388,7 @@ int XUctDecode(char* dest, int max, const XUChar* text, int length)
         ch = 0;
       }
     }
+#endif
     if(code && ch) {
       if(g0 != code) {
         if(ret++ < max) *(dest++) = '\x1b';
@@ -2382,12 +2462,15 @@ XUChar XUCharEncode(const char* text, int max, int code)
   c2 = (XUChar)(unsigned char)*text;
   if(!c2) return '?';
   if(code == XU_CONV_EUCJP) {
+#ifndef NO_JAPANESE
     if(c1 == 0x8e) return c2 + 0xfec0;
     if(c1 < 0xa1 || c1 > 0xf4) return '?';
     if(c2 < 0xa1 || c2 > 0xfe) return '?';
 //printf("EUCJP=0x%02x%02x num=%d 0x%04x\n",c1,c2, (c1 - 0xa1) * 94 + (c2 - 0xa1),table_jis0208[(c1 - 0xa1) * 94 + (c2 - 0xa1)]);
     ret = table_jis0208[(c1 - 0xa1) * 94 + (c2 - 0xa1)];
+#endif
   } else if(code == XU_CONV_SJIS) {
+#ifndef NO_JAPANESE
     if(c1 == 0x80 || c1 == 0xa0 || c1 > 0xfc) return '?';
     if(c2  < 0x40 || c2 == 0x7f || c2 > 0xfc) return '?';
     if(c1 >= 0xe0) c1 -= 0x40;
@@ -2395,7 +2478,9 @@ XUChar XUCharEncode(const char* text, int max, int code)
     num = (c1 - 0x81) * 188 + (c2 - 0x40);
 //printf("SJIS=0x%02x%02x num=%d 0x%04x\n",c1,c2,num,table_jis0208[num]);
     if(num < MAX_JIS_CHARS) ret = table_jis0208[num];
+#endif
   } else if(code == XU_CONV_EUCKR) {
+#ifndef NO_KSC5601
     if(0x81 <= c1 && c1 <= 0xc8) {
       if(c2 < 0x41 || c2 > 0xfe) return '?';
       if(0x5a < c2 && c2 < 0x61) return '?';
@@ -2407,16 +2492,21 @@ XUChar XUCharEncode(const char* text, int max, int code)
       if(c2 < 0xa1 || c2 > 0xfe) return '?';
       ret = table_ksc5601_hanja[(c1 - 0xca) * 94 + (c2 - 0xa1)];
     }
+#endif
   } else if(code == XU_CONV_EUCCN) {
+#ifndef NO_GB2312
     if(c1 < 0xa1 || c1 > 0xf7) return '?';
     if(c2 < 0xa1 || c2 > 0xfe) return '?';
     ret = table_gb2312[(c1 - 0xa1) * 94 + (c2 - 0xa1)];
+#endif
   } else if(code == XU_CONV_BIG5) {
+#ifndef NO_BIG5
     if(c1 < 0xa1 || c1 > 0xf9) return '?';
     if(c2 < 0x40 || c2 > 0xfe) return '?';
     if(0x7e < c2 && c2 < 0xa1) return '?';
     if(c2 > 0x7e) c2 -= 0x22;
     ret = table_big5[(c1 - 0xa1) * 157 + (c2 - 0x40)];
+#endif
   }
   if(ret) return ret;
   
@@ -2481,13 +2571,16 @@ int XUCharDecode(char* dest, int max, XUChar ch, int code)
   }
   
   if(code == XU_CONV_EUCJP) {
+#ifndef NO_JAPANESE
     if(0xff61 <= ch && ch <= 0xff9f) {
       ret = (ch - 0xfec0) + 0x8e00;
     } else {
       ret = table_rev_jis0208[ch];
       if(ret) ret += 0x8080;
     }
+#endif
   } else if(code == XU_CONV_SJIS) {
+#ifndef NO_JAPANESE
     if(0xff61 <= ch && ch <= 0xff9f) {
       if(max >= 1) dest[0] = (char)(ch - 0xfec0);
       return 1;
@@ -2502,13 +2595,20 @@ int XUCharDecode(char* dest, int max, XUChar ch, int code)
       if(r2 > 0x7e) r2++;
       ret = (r1 << 8) + r2;
     }
+#endif
   } else if(code == XU_CONV_EUCKR) {
+#ifndef NO_KSC5601
     ret = table_rev_ksc5601[ch];
+#endif
   } else if(code == XU_CONV_EUCCN) {
+#ifndef NO_GB2312
     ret = table_rev_gb2312[ch];
     if(ret) ret += 0x8080;
+#endif
   } else if(code == XU_CONV_BIG5) {
+#ifndef NO_BIG5
     ret = table_rev_big5[ch];
+#endif
   }
   if(!ret) {
     if(max >= 1) dest[0] = '?';
