@@ -1,20 +1,33 @@
-/*-------------------------------------------------------------------------*/
-/*  J3W ver 6.43  3D Animation Kit                                         */
-/*  j3dproc.cpp   04/04/2001                                               */
-/*  Copyright (C) 1996 - 2001 Jun Mizutani <jun.mizutani@nifty.ne.jp>      */
-/*                      All rights reserved.                               */
-/*                                                                         */
-/*   This file is part of the J3W 3D Animation Kit, and is covered under   */
-/*  the terms of the GNU General Public License, version 2. This file has  */
-/*  NO WARRANTY. See file COPYING for copyright details.                   */
-/*                                                                         */
-/*-------------------------------------------------------------------------*/
+//
+// Copyright (C) 1999-2004 WideStudio Development Team
+//
+// Permission is hereby granted, free of charge, to any person obtaining a copy
+// of this software and associated documentation files (the "Software"), to
+// deal in the Software without restriction, including without limitation the
+// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+// sell copies of the Software, and to permit persons to whom the Software is
+// furnished to do so, subject to the following conditions:
+//
+// The above copyright notice and this permission notice shall be included in
+// all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// SOFTWARE.
+// Except as contained in this notice, the name of WideStudio Development Team 
+// shall not be used in advertising or otherwise to promote the sale, use or 
+// other dealings in this Software without prior written authorization from  
+// WideStudio Development Team.
 
 #ifdef WS
 #include <stdio.h>
 #else //WS
 #include  <iomanip.h>
-#include  <iostream.h>
+#include  <iostream>
 #endif //WS
 #include  <stdlib.h>
 #include  <stdio.h>
@@ -25,8 +38,12 @@
 #endif //WS
 #include  "misc3d.h"
 
+#ifndef WS
+using namespace std;
+#endif
+
 const int version1 =  6;
-const int version2 = 43;
+const int version2 = 45;
 
 const int _RAND_MAX = 2147483647;
 
@@ -435,36 +452,24 @@ int TProcess::execute(long &delta)
                     break;
                 case 0xB :
                     if (param >= 0) {
-#ifdef WS
-                        _reg = j3w_round(sqrt(param));
-#else //WS
-                        _reg = round(sqrt(param));
-#endif //WS
+                        _reg = iround(sqrt(param));
                         if (_reg == 0) fl |= f_ZERO;
                         if (_reg < 0) fl |= f_MINUS;
                     } else err = 0xF2;
                     break;
                 case 0xC :
-#ifdef WS
-                    _reg = j3w_round(sin(RAD(param))*10000);
-#else //WS
-                    _reg = round(sin(RAD(param))*10000);
-#endif //WS
+                    _reg = iround(sin(RAD(param))*10000);
                     if (_reg == 0) fl |= f_ZERO;
                     if (_reg < 0) fl |= f_MINUS;
                     break;
                 case 0xD :
-#ifdef WS
-                    _reg = j3w_round(cos(RAD(param))*10000);
-#else //WS
-                    _reg = round(cos(RAD(param))*10000);
-#endif //WS
+                    _reg = iround(cos(RAD(param))*10000);
                     if (_reg == 0) fl |= f_ZERO;
                     if (_reg < 0) fl |= f_MINUS;
                     break;
                 case 0xE :
                     if ((_reg == 0) && (param == 0)) _reg = 0;
-                    else _reg = DEG(atan2(_reg, param));
+                    else _reg = DEG(atan2(double(_reg), double(param)));
                     if (_reg == 0) fl |= f_ZERO;
                     if (_reg < 0) fl |= f_MINUS;
                     break;
