@@ -1,21 +1,34 @@
-/*-------------------------------------------------------------------------*/
-/*  J3W ver 6.40  3D Animation Kit                                         */
-/*  jrlcode.cpp    9/17/98                                                 */
-/*  Copyright (C) 1995 - 1999 Jun Mizutani <mizutani.jun@nifty.ne.jp>      */
-/*                      All rights reserved.                               */
-/*                                                                         */
-/*   This file is part of the J3W 3D Animation Kit, and is covered under   */
-/*  the terms of the GNU General Public License, version 2. This file has  */
-/*  NO WARRANTY. See file COPYING for copyright details.                   */
-/*                                                                         */
-/*-------------------------------------------------------------------------*/
+//
+// Copyright (C) 1999-2004 WideStudio Development Team
+//
+// Permission is hereby granted, free of charge, to any person obtaining a copy
+// of this software and associated documentation files (the "Software"), to
+// deal in the Software without restriction, including without limitation the
+// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+// sell copies of the Software, and to permit persons to whom the Software is
+// furnished to do so, subject to the following conditions:
+//
+// The above copyright notice and this permission notice shall be included in
+// all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// SOFTWARE.
+// Except as contained in this notice, the name of WideStudio Development Team 
+// shall not be used in advertising or otherwise to promote the sale, use or 
+// other dealings in this Software without prior written authorization from  
+// WideStudio Development Team.
 
 #ifdef WS
 #include <stdio.h>
 #else //WS
 #include    <iomanip.h>
-#include    <iostream.h>
-#include    <fstream.h>
+#include    <iostream>
+#include    <fstream>
 #endif //WS
 #include    "jrlcode.h"
 #ifdef WS
@@ -70,7 +83,7 @@ dbprintf("cCode::LoadObjFile %s:%d done0 endpos=%d\n",__FILE__,__LINE__,endpos);
            return 1;
         }
 
-        long n;
+        unsigned long n;
         while(source >> hex >> n){
 dbprintf("cCode::LoadObjFile %s:%d endpos=%d n=%d\n",__FILE__,__LINE__,endpos,n);
           set_code(n);
