@@ -1,28 +1,45 @@
-/*-------------------------------------------------------------------------*/
-/*  J3W ver 6.43  3D Animation Kit                                         */
-/*  spaceh3d.cpp   4/ 8/2001                                               */
-/*  Copyright (C) 1996 - 2001  Jun Mizutani  <mizutani.jun@nifty.ne.jp>    */
-/*                      All rights reserved.                               */
-/*                                                                         */
-/*   This file is part of the J3W 3D Animation Kit, and is covered under   */
-/*  the terms of the GNU General Public License, version 2. This file has  */
-/*  NO WARRANTY. See file COPYING for copyright details.                   */
-/*                                                                         */
-/*-------------------------------------------------------------------------*/
+//
+// Copyright (C) 1999-2004 WideStudio Development Team
+//
+// Permission is hereby granted, free of charge, to any person obtaining a copy
+// of this software and associated documentation files (the "Software"), to
+// deal in the Software without restriction, including without limitation the
+// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+// sell copies of the Software, and to permit persons to whom the Software is
+// furnished to do so, subject to the following conditions:
+//
+// The above copyright notice and this permission notice shall be included in
+// all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// SOFTWARE.
+// Except as contained in this notice, the name of WideStudio Development Team 
+// shall not be used in advertising or otherwise to promote the sale, use or 
+// other dealings in this Software without prior written authorization from  
+// WideStudio Development Team.
 
 #ifdef WS
 #include <stdio.h>
 #else //WS
-#include <iostream.h>
+#include <iostream>
 #endif //WS
 #include <stdlib.h>
 #include <math.h>
 #include "spaceh3d.h"
 
+#ifndef WS
+using namespace std;
+#endif
+
 ClipType   FrontClip, BackClip, LeftClip, RightClip, TopClip, BottomClip;
 
 TSpaceH3D::TSpaceH3D(int objNo, long front, long back):
-                    light_dir(100.0, 0.0, 0.0)
+                    light_dir(100, 0, 0)
 {
     maxObj = objNo;
     pEye = 0;
@@ -211,15 +228,9 @@ void  TSpaceH3D::ClipLine(Vector &p1, Vector &p2, ClipType &clip, Vector &p)
     long dz = p2.z - p1.z;
     double numerator = clip.kx*p1.x + clip.ky*p1.y + clip.kz*p1.z + clip.m;
     double denominator = -clip.kx*dx - clip.ky*dy - clip.kz*dz;
-#ifdef WS
-    p.x = j3w_round(dx * numerator / denominator) + p1.x;
-    p.y = j3w_round(dy * numerator / denominator) + p1.y;
-    p.z = j3w_round(dz * numerator / denominator) + p1.z;
-#else //WS
-    p.x = round(dx * numerator / denominator) + p1.x;
-    p.y = round(dy * numerator / denominator) + p1.y;
-    p.z = round(dz * numerator / denominator) + p1.z;
-#endif //WS
+    p.x = iround(dx * numerator / denominator) + p1.x;
+    p.y = iround(dy * numerator / denominator) + p1.y;
+    p.z = iround(dz * numerator / denominator) + p1.z;
 }
 
 inline int TSpaceH3D::visible(Vector &p, ClipType &clip)
@@ -290,6 +301,7 @@ void TSpaceH3D::Clip3D_PolygonList()
     Vector va[POLYGONVERTEX];
     Polygon3D *p;
     TPolygons *po;
+    double x0,y0,z0,x1,y1,z1,x2,y2,z2;
 
     double wh_ratio = double(PScreen->get_width()) / double(PScreen->get_height());
     pglistmax = 0;
@@ -309,27 +321,44 @@ void TSpaceH3D::Clip3D_PolygonList()
                                 int m = -(p->index[k]);
                                 if (m < pp->Polygon.Vertex.GetCount()) {
                                     va[kk] = pp->Polygon.Vertex.vert[m]->eye;
-#ifdef WS
-                                    va[kk].z = j3w_round(va[kk].z * wh_ratio);
-#else //WS
-                                    va[kk].z = round(va[kk].z * wh_ratio);
-#endif //WS
+                                    va[kk].z = iround(va[kk].z * wh_ratio);
                                     if (angle == 1) va[kk].x = va[kk].x >> 1;
                                     kk++;
                                 }
                             }
                         } else {
                             va[kk] = po->Vertex.vert[p->index[k]]->eye;
-#ifdef WS
-                            va[kk].z = j3w_round(va[kk].z * wh_ratio);
-#else //WS
-                            va[kk].z = round(va[kk].z * wh_ratio);
-#endif //WS
+                            va[kk].z = iround(va[kk].z * wh_ratio);
                             if (angle == 1) va[kk].x = va[kk].x >> 1;
                             kk++;
                         }
                     }
+
                     n = kk;
+
+                    /* when parent's vertex is referred, calc normal vector */
+                    Vector v[3];
+
+                    if ((n > 2) && (p->f_normal == 0)) {
+                        for(int h=0; h<3; h++) {        /* for every vertex */
+                            if (p->index[h] < 0) {
+                                THObj3D* pp = ObjArray[i]->parent;
+                                if (pp != 0) {
+                                    v[h] = pp->Polygon.Vertex.vert[-(p->index[h])]->eye;
+                                }
+                            } else {
+                                v[h] = po->Vertex.vert[p->index[h]]->eye;
+                            }
+                        }
+                        x0 = v[0].x; y0 = v[0].y; z0 = v[0].z;
+                        x1 = v[1].x; y1 = v[1].y; z1 = v[1].z;
+                        x2 = v[2].x; y2 = v[2].y; z2 = v[2].z;
+                        p->enormal.x = (y1-y0)*(z2-z1) - (z1-z0)*(y2-y1);
+                        p->enormal.y = (z1-z0)*(x2-x1) - (x1-x0)*(z2-z1);
+                        p->enormal.z = (x1-x0)*(y2-y1) - (y1-y0)*(x2-x1);
+                        p->enormal.normalize();
+                    }
+
                     Clip_volume(n, va);
                     if (n != 0) {
                         pglist[pglistmax].index = VertCount;
@@ -337,6 +366,7 @@ void TSpaceH3D::Clip3D_PolygonList()
                         pglist[pglistmax].color = p->color;
                         pglist[pglistmax].reflection = p->reflection;
                         pglist[pglistmax].ambient = p->ambient;
+                        pglist[pglistmax].normal = p->enormal;
                         pglist[pglistmax].off_center = p->off_center;
                         for(int k=0; k<n; k++) ClippedVertex[VertCount+k] = va[k];
                         if (pglistmax < (MAXPOLYGON-1)) pglistmax++;
@@ -389,23 +419,40 @@ double Power(double X, int N)
 
 void shading(double cos_theta, double specl, PolygonType *p)
 {
-    double specular = specl * HIGHLIGHT * p->reflection * 255;
+    int specular = int(0.5 + specl * HIGHLIGHT * p->reflection * 255);
     if (cos_theta < 0) cos_theta = 0;
     cos_theta = cos_theta * (1.0 - p->ambient) + p->ambient;
-    p->r = int(0.5 + p->r * cos_theta + specular);
+
+    double Y  =  0.2990 * p->r + 0.5870 * p->g + 0.1140 * p->b;
+    double Cb = -0.1687 * p->r - 0.3313 * p->g + 0.5000 * p->b;
+    double Cr =  0.5000 * p->r - 0.4187 * p->g - 0.0813 * p->b;
+
+    Y *= cos_theta;
+
+    p->r = int(0.0 + Y + 1.4020*Cr);
+    p->g = int(0.0 + Y - 0.3441*Cb - 0.7141*Cr);
+    p->b = int(0.0 + Y + 1.7720*Cb);
+
+    if (p->r < 0) p->r = 0;
+    if (p->g < 0) p->g = 0;
+    if (p->b < 0) p->b = 0;
+
+    p->r += specular;
+    p->g += specular;
+    p->b += specular;
+
     if (p->r > 255) p->r = 255;
-    p->g = int(0.5 + p->g * cos_theta + specular);
     if (p->g > 255) p->g = 255;
-    p->b = int(0.5 + p->b * cos_theta + specular);
     if (p->b > 255) p->b = 255;
 }
 
 void TSpaceH3D::ShadePolygon()
 {
     int  k, m;
-    double x0,x1,x2,y0,y1,y2,z0,z1,z2;
     double cos_theta;
 
+    double hw_ratio = double(PScreen->get_height()) / double(PScreen->get_width());
+
     max2D = pglistmax;
     for (int i = 0; i<pglistmax; i++) {
         k = pglist[i].n;
@@ -421,42 +468,6 @@ void TSpaceH3D::ShadePolygon()
                     pglist[i].color = ColNum*ColWidth + pglist[i].color -16 + SYSCOLOR;
             } else  pglist[i].color = (pglist[i].color) * Shade + SYSCOLOR;
         } else {
-            x0 = ClippedVertex[m + 0].x;
-            x1 = ClippedVertex[m + 1].x;
-            x2 = ClippedVertex[m + 2].x;
-            y0 = ClippedVertex[m + 0].y;
-            y1 = ClippedVertex[m + 1].y;
-            y2 = ClippedVertex[m + 2].y;
-            z0 = ClippedVertex[m + 0].z;
-            z1 = ClippedVertex[m + 1].z;
-            z2 = ClippedVertex[m + 2].z;
-
-            if ((x0 == x1) && (y0 == y1) && (z0 == z1) && (k > 3)) {
-                x1 = x2; y1 = y2; z1 = z2;
-                x2 = ClippedVertex[m + 3].x;
-                y2 = ClippedVertex[m + 3].y;
-                z2 = ClippedVertex[m + 3].z;
-            }
-            if ((x0 == x2) && (y0 == y2) && (z0 == z2) && (k > 3)) {
-                x2 = ClippedVertex[m + 3].x;
-                y2 = ClippedVertex[m + 3].y;
-                z2 = ClippedVertex[m + 3].z;
-            }
-            if ((x1 == x2) && (y1 == y2) && (z1 == z2) && (k > 3)) {
-                x2 = ClippedVertex[m + 3].x;
-                y2 = ClippedVertex[m + 3].y;
-                z2 = ClippedVertex[m + 3].z;
-            }
-            if (angle == 1) {
-                x0 = x0 * 2;
-                x1 = x1 * 2;
-                x2 = x2 * 2;
-            }
-            Vector_d normal;
-            normal.x = (y1-y0)*(z2-z1) - (z1-z0)*(y2-y1);
-            normal.y = (z1-z0)*(x2-x1) - (x1-x0)*(z2-z1);
-            normal.z = (x1-x0)*(y2-y1) - (y1-y0)*(x2-x1);
-            normal.normalize();
 
             long sum_x = 0;
             long sum_y = 0;
@@ -464,7 +475,7 @@ void TSpaceH3D::ShadePolygon()
             for(int j=0; j < k; j++) {
               sum_x += ClippedVertex[m + j].x;
               sum_y += ClippedVertex[m + j].y;
-              sum_z += ClippedVertex[m + j].z;
+              sum_z += int(ClippedVertex[m + j].z * hw_ratio + 0.5);
             }
             sum_x /= k;
             sum_y /= k;
@@ -477,7 +488,8 @@ void TSpaceH3D::ShadePolygon()
 
             Vector_d center = Vector(0,0,0) - pglist[i].center_g;
             center.normalize();
-            cos_theta = center.dot_product(normal);
+            cos_theta = center.dot_product(pglist[i].normal);
+
             if (cos_theta < 0) pglist[i].color = -1;
             else if (pglist[i].color >= 256) {
 
@@ -523,8 +535,8 @@ void TSpaceH3D::ShadePolygon()
                     }
                     light_vec.normalize();
 
-                    double cos_ln = light_vec.dot_product(normal);
-                    Vector_d reflection = 2 * cos_ln * normal - light_vec;
+                    double cos_ln = light_vec.dot_product(pglist[i].normal);
+                    Vector_d reflection = 2 * cos_ln * pglist[i].normal - light_vec;
 
                     double cos_nr = center.dot_product(reflection);
                     if (cos_nr < 0) cos_nr = 0;
