@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <mac/WSDmacKeyboard.h>
 #include <mac/WSDmacFont.h>
@@ -138,8 +138,8 @@ void WSDmacKeyboard::_im_destroy(XIM,XPointer ptr,XPointer){
 
 long WSDmacKeyboard::initialize(){
   //ISO8859..
-  if (WSGIappCodeConvert()->getSystemLocale() > WS_EN_NONE &&
-      WSGIappCodeConvert()->getSystemLocale() < WS_EN_UTF8){
+  if (WSGIappCodeConvert()->getSystemEncoding() > WS_EN_NONE &&
+      WSGIappCodeConvert()->getSystemEncoding() < WS_EN_UTF8){
     return WS_NO_ERR;
   }
 #if 0 //XXZZ
@@ -618,7 +618,7 @@ WSCbool WSDmacKeyboard::deliverKeyEvent(XEvent* ev){
   _with_alt = ((ev->macKey.state & Mod1Mask) != 0     );
   _is_cursor = IsCursorKey(key);
   _is_function = IsFunctionKey(key);
-  setText(buffer,WSGIappCodeConvert()->getSystemLocale());
+  setText(buffer,WSGIappCodeConvert()->getSystemEncoding());
 
   if (key == WSK_Delete || key == WSK_Insert){
     _is_tty_function = True;
