@@ -14,8 +14,16 @@
 #include <stdarg.h>
 #include <string.h>
 
-static const char* xu_lang = NULL;
+static char* xu_lang = NULL;
 static char xu_language[3] = {0, 0, 0};
+
+char* XUGetLang(){
+  if (xu_lang == NULL){
+    return "C";
+  }
+  return xu_lang;
+}
+
 static int xu_locale_encoding = XU_CONV_NONE;
 int xunicode_enable = False;
 int XUGetLocale(){
@@ -273,13 +281,14 @@ static void XUInitLocale()
 
 static void XUInitEncoding()
 {
-extern void WSGFsetLangVal(long);
-#define WS_EN_LANG_JP 1
+#if 0
+//extern void WSGFsetLangVal(long);
+//#define WS_EN_LANG_JP 1
   if(XUIsEncoding("utf8")) {
     xu_locale_encoding = XU_CONV_UTF8;
-    if(!strcmp(xu_language, "ja")){
-      WSGFsetLangVal(WS_EN_LANG_JP);
-    }    
+//    if(!strcmp(xu_language, "ja")){
+//      WSGFsetLangVal(WS_EN_LANG_JP);
+//    }    
   } else if(XUIsEncoding("sjis") || XUIsEncoding("shiftjis")) {
     xu_locale_encoding = XU_CONV_SJIS;
   } else if(XUIsEncoding("eucjp")) {
@@ -296,15 +305,16 @@ extern void WSGFsetLangVal(long);
     xu_locale_encoding = XUGetISO8859();
   }
   if(xu_locale_encoding != XU_CONV_NONE) return;
-
+#endif
 #ifdef MacOS
   if(!strcmp(xu_language, "ja")){
     xu_locale_encoding = XU_CONV_UTF8;
-    WSGFsetLangVal(WS_EN_LANG_JP);
+    setenv("LANG","ja_JP.UTF-8",1);
+//    WSGFsetLangVal(WS_EN_LANG_JP);
     return;
   }
 #endif //MacOS
-  
+#if 0
   if(!strcmp(xu_language, "cs")) xu_locale_encoding = XU_CONV_ISO8859(2);
   if(!strcmp(xu_language, "he")) xu_locale_encoding = XU_CONV_ISO8859(8);
   if(!strcmp(xu_language, "hr")) xu_locale_encoding = XU_CONV_ISO8859(2);
@@ -318,6 +328,9 @@ extern void WSGFsetLangVal(long);
   if(xu_locale_encoding != XU_CONV_NONE) return;
   
   xu_locale_encoding = XU_CONV_ISO8859(1);
+#endif
+extern long WSGFgetEncoding(char*);
+  xu_locale_encoding = WSGFgetEncoding(xu_lang);
 }
 
 #ifndef MacOSX32
@@ -344,7 +357,7 @@ static void XUInitFontSet()
   }
 }
 #endif //MacOSX32
-
+#if 0
 static Bool XUIsEncoding(const char* enc)
 {
   const char* p1 = 0;
@@ -378,7 +391,7 @@ static int XUGetISO8859()
   if(iso < 1 || iso > 15) return XU_CONV_NONE;
   return XU_CONV_ISO8859(iso);
 }
-
+#endif
 #ifndef MacOSX32
 
 static void XUInitSetting()
