@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <nx/WSDnxAppDev.h>
@@ -73,7 +73,7 @@ _nxSocket_init   WSGIappXsocketInit;
 
 // A new semaphore function for initializing.
 int pthread_sem_init_np(pthread_sem_t* semp){
-  semp->locked = 0;
+  semp->value = 1;
   pthread_mutex_init(&(semp->mutex),NULL);
   pthread_cond_init(&(semp->lock_free),NULL);
   return 0;
@@ -82,10 +82,9 @@ int pthread_sem_init_np(pthread_sem_t* semp){
 // A new semaphore function for locking.
 int pthread_sem_lock_np(pthread_sem_t* semp){
   pthread_mutex_lock(&(semp->mutex));
-  while(semp->locked){
+  if (--semp->value < 0){
     pthread_cond_wait(&(semp->lock_free),&(semp->mutex));
   }
-  semp->locked++;
   pthread_mutex_unlock(&(semp->mutex));
   return 0;
 }
@@ -93,13 +92,9 @@ int pthread_sem_lock_np(pthread_sem_t* semp){
 // A new semaphore function for unlocking.
 int pthread_sem_unlock_np(pthread_sem_t* semp){
   pthread_mutex_lock(&(semp->mutex));
-  if (semp->locked < 1){
-    semp->locked = 0;
-    pthread_mutex_unlock(&(semp->mutex));
-    return -1;
+  if (++semp->value < 1){
+    pthread_cond_signal(&(semp->lock_free));
   }
-  semp->locked = 0;
-  pthread_cond_broadcast(&(semp->lock_free));
   pthread_mutex_unlock(&(semp->mutex));
   return 0;
 }
