@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall 
-// not be used in advertising or otherwise to promote the sale, use or other 
-// dealings in this Software without prior written authorization from  
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team 
+// shall not be used in advertising or otherwise to promote the sale, use or 
+// other dealings in this Software without prior written authorization from  
+// WideStudio Development Team.
 
 #include "xunicode.h"
 
@@ -49,10 +49,15 @@ BOOL xunicode_enable = FALSE;
 #include <locale.h>
 int xunicode_enable = False;
 
-static const char* xu_lang = NULL;
+static char* xu_lang = NULL;
 static char xu_language[3] = {0, 0, 0};
 
-
+char* XUGetLang(){
+  if (xu_lang == NULL){
+    return "C";
+  }
+  return xu_lang;
+} 
 
 /* link list */
 static XUInfoDisplay* xu_info_display = NULL;
@@ -276,13 +281,14 @@ static void XUInitLocale()
 
 static void XUInitEncoding()
 {
-extern void WSGFsetLangVal(long);
-#define WS_EN_LANG_JP 1
+#if 0
+//extern void WSGFsetLangVal(long);
+//#define WS_EN_LANG_JP 1
   if(XUIsEncoding("utf8")) {
     xu_locale_encoding = XU_CONV_UTF8;
-    if(!strcmp(xu_language, "ja")){
-      WSGFsetLangVal(WS_EN_LANG_JP);
-    }
+//    if(!strcmp(xu_language, "ja")){
+//      WSGFsetLangVal(WS_EN_LANG_JP);
+//    }
   } else if(XUIsEncoding("sjis") || XUIsEncoding("shiftjis")) {
     xu_locale_encoding = XU_CONV_SJIS;
   } else if(XUIsEncoding("eucjp")) {
@@ -299,15 +305,15 @@ extern void WSGFsetLangVal(long);
     xu_locale_encoding = XUGetISO8859();
   }
   if(xu_locale_encoding != XU_CONV_NONE) return;
-
+#endif
 #ifdef MacOS
   if(!strcmp(xu_language, "ja")){
     xu_locale_encoding = XU_CONV_UTF8;
-    WSGFsetLangVal(WS_EN_LANG_JP);
+//    WSGFsetLangVal(WS_EN_LANG_JP);
     return;
   }
 #endif //MacOS
-
+#if 0
   if(!strcmp(xu_language, "cs")) xu_locale_encoding = XU_CONV_ISO8859(2);
   if(!strcmp(xu_language, "he")) xu_locale_encoding = XU_CONV_ISO8859(8);
   if(!strcmp(xu_language, "hr")) xu_locale_encoding = XU_CONV_ISO8859(2);
@@ -321,6 +327,9 @@ extern void WSGFsetLangVal(long);
   if(xu_locale_encoding != XU_CONV_NONE) return;
   
   xu_locale_encoding = XU_CONV_ISO8859(1);
+#endif
+extern long WSGFgetEncoding(char*);
+  xu_locale_encoding = WSGFgetEncoding(xu_lang);
 }
 
 
@@ -346,7 +355,7 @@ static void XUInitFontSet()
   }
 }
 
-
+#if 0
 static Bool XUIsEncoding(const char* enc)
 {
   const char* p1 = 0;
@@ -380,7 +389,7 @@ static int XUGetISO8859()
   if(iso < 1 || iso > 15) return XU_CONV_NONE;
   return XU_CONV_ISO8859(iso);
 }
-
+#endif
 
 static void XUInitSetting()
 {
