@@ -245,7 +245,7 @@ public:
   char* getInstanceName();
   WSCushort getWidth();
   WSCushort getHeight();
-  void update();
+  virtual void update() = 0;
   void exit(long);
 };
 
@@ -260,7 +260,12 @@ public:
   WSCbase(WSCbase*,char*);
   ~WSCbase();
 
-  virtual long init();
+  %extend {
+    virtual long init() { return self->initialize(); };
+  }
+#ifdef SWIGPYTHON
+  virtual long initialize();
+#endif
   WSCbool getInitialized();
 
   void onMouseIn(WSCpoint*);
@@ -342,6 +347,11 @@ public:
   long redraw();
   long cdraw();
 
+  WSDdev* getdev();
+  WSDdev* getowndev();
+  WSDdev* getParentDev();
+  //WSDdev* attachdev();
+
 static WSCbase* getNewInstance(char* cname,WSCbase*,char*);
 static WSCbase* getFocusInstance();
 static WSCbase* getSpecialFocusInstance();
@@ -356,7 +366,7 @@ class WSDmouse {
     WSCbool getMousePosition(short* x,short* y);
     WSCbool getMousePosition(short* x,short* y,WSCbase*);
 
-    long getMouseStatus();
+    virtual long getMouseStatus() = 0;
     void setMousePosition(short x, short y);
     void setMouseCursor(long);
 
@@ -428,7 +438,7 @@ public:
 };
 class WSDkeyboard {
   public:
-    void setKey(long);
+    virtual void setKey(long) = 0;
     long getKey();
     WSCbool withShift();
     WSCbool withLock();
@@ -1377,7 +1387,7 @@ public:
     WSCsheet(WSCbase* parent, char* name);
     virtual ~WSCsheet();
 
-    virtual long init();
+    //virtual long init();
     virtual long clear(long col = WSCSHEET_DEF_COLS, long row = WSCSHEET_DEF_ROWS);
 
 public:
@@ -1602,6 +1612,49 @@ public:
   long      dbRefresh();
 };
 
+class WSDdev {
+  public:
+    virtual WSCbool getReady() = 0;
+};
+
+class WSDmwindowDev :public WSDdev{
+  public: 
+    WSDmwindowDev();
+    virtual WSCbool getReady();
+    virtual long beginDraw(short,short,WSCushort,WSCushort,WSCbool absolute = True,WSCbool scaling = True);
+    virtual long endDraw();
+    %apply unsigned short* OUTPUT { WSCushort* w, WSCushort* h };
+    void getGeometry(WSCushort* w,WSCushort* h);
+
+    virtual long createPixmap(WSCushort w,WSCushort h) = 0;
+    virtual long destroyPixmap() = 0;
+
+    virtual long copyToWindow(WSDdev*,short x,short y,WSCushort w,WSCushort h,
+                              short dx,short dy) = 0;
+    virtual long copyFromWindow(WSDdev*,short x,short y,WSCushort w,WSCushort h,
+                              short dx,short dy) = 0;
+    virtual long copyToWindowWithMask(WSDdev*,short x,short y,
+                                WSCushort w,WSCushort h,
+                                short dx,short dy,WSDimage*) = 0;
+    virtual long copyToWindowWithMask(WSDdev*,short x,short y,
+                                WSCushort w,WSCushort h,
+                                short dx,short dy,WSDmwindowDev*) = 0;
+
+    virtual long initBuffer() = 0;
+    virtual long setBufferRGB(WSCushort x,WSCushort y,
+                              WSCuchar r,WSCuchar g,WSCuchar b) = 0;
+    %apply unsigned char* OUTPUT { WSCuchar* r, WSCuchar* g, WSCuchar* b };
+    virtual long getBufferRGB(WSCushort x,WSCushort y,
+                              WSCuchar* r,WSCuchar* g,WSCuchar* b) = 0;
+    virtual long putBufferToPixmap() = 0;
+    //WSCuchar* getBuffer();
+    //long setBuffer(WSCuchar*);
+    virtual long loadFile(char*);
+    virtual long saveFile(char*,long);
+
+static WSDmwindowDev* getNewInstance();
+};
+
 //kind of mouse button state ,return value of WSDmouse::getMouseStatus()
 #define WS_MOUSE_SHIFT     (1<<0)
 #define WS_MOUSE_LOCK      (1<<1)
@@ -1733,6 +1786,11 @@ public:
 #define  WSEV_CHILD_ADDED         49
 #define  WSEV_SELECTION_CH        50
 
+#define WS_IMAGE_DEFAULT  (0)
+#define WS_IMAGE_XPM      (1)
+#define WS_IMAGE_BMP      (2)
+#define WS_IMAGE_PNG      (3)
+#define WS_IMAGE_JPG      (4)
 
 //-----------------------------------------------------------------------------
 #ifndef MSW //UNIX - Xwindow System
