@@ -1,3 +1,29 @@
+//
+// Copyright (C) 1999-2004 WideStudio Development Team
+//
+// Permission is hereby granted, free of charge, to any person obtaining a copy
+// of this software and associated documentation files (the "Software"), to
+// deal in the Software without restriction, including without limitation the
+// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+// sell copies of the Software, and to permit persons to whom the Software is
+// furnished to do so, subject to the following conditions:
+//
+// The above copyright notice and this permission notice shall be included in
+// all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// SOFTWARE.
+// Except as contained in this notice, the name of WideStudio Development Team 
+// shall not be used in advertising or otherwise to promote the sale, use or 
+// other dealings in this Software without prior written authorization from  
+// WideStudio Development Team.
+
+
 #include <WSCdb.h>
 #include <WSCdbDrv.h>
 #include <WSCdbPgsql.h>
@@ -427,6 +453,56 @@ long WSCdbPgsqlRecord::open(const char* stmt, short eCousor, short eAccess)
 	strncpy(buf1, stmt, 6);
 	buf1[6] = '\0';
 
+	oid[0] = '\0';
+	_oiduse = 0;
+
+	if(WSGFstricmp(buf1, "select") == 0) {
+		select = True;
+		if(!_pDB->getbeginTranmode()) {
+			if(_pDB->beginTran() == WS_ERR) {
+				return WS_ERR;
+			}
+			_pDB->setbeginTranmode(PGSQL_TRAN_RECORD_FUNCTION);
+		}
+		sprintf(_CurrsorName, "WSdbCursor%d%d", _pDB->getProcessId(), _pDB->getCursor());
+#ifndef BINARY
+		sprintf(buf1, "DECLARE %s CURSOR FOR ", _CurrsorName);
+#else
+		sprintf(buf1, "DECLARE %s BINARY CURSOR FOR ", _CurrsorName);
+#endif	
+		sql = (char*)&stmt[6];
+		getTableName((char*)stmt, _tableName, sizeof(_tableName));
+		strcpy(oid, "select ");
+
+		if(_access != WSCDB_SQL_CONCUR_READ_ONLY) {
+			sprintf(buf2, "%s select count(a.attname) from "
+				          "pg_class c, pg_attribute a "
+						  "where c.relname = '%s' "
+						  "and a.attrelid = c.oid and attname='oid'", buf1, _tableName);
+			// oid item check
+			res = PQexec(_pDB->_hconn, buf2);
+			TRACE_U(("WSCdbPgsqlRecord::open oid %s", buf2));
+			if(!IS_PGSQL_ERROR(res)) {
+				PQclear(res);
+				sprintf(buf2, "FETCH ALL IN %s", _CurrsorName);
+				res = PQexec(_pDB->_hconn, buf2);
+				if(atoi((char*)PQgetvalue(res, 0, 0)) > 0) {
+					_oiduse = 1;
+					sprintf(oid, "select %s.oid as oid_%s,", _tableName, _CurrsorName);
+					TRACE_U(("WSCdbPgsqlRecord::open oid use"));
+				}
+				PQclear(res);
+				sprintf(buf2, "CLOSE %s", _CurrsorName);
+				res = PQexec(_pDB->_hconn, buf2);
+			}
+			PQclear(res);
+		}
+	} else {
+		_CurrsorName[0] = '\0';
+		buf1[0] = '\0';
+		sql = (char*)stmt;
+	}
+/*
 	if(_access != WSCDB_SQL_CONCUR_READ_ONLY
 		&& WSGFstricmp(buf1, "select") == 0) {
 		select = True;
@@ -478,6 +554,7 @@ long WSCdbPgsqlRecord::open(const char* stmt, short eCousor, short eAccess)
 		oid[0] = '\0';
 		_oiduse = 0;
 	}
+*/
 	buf = new char[strlen(stmt) + strlen(buf1) + sizeof(oid) + 1];
 
 	sprintf(buf, "%s%s%s", buf1, oid, sql);
