@@ -1,3 +1,29 @@
+//
+// Copyright (C) 1999-2004 WideStudio Development Team
+//
+// Permission is hereby granted, free of charge, to any person obtaining a copy
+// of this software and associated documentation files (the "Software"), to
+// deal in the Software without restriction, including without limitation the
+// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+// sell copies of the Software, and to permit persons to whom the Software is
+// furnished to do so, subject to the following conditions:
+//
+// The above copyright notice and this permission notice shall be included in
+// all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// SOFTWARE.
+// Except as contained in this notice, the name of WideStudio Development Team 
+// shall not be used in advertising or otherwise to promote the sale, use or 
+// other dealings in this Software without prior written authorization from  
+// WideStudio Development Team.
+
+
 #include <WScom.h>
 #include <WSCvlabel.h>
 #include <WSCclassInformation.h>
@@ -42,15 +68,38 @@ public:
 static _dll_init _execute_initialize;
 
 void _lang_init_proc(){
+#ifndef NO_ENGLISH_MSG
 #include "English.cpp"
+#endif
+#ifndef NO_JAPANESE_EUC_MSG
 #ifndef _WSWIN32
 #include "Japanese.cpp"
 #endif
+#endif
+#ifndef NO_JAPANESE_SJIS_MSG
 #include "Japanese-sjis.cpp"
+#endif
+#ifndef NO_JAPANESE_UTF8_MSG
 #ifndef _WSWIN32
 #include "Japanese-utf8.cpp"
+#endif
+#endif
+#ifndef NO_KSC5601_MSG
+#ifndef _WSWIN32
 #include "Korean.cpp"
 #endif
+#endif
+#ifndef NO_GB2312_MSG
+#ifndef _WSWIN32
+#include "Chinese-zh_cn.cpp"
+#endif
+#endif
+#ifndef NO_ES_MSG
+#ifndef _WSWIN32
+#include "Espanol.cpp"
+#endif
+#endif
+
 }
 
 class _lang_init_{
@@ -99,6 +148,7 @@ WSCsheet::WSCsheet(WSCbase* base, char* objname) : WSCform(base, objname)
 	_vautoNumber = True;
 	_hautoNumber = True;
 	_initVisible = True;
+	_adjust = False;
 	
 	_vdb = NULL;
 	_dataSource = WSGFstrdup("");
@@ -2302,6 +2352,11 @@ WSCstring WSCsheet::getFixedCellText(long col, long row)
 }
 void WSCsheet::adjustScrollBar()
 {
+	if(_adjust) {
+		return;
+	}
+	_adjust = True;
+
 	long width = this->getProperty(WSNwidth);
 	long height = this->getProperty(WSNheight);
 
@@ -2323,7 +2378,8 @@ void WSCsheet::adjustScrollBar()
 	_hscrBar->setPropertyV(WSNmaximum,(WSCulong)(_cols + val - getFixedColumnCount() - 1));
 	_hscrBar->setPropertyV(WSNsliderSize,(WSCulong)val);
 	_hscrBar->setPropertyV(WSNincrement, (WSCushort)1);
-	_hscrBar->setPropertyV(WSNvalue, (WSCulong)getTopVisibleCol()-1);
+//	_hscrBar->setPropertyV(WSNvalue, (WSCulong)getTopVisibleCol()-1);
+	_hscrBar->setPropertyV(WSNvalue, (WSCulong)getTopVisibleCol()-getFixedColumnCount());
 	
 	
 	_vscrBar->setProperty(WSNx, _clientWidth + _shadow_thick);
@@ -2334,9 +2390,10 @@ void WSCsheet::adjustScrollBar()
 	_vscrBar->setPropertyV(WSNmaximum,(WSCulong)(_rows + val - getFixedRowCount() - 1));
 	_vscrBar->setPropertyV(WSNsliderSize,(WSCulong)val);
 	_vscrBar->setPropertyV(WSNincrement, (WSCushort)1);
-	_vscrBar->setPropertyV(WSNvalue, (WSCulong)getTopVisibleRow()-1);
-
+//	_vscrBar->setPropertyV(WSNvalue, (WSCulong)getTopVisibleRow()-1);
+	_vscrBar->setPropertyV(WSNvalue, (WSCulong)getTopVisibleRow()-getFixedRowCount());
 
+	_adjust = False;
 }
 char* WSCsheet::getUseScrBarClass()
 {
