@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,18 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
+#ifdef _WSWINCE
+#include <winsock.h>
+#endif
 #include <win/WSDwinAppDev.h>
 #include <WSCbaseList.h>
 #include <win/WSDwinKeyboard.h>
@@ -42,7 +45,6 @@
 #include <win/WSDwinThread.h>
 #include <win/WSDwinMutex.h>
 #include <win/WSDwinSemaphore.h>
-
 #define COLOR_MAX 256
 WSMFclassInit(WSDwinAppDev,WSDappDev);
 WSDappDev* _winAppDev_create_handler(){
@@ -132,6 +134,7 @@ WSMFtrace("WSGFdeviceInitialize done:\n");
   }
 }
 WSDwinAppDev::WSDwinAppDev(){
+dbprintf("WSDwinAppDev::WSDwinAppDev %s:%d start this=0x%x \n",__FILE__,__LINE__,this);
   _hinst = 0;
   _mfocus_dev = NULL;
   _palette = 0;
@@ -421,7 +424,16 @@ dbprintf("WndProc %s:%d done4\n",__FILE__,__LINE__);
 #if 0
   long ptr = GetWindowLong(hWnd,GWL_USERDATA);
 #else
+#ifndef _WSWINCE
   HANDLE ptr = GetProp(hWnd,"frm");
+#else
+  unsigned short str1[4];
+  str1[0] = 'f';
+  str1[1] = 'r';
+  str1[2] = 'm';
+  str1[3] = 0;
+  HANDLE ptr = GetProp(hWnd,str1);
+#endif
 #endif
   WSDwinformDev* frm = (WSDwinformDev*)ptr;
   if (message == WM_CHAR ||
@@ -441,7 +453,7 @@ dbprintf("WndProc %s:%d done5\n",__FILE__,__LINE__);
       return 0;
     }
   }
-
+#ifndef _WSWINCE
   if (message == WM_NCHITTEST){
 //printf("displatch.. nchittest..\n",hWnd);
     LRESULT ret = DefWindowProc(hWnd,message,uParam,lParam);
@@ -458,6 +470,7 @@ dbprintf("WndProc %s:%d done6\n",__FILE__,__LINE__);
 dbprintf("WndProc %s:%d done7\n",__FILE__,__LINE__);
     return ret;
   }
+#endif
   if (frm == NULL){
     HRESULT ret1 = DefWindowProc(hWnd,message,uParam,lParam);
 dbprintf("WndProc %s:%d done0\n",__FILE__,__LINE__);
@@ -509,12 +522,20 @@ dbprintf("WndProc %s:%d done8\n",__FILE__,__LINE__);
           return ret;
         }
       }
+#ifndef _WSWINCE
       if (_msg.message == WM_DESTROY ||
           _msg.message == WM_NCDESTROY){
           _loop_in = 0;
 dbprintf("WndProc %s:%d done9\n",__FILE__,__LINE__);
           return ret;
       } 
+#else
+      if (_msg.message == WM_DESTROY){
+          _loop_in = 0;
+dbprintf("WndProc %s:%d done9\n",__FILE__,__LINE__);
+          return ret;
+      } 
+#endif
       ret2 = GetMessage(&_msg,NULL,0,0);
       TranslateMessage(&_msg);
       DispatchMessage(&_msg);
@@ -689,6 +710,7 @@ long WSDwinAppDev::setInitPrm(int iprm,char** cprm){
 }
 long WSDwinAppDev::setWndProc(void* proc){
   _wnd_proc = proc;
+  return WS_NO_ERR;
 }
 void* WSDwinAppDev::getWndProc(){
   return _wnd_proc;
