@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <win/WSDwinColor.h>
@@ -62,6 +62,7 @@ long WSDwinColor::initialize(){
   long  rval = 0;
   long  gval = 0;
   long  bval = 0;
+  long  aval = 255;
 
   char* cname = getSrc();
 
@@ -73,10 +74,16 @@ long WSDwinColor::initialize(){
     long slen = strlen(cname);
     if(slen == 4){
       sscanf( cname,"#%1x%1x%1x",&rval,&gval,&bval);
+    }else if(slen == 5){
+      sscanf( cname,"#%1x%1x%1x%1x",&rval,&gval,&bval,&aval);
     }else if(slen == 7){
       sscanf( cname,"#%2x%2x%2x",&rval,&gval,&bval);
+    }else if(slen == 9){
+      sscanf( cname,"#%2x%2x%2x%2x",&rval,&gval,&bval,&aval);
     }else if(slen == 13){
       sscanf( cname,"#%4x%4x%4x",&rval,&gval,&bval);
+    }else if(slen == 17){
+      sscanf( cname,"#%4x%4x%4x%4x",&rval,&gval,&bval,&aval);
     }else{
       //black...
     }
