@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,22 +14,24 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <win/WSDwinAppDev.h>
 #include <WScom.h>
 #include <WSDfile.h>
 #include <win/WSDwinExecute.h>
 #include <stdio.h>
+#ifndef _WSWINCE
 #include <fcntl.h>
 #include <signal.h>
+#endif
 #include <WSCbaseList.h>
 #include <WSDfileSystem.h>
 #include <WSClocaleSet.h>
@@ -98,7 +100,9 @@ WSMFtrace("WSDwinExecute::_callback! pid=%d\n",_pid);
 }
 void WSDwinExecute::_check_thread(DWORD ptr){
   WSDwinExecute* obj = (WSDwinExecute*)ptr;
+#ifndef _WSWINCE
   WaitForInputIdle((HANDLE)obj->_pid,INFINITE);
+#endif
   DWORD ret = STILL_ACTIVE;
   while(ret == STILL_ACTIVE){
     WaitForSingleObject((HANDLE)obj->_pid,1);
@@ -180,10 +184,16 @@ WSMFtrace("WSDwinExecute::execute #%s# dir=#%s#  XXZZg1\n",exename,(char*)_dir_n
   PROCESS_INFORMATION pi;
   STARTUPINFO si;
   ZeroMemory(&si,sizeof(STARTUPINFO));
+#ifndef _WSWINCE
   GetStartupInfo(&si);
+#endif
   ZeroMemory(&pi,sizeof(PROCESS_INFORMATION));
   si.cb = sizeof(STARTUPINFO);
+#ifndef _WSWINCE
   si.dwFlags = STARTF_USESHOWWINDOW;
+#else
+  si.dwFlags = 0;
+#endif
   si.wShowWindow = SW_SHOWNORMAL;
 
   _exe_name = WSGIappFileSystem()->adjustFileName(exename);
@@ -192,6 +202,7 @@ WSMFtrace("WSDwinExecute::execute #%s# dir=#%s#  XXZZg1\n",exename,(char*)_dir_n
   WSCstring tmp(_exe_name);
   while( tmp.replaceString("//","/",0));
   while( tmp.replaceString("/","\\",0));
+#ifndef _WSWINCE
   WSCstring dname;
   if (strcmp(_dir_name.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),"")){
     dname = WSGIappFileSystem()->adjustFileName(_dir_name);
@@ -204,12 +215,14 @@ WSMFtrace("WSDwinExecute::execute2 dir=#%s#  XXZZg1\n",dname.getString(WSGIappLo
       return WS_ERR;
     }
   }
+#endif
 WSMFtrace("WSDwinExecute::execute2 #%s#  XXZZg1\n",tmp.getString( WSGIappLocaleSet()->getSystemLocaleEncoding() ));
   if (_thread2 != NULL){
     TerminateThread(_thread2,0);
     CloseHandle(_thread2);
     _thread2 = NULL;
   }
+#ifndef _WSWINCE
   if (mode == WS_EXEC_RDWR || mode == WS_EXEC_RD || mode == WS_EXEC_WR){
 //WSMFtrace("WSDwinExecute::execute2 #%s#\n",(char*)tmp);
     if (_thread != NULL){
@@ -287,10 +300,18 @@ WSMFtrace("WSDwinExecute::execute this=0x%x thread=0x%x err=%d\n",this,_thread,G
 
     return WS_NO_ERR;
   }
+#endif
 //  CreateProcess(NULL,tmp,NULL,NULL,FALSE,DETACHED_PROCESS,NULL,NULL,&si,&pi);
+#ifndef _WSWINCE
   BOOL ret1 = CreateProcess(NULL,
        tmp.getString( WSGIappLocaleSet()->getSystemLocaleEncoding()),
        NULL,NULL,FALSE,0,NULL,NULL,&si,&pi);
+#else
+  WSCushort* tmpstr = WSGFgetUCS2(tmp,WS_EN_DEFAULT);
+  BOOL ret1 = CreateProcess(NULL,tmpstr,
+       NULL,NULL,FALSE,0,NULL,NULL,&si,&pi);
+  delete tmpstr;
+#endif
 //printf("WSDwinExecute::exec pid=0x%x %d %d\n",pi.hProcess,ret1,GetLastError());
   if (pi.hProcess == 0){
     return WS_ERR;
