@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,20 +14,22 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <win/WSDwinFS.h>
 #include <WSCstring.h>
 #include <WSDenv.h>
+#ifndef _WSWINCE
 #include <unistd.h>
 #include <sys/stat.h>
+#endif
 #include <WSClistData.h>
 #include <WSClocaleSet.h>
 #include <Winnetwk.h>
@@ -72,39 +74,78 @@ static char  buf[1024];
 long WSDwinFS::rename(char* old_name,char* new_name){
   WSCstring name1(old_name);
   WSCstring name2(new_name);
+#ifndef _WSWINCE
   remove(name2.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
   long ret = ::rename(name1.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),
                       name2.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
   if (ret == 0){
     return WS_NO_ERR;
   }
+#else
+  WSCushort* str1 = WSGFgetUCS2(name1.getString(),WS_EN_DEFAULT);
+  WSCushort* str2 = WSGFgetUCS2(name2.getString(),WS_EN_DEFAULT);
+  DeleteFile(str2);
+  long ret = ::MoveFile(str1,str2);
+  delete str1;
+  delete str2;
+  if (ret != 0){
+    return WS_NO_ERR;
+  }
+#endif
   return WS_ERR;
 }
 
 long WSDwinFS::deleteFile(char* name){
   WSCstring fname(name);
   char* fn = fname.getString(WSGIappLocaleSet()->getSystemLocaleEncoding());
+#ifndef _WSWINCE
   if (remove(fn) == 0){
     return WS_NO_ERR;
   }
+#else
+  WSCushort* str1 = WSGFgetUCS2(fn,WS_EN_DEFAULT);
+  if (DeleteFile(str1)){
+    delete str1;
+    return WS_NO_ERR;
+  }
+  delete str1;
+#endif
   return WS_ERR;
 }
 
 long WSDwinFS::createDir(char* name){
   WSCstring fname(name);
   char* fn = fname.getString(WSGIappLocaleSet()->getSystemLocaleEncoding());
+#ifndef _WSWINCE
   if (_mkdir(fn) == 0){
     return WS_NO_ERR;
   }
+#else
+  WSCushort* str1 = WSGFgetUCS2(fn,WS_EN_DEFAULT);
+  if (CreateDirectory(str1,NULL) != 0){
+    delete str1;
+    return WS_NO_ERR;
+  }
+  delete str1;
+#endif
   return WS_ERR;
 }
 
 long WSDwinFS::deleteDir(char* name){
   WSCstring fname(name);
   char* fn = fname.getString(WSGIappLocaleSet()->getSystemLocaleEncoding());
+#ifndef _WSWINCE
   if (rmdir(fn) == 0){
     return WS_NO_ERR;
   }
+#else
+  WSCushort* str1 = WSGFgetUCS2(fn,WS_EN_DEFAULT);
+  if (RemoveDirectory(str1) != 0){
+    delete str1;
+    return WS_NO_ERR;
+  }
+  delete str1;
+#endif
   return WS_ERR;
 }
 
@@ -126,6 +167,7 @@ static long chk_file(char* file){
 }
 #endif
 long WSDwinFS::check(char* fname){
+#ifndef _WSWINCE
   WSCstring name(fname);
   char* fn = name.getString(WSGIappLocaleSet()->getSystemLocaleEncoding());
   struct _stat sret;
@@ -136,13 +178,16 @@ long WSDwinFS::check(char* fname){
   if ((sret.st_mode & S_IFMT) == S_IFDIR){
     ret |= WS_FS_DIR;
   }
-  if (!(sret.st_mode & S_IFREG)){
+  if (sret.st_mode & S_IFREG){
     ret |= WS_FS_FILE;
   }
   if ( _access(fn,W_OK) == -1){
     ret |= WS_FS_READONLY;
   }
   return ret;
+#else
+  return 0;
+#endif
 }
 
 WSClistData* WSDwinFS::showNetDir(char* dn,char* prvn){
@@ -166,7 +211,12 @@ WSClistData* WSDwinFS::showNetDir(char* dn,char* prvn){
   DWORD        lpcCount;
   DWORD        lpBufferSize;
   DWORD        re, i;
+#ifndef _WSWINCE
   char  lpBuffer2[4096];
+#else
+  WSCushort* lpBuff=NULL;
+  WSCushort* lpBuff2=NULL;
+#endif
 
   lphEnum  = 0;
   lpcCount = 0xFFFFFFF;
@@ -179,14 +229,37 @@ WSClistData* WSDwinFS::showNetDir(char* dn,char* prvn){
   if (dname != NULL ){
     WSCstring str(dname);
     str.replaceString("/","\\",0);
+#ifndef _WSWINCE
     strcpy(lpBuffer2,str.getString());
     NetResource.lpRemoteName = lpBuffer2;
+#else
+    lpBuff = WSGFgetUCS2(str.getString(),WS_EN_DEFAULT);
+    NetResource.lpRemoteName = lpBuff;
+#endif
   }else{
+#ifndef _WSWINCE
     NetResource.lpRemoteName = dname;
+#else
+    lpBuff = WSGFgetUCS2(name1.getString(),WS_EN_DEFAULT);
+    NetResource.lpRemoteName = lpBuff;
+#endif
   }
+#ifndef _WSWINCE
   NetResource.lpProvider		= prvname;
+#else
+  lpBuff2 = WSGFgetUCS2(name2.getString(),WS_EN_DEFAULT);
+  NetResource.lpProvider		= lpBuff2;
+#endif
   re = WNetOpenEnum(RESOURCE_GLOBALNET, RESOURCETYPE_ANY, 0, &NetResource, &lphEnum);
   if (re != 0){
+#ifdef _WSWINCE
+    if (lpBuff != NULL){
+      delete lpBuff;
+    }
+    if (lpBuff2 != NULL){
+      delete lpBuff2;
+    }
+#endif
     return NULL;
   }
 
@@ -206,7 +279,13 @@ WSClistData* WSDwinFS::showNetDir(char* dn,char* prvn){
       }
 
       WSCstring str;
+#ifndef _WSWINCE
       str.setString(lpBuffer[i].lpRemoteName,WSGIappLocaleSet()->getSystemLocaleEncoding());
+#else
+      char* tmpstr = WSGFgetString(lpBuffer[i].lpRemoteName,WS_EN_DEFAULT);
+      str.setString(tmpstr);
+      delete tmpstr;
+#endif
       str.replaceString("\\","/",0);
       if (dname != NULL ){
         if (!strncmp(dname,"//",2)){
@@ -229,6 +308,14 @@ WSClistData* WSDwinFS::showNetDir(char* dn,char* prvn){
     break;
   }
   WNetCloseEnum(lphEnum);
+#ifdef _WSWINCE
+    if (lpBuff != NULL){
+      delete lpBuff;
+    }
+    if (lpBuff2 != NULL){
+      delete lpBuff2;
+    }
+#endif
   return ret;
 }
 WSClistData* WSDwinFS::showDir(char* name){
@@ -236,6 +323,7 @@ WSClistData* WSDwinFS::showDir(char* name){
   WIN32_FIND_DATA fd;
   WSCstring str;
   str.setString(name,WS_EN_DEFAULT);
+#ifndef _WSWINCE
   if (!strcmp("",name)){
     DWORD drives = GetLogicalDrives();
     unsigned int i;
@@ -250,13 +338,20 @@ WSClistData* WSDwinFS::showDir(char* name){
     }
     return ret;
   }
+#endif
   str << "/*";
   str.replaceString("/","\\",0);
+#ifndef _WSWINCE
   HANDLE hFind = FindFirstFile(
              str.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()), &fd);
-
+#else
+  WSCushort* tmpstr = WSGFgetUCS2(str,WS_EN_DEFAULT);
+  HANDLE hFind = FindFirstFile(tmpstr,&fd);
+  delete tmpstr;
+#endif
   while( hFind != INVALID_HANDLE_VALUE ){
     if ( (fd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) != 0){
+#ifndef _WSWINCE
        if (!strcmp(fd.cFileName,".") || !strcmp(fd.cFileName,"..")){
          // reject...
        }else{
@@ -279,6 +374,31 @@ WSClistData* WSDwinFS::showDir(char* name){
            add_flag = True;
          }
        }
+#else
+       char* tmpst = WSGFgetString(fd.cFileName,WS_EN_DEFAULT);
+       WSCstring tmps(tmpst);
+       delete tmpst;
+       if (!strcmp(tmps.getString(),".") || !strcmp(tmps.getString(),"..")){
+         // reject...
+       }else{
+         long i;
+         long num = ret->getNum();
+         WSCbool add_flag = False;
+         for(i=0; i<num; i++){
+           char* item = (char*)(*ret)[i];
+           if (strcmp(item,tmps) > 0){
+             ret->add((void*)WSGFstrdup(tmps.getString(WS_EN_DEFAULT)),i);
+             add_flag = True;
+             break;
+           }
+         }
+         if (add_flag == False){
+           ret->add((void*)WSGFstrdup(tmps.getString(WS_EN_DEFAULT)));
+           add_flag = True;
+         }
+       }
+
+#endif
     }
     WSCbool exist = FindNextFile(hFind,&fd);
     if (exist == False){
@@ -294,14 +414,20 @@ WSClistData* WSDwinFS::showFile(char* name){
   str.setString(name,WS_EN_DEFAULT);
   str << "/*";
   str.replaceString("/","\\",0);
+#ifndef _WSWINCE
   HANDLE hFind = FindFirstFile(
              str.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()), &fd);
-
+#else
+  WSCushort* tmpstr = WSGFgetUCS2(name,WS_EN_DEFAULT);
+  HANDLE hFind = FindFirstFile(tmpstr,&fd);
+  delete tmpstr;
+#endif
   while( hFind != INVALID_HANDLE_VALUE ){
     if ( (fd.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) == 0){
       long i;
       long num = ret->getNum();
       WSCbool add_flag = False;
+#ifndef _WSWINCE
       for(i=0; i<num; i++){
         char* item = (char*)(*ret)[i];
         if (strcmp(item,fd.cFileName)>0){
@@ -317,6 +443,22 @@ WSClistData* WSDwinFS::showFile(char* name){
         str.setString(fd.cFileName,WSGIappLocaleSet()->getSystemLocaleEncoding());
         ret->add((void*)WSGFstrdup(str.getString(WS_EN_DEFAULT)));
       }
+#else
+      char* tmpst = WSGFgetString(fd.cFileName,WS_EN_DEFAULT);
+      WSCstring tmps(tmpst,WS_EN_DEFAULT);
+      delete tmpst;
+      for(i=0; i<num; i++){
+        char* item = (char*)(*ret)[i];
+        if (strcmp(item,tmps)>0){
+          ret->add((void*)WSGFstrdup(tmps.getString(WS_EN_DEFAULT)),i);
+          add_flag = True;
+          break;
+        }
+      }
+      if (add_flag == False){
+        ret->add((void*)WSGFstrdup(tmps.getString(WS_EN_DEFAULT)));
+      }
+#endif
     }
     WSCbool exist = FindNextFile(hFind,&fd);
     if (exist == False){
