@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <win/WSDwinImage.h>
@@ -30,6 +30,9 @@
 #include <WSDfileSystem.h>
 #include <win/WSDwinAppDev.h>
 #include <win/WSDwinColor.h>
+#ifdef _WSWINCE
+#include <winsock.h>
+#endif
 #include <WStcpcom.h>
 
 extern "C" {
@@ -43,6 +46,80 @@ extern long WSGFxBmpReadFileToPixmap(char* filename,HBITMAP* p,HBITMAP* p2,long*
 
 WSMFclassInit(WSDwinImage,WSDimage);
 
+#ifdef _WSWINCE
+int SetDIBits(HDC hdc,HBITMAP bm,UINT st,UINT scanline,void* buf1,BITMAPINFO* bmi,UINT pl){
+  WSCuchar* buf = (WSCuchar*)buf1;
+  int w = bmi->bmiHeader.biWidth;
+  int h = bmi->bmiHeader.biHeight;
+  int rowbyte = (w+1)*3 & ~3;
+
+  int i,j;
+  COLORREF c;
+  int p;
+  if (bmi->bmiHeader.biBitCount ==24){
+    for(i=0; i<h; i++){
+      p = rowbyte * i;
+      for(j=0; j<w; j++){
+        WSCuchar b = buf[p++];
+        WSCuchar g = buf[p++];
+        WSCuchar r = buf[p++];
+        c = PALETTERGB(r,g,b);
+        SetPixel(hdc,j,h-1-i,c);
+      }
+    }
+  }else if (bmi->bmiHeader.biBitCount ==32){
+    for(i=0; i<h; i++){
+      p = rowbyte * i;
+      for(j=0; j<w; j++){
+        WSCuchar b = buf[p++];
+        WSCuchar g = buf[p++];
+        WSCuchar r = buf[p++];
+        c = PALETTERGB(r,g,b);
+        p++;
+        SetPixel(hdc,j,h-1-i,c);
+      }
+    }
+  }
+  return True;
+}
+int GetDIBits(HDC hdc,HBITMAP bm,UINT st,UINT scanline,void* buf1,BITMAPINFO* bmi,UINT pl){
+  WSCuchar* buf = (WSCuchar*)buf1;
+  int w = bmi->bmiHeader.biWidth;
+  int h = bmi->bmiHeader.biHeight;
+  int rowbyte = (w+1)*3 & ~3;
+
+  int i,j;
+  COLORREF c;
+  int p;
+  if (bmi->bmiHeader.biBitCount ==24){
+    for(i=0; i<h; i++){
+      p = rowbyte * i;
+      for(j=0; j<w; j++){
+        c = GetPixel(hdc,j,h-1-i);
+        buf[p++] = GetBValue(c);
+        buf[p++] = GetGValue(c);
+        buf[p++] = GetRValue(c);
+      }
+    }
+  }else if (bmi->bmiHeader.biBitCount ==32){
+    for(i=0; i<h; i++){
+      p = rowbyte * i;
+      for(j=0; j<w; j++){
+        c = GetPixel(hdc,j,h-1-i);
+        buf[p++] = GetBValue(c);
+        buf[p++] = GetGValue(c);
+        buf[p++] = GetRValue(c);
+        buf[p++] = 0;
+      }
+    }
+  }
+  return True;
+}
+int GdiFlush(){
+  return 0;
+}
+#endif
+
 WSDimage* _win_image_create_handler(){
   WSDimage* image = new WSDwinImage();
   return image;
@@ -112,9 +189,11 @@ dbprintf("WSGFloadRemoteFile %s pbuf=0x%x size=%d\n",(char*)in2,pbuf,size);
   }
 
   if (in.isExist(".png") != -1 || in.isExist(".PNG") != -1){
+dbprintf("WSDwinImage::initialize %s start to read png.\n",(char*)in);
     WSCulong w,h;
     HBITMAP mask=0;
     hBitmap = PngReadFileToBitmap((char*)in,&w,&h,&mask);
+dbprintf("WSDwinImage::initialize %s read done.\n",(char*)in);
     if (hBitmap != 0){
       setImageWidth(w);
       setImageHeight(h);
@@ -149,9 +228,15 @@ WSMFtrace("XXZZim1 WSDwinImage::init fname=#%s# 0x%x \n",(char*)in,hBitmap);
     if (words > 1){
       WSCstring in2 = in.getWord(words-1,"\\");
       load_file_name = (char*)in2;
+#ifndef _WSWINCE
       hBitmap = (HBITMAP)LoadImage( NULL,
         (LPCTSTR)load_file_name,
         IMAGE_BITMAP, 0, 0, LR_LOADFROMFILE | LR_CREATEDIBSECTION | LR_LOADREALSIZE );
+#else
+      hBitmap = (HBITMAP)LoadImage( NULL,
+        (LPCTSTR)load_file_name,
+        IMAGE_BITMAP, 0, 0, LR_LOADREALSIZE );
+#endif
     }
   }
   if (hBitmap == 0){
@@ -162,24 +247,42 @@ WSMFtrace("XXZZim1 WSDwinImage::init fname=#%s# 0x%x \n",(char*)in,hBitmap);
     in2.replaceString(".JPG", ".bmp", 0);
     long val = (long)WSGIappImageSet()->getDefaultImageHandle((char*)in2);
     if (val != 0){
+#ifndef _WSWINCE
       hBitmap = (HBITMAP)LoadBitmap(WSGIwinAppDev()->getInstanceHandle(), (char*)val);
+#else
+      WSCushort* tmpstr = WSGFgetUCS2((char*)val,WS_EN_DEFAULT);
+      hBitmap = (HBITMAP)LoadBitmap(WSGIwinAppDev()->getInstanceHandle(), tmpstr);
+      delete tmpstr;
+#endif
     }
   }
   if (hBitmap == 0){
     in.replaceString(".bmp", ".ico", 0);
     in.replaceString(".BMP", ".ico", 0);
     load_file_name = (char*)in;
+#ifndef _WSWINCE
     hBitmap = (HBITMAP)LoadImage( NULL,
         (LPCTSTR)load_file_name,
         IMAGE_ICON, 0, 0, LR_LOADFROMFILE | LR_CREATEDIBSECTION | LR_LOADREALSIZE );
+#else
+    hBitmap = (HBITMAP)LoadImage( NULL,
+        (LPCTSTR)load_file_name,
+        IMAGE_ICON, 0, 0, LR_LOADREALSIZE );
+#endif
     if (hBitmap == 0){
       long words = in.getWords("\\");
       if (words > 1){
         WSCstring in2 = in.getWord(words-1,"\\");
         load_file_name = (char*)in2;
+#ifndef _WSWINCE
         hBitmap = (HBITMAP)LoadImage( NULL,
           (LPCTSTR)load_file_name,
           IMAGE_ICON, 0, 0, LR_LOADFROMFILE | LR_CREATEDIBSECTION | LR_LOADREALSIZE );
+#else
+        hBitmap = (HBITMAP)LoadImage( NULL,
+          (LPCTSTR)load_file_name,
+          IMAGE_ICON, 0, 0, LR_LOADREALSIZE );
+#endif
       }
     }
     if (hBitmap == 0){
@@ -190,9 +293,12 @@ WSMFtrace("XXZZim1 WSDwinImage::init fname=#%s# 0x%x \n",(char*)in,hBitmap);
       in2.replaceString(".JPG", ".ico", 0);
       long val = (long)WSGIappImageSet()->getDefaultImageHandle((char*)in2);
       if (val != 0){
+#ifndef _WSWINCE
         hBitmap = (HBITMAP)LoadIcon(WSGIwinAppDev()->getInstanceHandle(), (char*)val);
+#else
+        hBitmap = 0;
+#endif
       }
-WSMFtrace("XXZZim1 WSDwinImage::load val=%d #%s# hBitmap=0x%x hInst=0x%x done.\n",val,(char*)in2,hBitmap,WSGIwinAppDev()->getInstanceHandle());
     }
     if (hBitmap ==0) {
       return WS_ERR;
@@ -206,7 +312,6 @@ WSMFtrace("XXZZim1 WSDwinImage::load val=%d #%s# hBitmap=0x%x hInst=0x%x done.\n
   }
 
 
-
   if (hBitmap !=0) {
     DIBSECTION ds;
 //    SIZE size1;
@@ -241,9 +346,15 @@ static void exhandler(j_common_ptr jinf){
   struct jpeg_error_mgr2* jerr = (struct jpeg_error_mgr2*)jinf->err;
   longjmp(jerr->setjmp_buffer,1);
 }
+#ifndef _WSWIN32
 static int chandler(j_decompress_ptr jinf){
 return TRUE;
 }
+#else
+static unsigned char chandler(j_decompress_ptr jinf){
+return TRUE;
+}
+#endif
 typedef struct {
   struct jpeg_source_mgr pub;
   char* buf;
@@ -346,7 +457,7 @@ HBITMAP JpegReadFileToBitmap(char* filename,long size,WSCulong* w,WSCulong* h){
       if (size == 0){
         fclose(ifile);
       }
-      return -1;
+      return NULL;
     }
 
     jpeg_create_decompress(&jinf);
@@ -458,11 +569,17 @@ dbprintf("2 cinf->global_state=%d w,h=%d,%d components=%d\n",jinf.global_state,w
     ReleaseDC((HWND)WSGIwinAppDev()->getWindowResource(),hdc);
 
     mdc = CreateCompatibleDC(NULL);
+#ifdef _WSWINCE
+     HBITMAP pxbk = (HBITMAP)SelectObject(mdc,(void*)hBitmap);
+#endif
     if (!SetDIBits(mdc,hBitmap,0,height,data,&bmi,DIB_RGB_COLORS)){
 WSMFtrace("XXZZim1 setDIBits error %s\n",filename);
       DeleteObject((void*)hBitmap);
       hBitmap = 0;
     }
+#ifdef _WSWINCE
+     SelectObject(mdc,(void*)pxbk);
+#endif
     GdiFlush();
     DeleteDC(mdc);
 
@@ -768,15 +885,27 @@ fprintf(stderr,"png read error: out of memory..\n");
     ReleaseDC((HWND)WSGIwinAppDev()->getWindowResource(),hdc);
 
     mdc = CreateCompatibleDC(NULL);
+#ifdef _WSWINCE
+     HBITMAP pxbk = (HBITMAP)SelectObject(mdc,(void*)hBitmap);
+#endif
     if (!SetDIBits(mdc,hBitmap,0,height,data,&bmi,DIB_RGB_COLORS)){
       DeleteObject((void*)hBitmap);
       hBitmap = 0;
     }
+#ifdef _WSWINCE
+    SelectObject(mdc,(void*)pxbk);
+#endif
     if (components == 4){
+#ifdef _WSWINCE
+      pxbk = (HBITMAP)SelectObject(mdc,(void*)hBitmap2);
+#endif
       if (!SetDIBits(mdc,hBitmap2,0,height,data2,&bmi,DIB_RGB_COLORS)){
         DeleteObject((void*)hBitmap2);
         hBitmap2 = 0;
       }
+#ifdef _WSWINCE
+      SelectObject(mdc,(void*)pxbk);
+#endif
     }
     GdiFlush();
     DeleteDC(mdc);
@@ -919,10 +1048,16 @@ long WSGFxBmpReadFpToPixmap(char* fname,FILE* ifile,HBITMAP* p,HBITMAP* p2,long*
 
   if (cmptype == 3 && bit_cnt == 32){
   }else{
+#ifndef _WSWINCE
     *p = (HBITMAP)LoadImage( NULL,
                  (LPCTSTR)fname,
                  IMAGE_BITMAP, 0, 0,
                  LR_LOADFROMFILE | LR_CREATEDIBSECTION | LR_LOADREALSIZE );
+#else
+    *p = (HBITMAP)LoadImage( NULL,
+                 (LPCTSTR)fname,
+                 IMAGE_BITMAP, 0, 0, LR_LOADREALSIZE );
+#endif
     return WS_NO_ERR;
   }
   if (WSGFxreadLittleLong(ifile, &long_tmp) == -1){              // 34
