@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <win/WSDwinKeyboard.h>
 #include <windows.h>
@@ -112,6 +112,7 @@ long WSDwinKeyboard::startKanji(WSDdev* dev,short x,short y,short fontno,short f
   cf.ptCurrentPos.x = sx;
   cf.ptCurrentPos.y = sy;
   ImmSetCompositionWindow(_himc,&cf);
+#ifndef _WSWINCE
   if (fontno != _font_no){
     WSDfont* fn = WSGIappFontSet()->getFont(fontno);
     if (fn == NULL){
@@ -126,6 +127,7 @@ long WSDwinKeyboard::startKanji(WSDdev* dev,short x,short y,short fontno,short f
       }
     }
   }
+#endif
   _fep_on = True;
   return WS_NO_ERR;
 }
@@ -199,6 +201,7 @@ WSMFtrace("WSDwinKeyboard::setFepPos x,y=%d,%d\n",x,y);
   _fep_bg_no = bgno;
 WSMFtrace("WSDwinKeyboard::setFepPos()  fontno=%d fno=%d\n",fontno,_font_no);
 //printf("WSDwinKeyboard::setFepPos()  fontno=%d fno=%d\n",fontno,_font_no);
+#ifndef _WSWINCE
   if (fontno != _font_no){
     WSDfont* fn = WSGIappFontSet()->getFont(fontno);
     if (fn == NULL){
@@ -214,6 +217,7 @@ WSMFtrace("WSDwinKeyboard::setFepPos() setfl=0x%x\n",lf);
       }
     }
   }
+#endif
   return WS_NO_ERR;
 }
 
