@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <win/WSDwinAppDev.h>
 #include <win/WSDwinMessage.h>
@@ -62,8 +62,10 @@ int WSDwinMessage::receiveMessage(WSDwinMessage* p,void* val){
   char buffer[4096];
   buffer[4094] = 0;
   buffer[4095] = 0;
+#ifndef _WSWINCE
   long ret = GlobalGetAtomName(atom,buffer,4094);
   GlobalDeleteAtom(atom);
+
   if (ret == 0){
     return False;
   } 
@@ -71,14 +73,23 @@ int WSDwinMessage::receiveMessage(WSDwinMessage* p,void* val){
     p->sendMessage(buffer);
     return True;
   }
+#endif
   return False;
 }
 
 WSDwinMessage::WSDwinMessage(){
   _hkey = 0;
   DWORD dispos;
+#ifndef _WSWINCE
   LONG ret = RegCreateKeyEx(HKEY_CURRENT_USER,"SoftWare\\WideStudio\\WSTEMP",0,"",REG_OPTION_VOLATILE,
                    KEY_ALL_ACCESS,NULL,&_hkey,&dispos);
+#else
+  WSCushort* tmpstr = WSGFgetUCS2("SoftWare\\WideStudio\\WSTEMP",WS_EN_DEFAULT);
+  WSCushort  tmpstr2[1]; tmpstr2[0] = 0;
+  LONG ret = RegCreateKeyEx(HKEY_CURRENT_USER,tmpstr,0,tmpstr2,REG_OPTION_VOLATILE,
+                   KEY_ALL_ACCESS,NULL,&_hkey,&dispos);
+  delete tmpstr;
+#endif
 //printf("WSDwinMessage::WSDwinMessage ret=%d %d\n",ret,ERROR_SUCCESS);
   if (ret == ERROR_SUCCESS){
     _msg_instance_list.add((void*)this);
@@ -88,10 +99,23 @@ WSDwinMessage::WSDwinMessage(){
 WSDwinMessage::~WSDwinMessage(){
   if (_hkey != 0){
     _msg_instance_list.del((void*)this);
+#ifndef _WSWINCE
     RegDeleteValue(_hkey,_id.getString());
     WSCstring str = _id;
     str << "#THIS#";
     RegDeleteValue(_hkey,str.getString());
+#else
+    WSCushort* tmpstr = WSGFgetUCS2(_id,WS_EN_DEFAULT);
+    RegDeleteValue(_hkey,tmpstr);
+    delete tmpstr;
+
+    WSCstring str = _id;
+    str << "#THIS#";
+
+    tmpstr = WSGFgetUCS2(str,WS_EN_DEFAULT);
+    RegDeleteValue(_hkey,tmpstr);
+    delete tmpstr;
+#endif
   }
 }
 
@@ -99,11 +123,25 @@ long WSDwinMessage::initialize(){
 //printf("WSDwinMessage::initialize _hkey=0x%x\n",_hkey);
   if (_hkey != 0){
     HWND hwnd = WSGIwinAppDev()->getHWND();
+#ifndef _WSWINCE
     RegSetValueEx(_hkey,_id.getString() ,0,REG_DWORD,(const BYTE*)&hwnd,sizeof(DWORD));
     WSCstring str = _id;
     str << "#THIS#";
     WSDwinMessage* ptr = this;
     RegSetValueEx(_hkey,str.getString() ,0,REG_DWORD,(const BYTE*)&ptr,sizeof(DWORD));
+#else
+    WSCushort* tmpstr = WSGFgetUCS2(_id,WS_EN_DEFAULT);
+    RegSetValueEx(_hkey,tmpstr ,0,REG_DWORD,(const BYTE*)&hwnd,sizeof(DWORD));
+    delete tmpstr;
+
+    WSCstring str = _id;
+    str << "#THIS#";
+
+    WSDwinMessage* ptr = this;
+    tmpstr = WSGFgetUCS2(str,WS_EN_DEFAULT);
+    RegSetValueEx(_hkey,tmpstr,0,REG_DWORD,(const BYTE*)&ptr,sizeof(DWORD));
+    delete tmpstr;
+#endif
   }
   return 0 ;
 }
@@ -119,8 +157,17 @@ int WSDwinMessage::extSendMessage(char* dispname, char *message, char *data){
   HWND hwnd = NULL;
   HKEY hkey;
   DWORD dispos;
+#ifndef _WSWINCE
   LONG ret = RegCreateKeyEx(HKEY_CURRENT_USER,"SoftWare\\WideStudio\\WSTEMP",0,"",REG_OPTION_VOLATILE,
                    KEY_ALL_ACCESS,NULL,&hkey,&dispos);
+#else
+  WSCushort* tmpstr = WSGFgetUCS2("SoftWare\\WideStudio\\WSTEMP",WS_EN_DEFAULT);
+  WSCushort tmpstr2[1]; tmpstr[0] = 0;
+
+  LONG ret = RegCreateKeyEx(HKEY_CURRENT_USER,tmpstr,0,tmpstr2,REG_OPTION_VOLATILE,
+                   KEY_ALL_ACCESS,NULL,&hkey,&dispos);
+  delete tmpstr;
+#endif
 //printf("WSDwinMessage::extSendMessage hkey=0x%x\n",hkey);
 
   if (ret != ERROR_SUCCESS){
@@ -130,6 +177,7 @@ int WSDwinMessage::extSendMessage(char* dispname, char *message, char *data){
   if (hkey != 0){
     DWORD type;
     DWORD size = sizeof(DWORD);
+#ifndef _WSWINCE
     LONG ret = RegQueryValueEx(hkey,message,0,&type,(BYTE*)&hwnd,&size);
     if (ret != ERROR_SUCCESS){
       return WS_ERR;
@@ -137,11 +185,30 @@ int WSDwinMessage::extSendMessage(char* dispname, char *message, char *data){
     WSCstring str(message);
     str << "#THIS#";
     RegQueryValueEx(hkey,str.getString() ,0,&type,(BYTE*)&wparam,&size);
+#else
+    WSCushort* tmpstr = WSGFgetUCS2(message,WS_EN_DEFAULT);
+    LONG ret = RegQueryValueEx(hkey,tmpstr,0,&type,(BYTE*)&hwnd,&size);
+    delete tmpstr;
+    if (ret != ERROR_SUCCESS){
+      return WS_ERR;
+    }
+    WSCstring str(message);
+    str << "#THIS#";
+    tmpstr = WSGFgetUCS2(str,WS_EN_DEFAULT);
+    RegQueryValueEx(hkey,tmpstr,0,&type,(BYTE*)&wparam,&size);
+    delete tmpstr;
+#endif
     if (ret != ERROR_SUCCESS){
       return WS_ERR;
     }
   }
+#ifndef _WSWINCE
   ATOM atom = GlobalAddAtom(data);
+#else
+  tmpstr = WSGFgetUCS2(data,WS_EN_DEFAULT);
+  ATOM atom = GlobalAddAtom(tmpstr);
+  delete tmpstr;
+#endif
   lparam = (LPARAM)atom; 
   DWORD result;
   ret = SendMessageTimeout(hwnd,WM_USER,wparam,lparam,
