@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <win/WSDwinScrFrameDev.h>
 #include <win/WSDwinappDev.h>
@@ -159,6 +159,7 @@ WSMFtrace(" -> %d  w=0x%d\n",p.top,p.bottom - p.top);
                }
              }
              if (_h_scr_pos != vl){
+               pos_bk = _h_scr_pos;
                _h_scr_pos = vl;
                if (_addr_change_handler != NULL){
                  _addr_change_handler(this,_handler_data);
@@ -166,12 +167,13 @@ WSMFtrace(" -> %d  w=0x%d\n",p.top,p.bottom - p.top);
 
                if (_wnd != NULL){
                  GetClientRect(_wnd,&p);
+
                  MoveWindow(_wnd,-_h_scr_pos,-_v_scr_pos,_work_width,_work_height, True);
 //                 MoveWindow(_wnd,-_h_scr_pos,-_v_scr_pos,_work_width,_work_height, False);
                  exposeArea(_h_scr_pos,_v_scr_pos,_w_w,_w_h,False);
+                 _expose_children(_h_scr_pos,_v_scr_pos,_w_w,_w_h);
                }
              }
-             pos_bk = _h_scr_pos;
              break;
     case WSDEV_WORK_Y:
              vl = *(WSCushort*)data;
@@ -191,7 +193,9 @@ WSMFtrace(" -> %d  w=0x%d\n",p.top,p.bottom - p.top);
                  GetClientRect(_wnd,&p);
                  MoveWindow(_wnd,-_h_scr_pos,-_v_scr_pos,_work_width,_work_height, True);
 //                 MoveWindow(_wnd,-_h_scr_pos,-_v_scr_pos,_work_width,_work_height, False);
+//  invalidate(True);
                  exposeArea(_h_scr_pos,_v_scr_pos,_w_w,_w_h,False);
+                 _expose_children(_h_scr_pos,_v_scr_pos,_w_w,_w_h);
                }
              }
              break;
@@ -314,20 +318,66 @@ long WSDwinScrFrameDev::createWindow(){
 extern char szAppName[];
   _pwnd = windev->getHWND();
 WSMFtrace("CreateWindow  x,y,w,h=%d,%d,%d,%d\n",x,y,w,h);
+#ifndef _WSWINCE
   _scr_wnd = CreateWindow( szAppName,"",
                 WS_CHILD | WS_OVERLAPPED | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
                 x,y,w,h,_pwnd,
                 NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
-  WSDwinformDev* ptr = this;
-  SetWindowLong(_scr_wnd,GWL_USERDATA,(long)ptr);
+#else
+  WSCushort* tmpstr = WSGFgetUCS2(szAppName,WS_EN_DEFAULT);
+  WSCushort  tmpstr2[1]; tmpstr2[0] = 0;
+  _scr_wnd = CreateWindow( tmpstr,tmpstr2,
+                WS_CHILD | WS_CLIPSIBLINGS,
+                x,y,w,h,_pwnd,
+                NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
 
+#endif
+  WSDwinformDev* ptr = this;
+#if 0
+  SetWindowLong(_scr_wnd,GWL_USERDATA,(long)ptr);
+#else
+#ifndef _WSWINCE
+  SetProp(_scr_wnd,"frm",(HANDLE)ptr);
+#else
+  unsigned short str1[4];
+  str1[0] = 'f';
+  str1[1] = 'r';
+  str1[2] = 'm';
+  str1[3] = 0;
+  SetProp(_scr_wnd,str1,(HANDLE)ptr);
+#endif
+#endif
+
+#ifndef _WSWINCE
   _wnd = CreateWindow( szAppName,"",
                 WS_CHILD | WS_OVERLAPPED | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,
                 -_h_scr_pos,-_v_scr_pos,_work_width,_work_height,_scr_wnd,
                 NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
-
+#else
+  _wnd = CreateWindow( tmpstr,tmpstr2,
+                WS_CHILD | WS_CLIPSIBLINGS,
+                -_h_scr_pos,-_v_scr_pos,_work_width,_work_height,_scr_wnd,
+                NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+  delete tmpstr;
+#endif
+  if (WSGIwinAppDev()->getWndProc() != NULL){
+    SetWindowLong(_scr_wnd,GWL_WNDPROC,(LONG)WSGIwinAppDev()->getWndProc());
+    SetWindowLong(_wnd,GWL_WNDPROC,(LONG)WSGIwinAppDev()->getWndProc());
+  }
 WSMFtrace("x,y,w,h=%d,%d,%d,%d\n",x,y,w,h);
+#if 0
   SetWindowLong(_wnd,GWL_USERDATA,(long)ptr);
+#else
+#ifndef _WSWINCE
+  SetProp(_wnd,"frm",(HANDLE)ptr);
+#else
+  str1[0] = 'f';
+  str1[1] = 'r';
+  str1[2] = 'm';
+  str1[3] = 0;
+  SetProp(_wnd,str1,(HANDLE)ptr);
+#endif
+#endif
 
 WSMFtrace("WSDwinScrFrameDev this=0x%x wnd=0x%x pwnd=0x%x\n",this,_wnd,windev->getHWND());
 #ifdef DEBUG
@@ -391,7 +441,20 @@ long WSDwinScrFrameDev::destroyWindow(){
     WSGIwinAppDev()->setMouseFocusDev(NULL);
   }
   if (_wnd != 0){
+#if 0
     SetWindowLong(_wnd,GWL_USERDATA,(long)0);
+#else
+#ifndef _WSWINCE
+    SetProp(_wnd,"frm",(HANDLE)0);
+#else
+    unsigned short str1[4];
+    str1[0] = 'f';
+    str1[1] = 'r';
+    str1[2] = 'm';
+    str1[3] = 0;
+    SetProp(_wnd,str1,(HANDLE)0);
+#endif
+#endif
     MSG msg;
     while(PeekMessage(&msg,_wnd,0,0,PM_REMOVE)){
       if (msg.message == WM_PAINT){
@@ -404,7 +467,20 @@ long WSDwinScrFrameDev::destroyWindow(){
     _wnd = 0;
   }
   if (_scr_wnd != 0){
+#if 0
     SetWindowLong(_scr_wnd,GWL_USERDATA,(long)0);
+#else
+#ifndef _WSWINCE
+    SetProp(_scr_wnd,"frm",(HANDLE)0);
+#else
+    unsigned short str1[4];
+    str1[0] = 'f';
+    str1[1] = 'r';
+    str1[2] = 'm';
+    str1[3] = 0;
+    SetProp(_scr_wnd,str1,(HANDLE)0);
+#endif
+#endif
     MSG msg;
     while(PeekMessage(&msg,_scr_wnd,0,0,PM_REMOVE)){
       if (msg.message == WM_PAINT){
@@ -553,3 +629,40 @@ void WSDwinScrFrameDev::_clear_and_expose(){
   }
   onExpose(&r);
 }
+void WSDwinScrFrameDev::_expose_children(int x,int y,unsigned long w,unsigned long h){
+  WSCbase* client = getAttachedClient();
+  if (client == NULL){
+    return;
+  }
+  WSCbase* pclient = client->getParent();
+  if (pclient != NULL && pclient->getdev() == this){
+    client = pclient;
+  }
+  WSClistData list = client->getChildren();
+  long i;
+  long num = list.getNum();
+  for(i=0; i<num; i++){
+    WSCbase* child = (WSCbase*)list[i];
+    if (child->getVisible() == False){
+      continue;
+    }
+    WSDdev* dev = child->getdev();
+    if (dev == NULL){
+      continue;
+    }
+    WSDwinformDev* wdev =(WSDwinformDev*)dev->cast("WSDwinformDev");
+    if (wdev == NULL){
+      continue;
+    }
+    long ex,ey;
+    unsigned long ew,eh;
+    short dx,dy;
+    unsigned short dw,dh;
+    wdev->getWindowSize(&dx,&dy,&dw,&dh);
+    WSGFandArea(_h_scr_pos,_v_scr_pos,w,h,dx,dy,dw,dh,
+                &ex,&ey,&ew,&eh);
+    if (ew != 0 && eh != 0){
+      wdev->exposeArea(ex-dx,ey-dy,ew,eh);
+    }
+  }
+}
