@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <windows.h>
 #include <win/WSDwindraw.h>
@@ -36,6 +36,7 @@
 //#include <WSDwincom.h>
 #include <win/WSDwinappDev.h>
 #include <WSCvarc.h>
+#include <win/WSwincom.h>
 
 WSMFclassInit(WSDwindraw,WSCroot);
 #define HS_DOT 8
@@ -111,6 +112,7 @@ long WSDwindraw::setValue(long kind,long val){
     return WS_NO_ERR;
   }else
   if (kind == WSDEV_PR_PRINTER){
+#ifndef _WSWINCE
     if (val != 0){
       _printer = True;
       PRINTDLG pd;
@@ -180,6 +182,7 @@ long WSDwindraw::setValue(long kind,long val){
         _printer_hdc = 0;
       }
     }
+#endif
     return WS_NO_ERR;
   }
 //printf("err ret2\n");
@@ -260,7 +263,11 @@ long WSDwindraw::setLineDashType(char type){
       break;
     case 1:
     case 8:
+#ifndef _WSWINCE
       _dash_no = PS_DOT;
+#else
+      _dash_no = PS_DASH;
+#endif
       break;
     case 2:
     case 3:
@@ -268,11 +275,19 @@ long WSDwindraw::setLineDashType(char type){
       break;
     case 4:
     case 6:
+#ifndef _WSWINCE
       _dash_no = PS_DASHDOT;
+#else
+      _dash_no = PS_DASH;
+#endif
       break;
     case 5:
     case 7:
+#ifndef _WSWINCE
       _dash_no = PS_DASHDOTDOT;
+#else
+      _dash_no = PS_DASH;
+#endif
       break;
     default:
       _dash_no = PS_SOLID;
@@ -291,6 +306,7 @@ long WSDwindraw::setHatchPattern(char type){
     case 0: 
       _hatch_att =1;
       break;
+#ifndef _WSWINCE
     case 1: 
       _hatch_att =0;
       _hatch = HS_BDIAGONAL;
@@ -318,6 +334,7 @@ long WSDwindraw::setHatchPattern(char type){
     case 7:
       _hatch_att =0;
       _hatch = HS_DOT;
+#endif
     default:
       _hatch_att =1;
       break;
@@ -404,6 +421,7 @@ WSMFtrace("WSDwindraw::setResion %d,%d,%d,%d    XXZZ33x\n",x,y,w,h);
 }
 
 long WSDwindraw::drawArc(short x,short y,WSCushort w,WSCushort h,short a1,short a2){
+#ifndef _WSWINCE
   if (_printer_hdc != 0){
     x = (short)((x - _pr_x) * _pr_scale_x);
     y = (short)((y - _pr_y) * _pr_scale_y);
@@ -425,12 +443,74 @@ long WSDwindraw::drawArc(short x,short y,WSCushort w,WSCushort h,short a1,short
   double vx2 = x + w/2 + cos(3.141592 *(a1+a2)/64.0/180.0)*w/2;
   double vy2 = y + h/2 - sin(3.141592 *(a1+a2)/64.0/180.0)*h/2;
   Arc(_hdc,x,y,x+w,y+h, (int)vx1,(int)vy1,(int)vx2,(int)vy2);
-
   SetBkMode(_hdc,OPAQUE);
   SelectObject(_hdc,(void*)pen_bk);
   DeleteObject((void*)pen);
 
   return WS_NO_ERR;
+
+#else
+
+  int dx = x;
+  int dy = y;
+  int dw = w;
+  int dh = h;
+  int j;
+  for(j=0; j< _line_width; j++){
+    x = dx +j;
+    y = dy +j;
+    w = dw -j*2;
+    h = dh -j*2;
+    if (w < 1){
+      break;
+    }
+    if (h < 1){
+      break;
+    }
+
+    double an1 = (double)a1/64;
+    double an2 = (double)a2/64;
+    WSCbool circle = False;
+    if (an2 - an1 >= 360){
+      circle = True;
+      an2 = 360;
+    }
+#define WS_PI_VALUE 3.14159265358979323846
+    long points = (w+h)*2 * WS_PI_VALUE * an2 / 360;
+//  WSCpoint point[WS_PT_NUM+1];
+    WSCpoint* point = new WSCpoint[points+1];
+
+    long cnt = 0;
+    int i;
+    for(i=0; i<points; i++){
+      point[cnt].x = (long)(x + (double)w/2 +
+           w * cos(WS_PI_VALUE * (an1 + (an2* i)/(points-1))  / 180)/2 +0.5);
+      point[cnt].y = (long)(y + (double)h/2 -
+           h * sin(WS_PI_VALUE * (an1 + (an2* i)/(points-1))  / 180)/2 +0.5);
+      if (cnt > 0){
+        if (point[cnt].x == point[cnt-1].x &&
+            point[cnt].y == point[cnt-1].y){
+          continue;
+        }
+      }
+      cnt++;
+    }
+#if 0
+    for(i=0; i<cnt-1; i++){
+      drawLine(point[i].x,point[i].y,point[i+1].x,point[i+1].y);
+    }
+    if (circle != False){
+      drawLine(point[cnt-1].x,point[cnt-1].y,point[0].x,point[0].y);
+    }
+#endif
+    for(i=0; i<cnt; i++){
+      SetPixel(_hdc,point[i].x,point[i].y,_fg_color);
+    }
+    delete point;
+  }
+  return WS_NO_ERR;
+#endif
+
 //WSMFtrace("WSDwindraw::drawArc() is not implemented..\n");
 //#if 0
 //  if (_gc == 0 || _window == 0){
@@ -441,6 +521,7 @@ long WSDwindraw::drawArc(short x,short y,WSCushort w,WSCushort h,short a1,short
 //  return WS_NO_ERR;
 }
 long WSDwindraw::drawFillArc(short x,short y,WSCushort w,WSCushort h,short a1,short a2,char kind){
+#ifndef _WSWINCE
   if (_printer_hdc != 0){
     x = (short)((x - _pr_x) * _pr_scale_x);
     y = (short)((y - _pr_y) * _pr_scale_y);
@@ -458,7 +539,11 @@ long WSDwindraw::drawFillArc(short x,short y,WSCushort w,WSCushort h,short a1,sh
 
   HBRUSH brush;
   if (_hatch_att == 0 && _hatch != HS_DOT ){
+#ifndef _WSWINCE
     brush = CreateHatchBrush(_hatch,_fg_color);
+#else
+    brush = CreateSolidBrush(_fg_color);
+#endif
   }else{
     brush = CreateSolidBrush(_fg_color);
   }
@@ -481,6 +566,47 @@ long WSDwindraw::drawFillArc(short x,short y,WSCushort w,WSCushort h,short a1,sh
   DeleteObject((void*)brush);
 
   return WS_NO_ERR;
+#else
+
+  double an1 = (double)a1/64;
+  double an2 = (double)a2/64;
+  WSCbool circle = False;
+  if (an2 - an1 >= 360){
+    circle = True;
+    an2 = 360;
+  }
+//#define WS_PT_NUM 36
+  long points = (w+h)*2 * WS_PI_VALUE * an2 / 360;
+//  WSCpoint point[WS_PT_NUM+1];
+  WSCpoint* point = new WSCpoint[points+1];
+
+  long cnt = 0;
+  int i;
+  for(i=0; i<points; i++){
+    point[cnt].x = (long)(x + (double)w/2 +
+           w * cos(WS_PI_VALUE * (an1 + (an2* i)/(points-1))  / 180)/2 +0.5);
+    point[cnt].y = (long)(y + (double)h/2 -
+           h * sin(WS_PI_VALUE * (an1 + (an2* i)/(points-1))  / 180)/2 +0.5);
+    if (cnt > 0){
+      if (point[cnt].x == point[cnt-1].x &&
+          point[cnt].y == point[cnt-1].y){
+        continue;
+      }
+    }
+    cnt++;
+  }
+  if (circle == False && kind == WS_PI){
+    point[cnt].x = x + w/2;
+    point[cnt].y = y + h/2;
+    drawFillPoly(point,cnt+1);
+  }else{
+    drawFillPoly(point,cnt);
+  }
+  delete point;
+  return WS_NO_ERR;
+
+#endif
+
 #if 0
   if (_gc == 0 || _window == 0){
     return WS_ERR;
@@ -591,6 +717,7 @@ long WSDwindraw::drawLines(WSCpoint* points,long num){
   return WS_NO_ERR;
 }
 long WSDwindraw::drawRect(short x,short y,WSCushort w,WSCushort h){
+#ifndef _WSWINCE
   if (_printer_hdc != 0){
     x = (short)((x - _pr_x) * _pr_scale_x);
     y = (short)((y - _pr_y) * _pr_scale_y);
@@ -605,11 +732,15 @@ long WSDwindraw::drawRect(short x,short y,WSCushort w,WSCushort h){
   HPEN pen = CreatePen(_dash_no,_line_width,_fg_color);
   HPEN pen_bk = (HPEN)SelectObject(_hdc,(void*)pen);
 
+#ifndef _WSWINCE
   LOGBRUSH lb;
   lb.lbStyle = BS_NULL;
   lb.lbColor = _bg_color;
   lb.lbHatch = _hatch;
   HBRUSH brush = CreateBrushIndirect(&lb);
+#else
+  HBRUSH brush = CreateSolidBrush(_bg_color);
+#endif
   HBRUSH brush_bk = (HBRUSH)SelectObject(_hdc,(void*)brush);
 
   SetBkMode(_hdc,TRANSPARENT);
@@ -628,6 +759,45 @@ long WSDwindraw::drawRect(short x,short y,WSCushort w,WSCushort h){
   DeleteObject((void*)brush);
 
   return WS_NO_ERR;
+#else
+  if ( _line_type == 8 && _line_width < 2 ){
+    if (_printer_hdc != 0){
+      x = (short)((x - _pr_x) * _pr_scale_x);
+      y = (short)((y - _pr_y) * _pr_scale_y);
+      w = (WSCushort)(w * _pr_scale_x);
+      h = (WSCushort)(h * _pr_scale_y);
+    }
+
+    if (_hdc == 0 ){
+      return WS_ERR;
+    }
+//printf("WSDwindraw::drawRect %d,%d,%d,%d\n",x,y,w,h);
+    HPEN pen = CreatePen(_dash_no,_line_width,_fg_color);
+    HPEN pen_bk = (HPEN)SelectObject(_hdc,(void*)pen);
+
+    HBRUSH brush = CreateSolidBrush(_bg_color);
+    HBRUSH brush_bk = (HBRUSH)SelectObject(_hdc,(void*)brush);
+
+    SetBkMode(_hdc,TRANSPARENT);
+    _draw_dot(x,y,x,y+h-1,_hdc);
+    _draw_dot(x,y,x+w-1,y,_hdc);
+    _draw_dot(x,y+h-1,x+w-1,y+h-1,_hdc);
+    _draw_dot(x+w-1,y,x+w-1,y+h-1,_hdc);
+
+    SetBkMode(_hdc,OPAQUE);
+    SelectObject(_hdc,(void*)pen_bk);
+    SelectObject(_hdc,(void*)brush_bk);
+    DeleteObject((void*)pen);
+    DeleteObject((void*)brush);
+
+    return WS_NO_ERR;
+  }else{
+    drawLine(x,y,x+w,y);
+    drawLine(x,y,x,y+h);
+    drawLine(x+w,y,x+w,y+h+1);
+    return drawLine(x,y+h,x+w+1,y+h);
+  }
+#endif
 }
 long WSDwindraw::drawFillRect(short x,short y,WSCushort w,WSCushort h){
   if (_hdc == 0 ){
@@ -641,7 +811,11 @@ long WSDwindraw::drawFillRect(short x,short y,WSCushort w,WSCushort h){
 
   HBRUSH brush;
   if (_hatch_att == 0 && _hatch != HS_DOT ){
+#ifndef _WSWINCE
     brush = CreateHatchBrush(_hatch,_fg_color);
+#else
+    brush = CreateSolidBrush(_fg_color);
+#endif
   }else{
     brush = CreateSolidBrush(_fg_color);
   }
@@ -709,12 +883,15 @@ long WSDwindraw::drawRects(WSCrect* rects,long num){
 
   HPEN pen = CreatePen(_dash_no,_line_width,_fg_color);
   HPEN pen_bk = (HPEN)SelectObject(_hdc,(void*)pen);
-
+#ifndef _WSWINCE
   LOGBRUSH lb;
   lb.lbStyle = BS_NULL;
   lb.lbColor = _bg_color;
   lb.lbHatch = _hatch;
-  HBRUSH brush = CreateBrushIndirect(&lb);
+  HBRUSH brush = (HBRUSH)CreateBrushIndirect(&lb);
+#else
+  HBRUSH brush = CreateSolidBrush(_bg_color);
+#endif
   HBRUSH brush_bk = (HBRUSH)SelectObject(_hdc,(void*)brush);
 //  HBRUSH brush_bk = (HBRUSH)SelectObject(_hdc,(void*)NULL_BRUSH);
 
@@ -772,9 +949,13 @@ long WSDwindraw::drawFillRects(WSCrect* rects,long num){
 
   HBRUSH brush;
   if (_hatch_att == 0){
-    brush = CreateHatchBrush(_hatch,_fg_color);
+#ifndef _WSWINCE
+    brush = (HBRUSH)CreateHatchBrush(_hatch,_fg_color);
+#else
+    brush = (HBRUSH)CreateSolidBrush(_fg_color);
+#endif
   }else{
-    brush = CreateSolidBrush(_fg_color);
+    brush = (HBRUSH)CreateSolidBrush(_fg_color);
   }
 //  HBRUSH brush_bk = (HBRUSH)SelectObject(_hdc,(void*)NULL_BRUSH);
   HBRUSH brush_bk = (HBRUSH)SelectObject(_hdc,(void*)brush);
@@ -849,7 +1030,11 @@ long WSDwindraw::drawFillPoly(WSCpoint* points,long num){
 
   HBRUSH brush;
   if (_hatch_att == 0){
+#ifndef _WSWINCE
     brush = CreateHatchBrush(_hatch,_fg_color);
+#else
+    brush = CreateSolidBrush(_fg_color);
+#endif
   }else{
     brush = CreateSolidBrush(_fg_color);
   }
@@ -891,7 +1076,9 @@ void _draw_stretch_image_with_mask(HDC hdc,HDC mdc,HDC mdc2,HBITMAP pix,HBITMAP
       RealizePalette(mdc3);
       HBITMAP pix3 = CreateCompatibleBitmap(hdc,iw,ih);
       HBITMAP pxbk3 = (HBITMAP)SelectObject(mdc3,(void*)pix3);
+#ifndef _WSWINCE
       SetMapMode(mdc3,GetMapMode(hdc));
+#endif
       StretchBlt(mdc3,sx,sy,iw,ih,hdc,x,y,w,h,SRCCOPY);
 
       BITMAPINFO bmi;
@@ -911,11 +1098,9 @@ void _draw_stretch_image_with_mask(HDC hdc,HDC mdc,HDC mdc2,HBITMAP pix,HBITMAP
       unsigned char* buf1 = new unsigned char[bytes_per_line * ih];
       unsigned char* buf2 = new unsigned char[bytes_per_line * ih];
       unsigned char* buf3 = new unsigned char[bytes_per_line * ih];
-
       GetDIBits(mdc,pix,0,ih,(void*)buf3,&bmi,DIB_RGB_COLORS);
       GetDIBits(mdc2,pix2,0,ih,(void*)buf2,&bmi,DIB_RGB_COLORS);
       GetDIBits(mdc3,pix3,0,ih,(void*)buf1,&bmi,DIB_RGB_COLORS);
-
       int i,j;
       for(i=0; i<ih; i++){
         long ptr = i*bytes_per_line;
@@ -944,7 +1129,9 @@ void _draw_image_with_mask(HDC hdc,HDC mdc,HDC mdc2,HBITMAP pix,HBITMAP pix2,HPA
         RealizePalette(mdc3);
         HBITMAP pix3 = CreateCompatibleBitmap(hdc,w,h);
         HBITMAP pxbk3 = (HBITMAP)SelectObject(mdc3,(void*)pix3);
+#ifndef _WSWINCE
         SetMapMode(mdc3,GetMapMode(hdc));
+#endif
         BitBlt(mdc3,0,0,w,h,hdc,x,y,SRCCOPY);
 
         BITMAPINFO bmi;
@@ -967,7 +1154,6 @@ void _draw_image_with_mask(HDC hdc,HDC mdc,HDC mdc2,HBITMAP pix,HBITMAP pix2,HPA
         GetDIBits(mdc3,pix3,0,h,(void*)buf1,&bmi,DIB_RGB_COLORS);
         GetDIBits(mdc2,pix2,0,h,(void*)buf2,&bmi,DIB_RGB_COLORS);
         GetDIBits(mdc,pix,0,h,(void*)buf3,&bmi,DIB_RGB_COLORS);
-
         int i,j;
         for(i=0; i<h; i++){
           long ptr = i*bytes_per_line;
@@ -1025,17 +1211,22 @@ long WSDwindraw::drawStretchedImage(short x,short y,WSCushort w,WSCushort h,WSDi
       }
     }
     HBITMAP pxbk = (HBITMAP)SelectObject(mdc,(void*)pix);
+#ifndef _WSWINCE
     SetMapMode(mdc,GetMapMode(_hdc));
-
+#endif
     HBITMAP pxbk2 = (HBITMAP)0;
     if (pix2 != 0){
       pxbk2 = (HBITMAP)SelectObject(mdc2,(void*)pix2);
+#ifndef _WSWINCE
       SetMapMode(mdc2,GetMapMode(_hdc));
+#endif
     }
 
     WSCulong iw = image->getImageWidth();
     WSCulong ih = image->getImageHeight();
+#ifndef _WSWINCE
     SetStretchBltMode(_hdc,STRETCH_DELETESCANS);
+#endif
 
     if (pix2 == 0){
       if (_printer_hdc != 0){
@@ -1044,7 +1235,9 @@ long WSDwindraw::drawStretchedImage(short x,short y,WSCushort w,WSCushort h,WSDi
         RealizePalette(mdc2);
         HBITMAP pix2 = CreateCompatibleBitmap(mdc,w,h);
         HBITMAP pxbk2 = (HBITMAP)SelectObject(mdc2,(void*)pix2);
+#ifndef _WSWINCE
         SetMapMode(mdc2,GetMapMode(mdc));
+#endif
         StretchBlt(mdc2,0,0,w,h,mdc,0,0,iw,ih,SRCCOPY);
         int ret = StretchBlt(_hdc,x,y,w,h,mdc2,0,0,w,h,SRCCOPY);
 dbprintf("WSDwindraw::drawStretchedImage _hdc=0x%x mdc=0x%x pr ret=%d %d,%d,%d,%d<-%d,%d \n",_hdc,mdc,ret,x,y,w,h,iw,ih);
@@ -1095,7 +1288,9 @@ dbprintf("WSDwindraw::drawImage pix=0x%x pix2=0x%x pix3=0x%x\n",pix,pix2,pix3);
   POINT p;
   p.x = image->getImageWidth();
   p.y = image->getImageHeight();
+#ifndef _WSWINCE
   DPtoLP(_hdc,&p,1);
+#endif
 
   WSCushort pw = p.x;
   WSCushort ph = p.y;
@@ -1165,10 +1360,14 @@ dbprintf("WSDwindraw::drawImage pix=0x%x pix2=0x%x pix3=0x%x\n",pix,pix2,pix3);
     }
     HBITMAP pxbk = (HBITMAP)SelectObject(mdc,(void*)pix);
     HBITMAP pxbk2 = (HBITMAP)0;
+#ifndef _WSWINCE
     SetMapMode(mdc,GetMapMode(_hdc));
+#endif
     if (pix2 != 0){
       pxbk2 = (HBITMAP)SelectObject(mdc2,(void*)pix2);
+#ifndef _WSWINCE
       SetMapMode(mdc2,GetMapMode(_hdc));
+#endif
     }
     if (_printer_hdc != 0){
 dbprintf("WSDwindraw::drawImage _pr_scale_x=%f _pr_scale_y=%f\n",_pr_scale_x,_pr_scale_y);
@@ -1182,7 +1381,9 @@ dbprintf("WSDwindraw::drawImage _pr_scale_x=%f _pr_scale_y=%f\n",_pr_scale_x,_pr
       WSCulong ih2 = dh;
       dw = (WSCushort)(dw * _pr_scale_x);
       dh = (WSCushort)(dh * _pr_scale_y);
+#ifndef _WSWINCE
       SetStretchBltMode(_hdc,STRETCH_DELETESCANS);
+#endif
       WSCulong iw = image->getImageWidth();
       WSCulong ih = image->getImageHeight();
       if (pix2 == 0){
@@ -1191,7 +1392,9 @@ dbprintf("WSDwindraw::drawImage _pr_scale_x=%f _pr_scale_y=%f\n",_pr_scale_x,_pr
         RealizePalette(mdc2);
         HBITMAP pix2 = CreateCompatibleBitmap(mdc,dw,dh);
         HBITMAP pxbk2 = (HBITMAP)SelectObject(mdc2,(void*)pix2);
+#ifndef _WSWINCE
         SetMapMode(mdc2,GetMapMode(mdc));
+#endif
         int ret = StretchBlt(mdc2,0,0,dw,dh,mdc,dx -x -xoff,dy -y -yoff,iw2,ih2,SRCCOPY);
 dbprintf("WSDwindraw::drawImage _hdc=0x%x mdc=0x%x ret=%d %d,%d,%d,%d->%d,%d err=0x%x err=%d\n",_hdc,mdc,ret,dx2,dy2,dw,dh,dx -x -xoff,dy-y-yoff,GetLastError(),GetLastError());
         ret = BitBlt(_hdc,dx2,dy2,dw,dh,mdc2,0,0,SRCCOPY);
@@ -1220,7 +1423,9 @@ dbprintf("WSDwindraw::drawImage _hdc=0x%x mdc=0x%x ret=%d %d,%d,%d,%d->%d,%d \n"
         RealizePalette(mdc3);
         HBITMAP pix3 = CreateCompatibleBitmap(_hdc,pw,ph);
         HBITMAP pxbk3 = (HBITMAP)SelectObject(mdc3,(void*)pix3);
+#ifndef _WSWINCE
         SetMapMode(mdc3,GetMapMode(_hdc));
+#endif
         BitBlt(mdc3,0,0,pw,ph,_hdc,x+xoff,y+yoff,SRCCOPY);
 
         BITMAPINFO bmi;
@@ -1243,7 +1448,6 @@ dbprintf("WSDwindraw::drawImage _hdc=0x%x mdc=0x%x ret=%d %d,%d,%d,%d->%d,%d \n"
         GetDIBits(mdc3,pix3,0,ph,(void*)buf1,&bmi,DIB_RGB_COLORS);
         GetDIBits(mdc2,pix2,0,ph,(void*)buf2,&bmi,DIB_RGB_COLORS);
         GetDIBits(mdc,pix,0,ph,(void*)buf3,&bmi,DIB_RGB_COLORS);
-
         int i,j;
         for(i=0; i<ph; i++){
           long ptr = i*bytes_per_line;
@@ -1343,11 +1547,15 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
 
 
   HBITMAP pxbk = (HBITMAP)SelectObject(mdc,(void*)pix);
+#ifndef _WSWINCE
   SetMapMode(mdc,GetMapMode(_hdc));
+#endif
   HBITMAP pxbk2 = (HBITMAP)0;
   if (pix2 !=0){
     pxbk2 = (HBITMAP)SelectObject(mdc2,(void*)pix2);
+#ifndef _WSWINCE
     SetMapMode(mdc2,GetMapMode(_hdc));
+#endif
   } 
   if (_printer_hdc != 0){
 //    x = (short)((x - _pr_x) * _pr_scale_x);
@@ -1360,7 +1568,9 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
     WSCulong ih2 = dh;
     dw = (WSCushort)(dw * _pr_scale_x);
     dh = (WSCushort)(dh * _pr_scale_y);
+#ifndef _WSWINCE
     SetStretchBltMode(_hdc,STRETCH_DELETESCANS);
+#endif
     WSCulong iw = image->getImageWidth();
     WSCulong ih = image->getImageHeight();
     if (pix2 == 0){
@@ -1369,7 +1579,9 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
       RealizePalette(mdc2);
       HBITMAP pix2 = CreateCompatibleBitmap(mdc,dw,dh);
       HBITMAP pxbk2 = (HBITMAP)SelectObject(mdc2,(void*)pix2);
+#ifndef _WSWINCE
       SetMapMode(mdc2,GetMapMode(mdc));
+#endif
       StretchBlt(mdc2,0,0,dw,dh,mdc,dx -x +sx,dy -y +sy,iw2,ih2,SRCCOPY);
       BitBlt(_hdc,dx2,dy2,dw,dh,mdc2,0,0,SRCCOPY);
 //      StretchBlt(_hdc,dx2,dy2,dw,dh,mdc,dx -x +sx,dy -y +sy,iw2,ih2,SRCCOPY);
@@ -1405,7 +1617,9 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
       RealizePalette(mdc3);
       HBITMAP pix3 = CreateCompatibleBitmap(_hdc,iw,ih);
       HBITMAP pxbk3 = (HBITMAP)SelectObject(mdc3,(void*)pix3);
+#ifndef _WSWINCE
       SetMapMode(mdc3,GetMapMode(_hdc));
+#endif
       BitBlt(mdc3,0,0,iw,ih,_hdc,x -sx,y - sy,SRCCOPY);
 
       BITMAPINFO bmi;
@@ -1428,7 +1642,6 @@ long WSDwindraw::drawImage(short x,short y,short sx,short sy,WSCushort w,WSCusho
       GetDIBits(mdc3,pix3,0,ih,(void*)buf1,&bmi,DIB_RGB_COLORS);
       GetDIBits(mdc2,pix2,0,ih,(void*)buf2,&bmi,DIB_RGB_COLORS);
       GetDIBits(mdc,pix,0,ih,(void*)buf3,&bmi,DIB_RGB_COLORS);
-
       int i,j;
       for(i=0; i<ih; i++){
         long ptr = i*bytes_per_line;
@@ -1549,9 +1762,27 @@ WSMFtrace("XXZZr1 setRegion %d,%d,%d,%d bk %d,%d,%d,%d\n",clx,cly,clw,clh,clx_bk
     if (_printer_hdc != 0){
       short x1 = (short)((point.x - _pr_x) * _pr_scale_x);
       short y1 = (short)((point.y - _pr_y) * _pr_scale_y);
+#ifndef _WSWINCE
       TextOutW(_hdc,x1,y1,(WCHAR*)tstr2,slen);
+#else
+      RECT r;
+      r.left = 0;
+      r.top = 0;
+      r.right = 0;
+      r.bottom = 0;
+      ExtTextOutW(_hdc,x1,y1,ETO_OPAQUE,&r,(WCHAR*)tstr2,slen,NULL);
+#endif
     }else{
+#ifndef _WSWINCE
       TextOutW(_hdc,point.x,point.y,(WCHAR*)tstr2,slen);
+#else
+      RECT r;
+      r.left = 0;
+      r.top = 0;
+      r.right = 0;
+      r.bottom = 0;
+      ExtTextOutW(_hdc,point.x,point.y,ETO_OPAQUE,&r,(WCHAR*)tstr2,slen,NULL);
+#endif
     }
     if (inter_cur != False){
       if (cur > -1){
@@ -1579,9 +1810,27 @@ WSMFtrace("XXZZif1 drawstring cur=%d width=%d #%s#\n",cur,cx,str2.getString(WS_E
         if (_printer_hdc != 0){
           short x1 = (short)(((cx + point.x) - _pr_x) * _pr_scale_x);
           short y1 = (short)((point.y - _pr_y) * _pr_scale_y);
+#ifndef _WSWINCE
           TextOutW(_hdc,x1,y1,(WCHAR*)tstr,tlen);
+#else
+          RECT r;
+          r.left = 0;
+          r.top = 0;
+          r.right = 0;
+          r.bottom = 0;
+          ExtTextOutW(_hdc,x1,y1,ETO_OPAQUE,&r,(WCHAR*)tstr,tlen,NULL);
+#endif
         }else{
+#ifndef _WSWINCE
           TextOutW(_hdc,cx + point.x,point.y,(WCHAR*)tstr,tlen);
+#else
+          RECT r;
+          r.left = 0;
+          r.top = 0;
+          r.right = 0;
+          r.bottom = 0;
+          ExtTextOutW(_hdc,cx + point.x,point.y,ETO_OPAQUE,&r,(WCHAR*)tstr,tlen,NULL);
+#endif
         }
         delete tstr;
         SetBkMode(_hdc,TRANSPARENT);
@@ -1615,9 +1864,27 @@ WSMFtrace("XXZZif1 drawstring cur=%d width=%d #%s#\n",cur,cx,str2.getString(WS_E
       if (_printer_hdc != 0){
         short x1 = (short)((cx + point.x - _pr_x) * _pr_scale_x);
         short y1 = (short)((point.y - _pr_y) * _pr_scale_y);
+#ifndef _WSWINCE
         TextOutW(_hdc,x1,y1,(WCHAR*)tstr,tlen);
+#else
+        RECT r;
+        r.left = 0;
+        r.top = 0;
+        r.right = 0;
+        r.bottom = 0;
+        ExtTextOutW(_hdc,x1,y1,ETO_OPAQUE,&r,(WCHAR*)tstr,tlen,NULL);
+#endif
       }else{
+#ifndef _WSWINCE
         TextOutW(_hdc,cx + point.x,point.y,(WCHAR*)tstr,tlen);
+#else
+        RECT r;
+        r.left = 0;
+        r.top = 0;
+        r.right = 0;
+        r.bottom = 0;
+        ExtTextOutW(_hdc,cx + point.x,point.y,ETO_OPAQUE,&r,(WCHAR*)tstr,tlen,NULL);
+#endif
       }
       delete tstr;
       SetBkMode(_hdc,TRANSPARENT);
@@ -1651,9 +1918,27 @@ WSMFtrace("XXZZif1 drawstring cur=%d width=%d #%s#\n",cur,cx,str2.getString(WS_E
       if (_printer_hdc != 0){
         short x1 = (short)((points[i].x - _pr_x) * _pr_scale_x);
         short y1 = (short)((points[i].y - _pr_y) * _pr_scale_y);
+#ifndef _WSWINCE
         TextOutW(_hdc,x1,y1,(WCHAR*)tstr,WSGFstrlenUCS2(tstr));
+#else
+        RECT r;
+        r.left = 0;
+        r.top = 0;
+        r.right = 0;
+        r.bottom = 0;
+        ExtTextOutW(_hdc,x1,y1,ETO_OPAQUE,&r,(WCHAR*)tstr,WSGFstrlenUCS2(tstr),NULL);
+#endif
       }else{
+#ifndef _WSWINCE
         TextOutW(_hdc,points[i].x,points[i].y,(WCHAR*)tstr,WSGFstrlenUCS2(tstr));
+#else
+        RECT r;
+        r.left = 0;
+        r.top = 0;
+        r.right = 0;
+        r.bottom = 0;
+        ExtTextOutW(_hdc,points[i].x,points[i].y,ETO_OPAQUE,&r,(WCHAR*)tstr,WSGFstrlenUCS2(tstr),NULL);
+#endif
       }
       delete tstr;
 WSMFtrace("XXZZ windraw::drawString mline=%d hdc=0x%x points[i].y=%d fheight=%d cly=%d clh=%d\n",i,_hdc,points[i].y,fheight,cly,clh);
@@ -1679,9 +1964,27 @@ WSMFtrace("XXZZ windraw::drawString mline=%d hdc=0x%x points[i].y=%d fheight=%d
         if (_printer_hdc != 0){
           short x1 = (short)((cx + points[i].x - _pr_x) * _pr_scale_x);
           short y1 = (short)((points[i].y - _pr_y) * _pr_scale_y);
+#ifndef _WSWINCE
           TextOutW(_hdc,x1,y1,(WCHAR*)tstr,WSGFstrlenUCS2(tstr));
+#else
+          RECT r;
+          r.left = 0;
+          r.top = 0;
+          r.right = 0;
+          r.bottom = 0;
+          ExtTextOutW(_hdc,x1,y1,ETO_OPAQUE,&r,(WCHAR*)tstr,WSGFstrlenUCS2(tstr),NULL);
+#endif
         }else{
+#ifndef _WSWINCE
           TextOutW(_hdc,cx + points[i].x,points[i].y,(WCHAR*)tstr,WSGFstrlenUCS2(tstr));
+#else
+          RECT r;
+          r.left = 0;
+          r.top = 0;
+          r.right = 0;
+          r.bottom = 0;
+          ExtTextOutW(_hdc,cx + points[i].x,points[i].y,ETO_OPAQUE,&r,(WCHAR*)tstr,WSGFstrlenUCS2(tstr),NULL);
+#endif
         }
         delete tstr;
         SetBkMode(_hdc,TRANSPARENT);
@@ -1713,9 +2016,27 @@ WSMFtrace("XXZZ windraw::drawString mline=%d hdc=0x%x points[i].y=%d fheight=%d
         if (_printer_hdc != 0){
           short x1 = (short)((cx + points[i].x - _pr_x) * _pr_scale_x);
           short y1 = (short)((points[i].y - _pr_y) * _pr_scale_y);
+#ifndef _WSWINCE
           TextOutW(_hdc,x1,y1,(WCHAR*)tstr,WSGFstrlenUCS2(tstr));
+#else
+          RECT r;
+          r.left = 0;
+          r.top = 0;
+          r.right = 0;
+          r.bottom = 0;
+          ExtTextOutW(_hdc,x1,y1,ETO_OPAQUE,&r,(WCHAR*)tstr,WSGFstrlenUCS2(tstr),NULL);
+#endif
         }else{
+#ifndef _WSWINCE
           TextOutW(_hdc,cx + points[i].x,points[i].y,(WCHAR*)tstr,WSGFstrlenUCS2(tstr));
+#else
+          RECT r;
+          r.left = 0;
+          r.top = 0;
+          r.right = 0;
+          r.bottom = 0;
+          ExtTextOutW(_hdc,cx + points[i].x,points[i].y,ETO_OPAQUE,&r,(WCHAR*)tstr,WSGFstrlenUCS2(tstr),NULL);
+#endif
         }
         delete tstr;
         SetBkMode(_hdc,TRANSPARENT);
