@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <windows.h>
 #include <win/WSDwinformDev.h>
@@ -432,11 +432,15 @@ void WSDwinformDev::_clear_area(long x,long y,WSCulong w,WSCulong h){
     if (img != NULL){
       HDC mdc2 = CreateCompatibleDC(dc);
       HBITMAP bbk = (HBITMAP)SelectObject(mdc2,(void*)_bg_image);
+#ifndef _WSWINCE
       SetMapMode(mdc2,GetMapMode(dc));
+#endif
       POINT p;
       p.x = img->getImageWidth();
       p.y = img->getImageHeight();
+#ifndef _WSWINCE
       DPtoLP(dc,&p,1);
+#endif
       WSCushort pw = p.x;
       WSCushort ph = p.y;
       if (pw < 1){
@@ -455,7 +459,9 @@ void WSDwinformDev::_clear_area(long x,long y,WSCulong w,WSCulong h){
       if (bg_mask != (HBITMAP)-1 && bg_mask != (HBITMAP)0){
         mdc3 = CreateCompatibleDC(dc);
         bbk2 = (HBITMAP)SelectObject(mdc3,(void*)bg_mask);
+#ifndef _WSWINCE
         SetMapMode(mdc3,GetMapMode(dc));
+#endif
         HBRUSH brush = CreateSolidBrush(_bg_cref);
         FillRect(dc,&r,brush);
         DeleteObject(brush);
@@ -556,15 +562,21 @@ void WSDwinformDev::_setup_pixmap(short x,short y,WSCushort w,WSCushort h,short
   if (_bg_image != (HBITMAP)0){
     WSDimage* img = WSGIappImageSet()->getImage(_back_pixno);
     if (img != NULL){
+#ifndef _WSWINCE
       SIZE size1; 
       GetBitmapDimensionEx(_bg_image,&size1);
+#endif
       HDC mdc2 = CreateCompatibleDC(_mdc);
       HBITMAP bbk = (HBITMAP)SelectObject(mdc2,(void*)_bg_image);
+#ifndef _WSWINCE
       SetMapMode(mdc2,GetMapMode(_mdc));
+#endif
       POINT p;
       p.x = img->getImageWidth();
       p.y = img->getImageHeight();
+#ifndef _WSWINCE
       DPtoLP(_mdc,&p,1);
+#endif
       WSCushort pw = p.x;
       WSCushort ph = p.y;
       if (pw < 1){
@@ -582,8 +594,9 @@ void WSDwinformDev::_setup_pixmap(short x,short y,WSCushort w,WSCushort h,short
       if (bg_mask != (HBITMAP)-1 && bg_mask != (HBITMAP)0){
         mdc3 = CreateCompatibleDC(_mdc);
         bbk2 = (HBITMAP)SelectObject(mdc3,(void*)bg_mask);
+#ifndef _WSWINCE
         SetMapMode(mdc3,GetMapMode(_mdc));
-
+#endif
         HBRUSH br = CreateSolidBrush(bgref);
         FillRect(_mdc,&r,br);
         DeleteObject((void*)br);
@@ -667,8 +680,17 @@ extern char szAppName[];
 //  _wnd = CreateWindow( szAppName,"",WS_CHILD,x,y,w,h,windev->getHWND(),
 //WSMFtrace("CreateWindow  x,y,w,h=%d,%d,%d,%d\n",x,y,w,h);
   _pwnd = windev->getHWND();
+#ifndef _WSWINCE
   _wnd = CreateWindow( szAppName,"",WS_CHILD | WS_OVERLAPPED | WS_CLIPCHILDREN | WS_CLIPSIBLINGS,x,y,w,h,windev->getHWND(),
                         NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+#else
+  WSCushort* tmpstr = WSGFgetUCS2(szAppName,WS_EN_DEFAULT);
+  WSCushort tmpstr2[1];
+  tmpstr2[0] = 0;
+  _wnd = CreateWindow( tmpstr,tmpstr2,WS_CHILD | WS_CLIPSIBLINGS,x,y,w,h,windev->getHWND(),
+                        NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+  delete tmpstr;
+#endif
   if (WSGIwinAppDev()->getWndProc() != NULL){
     SetWindowLong(_wnd,GWL_WNDPROC,(LONG)WSGIwinAppDev()->getWndProc());
   }
@@ -676,7 +698,16 @@ extern char szAppName[];
 #if 0
   SetWindowLong(_wnd,GWL_USERDATA,(long)this);
 #else
+#ifndef _WSWINCE
   SetProp(_wnd,"frm",(HANDLE)this);
+#else
+  unsigned short str1[4];
+  str1[0] = 'f';
+  str1[1] = 'r';
+  str1[2] = 'm';
+  str1[3] = 0;
+  SetProp(_wnd,str1,(HANDLE)this);
+#endif
 #endif
 //WSMFtrace("WSDwinformDev  this=0x%x wnd=0x%x    pwnd=0x%x\n",this,_wnd,windev->getHWND());
 #ifdef DEBUG
@@ -900,7 +931,16 @@ WSMFtrace("WSDwinformDev::destroyWindow() remove callbacks is not implemented..\
 #if 0
     SetWindowLong(_wnd,GWL_USERDATA,(long)0);
 #else
+#ifndef _WSWINCE
     SetProp(_wnd,"frm",(HANDLE)0);
+#else
+    unsigned short str1[4];
+    str1[0] = 'f';
+    str1[1] = 'r';
+    str1[2] = 'm';
+    str1[3] = 0;
+    SetProp(_wnd,str1,(HANDLE)0);
+#endif
 #endif
     MSG msg;
     while(PeekMessage(&msg,_wnd,0,0,PM_REMOVE)){
@@ -1136,7 +1176,6 @@ void WSDwinformDev::_evh_mouse_in(WinEvent* ev){
     XDefineCursor(XtDisplay((HWND)dev->_wnd),XtWindow((HWND)dev->_wnd),val);
   }
 #endif
-
   onMouseIn(&point);
 }
 
@@ -1176,6 +1215,14 @@ void WSDwinformDev::_evh_mouse_move(WinEvent* ev){
   WSCpoint point;
   point.setPoint( (short)LOWORD(ev->lParam), (short)HIWORD(ev->lParam) );
 //WSMFtrace("WSDwinformDev::_evh_mouse_move()  pt=%d,%d\n",point.x,point.y);
+#ifdef _WSWINCE
+  RECT r;
+  GetWindowRect(_wnd,&r);
+extern int _mouse_pos_x;
+extern int _mouse_pos_y;
+  _mouse_pos_x = point.x + r.left;
+  _mouse_pos_y = point.y + r.top;
+#endif
 
   WSCbool b1 =  (ev->uParam & MK_LBUTTON) != 0 ? True:False;
   WSCbool b2 =  (ev->uParam & MK_MBUTTON) != 0 ? True:False;
@@ -1296,6 +1343,14 @@ void WSDwinformDev::_evh_btn_press(WinEvent* ev,int no){
 //WSMFtrace("WSDwinformDev::_evh_btn_press() this=0x%x\n",this);
   WSCpoint point;
   point.setPoint( LOWORD(ev->lParam),HIWORD(ev->lParam));
+#ifdef _WSWINCE
+  RECT r;
+  GetWindowRect(_wnd,&r);
+extern int _mouse_pos_x;
+extern int _mouse_pos_y;
+  _mouse_pos_x = point.x + r.left;
+  _mouse_pos_y = point.y + r.top;
+#endif
   long clk = WSGFclocktime();
   WSCbool dclicked = False;
   if ((WSCulong)clk - (WSCulong)_click_time<250){
@@ -1355,6 +1410,14 @@ void WSDwinformDev::_evh_btn_release(WinEvent* ev,int no){
 //printf("WSDwinformDev::_evh_btn_release() drop is not implemented..\n");
   WSCpoint point;
   point.setPoint( LOWORD(ev->lParam),HIWORD(ev->lParam) );
+#ifdef _WSWINCE
+  RECT r;
+  GetWindowRect(_wnd,&r);
+extern int _mouse_pos_x;
+extern int _mouse_pos_y;
+  _mouse_pos_x = point.x + r.left;
+  _mouse_pos_y = point.y + r.top;
+#endif
   if (_grabed == False){
     WSGIwinAppDev()->setGrabedWnd(NULL);
   }
