@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <windows.h>
 #include <WSCdevice.h>
@@ -421,7 +421,6 @@ long WSDwinmwinDev::initBuffer(){
   }
 
   _bmi = (WSCuchar*)malloc( ((_w+1)*3 & ~3) * _h);
- 
   int ret = GetDIBits(_mdc,_hBitmap,0,_h,_bmi,&bmi,DIB_RGB_COLORS);
   if (ret == 0){
     return WS_ERR;
@@ -484,7 +483,6 @@ long WSDwinmwinDev::putBufferToPixmap(){
   if (ret == 0){
     return WS_ERR;
   }
-                     
   return WS_NO_ERR;
 }
 
@@ -571,7 +569,8 @@ long PngWriteBufToFp(FILE* fp, char* buf,long width,long height) {
                 PNG_FILTER_TYPE_DEFAULT);
 
   void** png_row_ptrs = (void**)png_malloc(png_ptr, sizeof(void*) * height);
-  for (int i = 0; i < height; ++i) {
+  int i;
+  for (i = 0; i < height; ++i) {
     png_row_ptrs[i] = png_malloc(png_ptr, color_bpp * width);
     memcpy(png_row_ptrs[i], buf, color_bpp * width);
     buf += width * color_bpp;
@@ -581,7 +580,7 @@ long PngWriteBufToFp(FILE* fp, char* buf,long width,long height) {
   info_ptr->valid |= PNG_INFO_IDAT;
   png_write_png(png_ptr, info_ptr, PNG_TRANSFORM_IDENTITY, NULL);
 
-  for (int i = 0; i < height; ++i) {
+  for (i = 0; i < height; ++i) {
     png_free(png_ptr, png_row_ptrs[i]);
   }
   png_free(png_ptr, png_row_ptrs);
