@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,22 +14,26 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <windows.h>
+#ifdef _WSWINCE
+#include <winsock.h>
+#endif
 #include <WScom.h>
 #include <win/WSDwinAppDev.h>
 #include <win/WSDwinsocket.h>
+#ifndef _WSWIN32
 #include <winsock2.h>
-
+#endif
 WSMFclassInit(WSDwinsocket,WSDwinsocket);
 
 WSDsocket* _winsocket_create_handler(){
@@ -317,8 +321,13 @@ void* WSDwinsocket::_udp_read_thread_(void* ptr){
       _this->_stop_accept = False;
       return 0;
     }
-
+#ifndef _WSWINCE
     HANDLE sem = CreateSemaphore(NULL,0,1,"WAIT_READ");
+#else
+    WSCushort* tmpstr = WSGFgetUCS2("WAIT_READ",WS_EN_DEFAULT);
+    HANDLE sem = CreateSemaphore(NULL,0,1,tmpstr);
+    delete tmpstr;
+#endif
     _this->_sem = sem;
     _accept_send_type* data = new _accept_send_type;
     data->sock = _this;
