@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <windows.h>
 #include <win/WSwincom.h>
@@ -37,6 +37,9 @@
 #include <WSClocaleSet.h>
 #define DEBUG
 
+#ifdef _WSWINCE
+#define strdup _strdup
+#endif
 WSMFclassInit(WSDwinwinDev,WSDwinformDev);
 WSDdev* _wsdwinwindev_init_(){
   return new WSDwinwinDev();
@@ -54,7 +57,11 @@ static _WSDwinwinDev_init_ _init_to_run_WSDwinwinDev_;
 WSDwinwinDev::WSDwinwinDev(){
 dbprintf("WSDwinwinDev::WSDwinwinDev %s:%d start this=0x%x\n",__FILE__,__LINE__,this);
 //  _shell  = 0;
+#ifndef _WSWINCE
   _style = WS_OVERLAPPEDWINDOW;
+#else
+  _style = 0;
+#endif
 //  _style_ex = WS_EX_WINDOWEDGE | WS_EX_CLIENTEDGE;
   _style_ex = 0;
   _resize_sequence = False;
@@ -271,7 +278,11 @@ long WSDwinwinDev::setValue(long kind,void* data){
 //                  SetWindowLong(_shell,GWL_EXSTYLE,WS_EX_WINDOWEDGE | WS_EX_CLIENTEDGE);
              }else
              if (_title_bar_style == WS_FULL_TITLE){ 
+#ifndef _WSWINCE
                   _style = WS_OVERLAPPEDWINDOW;
+#else
+                  _style = 0;
+#endif
                   _style_ex = 0;
 //                  _style_ex = WS_EX_WINDOWEDGE | WS_EX_CLIENTEDGE;
 //                  SetWindowLong(_shell,GWL_EXSTYLE,WS_EX_WINDOWEDGE | WS_EX_CLIENTEDGE);
@@ -325,7 +336,13 @@ long WSDwinwinDev::setValue(long kind,void* data){
              _title_string = strdup(
                tmpstr.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
              if (_shell != (HWND)NULL){
+#ifndef _WSWINCE
                SetWindowText(_shell,_title_string);
+#else
+               WSCushort* tmpstr = WSGFgetUCS2(_title_string,WS_EN_DEFAULT);
+               SetWindowText(_shell,tmpstr);
+               delete tmpstr;
+#endif
              }
              break;
     case WSDEV_NO_FRAME:  
@@ -460,7 +477,9 @@ long WSDwinwinDev::setValue(long kind,void* data){
                ShowWindow(_shell,SW_SHOWNORMAL);
              }else
              if (*(long*)data == WS_WINDOW_MINIMIZE){
+#ifndef _WSWINCE
                ShowWindow(_shell,SW_SHOWMINIMIZED);
+#endif
              }else
              if (*(long*)data == WS_WINDOW_MAXIMIZE){
                ShowWindow(_shell,SW_SHOWMAXIMIZED);
@@ -481,6 +500,7 @@ long WSDwinwinDev::getValue(long kind,void* val){
       if (_shell == 0){
         return WS_ERR;
       }
+#ifndef _WSWINCE
       if (IsIconic(_shell)){
         *(long*)val = WS_WINDOW_MINIMIZE;
         return WS_NO_ERR;
@@ -489,6 +509,7 @@ long WSDwinwinDev::getValue(long kind,void* val){
         *(long*)val = WS_WINDOW_MAXIMIZE;
         return WS_NO_ERR;
       }
+#endif
       *(long*)val = WS_WINDOW_NORMAL;
       return WS_NO_ERR;
   }
@@ -518,6 +539,11 @@ extern char szAppName[];
   HWND alt_hwnd = (HWND)WSGIwinAppDev()->getContext2();
 dbprintf("WSDwinwinDev::createWindow %s:%d alt=0x%x\n",__FILE__,__LINE__,alt_hwnd);
 
+#ifdef _WSWINCE
+  WSCushort* tmpstr = WSGFgetUCS2(szAppName,WS_EN_DEFAULT);
+  WSCushort tmpstr2[1]; tmpstr2[0] = 0;
+#endif
+
   if (alt_hwnd == 0){
   if (_no_frame ){
 //    HWND pw = NULL;
@@ -529,30 +555,58 @@ dbprintf("WSDwinwinDev::createWindow %s:%d alt=0x%x\n",__FILE__,__LINE__,alt_hwn
 #endif
 //    _shell = CreateWindowEx( _style_ex,szAppName,"", _style | WS_CLIPSIBLINGS | WS_POPUP |WS_CLIPCHILDREN, x,y,w,h,pw,
       HWND pw = WSGIwinAppDev()->getHWND();
+#ifndef _WSWINCE
       _shell = CreateWindowEx( _style_ex,szAppName,"",
              _style | WS_CLIPSIBLINGS | WS_POPUP | WS_CLIPCHILDREN, x,y,w,h,pw,
                         NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+#else
+      _shell = CreateWindowEx( _style_ex,tmpstr,tmpstr2,
+             _style | WS_CLIPSIBLINGS | WS_POPUP | WS_CLIPCHILDREN, x,y,w,h,pw,
+                        NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+#endif
       SetWindowPos(_shell,HWND_TOPMOST,0,0,0,0,SWP_NOMOVE|SWP_NOSIZE|SWP_NOACTIVATE);
 //      SetWindowPos(_shell,HWND_TOPMOST,0,0,0,0,SWP_NOMOVE|SWP_NOSIZE);
 //WSMFtrace("CreateWindow NO_FRAME XXZZq2  %d,%d,%d,%d\n",x,y,w,h);
     }else{
+#ifndef _WSWINCE
       _shell = CreateWindowEx( _style_ex,szAppName,"", _style | WS_CLIPSIBLINGS | WS_CLIPCHILDREN, x,y,w,h,NULL,
                         NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
       SetWindowLong(_shell,GWL_STYLE,_style | WS_CLIPSIBLINGS | WS_CLIPCHILDREN);
+#else
+      _shell = CreateWindowEx( _style_ex,tmpstr,tmpstr2, WS_CLIPSIBLINGS | WS_CLIPCHILDREN, x,y,w,h,NULL,
+                        NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+#endif
 //      SetWindowLong(_shell,GWL_EXSTYLE,_style_ex);
 
 
     }
+#ifndef _WSWINCE
     _wnd = CreateWindow(szAppName,"",WS_OVERLAPPED | WS_CLIPCHILDREN | WS_CHILD | WS_CLIPSIBLINGS,0,0,w,h,_shell,NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+#else
+    _wnd = CreateWindow(tmpstr,tmpstr2, WS_CHILD | WS_CLIPSIBLINGS,0,0,w,h,_shell,NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+#endif
   }else{
     _shell = alt_hwnd;
-    _wnd = CreateWindow(szAppName,"",WS_OVERLAPPED | WS_CLIPCHILDREN | WS_CHILD | WS_CLIPSIBLINGS,0,0,w,h,_shell,NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
-
+#ifndef _WSWINCE
+    _wnd = CreateWindow(szAppName,"",WS_CLIPCHILDREN | WS_CHILD | WS_CLIPSIBLINGS,0,0,w,h,_shell,NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+#else
+    _wnd = CreateWindow(tmpstr,tmpstr2, WS_CHILD | WS_CLIPSIBLINGS,0,0,w,h,_shell,NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
+#endif
 
   }
 
+#ifdef _WSWINCE
+  delete tmpstr;
+#endif
+
   if (_title_string != NULL){
+#ifndef _WSWINCE
     SetWindowText(_shell,_title_string);
+#else
+    WSCushort* tmpstr = WSGFgetUCS2(_title_string,WS_EN_DEFAULT);
+    SetWindowText(_shell,tmpstr);
+    delete tmpstr;
+#endif
   }
 
   if (WSGIwinAppDev()->getWndProc() != NULL){
@@ -587,77 +641,20 @@ WSMFtrace("createwindow %d %d %d %d -> %d %d %d %d\n",x,y,w,h,p.left,p.top,p.rig
   SetWindowLong(_wnd,GWL_USERDATA,(long)ptr);
   SetWindowLong(_shell,GWL_USERDATA,(long)ptr);
 #else
+#ifndef _WSWINCE
   SetProp(_wnd,"frm",(HANDLE)ptr);
   SetProp(_shell,"frm",(HANDLE)ptr);
+#else
+  unsigned short str1[4];
+  str1[0] = 'f';
+  str1[1] = 'r';
+  str1[2] = 'm';
+  str1[3] = 0;
+  SetProp(_wnd,str1,(HANDLE)ptr);
+  SetProp(_shell,str1,(HANDLE)ptr);
+#endif
 #endif
 
-#if 0
-  Arg args[10];
-  long anum=0;
-  XtSetArg(args[anum],XtNinput,True);anum++;
-  XtSetArg(args[anum],XtNtransient,False);anum++;
-  XtSetArg(args[anum],XtNx,x);anum++;
-  XtSetArg(args[anum],XtNy,y);anum++;
-  XtSetArg(args[anum],XtNwidth,w);anum++;
-  XtSetArg(args[anum],XtNheight,h);anum++;
-  XtSetArg(args[anum],"mwmDecorations",_title_bar_style);anum++;
-  XtSetArg(args[anum],"dialogStyle",_modal);anum++;
-
-  if (_title_bar_style == 0 && _no_frame == 1){
-    XtSetArg(args[anum],XtNoverrideRedirect,True);anum++;
-  }else{
-    XtSetArg(args[anum],XtNoverrideRedirect,False);anum++;
-  }
-  XtSetArg(args[anum],XtNborderWidth,0); anum++;
-  WSDwinappDev* app = WSGIwinAppDev(); 
-  HWND parent = app->appHWND();
-  WSDwinformDev* xdev = getParentAreaDev();
-  if (xdev != NULL){
-    parent = xdev->getHWND();
-  }
-
-  _shell = XtCreatePopupShell ( "wsshell", transientShellHWNDClass, parent,
-               (ArgList)args, anum );
-  XtAddEventHandler(_shell,StructureNotifyMask | SubstructureNotifyMask,False,(XtEventHandler)_evh_resize,this);
-  XtAddEventHandler(_shell,FocusChangeMask,False,(XtEventHandler)_evh_focus_ch,this);
-  XtAddEventHandler(_shell,NoEventMask,True,(XtEventHandler)_evh_client_message,this);
-
-  anum =0;
-  if (_back_cno != -1){
-    WSDcolor* color = WSGIappColorSet()->getColor(_back_cno);
-    if (color != NULL){
-       XtSetArg(args[anum],XtNbackground,color->getValue1()); anum++;
-    }
-  }
-  if (_back_pixno == -1){
-    XtSetArg(args[anum],XtNbackgroundPixmap,UNSPECIFIED_PIXMAP); anum++;
-  }else{
-    WSDimage*  image = WSGIappImageSet()->getImage(_back_pixno);
-    if (image != NULL){
-      if (image->getValue1() == -1){
-          XtSetArg(args[anum],XtNbackgroundPixmap,UNSPECIFIED_PIXMAP); anum++;
-      }else{
-         Pixmap pid = (Pixmap)image->getValue1();
-         XtSetArg(args[anum],XtNbackgroundPixmap,pid); anum++;
-      }
-    }else{
-      XtSetArg(args[anum],XtNbackgroundPixmap,UNSPECIFIED_PIXMAP); anum++;
-    }
-  }
-//printf("create dev=0x%x _shell=0x%x\n",this,_shell);
-//fflush(stdout);
-  XtSetArg(args[anum],XtNborderWidth,0); anum++;
-  _wnd = XtCreateHWND ( "wswina", formHWNDClass, _shell,args,anum);
-  XtManageChild(_wnd);
-  XtAddEventHandler(_wnd,ExposureMask,False,(XtEventHandler)_evh_expose,this);
-  XtAddEventHandler(_wnd,ButtonPressMask,False,(XtEventHandler)_evh_btn_press,(WSDwinformDev*)this);
-  XtAddEventHandler(_wnd,ButtonReleaseMask,False,(XtEventHandler)_evh_btn_release,(WSDwinformDev*)this);
-  XtAddEventHandler(_wnd,ButtonMotionMask | PointerMotionMask,False,(XtEventHandler)_evh_mouse_move,(WSDwinformDev*)this);
-  XtAddEventHandler(_wnd,EnterWindowMask,False,(XtEventHandler)_evh_mouse_in,this);
-  XtAddEventHandler(_wnd,LeaveWindowMask,False,(XtEventHandler)_evh_mouse_out,(WSDwinformDev*)this);
-  XtAddEventHandler(_wnd,KeyPressMask | KeyReleaseMask,False,(XtEventHandler)_evh_dummy,(WSDwinformDev*)this);
-  XtAddCallback(_wnd,XtNdestroyCallback,_evh_delete2,this);
-#endif
 dbprintf("WSDwinwinDev::createWindow %s:%d done shell=0x%x wnd=0x%x\n",__FILE__,__LINE__,_shell,_wnd);
   return WS_NO_ERR;
 }
@@ -674,7 +671,17 @@ dbprintf("WSDwinwinDev::destroyWindow() %s:%d start wnd=0x%x,shell=0x%x\n",__FIL
 #if 0
     SetWindowLong(_wnd,GWL_USERDATA,(long)0);
 #else
+#ifndef _WSWINCE
     SetProp(_wnd,"frm",(HANDLE)0);
+#else
+  unsigned short str1[4];
+  str1[0] = 'f';
+  str1[1] = 'r';
+  str1[2] = 'm';
+  str1[3] = 0;
+  SetProp(_wnd,str1,(HANDLE)0);
+  SetProp(_shell,str1,(HANDLE)0);
+#endif
 #endif
     MSG msg;
     while(PeekMessage(&msg,_wnd,0,0,PM_REMOVE)){
@@ -691,7 +698,17 @@ dbprintf("WSDwinwinDev::destroyWindow() %s:%d start wnd=0x%x,shell=0x%x\n",__FIL
 #if 0
     SetWindowLong(_shell,GWL_USERDATA,(long)0);
 #else
+#ifndef _WSWINCE
     SetProp(_shell,"frm",(HANDLE)0);
+#else
+  unsigned short str1[4];
+  str1[0] = 'f';
+  str1[1] = 'r';
+  str1[2] = 'm';
+  str1[3] = 0;
+  SetProp(_wnd,str1,(HANDLE)0);
+  SetProp(_shell,str1,(HANDLE)0);
+#endif
 #endif
     MSG msg;
     while(PeekMessage(&msg,_shell,0,0,PM_REMOVE)){
@@ -861,16 +878,26 @@ long WSDwinwinDev::setVisible(WSCbool fl){
     MoveWindow(_shell,x,y, w + _diff_w ,h + _diff_h,False);
     MoveWindow(_wnd,0,0, w,h,False);
 //    _resized = True;
+#ifndef WS_NWIN
     if (_no_frame != False){
 //      SetWindowLong(_shell,GWL_STYLE,_style);
 //      SetWindowLong(_shell,GWL_EXSTYLE,_style_ex);
       ShowWindow(_wnd,SW_SHOWNOACTIVATE);
       ShowWindow(_shell,SW_SHOWNOACTIVATE);
     }else{
+#ifndef _WSWINCE
       ShowWindow(_wnd,SW_SHOW);
       ShowWindow(_shell,SW_SHOW);
       SetWindowPos(_shell,HWND_TOP,0,0,0,0,SWP_NOMOVE|SWP_NOSIZE);
+#else
+      ShowWindow(_wnd,SW_SHOW);
+      ShowWindow(_shell,SW_SHOW);
+      SetForegroundWindow(_shell);
+      UpdateWindow(_shell);
+      UpdateWindow(_wnd);
+#endif
     }
+#endif
   }
   return WS_NO_ERR;
 }
@@ -1010,10 +1037,11 @@ void WSDwinwinDev::_evh_move(WinEvent* ev){
 //WSMFtrace("_evh_move return1 x,y,w,h=%d %d %d %d\n",_w_x,_w_y,_w_w,_w_h);
     return;
   }
+#ifndef _WSWINCE
   if (IsIconic(WSGIwinAppDev()->getEventWnd())){
     return;
   }
-
+#endif
 //  if (_moved != 0){
 //    _moved = 0;
 //printf("_evh_move return2 x,y,w,h=%d %d %d %d\n",_w_x,_w_y,_w_w,_w_h);
@@ -1107,9 +1135,11 @@ void WSDwinwinDev::_evh_resize(WinEvent* ev){
   if (_wnd == WSGIwinAppDev()->getEventWnd()){
     return;
   }
+#ifndef _WSWINCE
   if (IsIconic( WSGIwinAppDev()->getEventWnd())){
     return;
   }
+#endif
 //  if (_resized != 0){
 //printf("_evh_resize exists return...XXZZz2\n");
 //    _resized = 0;
