@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,27 +14,33 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
-
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
+#ifdef _WSWINCE
+#include <winsock.h>
+#endif
 #include <WScom.h>
 #include <WStcpcom.h>
 #include <WSCstring.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <string.h>
+#ifndef _WSWINCE
+#include <unistd.h>
 #include <fcntl.h>
 #include <sys/types.h>
+#endif
 //#include <sys/socket.h>
+#ifndef _WSWIN32
 #include <sys/time.h>
+#endif
 //#include <sys/ioctl.h>
 //#include <arpa/inet.h>
 //#include <netdb.h>
@@ -316,10 +322,12 @@ long WSGFhttpInit(){
   _http_initialized = 1;
 extern void WSGFtcpInit();
   WSGFtcpInit();
+#ifndef _WSWINCE
   char* httpp = getenv("WSHTPROXY");
   if (httpp != NULL){
     strcpy(_http_proxy,httpp);
   }
+#endif
   return 0;
 }
 
@@ -607,7 +615,7 @@ long WSGFhttpWrite(SOCKET sock,char* path){
      while ((bytes_read=fread(tmp_buf, sizeof(char), sizeof(tmp_buf),fp)) > 0){
         total_sz += bytes_read;
      }
-     rewind(fp);
+     fseek(fp,0,SEEK_SET);
      buf=_append_typestr(buf);
      buf=_append_lenstr(buf, total_sz);
   }
