@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,24 +14,35 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <win/WSwincom.h>
 #include <WSCstring.h>
 #include <WSClocaleSet.h>
+#ifdef _WSWINCE
+#define strdup _strdup
+#endif
 
+#ifndef WS_NWIN
 extern "C" {
 void libwswin_func();
 };
 void libwswin_func(){
 }
+#else
+extern "C" {
+void libwsnwin_func();
+};
+void libwsnwin_func(){
+}
+#endif
 
 int _system(char* cmdname){
   int len = strlen(cmdname);
@@ -41,7 +52,11 @@ int _system(char* cmdname){
   ZeroMemory(&si,sizeof(STARTUPINFO));
   ZeroMemory(&pi,sizeof(PROCESS_INFORMATION));
   si.cb = sizeof(STARTUPINFO);
+#ifndef _WSWINCE
   si.dwFlags = STARTF_USESHOWWINDOW;
+#else
+  si.dwFlags = 0;
+#endif
   si.wShowWindow = SW_SHOWNORMAL;
   if (str[len-1] == '&'){
     str[len-1] = ' ';
@@ -50,9 +65,16 @@ int _system(char* cmdname){
     tmp.delTailSpace();
 WSMFtrace("_system #%s#\n",(char*)tmp);
 //    CreateProcess(NULL,(char*)tmp,NULL,NULL,FALSE,DETACHED_PROCESS,NULL,NULL,&si,&pi);
+#ifndef _WSWINCE
     CreateProcess(NULL,
        tmp.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),
        NULL,NULL,FALSE,0,NULL,NULL,&si,&pi);
+#else
+    WSCushort* tmpstr = WSGFgetUCS2(tmp,WS_EN_DEFAULT);
+    CreateProcess(NULL,tmpstr,
+       NULL,NULL,FALSE,0,NULL,NULL,&si,&pi);
+    delete tmpstr;
+#endif
     free(str);
     if (pi.hProcess == 0){
       return -1;
@@ -64,15 +86,23 @@ WSMFtrace("_system #%s#\n",(char*)str);
     WSCstring tmp(str);
     tmp.delHeadSpace();
     tmp.delTailSpace();
+#ifndef _WSWINCE
     CreateProcess(NULL,
        tmp.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),
        NULL,NULL,FALSE,0,NULL,NULL,&si,&pi);
+#else
+    WSCushort* tmpstr = WSGFgetUCS2(tmp,WS_EN_DEFAULT);
+    CreateProcess(NULL,tmpstr,
+       NULL,NULL,FALSE,0,NULL,NULL,&si,&pi);
+#endif
     free(str);
     if (pi.hProcess == 0){
 WSMFtrace("_system error\n");
       return -1;
     }
+#ifndef _WSWINCE
     WaitForInputIdle(pi.hProcess,INFINITE);
+#endif
 //    WaitForInputIdle(GetCurrentProcess(),5000);
     DWORD ret = STILL_ACTIVE;
     while(ret == STILL_ACTIVE){
@@ -90,7 +120,11 @@ int _system_console(char* cmdname){
   ZeroMemory(&si,sizeof(STARTUPINFO));
   ZeroMemory(&pi,sizeof(PROCESS_INFORMATION));
   si.cb = sizeof(STARTUPINFO);
+#ifndef _WSWINCE
   si.dwFlags = STARTF_USESHOWWINDOW;
+#else
+  si.dwFlags = 0;
+#endif
   si.wShowWindow = SW_SHOWNORMAL;
   if (str[len-1] == '&'){
     str[len-1] = ' ';
@@ -98,19 +132,33 @@ int _system_console(char* cmdname){
     tmp.delHeadSpace();
     tmp.delTailSpace();
 WSMFtrace("_system #%s#\n",(char*)tmp);
+#ifndef _WSWINCE
     CreateProcess(NULL,(char*)tmp,NULL,NULL,FALSE,CREATE_NEW_CONSOLE,NULL,NULL,&si,&pi);
+#else
+    WSCushort* tmpstr = WSGFgetUCS2(tmp,WS_EN_DEFAULT);
+    CreateProcess(NULL,tmpstr,NULL,NULL,FALSE,CREATE_NEW_CONSOLE,NULL,NULL,&si,&pi);
+    delete tmpstr;
+#endif
     free(str);
     if (pi.hProcess == 0){
       return -1;
     }
     return 0;
   }else{
+#ifndef _WSWINCE
     CreateProcess(NULL,str,NULL,NULL,FALSE,CREATE_NEW_CONSOLE,NULL,NULL,&si,&pi);
+#else
+    WSCushort* tmpstr = WSGFgetUCS2(str,WS_EN_DEFAULT);
+    CreateProcess(NULL,tmpstr,NULL,NULL,FALSE,CREATE_NEW_CONSOLE,NULL,NULL,&si,&pi);
+    delete tmpstr;
+#endif
     free(str);
     if (pi.hProcess == 0){
       return -1;
     }
+#ifndef _WSWINCE
     WaitForInputIdle(pi.hProcess,INFINITE);
+#endif
 //    WaitForInputIdle(GetCurrentProcess(),5000);
     DWORD ret = STILL_ACTIVE;
     while(ret == STILL_ACTIVE){
