@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2002 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,26 +14,31 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSClocaleSet.h>
 #include <WSCinitializeManager.h>
 
+#ifndef WS_NWIN
 void _libwswin_lang_init_proc(){
 WSMFtrace("_libwswin_lang_init_proc start:\n");
 #include "English.cpp"
+#ifndef _WSWIN32
 #include "Japanese.cpp"
+#endif
 #include "Japanese-sjis.cpp"
+#ifndef _WSWIN32
 #include "Korean.cpp"
 #include "Chinese-zh_cn.cpp"
+#endif
 WSMFtrace("_libwswin_lang_init_proc done:\n");
 }
 
@@ -46,3 +51,29 @@ public:
 
 static _libwswin_lang_init_ _run_libwswin_lang_init;
 
+#else
+
+void _libwsnwin_lang_init_proc(){
+WSMFtrace("_libwsnwin_lang_init_proc start:\n");
+#include "English.cpp"
+#ifndef _WSWIN32
+#include "Japanese.cpp"
+#endif
+#include "Japanese-sjis.cpp"
+#ifndef _WSWIN32
+#include "Korean.cpp"
+#include "Chinese-zh_cn.cpp"
+#endif
+WSMFtrace("_libwsnwin_lang_init_proc done:\n");
+}
+
+class _libwsnwin_lang_init_{
+public:
+  _libwsnwin_lang_init_(){
+    WSGIappInitializeManager()->addInitializeProc(_libwsnwin_lang_init_proc);
+  };
+};
+
+static _libwsnwin_lang_init_ _run_libwsnwin_lang_init;
+
+#endif
