@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall 
-// not be used in advertising or otherwise to promote the sale, use or other 
-// dealings in this Software without prior written authorization from  
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team 
+// shall not be used in advertising or otherwise to promote the sale, use or 
+// other dealings in this Software without prior written authorization from  
+// WideStudio Development Team.
 
 #include "xunicode.h"
 
@@ -30,8 +30,16 @@
 #include <stdarg.h>
 #include <string.h>
 
-static const char* xu_lang = NULL;
+static char* xu_lang = NULL;
 static char xu_language[3] = {0, 0, 0};
+
+char* XUGetLang(){
+  if (xu_lang == NULL){
+    return "C";
+  }
+  return xu_lang;
+} 
+
 static int xu_locale_encoding = XU_CONV_NONE;
 BOOL xunicode_enable = FALSE;
 int XUGetLocale(){
@@ -153,7 +161,11 @@ void XUInit()
   }else{
     xu_locale_encoding = XU_CONV_LOCALE;
   }
+#ifndef _WSWINCE
   char* xu_lang = getenv("LANG");
+#else
+  char* xu_lang = "";
+#endif
   if(xu_lang){
     xu_locale_encoding = XU_CONV_NONE;
     XUInitLocale();
@@ -278,7 +290,11 @@ static void XUInitTable()
 
 static void XUInitLocale()
 {
+#ifndef _WSWINCE
   xu_lang = getenv("LANG");
+#else
+  xu_lang = NULL;
+#endif
   if(!xu_lang) xu_lang = "C";
   strncpy(xu_language, xu_lang, 2);
   
@@ -293,6 +309,7 @@ static void XUInitLocale()
 
 static void XUInitEncoding()
 {
+#if 0
   if(XUIsEncoding("utf8")) {
     xu_locale_encoding = XU_CONV_UTF8;
   } else if(XUIsEncoding("sjis") || XUIsEncoding("shiftjis")) {
@@ -325,6 +342,9 @@ static void XUInitEncoding()
   if(xu_locale_encoding != XU_CONV_NONE) return;
   
   xu_locale_encoding = XU_CONV_ISO8859(1);
+#endif
+extern long WSGFgetEncoding(char*);
+  xu_locale_encoding = WSGFgetEncoding(xu_lang);
 }
 
 #ifndef WIN32
@@ -351,7 +371,7 @@ static void XUInitFontSet()
   }
 }
 #endif //WIN32
-
+#if 0
 static Bool XUIsEncoding(const char* enc)
 {
   const char* p1 = 0;
@@ -385,7 +405,7 @@ static int XUGetISO8859()
   if(iso < 1 || iso > 15) return XU_CONV_NONE;
   return XU_CONV_ISO8859(iso);
 }
-
+#endif
 #ifndef WIN32
 
 static void XUInitSetting()
