@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCwindow.h>
@@ -329,7 +329,7 @@ void initialize(){
     WSGIappMessageDialog()->setProperty(WSNheight,150);
     WSGIappMessageDialog()->setProperty(WSNwidth,500);
     WSGIappMessageDialog()->popup();
-    exit(1);
+    WSGFexit(1);
   }
 #ifdef MSW
 extern int _system(char*);
@@ -393,7 +393,7 @@ extern void create_main_window();
   question->setPropertyV(WSNtitleString,WSGFgettext("B4:WSSTR Confirmation"));
 
   WSCstring datadir;
-  datadir << "$(WSDIR)/sys/data/" << WSGIappLocaleSet()->getDefaultLocaleName();
+  datadir << "$(WSDIR)/sys/data/locale/" << WSGIappLocaleSet()->getSystemLocaleName();
   WSCstring data;
   data << datadir << "/lib1.data,";
   data << datadir << "/lib2.data,";
@@ -432,7 +432,7 @@ extern void _create_win_tracewin();
   _create_win_tracewin();
 
   WSCstring defprj;
-  defprj << "$(WSDIR)/sys/data/" << WSGIappLocaleSet()->getDefaultLocaleName()
+  defprj << "$(WSDIR)/sys/data/locale/" << WSGIappLocaleSet()->getSystemLocaleName()
          << "/default.prj";
   pe->setDefaultProjectName(defprj);
   pe->open(defprj);
@@ -443,7 +443,7 @@ extern void _create_win_tracewin();
 #endif
   if (ret != WS_NO_ERR){
     WSCstring defrc;
-    defrc << "$(WSDIR)/sys/data/" << WSGIappLocaleSet()->getDefaultLocaleName()
+    defrc << "$(WSDIR)/sys/data/locale/" << WSGIappLocaleSet()->getSystemLocaleName()
            << "/default.rc";
     pe->open_global(defrc);
   }
