@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCwizardDialog.h>
@@ -87,7 +87,7 @@ static void visop(WSCbase*){
   optbuf.clear();
   WSCstring cname;
   cname = pe->getProjectData("#WINC_NAME");
- long encoding = WSGFgetLocaleValue(pe->getProjectData("#ENCODING"));
+ long encoding = WSGFgetEncodingValue(pe->getProjectData("#ENCODING"));
  if (encoding == WS_EN_DEFAULT){
    encoding = WSGIappLocaleSet()->getSystemLocaleEncoding();
  }
@@ -95,7 +95,8 @@ static void visop(WSCbase*){
   WSCstring template_file;
   template_file << "$(WSDIR)/sys/data/"
 //               << WSGIappLocaleSet()->getDefaultLocaleName()
-               << WSGFgetLocaleName(encoding)
+               << WSGFgetEncodingName(encoding)
+//               << WSGIappLocaleSet()->getSystemLocaleName()
                << "/" << cname << "/templates";
   WSCstring* templates = WSGFreadTextFile(template_file,encoding);
 //                  WSGIappLocaleSet()->getSystemLocaleEncoding());
