@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSCbase.h>
@@ -115,7 +115,7 @@ void del_instance(WSCbase* target){
 long win_save(WSCbase* win){
   WSCstring str = WSGFcreateWinSrc(win);
   WSCstring fname(get_win_file_name(win));
-  long encoding = WSGFgetLocaleValue(pe->getProjectData("#ENCODING"));
+  long encoding = WSGFgetEncodingValue(pe->getProjectData("#ENCODING"));
   if (encoding == WS_EN_DEFAULT || encoding == WS_EN_NONE){
     encoding = WS_EN_LOCALE;
   }
@@ -141,7 +141,7 @@ long win_save(WSCbase* win){
 long check_win_save(WSCbase* win){
   WSCstring str = WSGFcreateWinSrc(win);
   WSCstring fname(get_win_file_name(win));
-  long encoding = WSGFgetLocaleValue(pe->getProjectData("#ENCODING"));
+  long encoding = WSGFgetEncodingValue(pe->getProjectData("#ENCODING"));
   if (encoding == WS_EN_DEFAULT || encoding == WS_EN_NONE){
     encoding = WS_EN_LOCALE;
   }
@@ -174,7 +174,7 @@ extern char* get_project_dir();
   }
   WSCstring fname(fselect->getFileName());
 
-  long encoding = WSGFgetLocaleValue(pe->getProjectData("#ENCODING"));
+  long encoding = WSGFgetEncodingValue(pe->getProjectData("#ENCODING"));
   if (encoding == WS_EN_DEFAULT || encoding == WS_EN_NONE){
     encoding = WS_EN_LOCALE;
   }
@@ -653,7 +653,7 @@ long read_win_file(char* dirname,char* fname,WSClistData* wlist){
     fname2 << dirname << "/" << fname;
   }
 
-  long encoding = WSGFgetLocaleValue(pe->getProjectData("#ENCODING"));
+  long encoding = WSGFgetEncodingValue(pe->getProjectData("#ENCODING"));
   if (encoding == WS_EN_DEFAULT || encoding == WS_EN_NONE){
     encoding = WS_EN_LOCALE;
   }
@@ -809,7 +809,7 @@ long _save_winfiles(char* dirname,char* filename,WSClistData* wlist){
     }else{
       fname2 << wname;
     }
-    long encoding = WSGFgetLocaleValue(pe->getProjectData("#ENCODING"));
+    long encoding = WSGFgetEncodingValue(pe->getProjectData("#ENCODING"));
     if (encoding == WS_EN_DEFAULT || encoding == WS_EN_NONE){
       encoding = WS_EN_LOCALE;
     }
@@ -947,11 +947,12 @@ extern WSCoption* nmopt1;
   if (!strcmp(ptr,"NONE")){
     win = WSCbase::getNewInstance(cname,NULL,iname);
   }else{
-    long encoding = WSGFgetLocaleValue(pe->getProjectData("#ENCODING"));
+    long encoding = WSGFgetEncodingValue(pe->getProjectData("#ENCODING"));
     WSCstring fname;
     fname << "$(WSDIR)/sys/data/"
 //          << WSGIappLocaleSet()->getDefaultLocaleName()
-          << WSGFgetLocaleName(encoding)
+          << WSGFgetEncodingName(encoding)
+//          << WSGIappLocaleSet()->getSystemLocaleName()
           << "/" << cname << "/" << ptr;
     if (encoding == WS_EN_DEFAULT || encoding == WS_EN_NONE){
       encoding = WS_EN_LOCALE;
@@ -1393,7 +1394,7 @@ WSCstring _get_structure_inf_work(WSCbase* base,int level){
       ret << "  ";
     }
     WSCstring pname(ac->getProcName(),WS_EN_UTF8);
-    long encoding = WSGFgetLocaleValue(pe->getProjectData("#ENCODING")); 
+    long encoding = WSGFgetEncodingValue(pe->getProjectData("#ENCODING")); 
     ret << " [" << pname.getString(encoding) << "]:" << ac->getTrigger()<<":";
     if (ac->getUseFile() == False){
       ret << ac->getFunctionName()<<"\n";
