@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <assert.h>
 #include <X11/Intrinsic.h>
@@ -490,7 +490,8 @@ cnt++;
     if (wait != False){
       XtAppNextEvent(_app_context,&e);
     }else{
-      Boolean fl = XtAppPeekEvent(_app_context,&e);
+//      Boolean fl = XtAppPeekEvent(_app_context,&e);
+      Boolean fl = XCheckMaskEvent(_disp,0xffffffff,&e);
       if (fl == 0){
         return WS_NO_ERR;
       }
@@ -632,10 +633,24 @@ static Atom prop6 = 0;
                       8,PropModeReplace,(unsigned char*)str,strlen(str));
 //printf("xappdev:: send data.. prop.. #%s# %d %d %d\n",str,XA_PRIMARY,XA_STRING,se.property);
     }else if (e.xselectionrequest.selection == XA_PRIMARY &&
-              e.xselectionrequest.target == XA_STRING ){
+//              e.xselectionrequest.target == XA_STRING ){
+              e.xselectionrequest.target == prop2 ){
 //printf("xappdev:: send data.. string target=0x%x XA_STRING\n",e.xselectionrequest.target);
       char* str = WSGIappKeyboard()->WSDkeyboard::getSelectedString(
                                WSGIappLocaleSet()->getSystemLocaleEncoding());
+#if 1
+      WSCushort* ustr = WSGFgetUCS2(str,
+                               WSGIappLocaleSet()->getSystemLocaleEncoding());
+      int maxlen = strlen(str)+1024;
+      char* str2 = new char[maxlen+1];
+extern int XUctDecode(char* dest, int max, const XUChar* text, int length);
+      XUctDecode(str2,maxlen,(XUChar*)ustr,WSGFstrlenUCS2(ustr));
+      XChangeProperty(_disp,se.requestor,se.property,se.target,
+                      8,PropModeReplace,(unsigned char*)str2,strlen(str2));
+      delete ustr;
+      delete str2;
+#endif
+#if 0
       char* str2 = NULL;
       WSCbool need_convert = False;
       WSCushort* ustr = NULL;
@@ -704,9 +719,15 @@ static Atom prop6 = 0;
       }else{
         XChangeProperty(_disp,se.requestor,se.property,se.target,
                       8,PropModeReplace,(unsigned char*)str2,strlen(str2));
+int i;
+for(i=0; i<strlen(str2);i++){
+printf("0x%x ",str2[i]);
+}
+printf("\n",str2[i]);
       }
       delete str2;
       delete ustr;
+#endif
     }else if (e.xselectionrequest.selection == XA_PRIMARY &&
          e.xselectionrequest.target == prop5 ){
 //printf("xappdev:: send data.. string target=0x%x UTF8_STRING\n",e.xselectionrequest.target);
@@ -929,31 +950,27 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
 #endif
 //printf("0x%x 0x%x 0x%x 0x%x nitems=%d\n",buffer[0],buffer[1],buffer[2],buffer[3],nitems);
         long encoding = WSGIappLocaleSet()->getSystemLocaleEncoding();
-        WSCstring tmp(buffer, encoding);
-        char b1[5];
-        b1[0] = 0x1b; 
-        b1[1] = 0x24; 
-        b1[2] = 0x29; 
-        b1[3] = 0x42; 
-        b1[4] = 0; 
-        tmp.replaceString(b1,"",0);
-        b1[0] = 0x1b; 
-        b1[1] = 0x29; 
-        b1[2] = 0x49; 
-        b1[3] = 0; 
-        tmp.replaceString(b1,"",0);
-        b1[0] = 0x1b; 
-        b1[1] = 0x28; 
-        b1[2] = 0x42; 
-        b1[3] = 0; 
-        tmp.replaceString(b1,"",0);
- 
-        WSGIxkeyboard()->WSDkeyboard::setSelectedString(
-                                    tmp.getString(encoding),encoding);
-//printf("type=%d fmt=%d left=%d\n",type,fmt,left);
-//printf("xappdev:: comming data by cut buffer...#%s# strlen=%d %d\n",buffer,strlen(buffer), WSGIappLocaleSet()->getSystemLocaleEncoding());
-//        WSGIxkeyboard()->WSDkeyboard::setSelectedString(buffer);
-//printf("xappdev:: comming data3...type=%d %d nitems=%d #%s#\n",type,fmt,nitems,buf);
+#if 0
+{
+  int i;
+  for(i=0; i<strlen(buffer); i++){
+printf("0x%x ",buffer[i]);
+  }
+printf("\n");
+}
+#endif
+        long len = strlen(buffer)+1;
+        WSCushort* ustr = new WSCushort[len];
+        if (ustr != NULL){
+extern int XUctEncode(XUChar* dest, int max, const char* text, int length);
+          XUctEncode(ustr,len,buffer,len-1);
+          char* str2 = WSGFgetString(ustr,WS_EN_UTF8);
+          if (str2 != NULL){
+            WSGIxkeyboard()->WSDkeyboard::setSelectedString(str2,WS_EN_UTF8);
+            delete str2;
+          }
+          delete ustr;
+        }
       }else{
 //printf("xappdev:: comming data... none...\n");
       }
@@ -976,40 +993,19 @@ dbprintf("WSDxappDev::_dispatchEvent %s:%d done5\n",__FILE__,__LINE__);
           buffer[8192] = 0;
         }
         long encoding = WSGIappLocaleSet()->getSystemLocaleEncoding();
-        WSCstring tmp(buffer, encoding);
-        char b1[5];
-        b1[0] = 0x1b; 
-        b1[1] = 0x24; 
-        b1[2] = 0x29; 
-        b1[3] = 0x42; 
-        b1[4] = 0; 
-        tmp.replaceString(b1,"",0);
-        b1[0] = 0x1b; 
-        b1[1] = 0x24; 
-        b1[2] = 0x28; 
-        b1[3] = 0x42; 
-        b1[4] = 0; 
 
-        if (tmp.isExist(b1) != -1){
-          char* str = WSGFcreateEucStringFromJisStr(buffer);
-          tmp.setString(str,WS_EN_EUCJP);
-          delete str;
+        long len = strlen(buffer)+1;
+        WSCushort* ustr = new WSCushort[len];
+        if (ustr != NULL){
+extern int XUctEncode(XUChar* dest, int max, const char* text, int length);
+          XUctEncode(ustr,len,buffer,len-1);
+          char* str2 = WSGFgetString(ustr,WS_EN_UTF8);
+          if (str2 != NULL){
+            WSGIxkeyboard()->WSDkeyboard::setSelectedString(str2,WS_EN_UTF8);
+            delete str2;
+          }
+          delete ustr;
         }
-
-        b1[0] = 0x1b; 
-        b1[1] = 0x29; 
-        b1[2] = 0x49; 
-        b1[3] = 0; 
-        tmp.replaceString(b1,"",0);
-        b1[0] = 0x1b; 
-        b1[1] = 0x28; 
-        b1[2] = 0x42; 
-        b1[3] = 0; 
-        tmp.replaceString(b1,"",0);
-//printf("0x%x 0x%x 0x%x 0x%x nitems=%d\n",buffer[0],buffer[1],buffer[2],buffer[3],nitems);
-
-        WSGIxkeyboard()->WSDkeyboard::setSelectedString(
-                                    tmp.getString(encoding),encoding);
       }
       WSGIxkeyboard()->selectionDataAvailable();
     }else{
