@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <X11/Xlib.h>
 #include <WScom.h>
@@ -96,53 +96,86 @@ Colormap WSDxcolor::getColormap(){
 
 
 long WSDxcolor::initialize(){
-   char* cname = getSrc();
-   if (cname == NULL){
-       cname = "black";
-   }
-   if ( colorIsStatic() == True || getUsePrivateCell() == False ){
-     Colormap cmap;
-     XColor c0;
-     XColor c1;
-     if (disp == NULL){
-       disp = XOpenDisplay((char*)NULL);
-     }
-     if (disp == NULL){
-       return WS_ERR;
-     }
-     cmap = getColormap();
-     XAllocNamedColor(disp,cmap,cname,&c1,&c0);
-     long pix = (long)c1.pixel;
-     setValue1(pix);
-     _xc1 = c0;
+  char* cname = getSrc();
+  if (cname == NULL){
+    cname = "black";
+  }
+  WSCbool alpha = False;
+  char buffer[32];
+  long rval = 0,gval = 0,bval = 0,aval=255;
+  if(cname[0] == '#'){
+    long slen = strlen(cname);
+    if(slen == 4){
+    }else if(slen == 5){
+      sscanf( cname,"#%1x%1x%1x%1x",&rval,&gval,&bval,&aval);
+      rval = rval *16;
+      gval = gval *16;
+      bval = bval *16;
+      aval = aval *16;
+      alpha = True;
+    }else if(slen == 7){
+    }else if(slen == 9){
+      sscanf( cname,"#%2x%2x%2x%2x",&rval,&gval,&bval,&aval);
+      alpha = True;
+    }else if(slen == 13){
+    }else if(slen == 17){
+      sscanf( cname,"#%4x%4x%4x%4x",&rval,&gval,&bval,&aval);
+      rval = rval /256;
+      gval = gval /256;
+      bval = bval /256;
+      aval = aval /256;
+      alpha = True;
+    }else{
+      //black...
+    }
+    if (alpha == True){
+      sprintf(buffer,"#%02x%02x%02x",rval,gval,bval);
+      cname = buffer;
+    }
+  }
+  if ( colorIsStatic() == True || getUsePrivateCell() == False ){
+    Colormap cmap;
+    XColor c0;
+    XColor c1;
+    if (disp == NULL){
+      disp = XOpenDisplay((char*)NULL);
+    }
+    if (disp == NULL){
+      return WS_ERR;
+    }
+    cmap = getColormap();
+    XAllocNamedColor(disp,cmap,cname,&c1,&c0);
+    long pix = (long)c1.pixel;
+    setValue1(pix);
+    _xc1 = c0;
 
-   }else{
-     Colormap cmap;
-     if (disp == NULL){
-       disp = XOpenDisplay((char*)NULL);
-     }
-     if (disp == NULL){
-       return WS_ERR;
-     }
-     cmap = getColormap();
-     WSCulong dummy;
-     if (_private_cell == 0){
-       XAllocColorCells(disp,cmap,True, &dummy,0, &_private_cell,1);
-     }
+  }else{
+    Colormap cmap;
+    if (disp == NULL){
+      disp = XOpenDisplay((char*)NULL);
+    }
+    if (disp == NULL){
+      return WS_ERR;
+    }
+    cmap = getColormap();
+    WSCulong dummy;
+    if (_private_cell == 0){
+      XAllocColorCells(disp,cmap,True, &dummy,0, &_private_cell,1);
+    }
 
-     XStoreNamedColor(disp,cmap, cname, _private_cell,
-                      DoRed|DoGreen|DoBlue);
-     XColor xc;
-     xc.pixel = _private_cell;
-     xc.flags = DoRed | DoGreen | DoBlue;
-     XQueryColor(disp,cmap,&xc);
+    XStoreNamedColor(disp,cmap, cname, _private_cell,
+                     DoRed|DoGreen|DoBlue);
+    XColor xc;
+    xc.pixel = _private_cell;
+    xc.flags = DoRed | DoGreen | DoBlue;
+    XQueryColor(disp,cmap,&xc);
 
-     long pix = (long)_private_cell;
+    long pix = (long)_private_cell;
 
-     setValue1(pix);
-     _xc1 = xc;
-   }
-   return WS_NO_ERR;
+    setValue1(pix);
+    _xc1 = xc;
+  }
+  return WS_NO_ERR;
 }
 XColor* WSDxcolor::getXColor1(){
   return &_xc1;
