@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <X11/Xlib.h>
 #include <WScom.h>
@@ -382,7 +382,7 @@ long WSDxfontSelect::initialize(){
   xfonvtex014->setPropertyV(WSNy,(short)5);
   xfonvtex014->setPropertyV(WSNwidth,(WSCushort)70);
   xfonvtex014->setPropertyV(WSNheight,(WSCushort)20);
-  xfonvtex014->setPropertyV(WSNshadowType,(char)WS_SHADOW_TRANS);
+  xfonvtex014->setPropertyV(WSNshadowType,(signed char)WS_SHADOW_TRANS);
   xfonvtex014->setVisible(True);
 
 #if 0
@@ -396,7 +396,7 @@ long WSDxfontSelect::initialize(){
   xfonvtex015->setPropertyV(WSNy,(short)25);
   xfonvtex015->setPropertyV(WSNwidth,(WSCushort)70);
   xfonvtex015->setPropertyV(WSNheight,(WSCushort)20);
-  xfonvtex015->setPropertyV(WSNshadowType,(char)WS_SHADOW_TRANS);
+  xfonvtex015->setPropertyV(WSNshadowType,(signed char)WS_SHADOW_TRANS);
   xfonvtex015->setVisible(True);
 #endif
 #if 0
@@ -410,7 +410,7 @@ long WSDxfontSelect::initialize(){
   xfonvtex016->setPropertyV(WSNy,(short)45);
   xfonvtex016->setPropertyV(WSNwidth,(WSCushort)70);
   xfonvtex016->setPropertyV(WSNheight,(WSCushort)20);
-  xfonvtex016->setPropertyV(WSNshadowType,(char)WS_SHADOW_TRANS);
+  xfonvtex016->setPropertyV(WSNshadowType,(signed char)WS_SHADOW_TRANS);
   xfonvtex016->setVisible(True);
 #endif
   xfonvtex017 = new  WSCvlabel(xfonarea001,"xfonvtex017");
@@ -424,7 +424,7 @@ long WSDxfontSelect::initialize(){
   xfonvtex017->setPropertyV(WSNy,(short)25);
   xfonvtex017->setPropertyV(WSNwidth,(WSCushort)70);
   xfonvtex017->setPropertyV(WSNheight,(WSCushort)20);
-  xfonvtex017->setPropertyV(WSNshadowType,(char)WS_SHADOW_TRANS);
+  xfonvtex017->setPropertyV(WSNshadowType,(signed char)WS_SHADOW_TRANS);
   xfonvtex017->setVisible(True);
 #if 0
   WSCvlabel* xfonvtex018 = new  WSCvlabel(xfonarea001,"xfonvtex018");
@@ -437,7 +437,7 @@ long WSDxfontSelect::initialize(){
   xfonvtex018->setPropertyV(WSNy,(short)85);
   xfonvtex018->setPropertyV(WSNwidth,(WSCushort)70);
   xfonvtex018->setPropertyV(WSNheight,(WSCushort)20);
-  xfonvtex018->setPropertyV(WSNshadowType,(char)WS_SHADOW_TRANS);
+  xfonvtex018->setPropertyV(WSNshadowType,(signed char)WS_SHADOW_TRANS);
   xfonvtex018->setVisible(True);
 #endif
 
@@ -452,7 +452,7 @@ long WSDxfontSelect::initialize(){
   xfonvtex019->setPropertyV(WSNy,(short)105);
   xfonvtex019->setPropertyV(WSNwidth,(WSCushort)70);
   xfonvtex019->setPropertyV(WSNheight,(WSCushort)20);
-  xfonvtex019->setPropertyV(WSNshadowType,(char)WS_SHADOW_TRANS);
+  xfonvtex019->setPropertyV(WSNshadowType,(signed char)WS_SHADOW_TRANS);
   xfonvtex019->setVisible(True);
 #endif
 
@@ -466,7 +466,7 @@ long WSDxfontSelect::initialize(){
   xfonvtex020->setPropertyV(WSNy,(short)125);
   xfonvtex020->setPropertyV(WSNwidth,(WSCushort)70);
   xfonvtex020->setPropertyV(WSNheight,(WSCushort)20);
-  xfonvtex020->setPropertyV(WSNshadowType,(char)WS_SHADOW_TRANS);
+  xfonvtex020->setPropertyV(WSNshadowType,(signed char)WS_SHADOW_TRANS);
 
 //  if (!strcmp(WSGIappLocaleSet()->getDefaultLocaleName(),WS_LOCALE_JAPANESE)){
 //    //japanese
