@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <X11/Xlib.h>
 #include <unistd.h>
@@ -87,9 +87,9 @@ long WSDximage::initialize(){
 
      if (dl_init == 0){
 #ifndef MacOS
-       dl = dlopen("xpm.so",RTLD_LAZY);
+       dl = dlopen("libwsxpm.so",RTLD_LAZY);
        if (dl == NULL){
-         dl = dlopen("./xpm.so",RTLD_LAZY);
+         dl = dlopen("./libwsxpm.so",RTLD_LAZY);
        }
 #else //MacOS
        dl = dlopen("/usr/lib/xpm.bundle",RTLD_LAZY);
@@ -100,7 +100,7 @@ long WSDximage::initialize(){
        dl_init = 1;
        if (dl == NULL){
 #ifndef MacOS
-WSMFtrace("ERROR. in WSDximage::initialize(). Library xpm.so open error. \nso, Xpm image can not support...\n");
+WSMFtrace("ERROR. in WSDximage::initialize(). Library libwsxpm.so open error. \nso, Xpm image can not support...\n");
 #else //MacOS
 WSMFtrace("ERROR. in WSDximage::initialize(). Library /usr/lib/xpm.bundle open error. \nso, Xpm image can not support...\n");
 #endif //MacOS
@@ -180,9 +180,9 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library libXpm.so is invalid. \nso
 
      if (dl_init == 0){
 #ifndef MacOS
-       dl = dlopen("jpg.so",RTLD_LAZY);
+       dl = dlopen("libwsjpg.so",RTLD_LAZY);
        if (dl == NULL){
-         dl = dlopen("./jpg.so",RTLD_LAZY);
+         dl = dlopen("./libwsjpg.so",RTLD_LAZY);
        }
 #else //MacOS
        dl = dlopen("/usr/lib/jpg.bundle",RTLD_LAZY);
@@ -193,7 +193,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library libXpm.so is invalid. \nso
        dl_init = 1;
        if (dl == NULL){
 #ifndef MacOS
-WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.so open error. \nso, jpeg image can not support...\n");
+WSMFtrace("ERROR. in WSDximage::initialize(). Library libwsjpg.so open error. \nso, jpeg image can not support...\n");
 #else //MacOS
 WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.bundle open error. \nso, jpeg image can not support...\n");
 #endif //MacOS
@@ -201,7 +201,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.bundle open error. \ns
          fn = (long (*)(Display*,Window,GC,char*,long,Pixmap*,long*,long*))
                 dlsym(dl,"JpegReadFileToPixmap");
          if (fn == NULL){
-WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.so is invalid. \nso, jpeg image can not support...\n");
+WSMFtrace("ERROR. in WSDximage::initialize(). Library libwsjpg.so is invalid. \nso, jpeg image can not support...\n");
          }
        }
      }
@@ -250,9 +250,9 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.so is invalid. \nso, j
 
      if (dl_init == 0){
 #ifndef MacOS
-       dl = dlopen("png.so",RTLD_LAZY);
+       dl = dlopen("libwspng.so",RTLD_LAZY);
        if (dl == NULL){
-         dl = dlopen("./png.so",RTLD_LAZY);
+         dl = dlopen("./libwspng.so",RTLD_LAZY);
        }
 #else //MacOS
        dl = dlopen("/usr/lib/png.bundle",RTLD_LAZY);
@@ -263,7 +263,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library jpg.so is invalid. \nso, j
        dl_init = 1;
        if (dl == NULL){
 #ifndef MacOS
-WSMFtrace("ERROR. in WSDximage::initialize(). Library png.so open error. \nso, jpeg image can not support...\n");
+WSMFtrace("ERROR. in WSDximage::initialize(). Library libwspng.so open error. \nso, jpeg image can not support...\n");
 #else //MacOS
 WSMFtrace("ERROR. in WSDximage::initialize(). Library png.bundle open error. \nso, jpeg image can not support...\n");
 #endif //MacOS
@@ -271,7 +271,7 @@ WSMFtrace("ERROR. in WSDximage::initialize(). Library png.bundle open error. \ns
          fn = (long (*)(Display*,Window,GC,char*,Pixmap*,Pixmap*,long*,long*))
                 dlsym(dl,"PngReadFileToPixmap");
          if (fn == NULL){
-WSMFtrace("ERROR. in WSDximage::initialize(). Library png.so is invalid. \nso, jpeg image can not support...\n");
+WSMFtrace("ERROR. in WSDximage::initialize(). Library libwspng.so is invalid. \nso, jpeg image can not support...\n");
          }
        }
      }
