@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,15 +14,15 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <x11/WSDxkeyboard.h>
 #include <X11/Xutil.h>
@@ -163,12 +163,12 @@ WSDdev* WSDxkeyboard::getDevForKI(){
 long xim_lang = WS_EN_NONE;
 long WSDxkeyboard::initialize(){
   if (getenv("WS_XIM_LANG")){
-extern long WSGFgetLocaleValue(char*);
-    xim_lang = WSGFgetLocaleValue(getenv("WS_XIM_LANG"));
+extern long WSGFgetEncodingValue(char*);
+    xim_lang = WSGFgetEncodingValue(getenv("WS_XIM_LANG"));
   }
   //ISO8859..
-  if (WSGIappCodeConvert()->getSystemLocale() > WS_EN_NONE &&
-      WSGIappCodeConvert()->getSystemLocale() < WS_EN_UTF8){
+  if (WSGIappCodeConvert()->getSystemEncoding() > WS_EN_NONE &&
+      WSGIappCodeConvert()->getSystemEncoding() < WS_EN_UTF8){
     return WS_NO_ERR;
   }
 #ifndef KINPUT2 //XIM
@@ -666,7 +666,7 @@ void WSDxkeyboard::_kanji_input(Widget,Atom,Atom,int pformat,
     obj->_is_function = False;
     obj->_is_cursor = False;
     obj->_is_tty_function = False;
-    obj->setText(kanji_euc_str,WSGIappCodeConvert()->getSystemLocale());
+    obj->setText(kanji_euc_str,WSGIappCodeConvert()->getSystemEncoding());
     delete kanji_euc_str;
     obj->executeHandler(True);
     obj->executeHandler(False);
@@ -852,7 +852,7 @@ WSCbool WSDxkeyboard::deliverKeyEvent(XEvent* ev){
   _is_cursor = IsCursorKey(key);
   _is_function = IsFunctionKey(key);
   if (xim_lang == WS_EN_NONE){
-    setText(buffer,WSGIappCodeConvert()->getSystemLocale());
+    setText(buffer,WSGIappCodeConvert()->getSystemEncoding());
   }else{
     setText(buffer,xim_lang);
   }
