@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,27 +14,42 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 //
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #include <WScom.h>
 #include <WSClocaleSet.h>
 #include <WSCinitializeManager.h>
 
 void _libwsx11_lang_init_proc(){
+#ifndef NO_ENGLISH_MSG
 #include "English.cpp"
+#endif
+#ifndef NO_JAPANESE_EUC_MSG
 #include "Japanese.cpp"
+#endif
+#ifndef NO_JAPANESE_SJIS_MSG
 #include "Japanese-sjis.cpp"
+#endif
+#ifndef NO_JAPANESE_UTF8_MSG
 #include "Japanese-utf8.cpp"
+#endif
+#ifndef NO_KSC5601_MSG
 #include "Korean.cpp"
+#endif
+#ifndef NO_GB2312_MSG
 #include "Chinese-zh_cn.cpp"
+#endif
+#ifndef NO_ES_MSG
+#include "Espanol.cpp"
+#endif
 }
 
 class _libwsx11_lang_init_{
