@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,14 +14,14 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall 
-// not be used in advertising or otherwise to promote the sale, use or other 
-// dealings in this Software without prior written authorization from  
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team 
+// shall not be used in advertising or otherwise to promote the sale, use or 
+// other dealings in this Software without prior written authorization from  
+// WideStudio Development Team.
 
 #include "xunicode.h"
 
@@ -42,9 +42,16 @@ BOOL xunicode_enable = FALSE;
 #include <locale.h>
 int xunicode_enable = False;
 
-static const char* xu_lang = NULL;
+static char* xu_lang = NULL;
 static char xu_language[3] = {0, 0, 0};
 
+char* XUGetLang(){
+  if (xu_lang == NULL){
+    return "C";
+  }
+  return xu_lang;
+}
+
 #define DEFAULT_CHAR_SET_BIG5 \
 "* -kc-fixed-*-big5-0, \
  -isas-song ti-*-gb2312.1980-0, \
@@ -294,7 +301,8 @@ static void XUInitLocale()
   strncpy(xu_language, xu_lang, 2);
   
   XUInitEncoding();
-  
+//printf("lang=#%s# %d\n",xu_language,xu_locale_encoding);
+
   if(setlocale(LC_ALL, "")) XUInitFontSet();
   XSetLocaleModifiers("");
 }
@@ -302,13 +310,14 @@ static void XUInitLocale()
 
 static void XUInitEncoding()
 {
-extern void WSGFsetLangVal(long);
-#define WS_EN_LANG_JP 1
+#if 0
+//extern void WSGFsetLangVal(long);
+//#define WS_EN_LANG_JP 1
   if(XUIsEncoding("utf8")) {
     xu_locale_encoding = XU_CONV_UTF8;
-    if(!strcmp(xu_language, "ja")){
-      WSGFsetLangVal(WS_EN_LANG_JP);
-    }
+//    if(!strcmp(xu_language, "ja")){
+//      WSGFsetLangVal(WS_EN_LANG_JP);
+//    }
   } else if(XUIsEncoding("sjis") || XUIsEncoding("shiftjis")) {
     xu_locale_encoding = XU_CONV_SJIS;
   } else if(XUIsEncoding("eucjp")) {
@@ -325,16 +334,16 @@ extern void WSGFsetLangVal(long);
     xu_locale_encoding = XUGetISO8859();
   }
   if(xu_locale_encoding != XU_CONV_NONE) return;
-
+#endif
 #ifdef MacOS
   if(!strcmp(xu_language, "ja")){
     xu_locale_encoding = XU_CONV_UTF8;
     setenv("LANG","ja_JP.UTF-8",1);
-    WSGFsetLangVal(WS_EN_LANG_JP);
+//    WSGFsetLangVal(WS_EN_LANG_JP);
     return;
   }
 #endif //MacOS
-
+#if 0
   if(!strcmp(xu_language, "cs")) xu_locale_encoding = XU_CONV_ISO8859(2);
   if(!strcmp(xu_language, "he")) xu_locale_encoding = XU_CONV_ISO8859(8);
   if(!strcmp(xu_language, "hr")) xu_locale_encoding = XU_CONV_ISO8859(2);
@@ -348,6 +357,9 @@ extern void WSGFsetLangVal(long);
   if(xu_locale_encoding != XU_CONV_NONE) return;
   
   xu_locale_encoding = XU_CONV_ISO8859(1);
+#endif
+extern long WSGFgetEncoding(char*);
+  xu_locale_encoding = WSGFgetEncoding(xu_lang);
 }
 
 
@@ -373,7 +385,7 @@ static void XUInitFontSet()
   }
 }
 
-
+#if 0
 static Bool XUIsEncoding(const char* enc)
 {
   const char* p1 = 0;
@@ -407,7 +419,7 @@ static int XUGetISO8859()
   if(iso < 1 || iso > 15) return XU_CONV_NONE;
   return XU_CONV_ISO8859(iso);
 }
-
+#endif
 
 static void XUInitSetting()
 {
@@ -752,7 +764,6 @@ int XUQueryChar(XUChar* c, Display* display, XUInfoFont* fi)
   } else {
     charset = XU_FONT_UNICODE;
   }
-  
   for(i = 0; i < fi->count; i++) {
     if(charset != XU_FONT_UNICODE) break;
     switch(fi->order[i]) {
@@ -825,6 +836,7 @@ int XUQueryChar(XUChar* c, Display* display, XUInfoFont* fi)
 
 void XUTextExtents(Display* display, XFontStruct* font_struct, const XUChar* string, int nchars, int* direction_return, int* font_ascent_return, int* font_descent_return, XCharStruct* overall_return)
 {
+
   char* fn = 0;
   XUInfoFont* fi = 0;
   XFontStruct* f = 0;
@@ -1183,7 +1195,6 @@ XFontStruct* XULoadSearchFont(Display* display, const char* font, int charset)
   if(!XUSearchFont(buf, 256, display, font, charset)) {
     return NULL;
   }
-  
   f->font[charset] = XLoadQueryFont(display, buf);
   return f->font[charset];
 }
